
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 2013
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('iadd_sat', 'a', 0) => a
 *    ('isub_sat', 'a', 0) => a
 *    ('uadd_sat', 'a', 0) => a
 *    ('usub_sat', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a')
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0)
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0)
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b'))
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2))
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3))
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4))
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5))
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0)
 *    ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z')))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h'))))
 *    ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p')))))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z')))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h'))))
 *    ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p')))))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z')))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h'))))
 *    ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p')))))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z')))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h'))))
 *    ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p')))))
 *    ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', 0) => 0
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', ('inot', 'a')) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', -1) => -1
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('ixor', 'a', ('ixor', 'a', 'b')) => b
 *    ('ixor', 'a', -1) => ('inot', 'a')
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', -1, 'a') => -1
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b')))
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b')))
 *    ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('fround_even', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y
 *    ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0
 *    ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31)
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a')
 *    ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a')
 *    ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a')
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0))
 *    ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False
 *    ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False
 *    ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width')
 *    ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width')
 *    ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('iadd_sat', 'a', 0) => a */
   /* search39_0 -> 32 in the cache */
   /* search39_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace39 -> 32 in the cache */

   /* ('isub_sat', 'a', 0) => a */
   /* search40_0 -> 32 in the cache */
   /* search40_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace40 -> 32 in the cache */

   /* ('uadd_sat', 'a', 0) => a */
   /* search41_0 -> 32 in the cache */
   /* search41_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace41 -> 32 in the cache */

   /* ('usub_sat', 'a', 0) => a */
   /* search42_0 -> 32 in the cache */
   /* search42_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace42 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search43_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace43 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search44_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 126 },
      -1,
   } },

   /* replace44 -> 126 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search45_1_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 130, 132 },
      -1,
   } },

   /* replace45_0 -> 128 in the cache */
   /* replace45_1_0 -> 129 in the cache */
   /* replace45_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 128, 134 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search46_0_0 -> 16 in the cache */
   /* search46_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search46_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 136, 138 },
      -1,
   } },

   /* replace46_0 -> 16 in the cache */
   /* replace46_1_0 -> 36 in the cache */
   /* replace46_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 140 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search47_0 -> 0 in the cache */
   /* search47_1 -> 3 in the cache */
   /* search47_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 142, 143 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 144 },
      -1,
   } },

   /* replace47_0 -> 0 in the cache */
   /* replace47_1_0 -> 3 in the cache */
   /* replace47_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 142 },
      -1,
   } },
   /* replace47_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 146, 143 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search48_0 -> 0 in the cache */
   /* search48_1 -> 3 in the cache */
   /* search48_2_0 -> 0 in the cache */
   /* search48_2_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 142 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 148 },
      -1,
   } },

   /* replace48_0 -> 0 in the cache */
   /* replace48_1_0 -> 3 in the cache */
   /* replace48_1_1 -> 142 in the cache */
   /* replace48_1 -> 146 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 146 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 152 },
      0,
   } },
   /* search49_1_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 151, 154, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 153, 156 },
      -1,
   } },

   /* replace49_0 -> 151 in the cache */
   /* replace49_1_0 -> 152 in the cache */
   /* replace49_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 152, 154 },
      -1,
   } },
   /* replace49_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 151, 158, 155 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search50_0 -> 151 in the cache */
   /* search50_1_0 -> 152 in the cache */
   /* search50_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 154 },
      0,
   } },
   /* search50_2_0 -> 152 in the cache */
   /* search50_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 151, 160, 161 },
      -1,
   } },

   /* replace50_0 -> 152 in the cache */
   /* replace50_1_0 -> 151 in the cache */
   /* replace50_1_1 -> 154 in the cache */
   /* replace50_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 151, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 152, 163 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search51_0 -> 16 in the cache */
   /* search51_1 -> 36 in the cache */
   /* search51_2_0 -> 16 in the cache */
   /* search51_2_1 -> 137 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 137, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 166 },
      -1,
   } },

   /* replace51_0 -> 16 in the cache */
   /* replace51_1_0 -> 36 in the cache */
   /* replace51_1_1 -> 137 in the cache */
   /* replace51_1 -> 140 in the cache */
   /* replace51_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 140, 165 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search52_0 -> 16 in the cache */
   /* search52_1 -> 36 in the cache */
   /* search52_2_0 -> 16 in the cache */
   /* search52_2_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 137 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 169 },
      -1,
   } },

   /* replace52_0 -> 16 in the cache */
   /* replace52_1_0 -> 36 in the cache */
   /* replace52_1_1 -> 137 in the cache */
   /* replace52_1 -> 140 in the cache */
   /* replace52 -> 141 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search53_0_0 -> 16 in the cache */
   /* search53_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search53_1_0 -> 16 in the cache */
   /* search53_1_1 -> 137 in the cache */
   /* search53_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 137, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 171, 172 },
      -1,
   } },

   /* replace53_0 -> 16 in the cache */
   /* replace53_1_0 -> 36 in the cache */
   /* replace53_1_1 -> 137 in the cache */
   /* replace53_1 -> 140 in the cache */
   /* replace53_2 -> 165 in the cache */
   /* replace53 -> 168 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search54_0 -> 16 in the cache */
   /* search54_1_0 -> 36 in the cache */
   /* search54_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 137 },
      0,
   } },
   /* search54_2_0 -> 36 in the cache */
   /* search54_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 174, 175 },
      -1,
   } },

   /* replace54_0 -> 36 in the cache */
   /* replace54_1_0 -> 16 in the cache */
   /* replace54_1_1 -> 137 in the cache */
   /* replace54_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 177 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search55_0_0 -> 128 in the cache */
   /* search55_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search55_1_0 -> 128 in the cache */
   /* search55_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 179, 180 },
      -1,
   } },

   /* replace55_0 -> 128 in the cache */
   /* replace55_1_0 -> 129 in the cache */
   /* replace55_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 128, 182 },
      -1,
   } },

   /* ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 184, 185 },
      -1,
   } },
   /* search56_1_0 -> 131 in the cache */
   /* search56_1_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 186, 187 },
      -1,
   } },

   /* replace56_0_0 -> 184 in the cache */
   /* replace56_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 184, 131 },
      -1,
   } },
   /* replace56_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 189, 185 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search57_0_0 -> 128 in the cache */
   /* search57_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search57_1_0 -> 128 in the cache */
   /* search57_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 191, 192 },
      -1,
   } },

   /* replace57_0 -> 128 in the cache */
   /* replace57_1_0 -> 129 in the cache */
   /* replace57_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 128, 194 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search58_0_0 -> 128 in the cache */
   /* search58_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search58_1_0 -> 128 in the cache */
   /* search58_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 196, 197 },
      -1,
   } },

   /* replace58_0 -> 128 in the cache */
   /* replace58_1_0 -> 129 in the cache */
   /* replace58_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 128, 199 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0) */
   /* search59_0_0 -> 0 in the cache */
   /* search59_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search59_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace59_0_0 -> 0 in the cache */
   /* replace59_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace59_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 203, 86 },
      -1,
   } },

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0) */
   /* search60_0_0 -> 0 in the cache */
   /* search60_0_1 -> 1 in the cache */
   /* search60_0 -> 201 in the cache */
   /* search60_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace60_0_0 -> 0 in the cache */
   /* replace60_0_1 -> 3 in the cache */
   /* replace60_0 -> 203 in the cache */
   /* replace60_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 203, 86 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search61_0_0 -> 32 in the cache */
   /* search61_0 -> 98 in the cache */
   /* search61_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace61 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search62_0_0 -> 32 in the cache */
   /* search62_0 -> 100 in the cache */
   /* search62_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace62 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search63_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search63_1_0 -> 0 in the cache */
   /* search63_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 209, 210 },
      -1,
   } },

   /* replace63 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search64_0 -> 0 in the cache */
   /* search64_1_0_0 -> 0 in the cache */
   /* search64_1_0 -> 209 in the cache */
   /* search64_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 209, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 212 },
      -1,
   } },

   /* replace64 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search65_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search65_1_0 -> 0 in the cache */
   /* search65_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 214, 215 },
      -1,
   } },

   /* replace65 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search66_0 -> 0 in the cache */
   /* search66_1_0_0 -> 0 in the cache */
   /* search66_1_0 -> 214 in the cache */
   /* search66_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 214, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 217 },
      -1,
   } },

   /* replace66 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search67_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search67_1_0_0 -> 32 in the cache */
   /* search67_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 219, 220 },
      -1,
   } },

   /* replace67_0_0 -> 32 in the cache */
   /* replace67_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search68_0 -> 32 in the cache */
   /* search68_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace68 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search69_0 -> 11 in the cache */
   /* search69_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace69 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace70 -> 117 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search71_0 -> 16 in the cache */
   /* search71_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace71 -> 117 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search72_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 227 },
      -1,
   } },

   /* replace72_0 -> 16 in the cache */
   /* replace72_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 230, 231 },
      -1,
   } },

   /* replace73_0 -> 16 in the cache */
   /* replace73_1 -> 36 in the cache */
   /* replace73 -> 229 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search74_0 -> 16 in the cache */
   /* search74_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace74_0 -> 16 in the cache */
   /* replace74_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search75_0 -> 16 in the cache */
   /* search75_1 -> 227 in the cache */
   /* search75_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 227, 137 },
      -1,
   } },

   /* replace75_0 -> 16 in the cache */
   /* replace75_1 -> 36 in the cache */
   /* replace75_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search76_0 -> 230 in the cache */
   /* search76_1 -> 231 in the cache */
   /* search76_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 230, 231, 137 },
      -1,
   } },

   /* replace76_0 -> 16 in the cache */
   /* replace76_1 -> 36 in the cache */
   /* replace76_2 -> 137 in the cache */
   /* replace76 -> 236 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search77_0 -> 16 in the cache */
   /* search77_1 -> 16 in the cache */
   /* search77_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace77_0 -> 16 in the cache */
   /* replace77_1 -> 16 in the cache */
   /* replace77_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search78_0 -> 32 in the cache */
   /* search78_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace78 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search79_0 -> 16 in the cache */
   /* search79_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace79 -> 124 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search80_0 -> 16 in the cache */
   /* search80_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 126 },
      -1,
   } },

   /* replace80 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search81_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 243 },
      -1,
   } },

   /* replace81 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search82_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 245 },
      -1,
   } },

   /* replace82 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search83_0 -> 32 in the cache */
   /* search83_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 243 },
      1,
   } },

   /* replace83 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search84_0 -> 32 in the cache */
   /* search84_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace84 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search85_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 249 },
      -1,
   } },

   /* replace85_0 -> 32 in the cache */
   /* replace85 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search86_0 -> 32 in the cache */
   /* search86_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace86_0 -> 32 in the cache */
   /* replace86 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search87_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search87_1_0 -> 32 in the cache */
   /* search87_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 252, 253 },
      -1,
   } },

   /* replace87_0_0 -> 32 in the cache */
   /* replace87_0 -> 103 in the cache */
   /* replace87_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search88_0_0_0 -> 32 in the cache */
   /* search88_0_0 -> 252 in the cache */
   /* search88_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 252, 32 },
      -1,
   } },
   /* search88_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 256, 32 },
      -1,
   } },

   /* replace88_0_0 -> 32 in the cache */
   /* replace88_0 -> 103 in the cache */
   /* replace88_1 -> 32 in the cache */
   /* replace88 -> 255 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search89_1 -> 0 in the cache */
   /* search89_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 258, 0, 3 },
      -1,
   } },

   /* replace89 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search90_0 -> 115 in the cache */
   /* search90_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 260 },
      1,
   } },

   /* replace90 -> 260 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search91_0 -> 117 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace91 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search92_0 -> 117 in the cache */
   /* search92_1 -> 16 in the cache */
   /* search92_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 117, 16, 36 },
      -1,
   } },

   /* replace92_0 -> 117 in the cache */
   /* replace92_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 117, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search93_0 -> 0 in the cache */
   /* search93_1 -> 3 in the cache */
   /* search93_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 258 },
      -1,
   } },

   /* replace93_0 -> 0 in the cache */
   /* replace93_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search94_0 -> 11 in the cache */
   /* search94_1 -> 260 in the cache */
   /* search94_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 115 },
      -1,
   } },

   /* replace94_0 -> 11 in the cache */
   /* replace94_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search95_0 -> 16 in the cache */
   /* search95_1 -> 36 in the cache */
   /* search95_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace95_0 -> 16 in the cache */
   /* replace95_1 -> 36 in the cache */
   /* replace95 -> 229 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search96_0 -> 16 in the cache */
   /* search96_1 -> 36 in the cache */
   /* search96_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace96_0 -> 16 in the cache */
   /* replace96_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search97_1 -> 0 in the cache */
   /* search97_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 272, 0, 3 },
      -1,
   } },

   /* replace97_0 -> 0 in the cache */
   /* replace97_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search98_0 -> 245 in the cache */
   /* search98_1 -> 16 in the cache */
   /* search98_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 245, 16, 36 },
      -1,
   } },

   /* replace98_0 -> 16 in the cache */
   /* replace98_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search99_1 -> 0 in the cache */
   /* search99_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 277, 0, 3 },
      -1,
   } },

   /* replace99_0_0 -> 0 in the cache */
   /* replace99_0 -> 214 in the cache */
   /* replace99_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 214, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search100_1 -> 16 in the cache */
   /* search100_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 280, 16, 36 },
      -1,
   } },

   /* replace100_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace100_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 282, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search101_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 284, 285, 131 },
      -1,
   } },

   /* replace101_0_0 -> 128 in the cache */
   /* replace101_0_1 -> 129 in the cache */
   /* replace101_0 -> 130 in the cache */
   /* replace101_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 130, 131 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search102_1 -> 33 in the cache */
   /* search102_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 288, 33, 137 },
      -1,
   } },

   /* replace102_0_0 -> 16 in the cache */
   /* replace102_0_1 -> 36 in the cache */
   /* replace102_0 -> 136 in the cache */
   /* replace102_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 136, 137 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search103_0 -> 0 in the cache */
   /* search103_1 -> 3 in the cache */
   /* search103_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 258 },
      -1,
   } },

   /* replace103 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search104_0 -> 0 in the cache */
   /* search104_1 -> 3 in the cache */
   /* search104_2 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 272 },
      -1,
   } },

   /* replace104 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search105_0 -> 0 in the cache */
   /* search105_1 -> 0 in the cache */
   /* search105_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace105 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search106_0 -> 258 in the cache */
   /* search106_1 -> 0 in the cache */
   /* search106_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 258, 0, 3 },
      -1,
   } },

   /* replace106_0 -> 0 in the cache */
   /* replace106_1 -> 3 in the cache */
   /* replace106 -> 266 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search107_0 -> 128 in the cache */
   /* search107_1_0 -> 128 in the cache */
   /* search107_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 128, 129 },
      0,
   } },
   /* search107_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 128, 295, 131 },
      -1,
   } },

   /* replace107_0_0 -> 129 in the cache */
   /* replace107_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 129, 131 },
      -1,
   } },
   /* replace107_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 297, 128 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 124 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 124 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search110_0 -> 16 in the cache */
   /* search110_1 -> 124 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 124 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search112_0 -> 16 in the cache */
   /* search112_1 -> 124 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search113_0 -> 16 in the cache */
   /* search113_1 -> 124 in the cache */
   /* search113_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace113 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search114_0 -> 16 in the cache */
   /* search114_1 -> 124 in the cache */
   /* search114_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace114 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search115_0 -> 16 in the cache */
   /* search115_1 -> 124 in the cache */
   /* search115_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace115 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search116_0 -> 16 in the cache */
   /* search116_1 -> 124 in the cache */
   /* search116_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 124, 36 },
      -1,
   } },

   /* replace116 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search117_0 -> 124 in the cache */
   /* search117_1 -> 16 in the cache */
   /* search117_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 124, 16, 36 },
      -1,
   } },

   /* replace117 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search118_0 -> 16 in the cache */
   /* search118_1 -> 124 in the cache */
   /* search118_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 124, 36 },
      -1,
   } },

   /* replace118 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search119_0 -> 124 in the cache */
   /* search119_1 -> 16 in the cache */
   /* search119_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 124, 16, 36 },
      -1,
   } },

   /* replace119 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search120_0_0 -> 16 in the cache */
   /* search120_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 312, 313 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2_0 -> 137 in the cache */
   /* replace120_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search121_0_0 -> 16 in the cache */
   /* search121_0_1 -> 36 in the cache */
   /* search121_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search121_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 317, 313 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2_0 -> 137 in the cache */
   /* replace121_2_1 -> 165 in the cache */
   /* replace121_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search122_0_0 -> 16 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 311 },
      0,
   } },
   /* search122_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 320, 313 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2_0 -> 137 in the cache */
   /* replace122_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 322 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search123_0_0 -> 16 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search123_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 324, 313 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2_0 -> 137 in the cache */
   /* replace123_2_1 -> 165 in the cache */
   /* replace123_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search124_0_0 -> 16 in the cache */
   /* search124_0_1 -> 36 in the cache */
   /* search124_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search124_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 327, 313 },
      -1,
   } },

   /* replace124_0 -> 16 in the cache */
   /* replace124_1 -> 36 in the cache */
   /* replace124_2_0 -> 137 in the cache */
   /* replace124_2_1 -> 165 in the cache */
   /* replace124_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search125_0_1 -> 36 in the cache */
   /* search125_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search125_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 331, 137 },
      -1,
   } },

   /* replace125_0 -> 16 in the cache */
   /* replace125_1 -> 36 in the cache */
   /* replace125_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search126_0_0 -> 330 in the cache */
   /* search126_0_1 -> 36 in the cache */
   /* search126_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search126_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 334, 137 },
      -1,
   } },

   /* replace126_0 -> 16 in the cache */
   /* replace126_1 -> 36 in the cache */
   /* replace126_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search127_0_0 -> 330 in the cache */
   /* search127_0_1 -> 36 in the cache */
   /* search127_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 330, 36, 124 },
      -1,
   } },
   /* search127_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 337, 137 },
      -1,
   } },

   /* replace127_0 -> 16 in the cache */
   /* replace127_1 -> 36 in the cache */
   /* replace127_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search128_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search128_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 340, 124 },
      -1,
   } },
   /* search128_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 341, 137 },
      -1,
   } },

   /* replace128_0 -> 16 in the cache */
   /* replace128_1 -> 36 in the cache */
   /* replace128_2 -> 137 in the cache */
   /* replace128 -> 339 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search129_0_0 -> 330 in the cache */
   /* search129_0_1 -> 36 in the cache */
   /* search129_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search129_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 343, 137 },
      -1,
   } },

   /* replace129_0 -> 16 in the cache */
   /* replace129_1 -> 36 in the cache */
   /* replace129_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search130_0_0 -> 330 in the cache */
   /* search130_0_1 -> 36 in the cache */
   /* search130_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search130_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 346, 137 },
      -1,
   } },

   /* replace130_0 -> 16 in the cache */
   /* replace130_1 -> 36 in the cache */
   /* replace130_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 288 in the cache */
   /* search131_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace131_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 351, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 288 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace132_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 354, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 288 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 288, 33, 349 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },
   /* replace133_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 357, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search134_0 -> 288 in the cache */
   /* search134_1 -> 33 in the cache */
   /* search134_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace134_0_0 -> 16 in the cache */
   /* replace134_0_1 -> 36 in the cache */
   /* replace134_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace134_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 360, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search135_0 -> 288 in the cache */
   /* search135_1 -> 33 in the cache */
   /* search135_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace135_0_0 -> 16 in the cache */
   /* replace135_0_1 -> 36 in the cache */
   /* replace135_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace135_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 363, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search136_0 -> 288 in the cache */
   /* search136_1 -> 33 in the cache */
   /* search136_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace136_0_0 -> 16 in the cache */
   /* replace136_0_1 -> 36 in the cache */
   /* replace136_0_2 -> 124 in the cache */
   /* replace136_0 -> 351 in the cache */
   /* replace136_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 351, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search137_0 -> 288 in the cache */
   /* search137_1 -> 33 in the cache */
   /* search137_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace137_0_0 -> 16 in the cache */
   /* replace137_0_1 -> 36 in the cache */
   /* replace137_0_2 -> 124 in the cache */
   /* replace137_0 -> 354 in the cache */
   /* replace137_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 354, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search138_0 -> 288 in the cache */
   /* search138_1 -> 33 in the cache */
   /* search138_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 288, 33, 349 },
      -1,
   } },

   /* replace138_0_0 -> 16 in the cache */
   /* replace138_0_1 -> 36 in the cache */
   /* replace138_0_2 -> 124 in the cache */
   /* replace138_0 -> 357 in the cache */
   /* replace138_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 357, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search139_0 -> 288 in the cache */
   /* search139_1 -> 33 in the cache */
   /* search139_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace139_0_0 -> 16 in the cache */
   /* replace139_0_1 -> 36 in the cache */
   /* replace139_0_2 -> 124 in the cache */
   /* replace139_0 -> 360 in the cache */
   /* replace139_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 360, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search140_0 -> 288 in the cache */
   /* search140_1 -> 33 in the cache */
   /* search140_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace140_0_0 -> 16 in the cache */
   /* replace140_0_1 -> 36 in the cache */
   /* replace140_0_2 -> 124 in the cache */
   /* replace140_0 -> 363 in the cache */
   /* replace140_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 363, 137 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search141_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 375, 117 },
      -1,
   } },
   /* search141_0_1 -> 117 in the cache */
   /* search141_0_2 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 376, 117, 185 },
      -1,
   } },
   /* search141_1_0_0 -> 185 in the cache */
   /* search141_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 185, 117 },
      -1,
   } },
   /* search141_1_1 -> 117 in the cache */
   /* search141_1_2 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 378, 117, 375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 377, 379 },
      -1,
   } },

   /* replace141_0 -> 185 in the cache */
   /* replace141_1 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 185, 375 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search142_0 -> 16 in the cache */
   /* search142_1_0_0 -> 16 in the cache */
   /* search142_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 117 },
      -1,
   } },
   /* search142_1_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 382, 117, 383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 384 },
      -1,
   } },

   /* replace142_0 -> 16 in the cache */
   /* replace142_1 -> 36 in the cache */
   /* replace142 -> 271 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search143_0_0_0 -> 375 in the cache */
   /* search143_0_0_1 -> 117 in the cache */
   /* search143_0_0 -> 376 in the cache */
   /* search143_0_1 -> 117 in the cache */
   /* search143_0_2 -> 185 in the cache */
   /* search143_0 -> 377 in the cache */
   /* search143_1_0_0 -> 185 in the cache */
   /* search143_1_0_1 -> 117 in the cache */
   /* search143_1_0 -> 378 in the cache */
   /* search143_1_1 -> 117 in the cache */
   /* search143_1_2 -> 375 in the cache */
   /* search143_1 -> 379 in the cache */
   /* search143_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 377, 379, 137 },
      -1,
   } },

   /* replace143_0 -> 185 in the cache */
   /* replace143_1 -> 375 in the cache */
   /* replace143_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 185, 375, 137 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search144_0 -> 16 in the cache */
   /* search144_1_0_0 -> 16 in the cache */
   /* search144_1_0_1 -> 117 in the cache */
   /* search144_1_0 -> 382 in the cache */
   /* search144_1_1 -> 117 in the cache */
   /* search144_1_2 -> 383 in the cache */
   /* search144_1 -> 384 in the cache */
   /* search144_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 384, 137 },
      -1,
   } },

   /* replace144_0 -> 16 in the cache */
   /* replace144_1 -> 36 in the cache */
   /* replace144_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b')) */
   /* search145_0_0 -> 375 in the cache */
   /* search145_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      0, 1,
      { 375, 117 },
      -1,
   } },
   /* search145_1 -> 245 in the cache */
   /* search145_2_0_0 -> 185 in the cache */
   /* search145_2_0_1 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 185, 375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 391 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 390, 245, 392 },
      -1,
   } },

   /* replace145_0_0 -> 185 in the cache */
   /* replace145_0_1 -> 375 in the cache */
   /* replace145_0 -> 381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 381 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 137 in the cache */
   /* search146 -> 333 in the cache */

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 395, 396 },
      -1,
   } },
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 399, 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 397, 401 },
      -1,
   } },
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 404, 405 },
      -1,
   } },
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 407 },
      -1,
   } },
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 408, 409 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 406, 410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 402, 411 },
      -1,
   } },
   /* replace146_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 412, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 137 in the cache */
   /* search147 -> 336 in the cache */

   /* replace147_0_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace147_0_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 414, 415 },
      -1,
   } },
   /* replace147_0_0_1_0_0 -> 16 in the cache */
   /* replace147_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace147_0_0_1_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 417, 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 416, 419 },
      -1,
   } },
   /* replace147_0_1_0_0_0 -> 16 in the cache */
   /* replace147_0_1_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* replace147_0_1_0_1_0 -> 36 in the cache */
   /* replace147_0_1_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 421, 422 },
      -1,
   } },
   /* replace147_0_1_1_0_0 -> 16 in the cache */
   /* replace147_0_1_1_0_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 407 },
      -1,
   } },
   /* replace147_0_1_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 424, 425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 423, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 420, 427 },
      -1,
   } },
   /* replace147_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 428, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 137 in the cache */
   /* search148 -> 339 in the cache */

   /* replace148_0_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_0_1 -> 124 in the cache */
   /* replace148_0_0_0_0 -> 395 in the cache */
   /* replace148_0_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_0_1_1 -> 124 in the cache */
   /* replace148_0_0_0_1 -> 415 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 395, 415 },
      -1,
   } },
   /* replace148_0_0_1_0_0 -> 16 in the cache */
   /* replace148_0_0_1_0_1 -> 398 in the cache */
   /* replace148_0_0_1_0 -> 399 in the cache */
   /* replace148_0_0_1_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1_1 -> 398 in the cache */
   /* replace148_0_0_1_1 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 399, 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 430, 431 },
      -1,
   } },
   /* replace148_0_1_0_0_0 -> 16 in the cache */
   /* replace148_0_1_0_0_1 -> 403 in the cache */
   /* replace148_0_1_0_0 -> 404 in the cache */
   /* replace148_0_1_0_1_0 -> 36 in the cache */
   /* replace148_0_1_0_1_1 -> 403 in the cache */
   /* replace148_0_1_0_1 -> 422 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 404, 422 },
      -1,
   } },
   /* replace148_0_1_1_0_0 -> 16 in the cache */
   /* replace148_0_1_1_0_1 -> 407 in the cache */
   /* replace148_0_1_1_0 -> 408 in the cache */
   /* replace148_0_1_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1_1 -> 407 in the cache */
   /* replace148_0_1_1_1 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 408, 425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 433, 434 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 432, 435 },
      -1,
   } },
   /* replace148_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 436, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search149_0 -> 16 in the cache */
   /* search149_1 -> 36 in the cache */
   /* search149_2 -> 137 in the cache */
   /* search149 -> 345 in the cache */

   /* replace149_0_0_0_0 -> 16 in the cache */
   /* replace149_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace149_0_0_1_0 -> 36 in the cache */
   /* replace149_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 438, 439 },
      -1,
   } },
   /* replace149_0_1_0_0 -> 16 in the cache */
   /* replace149_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace149_0_1_1_0 -> 36 in the cache */
   /* replace149_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 441, 442 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 440, 443 },
      -1,
   } },
   /* replace149_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 444, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search150_0 -> 16 in the cache */
   /* search150_1 -> 36 in the cache */
   /* search150_2 -> 137 in the cache */
   /* search150 -> 348 in the cache */

   /* replace150_0_0_0_0 -> 16 in the cache */
   /* replace150_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace150_0_0_1_0 -> 36 in the cache */
   /* replace150_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 446, 447 },
      -1,
   } },
   /* replace150_0_1_0_0 -> 16 in the cache */
   /* replace150_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace150_0_1_1_0 -> 36 in the cache */
   /* replace150_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 449, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 448, 451 },
      -1,
   } },
   /* replace150_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 452, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search151_0 -> 16 in the cache */
   /* search151_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 454 },
      -1,
   } },

   /* replace151_0 -> 16 in the cache */
   /* replace151_1 -> 36 in the cache */
   /* replace151_2 -> 137 in the cache */
   /* replace151 -> 336 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search152_0 -> 16 in the cache */
   /* search152_1 -> 36 in the cache */
   /* search152_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace152_0_0_0_0_0 -> 16 in the cache */
   /* replace152_0_0_0_0_1 -> 124 in the cache */
   /* replace152_0_0_0_0 -> 414 in the cache */
   /* replace152_0_0_0_1_0 -> 36 in the cache */
   /* replace152_0_0_0_1_1 -> 124 in the cache */
   /* replace152_0_0_0_1 -> 415 in the cache */
   /* replace152_0_0_0 -> 416 in the cache */
   /* replace152_0_0_1_0_0 -> 16 in the cache */
   /* replace152_0_0_1_0_1 -> 398 in the cache */
   /* replace152_0_0_1_0 -> 417 in the cache */
   /* replace152_0_0_1_1_0 -> 36 in the cache */
   /* replace152_0_0_1_1_1 -> 398 in the cache */
   /* replace152_0_0_1_1 -> 418 in the cache */
   /* replace152_0_0_1 -> 419 in the cache */
   /* replace152_0_0 -> 420 in the cache */
   /* replace152_0_1_0_0_0 -> 16 in the cache */
   /* replace152_0_1_0_0_1 -> 403 in the cache */
   /* replace152_0_1_0_0 -> 421 in the cache */
   /* replace152_0_1_0_1_0 -> 36 in the cache */
   /* replace152_0_1_0_1_1 -> 403 in the cache */
   /* replace152_0_1_0_1 -> 422 in the cache */
   /* replace152_0_1_0 -> 423 in the cache */
   /* replace152_0_1_1_0_0 -> 16 in the cache */
   /* replace152_0_1_1_0_1 -> 407 in the cache */
   /* replace152_0_1_1_0 -> 424 in the cache */
   /* replace152_0_1_1_1_0 -> 36 in the cache */
   /* replace152_0_1_1_1_1 -> 407 in the cache */
   /* replace152_0_1_1_1 -> 425 in the cache */
   /* replace152_0_1_1 -> 426 in the cache */
   /* replace152_0_1 -> 427 in the cache */
   /* replace152_0 -> 428 in the cache */
   /* replace152_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 428, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search153_0 -> 16 in the cache */
   /* search153_1 -> 36 in the cache */
   /* search153_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace153_0_0_0_0_0 -> 16 in the cache */
   /* replace153_0_0_0_0_1 -> 124 in the cache */
   /* replace153_0_0_0_0 -> 395 in the cache */
   /* replace153_0_0_0_1_0 -> 36 in the cache */
   /* replace153_0_0_0_1_1 -> 124 in the cache */
   /* replace153_0_0_0_1 -> 396 in the cache */
   /* replace153_0_0_0 -> 397 in the cache */
   /* replace153_0_0_1_0_0 -> 16 in the cache */
   /* replace153_0_0_1_0_1 -> 398 in the cache */
   /* replace153_0_0_1_0 -> 399 in the cache */
   /* replace153_0_0_1_1_0 -> 36 in the cache */
   /* replace153_0_0_1_1_1 -> 398 in the cache */
   /* replace153_0_0_1_1 -> 400 in the cache */
   /* replace153_0_0_1 -> 401 in the cache */
   /* replace153_0_0 -> 402 in the cache */
   /* replace153_0_1_0_0_0 -> 16 in the cache */
   /* replace153_0_1_0_0_1 -> 403 in the cache */
   /* replace153_0_1_0_0 -> 404 in the cache */
   /* replace153_0_1_0_1_0 -> 36 in the cache */
   /* replace153_0_1_0_1_1 -> 403 in the cache */
   /* replace153_0_1_0_1 -> 405 in the cache */
   /* replace153_0_1_0 -> 406 in the cache */
   /* replace153_0_1_1_0_0 -> 16 in the cache */
   /* replace153_0_1_1_0_1 -> 407 in the cache */
   /* replace153_0_1_1_0 -> 408 in the cache */
   /* replace153_0_1_1_1_0 -> 36 in the cache */
   /* replace153_0_1_1_1_1 -> 407 in the cache */
   /* replace153_0_1_1_1 -> 409 in the cache */
   /* replace153_0_1_1 -> 410 in the cache */
   /* replace153_0_1 -> 411 in the cache */
   /* replace153_0 -> 412 in the cache */
   /* replace153_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 412, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search154_0 -> 16 in the cache */
   /* search154_1 -> 36 in the cache */
   /* search154_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },

   /* replace154_0_0_0_0_0 -> 16 in the cache */
   /* replace154_0_0_0_0_1 -> 124 in the cache */
   /* replace154_0_0_0_0 -> 395 in the cache */
   /* replace154_0_0_0_1_0 -> 36 in the cache */
   /* replace154_0_0_0_1_1 -> 124 in the cache */
   /* replace154_0_0_0_1 -> 415 in the cache */
   /* replace154_0_0_0 -> 430 in the cache */
   /* replace154_0_0_1_0_0 -> 16 in the cache */
   /* replace154_0_0_1_0_1 -> 398 in the cache */
   /* replace154_0_0_1_0 -> 399 in the cache */
   /* replace154_0_0_1_1_0 -> 36 in the cache */
   /* replace154_0_0_1_1_1 -> 398 in the cache */
   /* replace154_0_0_1_1 -> 418 in the cache */
   /* replace154_0_0_1 -> 431 in the cache */
   /* replace154_0_0 -> 432 in the cache */
   /* replace154_0_1_0_0_0 -> 16 in the cache */
   /* replace154_0_1_0_0_1 -> 403 in the cache */
   /* replace154_0_1_0_0 -> 404 in the cache */
   /* replace154_0_1_0_1_0 -> 36 in the cache */
   /* replace154_0_1_0_1_1 -> 403 in the cache */
   /* replace154_0_1_0_1 -> 422 in the cache */
   /* replace154_0_1_0 -> 433 in the cache */
   /* replace154_0_1_1_0_0 -> 16 in the cache */
   /* replace154_0_1_1_0_1 -> 407 in the cache */
   /* replace154_0_1_1_0 -> 408 in the cache */
   /* replace154_0_1_1_1_0 -> 36 in the cache */
   /* replace154_0_1_1_1_1 -> 407 in the cache */
   /* replace154_0_1_1_1 -> 425 in the cache */
   /* replace154_0_1_1 -> 434 in the cache */
   /* replace154_0_1 -> 435 in the cache */
   /* replace154_0 -> 436 in the cache */
   /* replace154_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 436, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search155_0 -> 16 in the cache */
   /* search155_1 -> 36 in the cache */
   /* search155_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace155_0_0_0_0 -> 16 in the cache */
   /* replace155_0_0_0_1 -> 124 in the cache */
   /* replace155_0_0_0 -> 446 in the cache */
   /* replace155_0_0_1_0 -> 36 in the cache */
   /* replace155_0_0_1_1 -> 124 in the cache */
   /* replace155_0_0_1 -> 447 in the cache */
   /* replace155_0_0 -> 448 in the cache */
   /* replace155_0_1_0_0 -> 16 in the cache */
   /* replace155_0_1_0_1 -> 398 in the cache */
   /* replace155_0_1_0 -> 449 in the cache */
   /* replace155_0_1_1_0 -> 36 in the cache */
   /* replace155_0_1_1_1 -> 398 in the cache */
   /* replace155_0_1_1 -> 450 in the cache */
   /* replace155_0_1 -> 451 in the cache */
   /* replace155_0 -> 452 in the cache */
   /* replace155_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 452, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search156_0 -> 16 in the cache */
   /* search156_1 -> 36 in the cache */
   /* search156_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace156_0_0_0_0 -> 16 in the cache */
   /* replace156_0_0_0_1 -> 124 in the cache */
   /* replace156_0_0_0 -> 438 in the cache */
   /* replace156_0_0_1_0 -> 36 in the cache */
   /* replace156_0_0_1_1 -> 124 in the cache */
   /* replace156_0_0_1 -> 439 in the cache */
   /* replace156_0_0 -> 440 in the cache */
   /* replace156_0_1_0_0 -> 16 in the cache */
   /* replace156_0_1_0_1 -> 398 in the cache */
   /* replace156_0_1_0 -> 441 in the cache */
   /* replace156_0_1_1_0 -> 36 in the cache */
   /* replace156_0_1_1_1 -> 398 in the cache */
   /* replace156_0_1_1 -> 442 in the cache */
   /* replace156_0_1 -> 443 in the cache */
   /* replace156_0 -> 444 in the cache */
   /* replace156_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 444, 137 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1 -> 260 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 260, 467 },
      -1,
   } },

   /* replace157_0 -> 466 in the cache */
   /* replace157_1 -> 260 in the cache */
   /* replace157_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 260, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search158_0 -> 11 in the cache */
   /* search158_1_0 -> 11 in the cache */
   /* search158_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 470, 471 },
      -1,
   } },

   /* replace158_0_0 -> 260 in the cache */
   /* replace158_0_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 260, 471 },
      -1,
   } },
   /* replace158_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 473, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search159_0_0 -> 11 in the cache */
   /* search159_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 260 },
      0,
   } },
   /* search159_1_0 -> 11 in the cache */
   /* search159_1_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 471 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 475, 476, 477 },
      -1,
   } },

   /* replace159_0_0 -> 260 in the cache */
   /* replace159_0_1 -> 471 in the cache */
   /* replace159_0_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 260, 471, 477 },
      -1,
   } },
   /* replace159_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 479, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search160_0 -> 11 in the cache */
   /* search160_1_0 -> 11 in the cache */
   /* search160_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 260 },
      0,
   } },
   /* search160_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 481, 471 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace160_0_1 -> 260 in the cache */
   /* replace160_0_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 483, 260, 471 },
      -1,
   } },
   /* replace160_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 484, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search161_0_0 -> 11 in the cache */
   /* search161_0_1_0 -> 483 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 488 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search161_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 489, 491 },
      -1,
   } },

   /* replace161_0 -> 11 in the cache */
   /* replace161_1 -> 490 in the cache */
   /* replace161_2 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 490, 486 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search162_0_0 -> 11 in the cache */
   /* search162_0_1_0_0 -> 483 in the cache */
   /* search162_0_1_0_1_0 -> 486 in the cache */
   /* search162_0_1_0_1 -> 487 in the cache */
   /* search162_0_1_0 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 494 },
      -1,
   } },
   /* search162_1_0 -> 490 in the cache */
   /* search162_1_1_0 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 495, 497 },
      -1,
   } },

   /* replace162_0 -> 11 in the cache */
   /* replace162_1 -> 490 in the cache */
   /* replace162_2_0 -> 486 in the cache */
   /* replace162_2 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 490, 496 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search163_0 -> 11 in the cache */
   /* search163_1_0 -> 486 in the cache */
   /* search163_1_1_0 -> 490 in the cache */
   /* search163_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 490, 500 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 486, 501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 502 },
      -1,
   } },

   /* replace163_0 -> 11 in the cache */
   /* replace163_1 -> 490 in the cache */
   /* replace163_2 -> 486 in the cache */
   /* replace163 -> 493 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search164_0_0 -> 11 in the cache */
   /* search164_0_1_0 -> 483 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 506 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 507 },
      -1,
   } },
   /* search164_1_0 -> 490 in the cache */
   /* search164_1_1_0 -> 504 in the cache */
   /* search164_1_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 508, 509 },
      -1,
   } },

   /* replace164_0 -> 504 in the cache */
   /* replace164_1 -> 490 in the cache */
   /* replace164_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 490, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search165_0 -> 11 in the cache */
   /* search165_1_0_0 -> 504 in the cache */
   /* search165_1_0 -> 505 in the cache */
   /* search165_1_1_0 -> 490 in the cache */
   /* search165_1_1_1_0 -> 11 in the cache */
   /* search165_1_1_1 -> 500 in the cache */
   /* search165_1_1 -> 501 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 505, 501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 512 },
      -1,
   } },

   /* replace165_0 -> 504 in the cache */
   /* replace165_1 -> 490 in the cache */
   /* replace165_2 -> 11 in the cache */
   /* replace165 -> 511 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search166_0 -> 11 in the cache */
   /* search166_1_0 -> 483 in the cache */
   /* search166_1_1_0_0 -> 504 in the cache */
   /* search166_1_1_0 -> 505 in the cache */
   /* search166_1_1 -> 506 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 483, 506 },
      -1,
   } },
   /* search166_2_0 -> 490 in the cache */
   /* search166_2_1_0 -> 504 in the cache */
   /* search166_2_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 490, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 514, 515 },
      -1,
   } },

   /* replace166_0 -> 504 in the cache */
   /* replace166_1 -> 490 in the cache */
   /* replace166_2 -> 11 in the cache */
   /* replace166 -> 511 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search167_1_0 -> 504 in the cache */
   /* search167_1 -> 505 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 518 },
      -1,
   } },
   /* search167_2_1_0 -> 504 in the cache */
   /* search167_2_1 -> 505 in the cache */
   /* search167_2_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 519, 505, 518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 517, 505, 520 },
      -1,
   } },

   /* replace167_0 -> 504 in the cache */
   /* replace167_1 -> 517 in the cache */
   /* replace167_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 517, 518 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search168_1_0 -> 260 in the cache */
   /* search168_1_1_0 -> 518 in the cache */
   /* search168_1_1 -> 519 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 260, 519 },
      -1,
   } },
   /* search168_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 524, 525, 518 },
      -1,
   } },

   /* replace168_0 -> 523 in the cache */
   /* replace168_1 -> 260 in the cache */
   /* replace168_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 260, 518 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search169_0_0 -> 523 in the cache */
   /* search169_0 -> 524 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 528 },
      -1,
   } },
   /* search169_1_1 -> 490 in the cache */
   /* search169_1_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 529, 490, 477 },
      -1,
   } },
   /* search169_2_0 -> 528 in the cache */
   /* search169_2_1 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 528, 490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 524, 530, 531 },
      -1,
   } },

   /* replace169_0 -> 523 in the cache */
   /* replace169_1 -> 477 in the cache */
   /* replace169_2_0 -> 528 in the cache */
   /* replace169_2_1 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 528, 490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 477, 533 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search170_0 -> 483 in the cache */
   /* search170_1_0_0_0 -> 483 in the cache */
   /* search170_1_0_0_1_0 -> 11 in the cache */
   /* search170_1_0_0_1 -> 500 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 500 },
      -1,
   } },
   /* search170_1_0_1_0 -> 483 in the cache */
   /* search170_1_0_1_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 483, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 535, 537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 483, 539 },
      -1,
   } },

   /* replace170_0 -> 260 in the cache */
   /* replace170_1 -> 483 in the cache */
   /* replace170_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 260, 483, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1 -> 36 in the cache */
   /* search171_2_0 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 542 },
      -1,
   } },

   /* replace171_0 -> 466 in the cache */
   /* replace171_1 -> 36 in the cache */
   /* replace171_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search172_0 -> 16 in the cache */
   /* search172_1_0 -> 16 in the cache */
   /* search172_1_1 -> 36 in the cache */
   /* search172_1 -> 276 in the cache */
   /* search172_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 276, 137 },
      -1,
   } },

   /* replace172_0_0 -> 36 in the cache */
   /* replace172_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 137 },
      -1,
   } },
   /* replace172_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 546, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search173_0_0 -> 16 in the cache */
   /* search173_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search173_1_0 -> 16 in the cache */
   /* search173_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 137 },
      0,
   } },
   /* search173_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 548, 549, 165 },
      -1,
   } },

   /* replace173_0_0 -> 36 in the cache */
   /* replace173_0_1 -> 137 in the cache */
   /* replace173_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 137, 165 },
      -1,
   } },
   /* replace173_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 551, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search174_0 -> 16 in the cache */
   /* search174_1_0 -> 16 in the cache */
   /* search174_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search174_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 553, 137 },
      -1,
   } },

   /* replace174_0_0 -> 245 in the cache */
   /* replace174_0_1 -> 36 in the cache */
   /* replace174_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 245, 36, 137 },
      -1,
   } },
   /* replace174_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 555, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search175_0_0 -> 16 in the cache */
   /* search175_0_1_0 -> 245 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 558 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 559 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search175_1_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 560, 562 },
      -1,
   } },

   /* replace175_0 -> 16 in the cache */
   /* replace175_1 -> 561 in the cache */
   /* replace175_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 561, 557 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search176_0_0 -> 16 in the cache */
   /* search176_0_1_0_0 -> 245 in the cache */
   /* search176_0_1_0_1_0 -> 557 in the cache */
   /* search176_0_1_0_1 -> 558 in the cache */
   /* search176_0_1_0 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 565 },
      -1,
   } },
   /* search176_1_0 -> 561 in the cache */
   /* search176_1_1_0 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 567 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 566, 568 },
      -1,
   } },

   /* replace176_0 -> 16 in the cache */
   /* replace176_1 -> 561 in the cache */
   /* replace176_2_0 -> 557 in the cache */
   /* replace176_2 -> 567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 561, 567 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search177_0 -> 16 in the cache */
   /* search177_1_0 -> 557 in the cache */
   /* search177_1_1_0 -> 561 in the cache */
   /* search177_1_1_1_0 -> 16 in the cache */
   /* search177_1_1_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 561, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 557, 571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 572 },
      -1,
   } },

   /* replace177_0 -> 16 in the cache */
   /* replace177_1 -> 561 in the cache */
   /* replace177_2 -> 557 in the cache */
   /* replace177 -> 564 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search178_0_0 -> 16 in the cache */
   /* search178_0_1_0 -> 245 in the cache */
   /* search178_0_1_1_0_0 -> 504 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 575 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 576 },
      -1,
   } },
   /* search178_1_0 -> 561 in the cache */
   /* search178_1_1_0 -> 504 in the cache */
   /* search178_1_1 -> 574 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 577, 578 },
      -1,
   } },

   /* replace178_0 -> 504 in the cache */
   /* replace178_1 -> 561 in the cache */
   /* replace178_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 561, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search179_0 -> 16 in the cache */
   /* search179_1_0_0 -> 504 in the cache */
   /* search179_1_0 -> 574 in the cache */
   /* search179_1_1_0 -> 561 in the cache */
   /* search179_1_1_1_0 -> 16 in the cache */
   /* search179_1_1_1 -> 282 in the cache */
   /* search179_1_1 -> 571 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 574, 571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 581 },
      -1,
   } },

   /* replace179_0 -> 504 in the cache */
   /* replace179_1 -> 561 in the cache */
   /* replace179_2 -> 16 in the cache */
   /* replace179 -> 580 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search180_0 -> 16 in the cache */
   /* search180_1_0 -> 245 in the cache */
   /* search180_1_1_0_0 -> 504 in the cache */
   /* search180_1_1_0 -> 574 in the cache */
   /* search180_1_1 -> 575 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 245, 575 },
      -1,
   } },
   /* search180_2_0 -> 561 in the cache */
   /* search180_2_1_0 -> 504 in the cache */
   /* search180_2_1 -> 574 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 561, 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 583, 584 },
      -1,
   } },

   /* replace180_0 -> 504 in the cache */
   /* replace180_1 -> 561 in the cache */
   /* replace180_2 -> 16 in the cache */
   /* replace180 -> 580 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search181_0 -> 375 in the cache */
   /* search181_1_0 -> 504 in the cache */
   /* search181_1 -> 574 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 586 },
      -1,
   } },
   /* search181_2_1_0 -> 504 in the cache */
   /* search181_2_1 -> 574 in the cache */
   /* search181_2_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 587, 574, 586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 375, 574, 588 },
      -1,
   } },

   /* replace181_0 -> 504 in the cache */
   /* replace181_1 -> 375 in the cache */
   /* replace181_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 375, 586 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search182_0_0 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search182_1_0 -> 36 in the cache */
   /* search182_1_1_0 -> 586 in the cache */
   /* search182_1_1 -> 587 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 587 },
      -1,
   } },
   /* search182_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 591, 592, 586 },
      -1,
   } },

   /* replace182_0 -> 523 in the cache */
   /* replace182_1 -> 36 in the cache */
   /* replace182_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 36, 586 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search183_0_0 -> 523 in the cache */
   /* search183_0 -> 591 in the cache */
   /* search183_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 185 },
      -1,
   } },
   /* search183_1_1 -> 561 in the cache */
   /* search183_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 595, 561, 165 },
      -1,
   } },
   /* search183_2_0 -> 185 in the cache */
   /* search183_2_1 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 185, 561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 591, 596, 597 },
      -1,
   } },

   /* replace183_0 -> 523 in the cache */
   /* replace183_1 -> 165 in the cache */
   /* replace183_2_0 -> 185 in the cache */
   /* replace183_2_1 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 185, 561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 165, 599 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search184_0 -> 245 in the cache */
   /* search184_1_0_0_0 -> 245 in the cache */
   /* search184_1_0_0_1_0 -> 16 in the cache */
   /* search184_1_0_0_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 282 },
      -1,
   } },
   /* search184_1_0_1_0 -> 245 in the cache */
   /* search184_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 245, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 601, 603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 604 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 245, 605 },
      -1,
   } },

   /* replace184_0 -> 36 in the cache */
   /* replace184_1 -> 245 in the cache */
   /* replace184_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 245, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1 -> 41 in the cache */
   /* search185_2_0 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 608 },
      -1,
   } },

   /* replace185_0 -> 466 in the cache */
   /* replace185_1 -> 41 in the cache */
   /* replace185_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search186_0 -> 21 in the cache */
   /* search186_1_0 -> 21 in the cache */
   /* search186_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 611, 612 },
      -1,
   } },

   /* replace186_0_0 -> 41 in the cache */
   /* replace186_0_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 612 },
      -1,
   } },
   /* replace186_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 614, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search187_0_0 -> 21 in the cache */
   /* search187_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search187_1_0 -> 21 in the cache */
   /* search187_1_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 612 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 616, 617, 618 },
      -1,
   } },

   /* replace187_0_0 -> 41 in the cache */
   /* replace187_0_1 -> 612 in the cache */
   /* replace187_0_2 -> 618 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 612, 618 },
      -1,
   } },
   /* replace187_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 620, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search188_0 -> 21 in the cache */
   /* search188_1_0 -> 21 in the cache */
   /* search188_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search188_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 622, 612 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace188_0_1 -> 41 in the cache */
   /* replace188_0_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 624, 41, 612 },
      -1,
   } },
   /* replace188_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 625, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search189_0_0 -> 21 in the cache */
   /* search189_0_1_0 -> 624 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 629 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search189_1_1 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 630, 632 },
      -1,
   } },

   /* replace189_0 -> 21 in the cache */
   /* replace189_1 -> 631 in the cache */
   /* replace189_2 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 631, 627 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search190_0_0 -> 21 in the cache */
   /* search190_0_1_0_0 -> 624 in the cache */
   /* search190_0_1_0_1_0 -> 627 in the cache */
   /* search190_0_1_0_1 -> 628 in the cache */
   /* search190_0_1_0 -> 629 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 635 },
      -1,
   } },
   /* search190_1_0 -> 631 in the cache */
   /* search190_1_1_0 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 636, 638 },
      -1,
   } },

   /* replace190_0 -> 21 in the cache */
   /* replace190_1 -> 631 in the cache */
   /* replace190_2_0 -> 627 in the cache */
   /* replace190_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 631, 637 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search191_0 -> 21 in the cache */
   /* search191_1_0 -> 627 in the cache */
   /* search191_1_1_0 -> 631 in the cache */
   /* search191_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 631, 641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 627, 642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 643 },
      -1,
   } },

   /* replace191_0 -> 21 in the cache */
   /* replace191_1 -> 631 in the cache */
   /* replace191_2 -> 627 in the cache */
   /* replace191 -> 634 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search192_0_0 -> 21 in the cache */
   /* search192_0_1_0 -> 624 in the cache */
   /* search192_0_1_1_0_0 -> 504 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 646 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 647 },
      -1,
   } },
   /* search192_1_0 -> 631 in the cache */
   /* search192_1_1_0 -> 504 in the cache */
   /* search192_1_1 -> 645 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 648, 649 },
      -1,
   } },

   /* replace192_0 -> 504 in the cache */
   /* replace192_1 -> 631 in the cache */
   /* replace192_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 631, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search193_0 -> 21 in the cache */
   /* search193_1_0_0 -> 504 in the cache */
   /* search193_1_0 -> 645 in the cache */
   /* search193_1_1_0 -> 631 in the cache */
   /* search193_1_1_1_0 -> 21 in the cache */
   /* search193_1_1_1 -> 641 in the cache */
   /* search193_1_1 -> 642 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 645, 642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 652 },
      -1,
   } },

   /* replace193_0 -> 504 in the cache */
   /* replace193_1 -> 631 in the cache */
   /* replace193_2 -> 21 in the cache */
   /* replace193 -> 651 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search194_0 -> 21 in the cache */
   /* search194_1_0 -> 624 in the cache */
   /* search194_1_1_0_0 -> 504 in the cache */
   /* search194_1_1_0 -> 645 in the cache */
   /* search194_1_1 -> 646 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 624, 646 },
      -1,
   } },
   /* search194_2_0 -> 631 in the cache */
   /* search194_2_1_0 -> 504 in the cache */
   /* search194_2_1 -> 645 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 631, 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 654, 655 },
      -1,
   } },

   /* replace194_0 -> 504 in the cache */
   /* replace194_1 -> 631 in the cache */
   /* replace194_2 -> 21 in the cache */
   /* replace194 -> 651 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search195_1_0 -> 504 in the cache */
   /* search195_1 -> 645 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 658 },
      -1,
   } },
   /* search195_2_1_0 -> 504 in the cache */
   /* search195_2_1 -> 645 in the cache */
   /* search195_2_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 659, 645, 658 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 657, 645, 660 },
      -1,
   } },

   /* replace195_0 -> 504 in the cache */
   /* replace195_1 -> 657 in the cache */
   /* replace195_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 657, 658 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search196_0_0 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search196_1_0 -> 41 in the cache */
   /* search196_1_1_0 -> 658 in the cache */
   /* search196_1_1 -> 659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 659 },
      -1,
   } },
   /* search196_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 663, 664, 658 },
      -1,
   } },

   /* replace196_0 -> 523 in the cache */
   /* replace196_1 -> 41 in the cache */
   /* replace196_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 41, 658 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search197_0_0 -> 523 in the cache */
   /* search197_0 -> 663 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 667 },
      -1,
   } },
   /* search197_1_1 -> 631 in the cache */
   /* search197_1_2 -> 618 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 668, 631, 618 },
      -1,
   } },
   /* search197_2_0 -> 667 in the cache */
   /* search197_2_1 -> 631 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 667, 631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 663, 669, 670 },
      -1,
   } },

   /* replace197_0 -> 523 in the cache */
   /* replace197_1 -> 618 in the cache */
   /* replace197_2_0 -> 667 in the cache */
   /* replace197_2_1 -> 631 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 667, 631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 618, 672 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search198_0 -> 624 in the cache */
   /* search198_1_0_0_0 -> 624 in the cache */
   /* search198_1_0_0_1_0 -> 21 in the cache */
   /* search198_1_0_0_1 -> 641 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 641 },
      -1,
   } },
   /* search198_1_0_1_0 -> 624 in the cache */
   /* search198_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 624, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 674, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 624, 678 },
      -1,
   } },

   /* replace198_0 -> 41 in the cache */
   /* replace198_1 -> 624 in the cache */
   /* replace198_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 624, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search199_0_0 -> 151 in the cache */
   /* search199_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 151, 152 },
      0,
   } },
   /* search199_1_0 -> 151 in the cache */
   /* search199_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 154 },
      0,
   } },
   /* search199_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 681, 682, 155 },
      -1,
   } },

   /* replace199_0_0 -> 152 in the cache */
   /* replace199_0_1 -> 154 in the cache */
   /* replace199_0_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 152, 154, 155 },
      -1,
   } },
   /* replace199_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 684, 151 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search200_0 -> 0 in the cache */
   /* search200_1 -> 258 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 258, 686 },
      -1,
   } },

   /* replace200_0_0_0 -> 0 in the cache */
   /* replace200_0_0 -> 214 in the cache */
   /* replace200_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 214, 686 },
      -1,
   } },
   /* replace200_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 688, 0 },
      -1,
   } },

   /* ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search201_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace201_0_0 -> 32 in the cache */
   /* replace201_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   /* replace201_1_0_0_0 -> 32 in the cache */
   /* replace201_1_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 692 },
      -1,
   } },
   /* replace201_2_0_0 -> 32 in the cache */
   /* replace201_2_0 -> 103 in the cache */
   /* replace201_2 -> 692 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 691, 693, 692 },
      -1,
   } },

   /* ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search202_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace202_0 -> 11 in the cache */
   /* replace202_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 696 },
      -1,
   } },

   /* ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search203_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace203_0 -> 16 in the cache */
   /* replace203_1_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 699 },
      -1,
   } },

   /* ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search204_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace204_0 -> 21 in the cache */
   /* replace204_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 702 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search205_0 -> 11 in the cache */
   /* search205_1_0_0 -> 11 in the cache */
   /* search205_1_0 -> 696 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 696 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 704 },
      -1,
   } },

   /* replace205_0 -> 11 in the cache */
   /* replace205 -> 695 in the cache */

   /* ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search206_0 -> 16 in the cache */
   /* search206_1_0_0 -> 16 in the cache */
   /* search206_1_0 -> 699 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 706 },
      -1,
   } },

   /* replace206_0 -> 16 in the cache */
   /* replace206 -> 698 in the cache */

   /* ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search207_0 -> 21 in the cache */
   /* search207_1_0_0 -> 21 in the cache */
   /* search207_1_0 -> 702 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 708 },
      -1,
   } },

   /* replace207_0 -> 21 in the cache */
   /* replace207 -> 701 in the cache */

   /* ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search208_0 -> 11 in the cache */
   /* search208 -> 696 in the cache */

   /* replace208_0 -> 11 in the cache */
   /* replace208_1_0 -> 11 in the cache */
   /* replace208_1 -> 695 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 695 },
      -1,
   } },

   /* ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search209_0 -> 16 in the cache */
   /* search209 -> 699 in the cache */

   /* replace209_0 -> 16 in the cache */
   /* replace209_1_0 -> 16 in the cache */
   /* replace209_1 -> 698 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 698 },
      -1,
   } },

   /* ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search210_0 -> 21 in the cache */
   /* search210 -> 702 in the cache */

   /* replace210_0 -> 21 in the cache */
   /* replace210_1_0 -> 21 in the cache */
   /* replace210_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 701 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search211_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace211_0_0_0 -> 32 in the cache */
   /* replace211_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 714 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search212_0 -> 11 in the cache */
   /* search212_1 -> 260 in the cache */
   /* search212_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 471 },
      -1,
   } },

   /* replace212_0_0 -> 11 in the cache */
   /* replace212_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace212_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 717, 471 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search213_0 -> 16 in the cache */
   /* search213_1 -> 36 in the cache */
   /* search213_2 -> 137 in the cache */
   /* search213 -> 236 in the cache */

   /* replace213_0_0 -> 16 in the cache */
   /* replace213_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace213_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 719, 137 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search214_0 -> 21 in the cache */
   /* search214_1 -> 41 in the cache */
   /* search214_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 612 },
      -1,
   } },

   /* replace214_0_0 -> 21 in the cache */
   /* replace214_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace214_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 722, 612 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search215_0 -> 16 in the cache */
   /* search215_1 -> 36 in the cache */
   /* search215_2 -> 137 in the cache */
   /* search215 -> 389 in the cache */

   /* replace215_0_0 -> 16 in the cache */
   /* replace215_0_1 -> 36 in the cache */
   /* replace215_0 -> 136 in the cache */
   /* replace215_1 -> 137 in the cache */
   /* replace215 -> 290 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search216_0 -> 11 in the cache */
   /* search216_1 -> 260 in the cache */
   /* search216_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 471 },
      -1,
   } },

   /* replace216_0_0 -> 11 in the cache */
   /* replace216_0_1 -> 260 in the cache */
   /* replace216_0 -> 717 in the cache */
   /* replace216_1 -> 471 in the cache */
   /* replace216 -> 718 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search217_0 -> 16 in the cache */
   /* search217_1 -> 36 in the cache */
   /* search217_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace217_0_0 -> 16 in the cache */
   /* replace217_0_1 -> 36 in the cache */
   /* replace217_0 -> 719 in the cache */
   /* replace217_1 -> 137 in the cache */
   /* replace217 -> 720 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search218_0 -> 21 in the cache */
   /* search218_1 -> 41 in the cache */
   /* search218_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 612 },
      -1,
   } },

   /* replace218_0_0 -> 21 in the cache */
   /* replace218_0_1 -> 41 in the cache */
   /* replace218_0 -> 722 in the cache */
   /* replace218_1 -> 612 in the cache */
   /* replace218 -> 723 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search219_0 -> 16 in the cache */
   /* search219_1 -> 36 in the cache */
   /* search219_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace219_0_0 -> 16 in the cache */
   /* replace219_0_1 -> 36 in the cache */
   /* replace219_0 -> 136 in the cache */
   /* replace219_1 -> 137 in the cache */
   /* replace219 -> 290 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 728 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 729 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 731, 732 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 730, 733 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 734, 735 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 736, 737 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace220_1_0_0_0 -> 731 in the cache */
   /* replace220_1_0_0_1 -> 732 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 731, 732 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 740, 741 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 742, 743 },
      -1,
   } },
   /* replace220_2_0 -> 741 in the cache */
   /* replace220_2_1 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 741, 743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 739, 744, 745 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search221_0 -> 0 in the cache */
   /* search221_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace221_0_3 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 748, 749, 750, 272 },
      -1,
   } },
   /* replace221_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 751, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search222_0_0 -> 151 in the cache */
   /* search222_0_1 -> 152 in the cache */
   /* search222_0_2 -> 154 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 151, 152, 154, 753 },
      -1,
   } },
   /* search222_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 754, 155 },
      -1,
   } },

   /* replace222_0_0 -> 151 in the cache */
   /* replace222_0_1 -> 152 in the cache */
   /* replace222_0_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 151, 152, 154 },
      -1,
   } },
   /* replace222_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 756, 155 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search223_0_0 -> 0 in the cache */
   /* search223_0_1 -> 258 in the cache */
   /* search223_0_2 -> 258 in the cache */
   /* search223_0_3 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 258, 258, 258 },
      -1,
   } },
   /* search223_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 758, 3 },
      -1,
   } },

   /* replace223_0 -> 0 in the cache */
   /* replace223_1 -> 3 in the cache */
   /* replace223 -> 266 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search224_0_0 -> 128 in the cache */
   /* search224_0_1 -> 129 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search224_0_3 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 128, 129, 760, 760 },
      -1,
   } },
   /* search224_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 761, 131 },
      -1,
   } },

   /* replace224_0_0 -> 128 in the cache */
   /* replace224_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace224_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 763, 131 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search225_0_0 -> 151 in the cache */
   /* search225_0_1 -> 152 in the cache */
   /* search225_0_2 -> 154 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 151, 152, 154, 765 },
      -1,
   } },
   /* search225_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 766, 155 },
      -1,
   } },

   /* replace225_0_0 -> 151 in the cache */
   /* replace225_0_1 -> 152 in the cache */
   /* replace225_0_2 -> 154 in the cache */
   /* replace225_0 -> 756 in the cache */
   /* replace225_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 756, 155 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search226_0_0 -> 0 in the cache */
   /* search226_0_1 -> 258 in the cache */
   /* search226_0_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 258, 258 },
      -1,
   } },
   /* search226_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 769, 3 },
      -1,
   } },

   /* replace226_0 -> 0 in the cache */
   /* replace226_1 -> 3 in the cache */
   /* replace226 -> 266 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search227_0_0 -> 128 in the cache */
   /* search227_0_1 -> 129 in the cache */
   /* search227_0_2 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 128, 129, 760 },
      -1,
   } },
   /* search227_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 771, 131 },
      -1,
   } },

   /* replace227_0_0 -> 128 in the cache */
   /* replace227_0_1 -> 129 in the cache */
   /* replace227_0 -> 763 in the cache */
   /* replace227_1 -> 131 in the cache */
   /* replace227 -> 764 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search228_0_0 -> 0 in the cache */
   /* search228_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 258 },
      -1,
   } },
   /* search228_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 773, 3 },
      -1,
   } },

   /* replace228_0 -> 0 in the cache */
   /* replace228_1 -> 3 in the cache */
   /* replace228 -> 266 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search229_0 -> 32 in the cache */
   /* search229_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 243 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 776, 777 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search230_0 -> 0 in the cache */
   /* search230_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace230_0_0 -> 0 in the cache */
   /* replace230_0_1 -> 3 in the cache */
   /* replace230_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search231_0 -> 0 in the cache */
   /* search231_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace231_0_0 -> 0 in the cache */
   /* replace231_0_1 -> 3 in the cache */
   /* replace231_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search232_0 -> 0 in the cache */
   /* search232_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace232_0_0 -> 0 in the cache */
   /* replace232_0_1 -> 3 in the cache */
   /* replace232_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search233_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace233_0 -> 776 in the cache */
   /* replace233_1 -> 777 in the cache */
   /* replace233 -> 778 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 786 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 787 },
      0,
   } },
   /* search234_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 788, 243 },
      -1,
   } },

   /* replace234_0_0 -> 243 in the cache */
   /* replace234_0_1_0 -> 32 in the cache */
   /* replace234_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 243, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 790 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search235_0_0_0 -> 128 in the cache */
   /* search235_0_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 285 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 792, 793 },
      -1,
   } },
   /* search235_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 794, 313 },
      -1,
   } },

   /* replace235_0_0 -> 128 in the cache */
   /* replace235_0_1_0 -> 129 in the cache */
   /* replace235_0_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 129, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 796 },
      -1,
   } },
   /* replace235_1_0 -> 131 in the cache */
   /* replace235_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 797, 798 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search236_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 800 },
      -1,
   } },
   /* search236_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 801, 311 },
      -1,
   } },

   /* replace236_0 -> 0 in the cache */
   /* replace236_1_0 -> 3 in the cache */
   /* replace236_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 803 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search237_0_0 -> 6 in the cache */
   /* search237_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search237_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 805, 311 },
      -1,
   } },

   /* replace237_0_0_0_0 -> 36 in the cache */
   /* replace237_0_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 9 },
      -1,
   } },
   /* replace237_0_0_1_0 -> 137 in the cache */
   /* replace237_0_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 807, 808 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 809, 810 },
      -1,
   } },
   /* replace237_1_0 -> 6 in the cache */
   /* replace237_1_1_0 -> 36 in the cache */
   /* replace237_1_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 812 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 811, 813, 814 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search238_0_0 -> 6 in the cache */
   /* search238_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search238_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 816, 311 },
      -1,
   } },

   /* replace238_0_0_0_0 -> 36 in the cache */
   /* replace238_0_0_0_1 -> 9 in the cache */
   /* replace238_0_0_0 -> 807 in the cache */
   /* replace238_0_0_1_0 -> 137 in the cache */
   /* replace238_0_0_1_1 -> 9 in the cache */
   /* replace238_0_0_1 -> 808 in the cache */
   /* replace238_0_0 -> 809 in the cache */
   /* replace238_0_1 -> 810 in the cache */
   /* replace238_0 -> 811 in the cache */
   /* replace238_1_0 -> 6 in the cache */
   /* replace238_1_1_0 -> 36 in the cache */
   /* replace238_1_1_1 -> 137 in the cache */
   /* replace238_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 812 },
      -1,
   } },
   /* replace238_2 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 811, 818, 814 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7)) */
   /* search239_0_0 -> 6 in the cache */
   /* search239_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search239_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 820, 311 },
      -1,
   } },

   /* replace239_0 -> 6 in the cache */
   /* replace239_1_0_0_0 -> 36 in the cache */
   /* replace239_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 9 },
      -1,
   } },
   /* replace239_1_0_1_0 -> 137 in the cache */
   /* replace239_1_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 822, 823 },
      -1,
   } },
   /* replace239_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 824, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 825 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search240_0_0 -> 11 in the cache */
   /* search240_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search240_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 827, 311 },
      -1,
   } },

   /* replace240_0_0_0_0 -> 36 in the cache */
   /* replace240_0_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 14 },
      -1,
   } },
   /* replace240_0_0_1_0 -> 137 in the cache */
   /* replace240_0_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 829, 830 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 831, 832 },
      -1,
   } },
   /* replace240_1_0 -> 11 in the cache */
   /* replace240_1_1_0 -> 36 in the cache */
   /* replace240_1_1_1 -> 137 in the cache */
   /* replace240_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 812 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 833, 834, 835 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search241_0_0 -> 11 in the cache */
   /* search241_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search241_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 837, 311 },
      -1,
   } },

   /* replace241_0_0_0_0 -> 36 in the cache */
   /* replace241_0_0_0_1 -> 14 in the cache */
   /* replace241_0_0_0 -> 829 in the cache */
   /* replace241_0_0_1_0 -> 137 in the cache */
   /* replace241_0_0_1_1 -> 14 in the cache */
   /* replace241_0_0_1 -> 830 in the cache */
   /* replace241_0_0 -> 831 in the cache */
   /* replace241_0_1 -> 832 in the cache */
   /* replace241_0 -> 833 in the cache */
   /* replace241_1_0 -> 11 in the cache */
   /* replace241_1_1_0 -> 36 in the cache */
   /* replace241_1_1_1 -> 137 in the cache */
   /* replace241_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 812 },
      -1,
   } },
   /* replace241_2 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 833, 839, 835 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15)) */
   /* search242_0_0 -> 11 in the cache */
   /* search242_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search242_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 841, 311 },
      -1,
   } },

   /* replace242_0 -> 11 in the cache */
   /* replace242_1_0_0_0 -> 36 in the cache */
   /* replace242_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 14 },
      -1,
   } },
   /* replace242_1_0_1_0 -> 137 in the cache */
   /* replace242_1_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 843, 844 },
      -1,
   } },
   /* replace242_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 845, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 846 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search243_0_0 -> 16 in the cache */
   /* search243_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search243_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 848, 311 },
      -1,
   } },

   /* replace243_0_0_0_0 -> 36 in the cache */
   /* replace243_0_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 19 },
      -1,
   } },
   /* replace243_0_0_1_0 -> 137 in the cache */
   /* replace243_0_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 850, 851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 852, 853 },
      -1,
   } },
   /* replace243_1_0 -> 16 in the cache */
   /* replace243_1_1_0 -> 36 in the cache */
   /* replace243_1_1_1 -> 137 in the cache */
   /* replace243_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 812 },
      -1,
   } },
   /* replace243_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 855, 124 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search244_0_0 -> 16 in the cache */
   /* search244_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search244_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 857, 311 },
      -1,
   } },

   /* replace244_0_0_0_0 -> 36 in the cache */
   /* replace244_0_0_0_1 -> 19 in the cache */
   /* replace244_0_0_0 -> 850 in the cache */
   /* replace244_0_0_1_0 -> 137 in the cache */
   /* replace244_0_0_1_1 -> 19 in the cache */
   /* replace244_0_0_1 -> 851 in the cache */
   /* replace244_0_0 -> 852 in the cache */
   /* replace244_0_1 -> 853 in the cache */
   /* replace244_0 -> 854 in the cache */
   /* replace244_1_0 -> 16 in the cache */
   /* replace244_1_1_0 -> 36 in the cache */
   /* replace244_1_1_1 -> 137 in the cache */
   /* replace244_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 812 },
      -1,
   } },
   /* replace244_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 859, 124 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31)) */
   /* search245_0_0 -> 16 in the cache */
   /* search245_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search245_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 861, 311 },
      -1,
   } },

   /* replace245_0 -> 16 in the cache */
   /* replace245_1_0_0_0 -> 36 in the cache */
   /* replace245_1_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 19 },
      -1,
   } },
   /* replace245_1_0_1_0 -> 137 in the cache */
   /* replace245_1_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 863, 864 },
      -1,
   } },
   /* replace245_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 865, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 866 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search246_0_0 -> 21 in the cache */
   /* search246_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search246_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 868, 311 },
      -1,
   } },

   /* replace246_0_0_0_0 -> 36 in the cache */
   /* replace246_0_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 24 },
      -1,
   } },
   /* replace246_0_0_1_0 -> 137 in the cache */
   /* replace246_0_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 870, 871 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 872, 873 },
      -1,
   } },
   /* replace246_1_0 -> 21 in the cache */
   /* replace246_1_1_0 -> 36 in the cache */
   /* replace246_1_1_1 -> 137 in the cache */
   /* replace246_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 812 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 874, 875, 876 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search247_0_0 -> 21 in the cache */
   /* search247_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search247_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 878, 311 },
      -1,
   } },

   /* replace247_0_0_0_0 -> 36 in the cache */
   /* replace247_0_0_0_1 -> 24 in the cache */
   /* replace247_0_0_0 -> 870 in the cache */
   /* replace247_0_0_1_0 -> 137 in the cache */
   /* replace247_0_0_1_1 -> 24 in the cache */
   /* replace247_0_0_1 -> 871 in the cache */
   /* replace247_0_0 -> 872 in the cache */
   /* replace247_0_1 -> 873 in the cache */
   /* replace247_0 -> 874 in the cache */
   /* replace247_1_0 -> 21 in the cache */
   /* replace247_1_1_0 -> 36 in the cache */
   /* replace247_1_1_1 -> 137 in the cache */
   /* replace247_1_1 -> 812 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 812 },
      -1,
   } },
   /* replace247_2 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 874, 880, 876 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63)) */
   /* search248_0_0 -> 21 in the cache */
   /* search248_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search248_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 882, 311 },
      -1,
   } },

   /* replace248_0 -> 21 in the cache */
   /* replace248_1_0_0_0 -> 36 in the cache */
   /* replace248_1_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 24 },
      -1,
   } },
   /* replace248_1_0_1_0 -> 137 in the cache */
   /* replace248_1_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 884, 885 },
      -1,
   } },
   /* replace248_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 886, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 887 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search249_0_0 -> 6 in the cache */
   /* search249_0_1 -> 33 in the cache */
   /* search249_0 -> 816 in the cache */
   /* search249_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 816, 36 },
      -1,
   } },

   /* replace249_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace249_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 890, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 891 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search250_0_0 -> 6 in the cache */
   /* search250_0_1 -> 33 in the cache */
   /* search250_0 -> 820 in the cache */
   /* search250_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 820, 36 },
      -1,
   } },

   /* replace250_0 -> 6 in the cache */
   /* replace250_1_0 -> 890 in the cache */
   /* replace250_1_1 -> 36 in the cache */
   /* replace250_1 -> 891 in the cache */
   /* replace250 -> 892 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search251_0_0 -> 6 in the cache */
   /* search251_0_1 -> 33 in the cache */
   /* search251_0 -> 805 in the cache */
   /* search251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 805, 36 },
      -1,
   } },

   /* replace251_0 -> 6 in the cache */
   /* replace251_1_0 -> 890 in the cache */
   /* replace251_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 890, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 895 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search252_0_0 -> 11 in the cache */
   /* search252_0_1 -> 33 in the cache */
   /* search252_0 -> 837 in the cache */
   /* search252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 837, 36 },
      -1,
   } },

   /* replace252_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace252_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 898, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 899 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search253_0_0 -> 11 in the cache */
   /* search253_0_1 -> 33 in the cache */
   /* search253_0 -> 841 in the cache */
   /* search253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 841, 36 },
      -1,
   } },

   /* replace253_0 -> 11 in the cache */
   /* replace253_1_0 -> 898 in the cache */
   /* replace253_1_1 -> 36 in the cache */
   /* replace253_1 -> 899 in the cache */
   /* replace253 -> 900 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search254_0_0 -> 11 in the cache */
   /* search254_0_1 -> 33 in the cache */
   /* search254_0 -> 827 in the cache */
   /* search254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 827, 36 },
      -1,
   } },

   /* replace254_0 -> 11 in the cache */
   /* replace254_1_0 -> 898 in the cache */
   /* replace254_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 898, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 903 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search255_0_0 -> 16 in the cache */
   /* search255_0_1 -> 33 in the cache */
   /* search255_0 -> 857 in the cache */
   /* search255_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 857, 36 },
      -1,
   } },

   /* replace255_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace255_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 906, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 907 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search256_0_0 -> 16 in the cache */
   /* search256_0_1 -> 33 in the cache */
   /* search256_0 -> 861 in the cache */
   /* search256_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 861, 36 },
      -1,
   } },

   /* replace256_0 -> 16 in the cache */
   /* replace256_1_0 -> 906 in the cache */
   /* replace256_1_1 -> 36 in the cache */
   /* replace256_1 -> 907 in the cache */
   /* replace256 -> 908 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search257_0_0 -> 16 in the cache */
   /* search257_0_1 -> 33 in the cache */
   /* search257_0 -> 848 in the cache */
   /* search257_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 848, 36 },
      -1,
   } },

   /* replace257_0 -> 16 in the cache */
   /* replace257_1_0 -> 906 in the cache */
   /* replace257_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 906, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 911 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search258_0_0 -> 21 in the cache */
   /* search258_0_1 -> 33 in the cache */
   /* search258_0 -> 878 in the cache */
   /* search258_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 878, 36 },
      -1,
   } },

   /* replace258_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace258_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 914, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 915 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search259_0_0 -> 21 in the cache */
   /* search259_0_1 -> 33 in the cache */
   /* search259_0 -> 882 in the cache */
   /* search259_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 882, 36 },
      -1,
   } },

   /* replace259_0 -> 21 in the cache */
   /* replace259_1_0 -> 914 in the cache */
   /* replace259_1_1 -> 36 in the cache */
   /* replace259_1 -> 915 in the cache */
   /* replace259 -> 916 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search260_0_0 -> 21 in the cache */
   /* search260_0_1 -> 33 in the cache */
   /* search260_0 -> 868 in the cache */
   /* search260_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 868, 36 },
      -1,
   } },

   /* replace260_0 -> 21 in the cache */
   /* replace260_1_0 -> 914 in the cache */
   /* replace260_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 914, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 919 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search261_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 921 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 922, 923 },
      -1,
   } },

   /* replace261_0 -> 16 in the cache */
   /* replace261_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search262_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 926 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 927, 928 },
      -1,
   } },

   /* replace262_0 -> 0 in the cache */
   /* replace262_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search263_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 931 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 932, 933 },
      -1,
   } },

   /* replace263_0_0 -> 16 in the cache */
   /* replace263_0_1 -> 933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 933 },
      -1,
   } },
   /* replace263_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 935, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search264_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 937 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 938, 939 },
      -1,
   } },

   /* replace264_0_0 -> 16 in the cache */
   /* replace264_0_1 -> 939 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 939 },
      -1,
   } },
   /* replace264_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 941, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search265_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 943 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 944, 945 },
      -1,
   } },

   /* replace265_0_0 -> 16 in the cache */
   /* replace265_0_1 -> 945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 945 },
      -1,
   } },
   /* replace265_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 947, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search266_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 949 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 950, 951 },
      -1,
   } },

   /* replace266_0_0 -> 16 in the cache */
   /* replace266_0_1 -> 951 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 951 },
      -1,
   } },
   /* replace266_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 953, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search267_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 955 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 956, 957 },
      -1,
   } },

   /* replace267_0_0 -> 16 in the cache */
   /* replace267_0_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 957 },
      -1,
   } },
   /* replace267_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 959, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search268_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 961 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 962, 963 },
      -1,
   } },

   /* replace268_0_0 -> 16 in the cache */
   /* replace268_0_1 -> 963 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 963 },
      -1,
   } },
   /* replace268_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 965, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search269_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 967 },
      -1,
   } },
   /* search269_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 968, 398 },
      -1,
   } },

   /* replace269_0 -> 16 in the cache */
   /* replace269_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 398 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search270_0_0 -> 16 in the cache */
   /* search270_0_1 -> 398 in the cache */
   /* search270_0 -> 970 in the cache */
   /* search270_1 -> 933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 970, 933 },
      -1,
   } },

   /* replace270_0 -> 16 in the cache */
   /* replace270_1 -> 398 in the cache */
   /* replace270 -> 970 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search271_0_0 -> 16 in the cache */
   /* search271_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* search271_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 972, 967 },
      -1,
   } },

   /* replace271_0 -> 16 in the cache */
   /* replace271_1 -> 398 in the cache */
   /* replace271 -> 972 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search272_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 974 },
      -1,
   } },
   /* search272_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 975, 403 },
      -1,
   } },

   /* replace272_0 -> 16 in the cache */
   /* replace272_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 403 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search273_0_0 -> 16 in the cache */
   /* search273_0_1 -> 403 in the cache */
   /* search273_0 -> 977 in the cache */
   /* search273_1 -> 939 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 977, 939 },
      -1,
   } },

   /* replace273_0 -> 16 in the cache */
   /* replace273_1 -> 403 in the cache */
   /* replace273 -> 977 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search274_0_0 -> 16 in the cache */
   /* search274_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* search274_1 -> 974 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 979, 974 },
      -1,
   } },

   /* replace274_0 -> 16 in the cache */
   /* replace274_1 -> 403 in the cache */
   /* replace274 -> 979 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search275_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 981 },
      -1,
   } },
   /* search275_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 982, 832 },
      -1,
   } },

   /* replace275_0 -> 16 in the cache */
   /* replace275_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 832 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search276_0_0 -> 16 in the cache */
   /* search276_0_1 -> 832 in the cache */
   /* search276_0 -> 984 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 984, 985 },
      -1,
   } },

   /* replace276_0 -> 16 in the cache */
   /* replace276_1 -> 832 in the cache */
   /* replace276 -> 984 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search277_0_0 -> 16 in the cache */
   /* search277_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 832 },
      -1,
   } },
   /* search277_1 -> 981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 987, 981 },
      -1,
   } },

   /* replace277_0 -> 16 in the cache */
   /* replace277_1 -> 832 in the cache */
   /* replace277 -> 987 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search278_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 989 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 990, 991 },
      -1,
   } },

   /* replace278_0 -> 16 in the cache */
   /* replace278_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 991 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search279_0_0 -> 16 in the cache */
   /* search279_0_1 -> 991 in the cache */
   /* search279_0 -> 993 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 993, 994 },
      -1,
   } },

   /* replace279_0 -> 16 in the cache */
   /* replace279_1 -> 991 in the cache */
   /* replace279 -> 993 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search280_0_0 -> 16 in the cache */
   /* search280_0_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 991 },
      -1,
   } },
   /* search280_1 -> 989 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 996, 989 },
      -1,
   } },

   /* replace280_0 -> 16 in the cache */
   /* replace280_1 -> 991 in the cache */
   /* replace280 -> 996 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search281_0_0 -> 0 in the cache */
   /* search281_0_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 800 },
      -1,
   } },
   /* search281_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 998, 311 },
      -1,
   } },

   /* replace281_0_0 -> 0 in the cache */
   /* replace281_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 137 },
      -1,
   } },
   /* replace281_1_0 -> 3 in the cache */
   /* replace281_1_1 -> 137 in the cache */
   /* replace281_1 -> 803 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1000, 803 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search282_0_0 -> 128 in the cache */
   /* search282_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 128, 285 },
      0,
   } },
   /* search282_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1002, 793 },
      -1,
   } },

   /* replace282_0_0 -> 128 in the cache */
   /* replace282_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace282_1_0 -> 129 in the cache */
   /* replace282_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 1004, 1005 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search283_0_0_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 151, 1007 },
      0,
   } },
   /* search283_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 1008, 154 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 1009, 1010 },
      -1,
   } },

   /* replace283_0_0_0 -> 151 in the cache */
   /* replace283_0_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 151, 154 },
      -1,
   } },
   /* replace283_0_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 1012, 155 },
      -1,
   } },
   /* replace283_1_0 -> 152 in the cache */
   /* replace283_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 1013, 1014 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search284_0_0_0 -> 128 in the cache */
   /* search284_0_0_1 -> 285 in the cache */
   /* search284_0_0 -> 1002 in the cache */
   /* search284_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1002, 131 },
      0,
   } },
   /* search284_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 1016, 313 },
      -1,
   } },

   /* replace284_0_0_0 -> 128 in the cache */
   /* replace284_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace284_0_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1018, 165 },
      -1,
   } },
   /* replace284_1_0 -> 129 in the cache */
   /* replace284_1_1 -> 165 in the cache */
   /* replace284_1 -> 796 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1019, 796 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1021, 1022 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1023 },
      -1,
   } },

   /* replace285_0 -> 0 in the cache */
   /* replace285_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search286_0_0 -> 1021 in the cache */
   /* search286_0_1 -> 1022 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1021, 1022 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1026 },
      -1,
   } },

   /* replace286_0 -> 0 in the cache */
   /* replace286_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search287_0_0 -> 0 in the cache */
   /* search287_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1029 },
      -1,
   } },

   /* replace287_0 -> 0 in the cache */
   /* replace287_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search288_0_0 -> 0 in the cache */
   /* search288_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1032 },
      -1,
   } },

   /* replace288_0 -> 0 in the cache */
   /* replace288_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search289_0_0 -> 0 in the cache */
   /* search289_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1035 },
      -1,
   } },

   /* replace289_0 -> 0 in the cache */
   /* replace289_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search290_0_0 -> 0 in the cache */
   /* search290_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1038 },
      -1,
   } },

   /* replace290_0 -> 0 in the cache */
   /* replace290_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search291_0_0 -> 0 in the cache */
   /* search291_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1041 },
      -1,
   } },

   /* replace291_0 -> 0 in the cache */
   /* replace291_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search292_0_0 -> 0 in the cache */
   /* search292_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1044 },
      -1,
   } },

   /* replace292_0 -> 0 in the cache */
   /* replace292_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search293_0_0 -> 0 in the cache */
   /* search293_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1047 },
      -1,
   } },

   /* replace293_0 -> 0 in the cache */
   /* replace293_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search294_0_0 -> 0 in the cache */
   /* search294_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1050 },
      -1,
   } },

   /* replace294_0 -> 0 in the cache */
   /* replace294_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search295_0_0 -> 0 in the cache */
   /* search295_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search295_1_0 -> 0 in the cache */
   /* search295_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1053, 1054 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search296_0_0 -> 0 in the cache */
   /* search296_0_1 -> 3 in the cache */
   /* search296_0 -> 1028 in the cache */
   /* search296_1_0 -> 3 in the cache */
   /* search296_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1028, 1057 },
      -1,
   } },

   /* replace296 -> 1056 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search297_0_0 -> 0 in the cache */
   /* search297_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search297_1_0 -> 0 in the cache */
   /* search297_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1059, 1060 },
      -1,
   } },

   /* replace297 -> 1056 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search298_0_0 -> 0 in the cache */
   /* search298_0_1 -> 3 in the cache */
   /* search298_0 -> 1043 in the cache */
   /* search298_1_0 -> 3 in the cache */
   /* search298_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1043, 1062 },
      -1,
   } },

   /* replace298 -> 1056 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0_1 -> 3 in the cache */
   /* search299_0 -> 1046 in the cache */
   /* search299_1_0 -> 3 in the cache */
   /* search299_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1046, 1064 },
      -1,
   } },

   /* replace299 -> 1056 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search300_0_0 -> 0 in the cache */
   /* search300_0 -> 214 in the cache */
   /* search300_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 214, 1066 },
      -1,
   } },

   /* replace300_0 -> 3 in the cache */
   /* replace300_1 -> 0 in the cache */
   /* replace300 -> 1057 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search301_0_0 -> 0 in the cache */
   /* search301_0 -> 214 in the cache */
   /* search301_1_0 -> 3 in the cache */
   /* search301_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 214, 1066 },
      -1,
   } },

   /* replace301_0 -> 3 in the cache */
   /* replace301_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search302_0_0 -> 0 in the cache */
   /* search302_0 -> 214 in the cache */
   /* search302_1_0 -> 3 in the cache */
   /* search302_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 214, 1066 },
      -1,
   } },

   /* replace302_0 -> 3 in the cache */
   /* replace302_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search303_0_0 -> 0 in the cache */
   /* search303_0 -> 214 in the cache */
   /* search303_1_0 -> 3 in the cache */
   /* search303_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 214, 1066 },
      -1,
   } },

   /* replace303_0 -> 3 in the cache */
   /* replace303_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search304_0_0 -> 32 in the cache */
   /* search304_0 -> 98 in the cache */
   /* search304_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 249 },
      -1,
   } },

   /* replace304_0 -> 243 in the cache */
   /* replace304_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search305_0 -> 249 in the cache */
   /* search305_1_0 -> 32 in the cache */
   /* search305_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 249, 98 },
      -1,
   } },

   /* replace305_0 -> 32 in the cache */
   /* replace305_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search306_0_0 -> 32 in the cache */
   /* search306_0 -> 98 in the cache */
   /* search306_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 249 },
      -1,
   } },

   /* replace306_0 -> 243 in the cache */
   /* replace306_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search307_0 -> 249 in the cache */
   /* search307_1_0 -> 32 in the cache */
   /* search307_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 249, 98 },
      -1,
   } },

   /* replace307_0 -> 32 in the cache */
   /* replace307_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search308_0_0 -> 32 in the cache */
   /* search308_0 -> 98 in the cache */
   /* search308_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 249 },
      -1,
   } },

   /* replace308_0 -> 243 in the cache */
   /* replace308_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 243, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search309_0 -> 249 in the cache */
   /* search309_1_0 -> 32 in the cache */
   /* search309_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 249, 98 },
      -1,
   } },

   /* replace309_0 -> 32 in the cache */
   /* replace309_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 243 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1087 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1086, 1088 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace310_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search311_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1092, 1093 },
      -1,
   } },

   /* replace311_0 -> 0 in the cache */
   /* replace311_1 -> 3 in the cache */
   /* replace311 -> 1025 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search312_0_0 -> 0 in the cache */
   /* search312_0 -> 1092 in the cache */
   /* search312_1 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1092, 1093 },
      -1,
   } },

   /* replace312_0 -> 0 in the cache */
   /* replace312_1 -> 3 in the cache */
   /* replace312 -> 1034 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search313_0_0 -> 0 in the cache */
   /* search313_0 -> 1092 in the cache */
   /* search313_1 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1092, 1093 },
      -1,
   } },

   /* replace313_0 -> 0 in the cache */
   /* replace313_1 -> 3 in the cache */
   /* replace313 -> 1031 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search314_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search314_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1097, 243 },
      -1,
   } },

   /* replace314_0 -> 32 in the cache */
   /* replace314_1 -> 243 in the cache */
   /* replace314 -> 1081 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search315_0 -> 113 in the cache */
   /* search315_1_0 -> 32 in the cache */
   /* search315_1 -> 1097 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 1097 },
      -1,
   } },

   /* replace315_0 -> 113 in the cache */
   /* replace315_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search316_1_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1101, 1102 },
      -1,
   } },

   /* replace316_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search317_0_0_0 -> 739 in the cache */
   /* search317_0_0 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1102 },
      -1,
   } },
   /* search317_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1105, 1101 },
      -1,
   } },

   /* replace317_0 -> 739 in the cache */
   /* replace317 -> 1104 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search318_0_0_0 -> 739 in the cache */
   /* search318_0_0 -> 1102 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1102, 1108 },
      -1,
   } },
   /* search318_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1109, 1101 },
      -1,
   } },

   /* replace318_0 -> 739 in the cache */
   /* replace318_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 739, 1107 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search319_0_0 -> 739 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search319_0_2_0 -> 1107 in the cache */
   /* search319_0_2 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1112, 1108 },
      -1,
   } },
   /* search319_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1113, 1101 },
      -1,
   } },

   /* replace319_0 -> 739 in the cache */
   /* replace319_1 -> 1107 in the cache */
   /* replace319 -> 1111 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search320_0_0 -> 739 in the cache */
   /* search320_0 -> 1102 in the cache */
   /* search320_1_0_0 -> 1107 in the cache */
   /* search320_1_0 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1108 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1102, 1115 },
      -1,
   } },

   /* replace320_0 -> 739 in the cache */
   /* replace320_1 -> 1107 in the cache */
   /* replace320 -> 1111 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search321_0_0_0 -> 739 in the cache */
   /* search321_0_0 -> 1102 in the cache */
   /* search321_0_1_0 -> 1107 in the cache */
   /* search321_0_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1102, 1108 },
      -1,
   } },
   /* search321_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1117, 1101 },
      -1,
   } },

   /* replace321_0 -> 739 in the cache */
   /* replace321_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 739, 1107 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search322_0_0 -> 739 in the cache */
   /* search322_0_1_0 -> 1107 in the cache */
   /* search322_0_1 -> 1108 in the cache */
   /* search322_0_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1108, 1101 },
      -1,
   } },
   /* search322_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1120, 1101 },
      -1,
   } },

   /* replace322_0 -> 739 in the cache */
   /* replace322_1 -> 1107 in the cache */
   /* replace322 -> 1119 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search323_0_0_0 -> 739 in the cache */
   /* search323_0_0 -> 1102 in the cache */
   /* search323_0_1_0_0 -> 1107 in the cache */
   /* search323_0_1_0 -> 1108 in the cache */
   /* search323_0_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1102, 1115 },
      -1,
   } },
   /* search323_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1122, 1101 },
      -1,
   } },

   /* replace323_0 -> 739 in the cache */
   /* replace323_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 739, 1107 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search324_0_0 -> 739 in the cache */
   /* search324_0 -> 1102 in the cache */
   /* search324_1_0 -> 1107 in the cache */
   /* search324_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1102, 1108 },
      -1,
   } },

   /* replace324_0 -> 739 in the cache */
   /* replace324_1 -> 1107 in the cache */
   /* replace324 -> 1124 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search325_0_0_0 -> 739 in the cache */
   /* search325_0_0 -> 1102 in the cache */
   /* search325_0 -> 1105 in the cache */
   /* search325_1_0_0 -> 1107 in the cache */
   /* search325_1_0 -> 1108 in the cache */
   /* search325_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1105, 1115 },
      -1,
   } },

   /* replace325_0 -> 739 in the cache */
   /* replace325_1 -> 1107 in the cache */
   /* replace325 -> 1124 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search326_0_0_0 -> 739 in the cache */
   /* search326_0_0 -> 1102 in the cache */
   /* search326_0_1_0 -> 1107 in the cache */
   /* search326_0_1 -> 1108 in the cache */
   /* search326_0 -> 1109 in the cache */
   /* search326_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1109, 1101 },
      -1,
   } },

   /* replace326_0_0 -> 739 in the cache */
   /* replace326_0_1 -> 1107 in the cache */
   /* replace326_0 -> 1111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1111 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search327_0_0 -> 739 in the cache */
   /* search327_0_1 -> 1112 in the cache */
   /* search327_0_2_0 -> 1107 in the cache */
   /* search327_0_2 -> 1108 in the cache */
   /* search327_0 -> 1113 in the cache */
   /* search327_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1113, 1101 },
      -1,
   } },

   /* replace327_0_0 -> 739 in the cache */
   /* replace327_0_1 -> 1107 in the cache */
   /* replace327_0 -> 1111 in the cache */
   /* replace327 -> 1128 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search328_0_0 -> 739 in the cache */
   /* search328_0 -> 1102 in the cache */
   /* search328_1_0_0 -> 1107 in the cache */
   /* search328_1_0 -> 1108 in the cache */
   /* search328_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1102, 1115 },
      -1,
   } },

   /* replace328_0_0 -> 739 in the cache */
   /* replace328_0_1 -> 1107 in the cache */
   /* replace328_0 -> 1111 in the cache */
   /* replace328 -> 1128 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search329_0_0_0 -> 739 in the cache */
   /* search329_0_0 -> 1102 in the cache */
   /* search329_0_1_0 -> 1107 in the cache */
   /* search329_0_1 -> 1108 in the cache */
   /* search329_0 -> 1117 in the cache */
   /* search329_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1117, 1101 },
      -1,
   } },

   /* replace329_0_0 -> 739 in the cache */
   /* replace329_0_1 -> 1107 in the cache */
   /* replace329_0 -> 1119 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1119 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search330_0_0 -> 739 in the cache */
   /* search330_0_1_0 -> 1107 in the cache */
   /* search330_0_1 -> 1108 in the cache */
   /* search330_0_2 -> 1101 in the cache */
   /* search330_0 -> 1120 in the cache */
   /* search330_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1120, 1101 },
      -1,
   } },

   /* replace330_0_0 -> 739 in the cache */
   /* replace330_0_1 -> 1107 in the cache */
   /* replace330_0 -> 1119 in the cache */
   /* replace330 -> 1132 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search331_0_0_0 -> 739 in the cache */
   /* search331_0_0 -> 1102 in the cache */
   /* search331_0_1_0_0 -> 1107 in the cache */
   /* search331_0_1_0 -> 1108 in the cache */
   /* search331_0_1 -> 1115 in the cache */
   /* search331_0 -> 1122 in the cache */
   /* search331_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1122, 1101 },
      -1,
   } },

   /* replace331_0 -> 739 in the cache */
   /* replace331_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 739, 1107 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search332_0_0 -> 739 in the cache */
   /* search332_0 -> 1102 in the cache */
   /* search332_1_0 -> 1107 in the cache */
   /* search332_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1102, 1108 },
      -1,
   } },

   /* replace332_0 -> 739 in the cache */
   /* replace332_1 -> 1107 in the cache */
   /* replace332 -> 1135 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search333_0_0_0 -> 739 in the cache */
   /* search333_0_0 -> 1102 in the cache */
   /* search333_0 -> 1105 in the cache */
   /* search333_1_0_0 -> 1107 in the cache */
   /* search333_1_0 -> 1108 in the cache */
   /* search333_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1105, 1115 },
      -1,
   } },

   /* replace333_0 -> 739 in the cache */
   /* replace333_1 -> 1107 in the cache */
   /* replace333 -> 1135 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search334_0_0_0_0 -> 739 in the cache */
   /* search334_0_0_0 -> 1102 in the cache */
   /* search334_0_0_1_0 -> 1107 in the cache */
   /* search334_0_0_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1102, 1108 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1138 },
      -1,
   } },
   /* search334_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1139, 1101 },
      -1,
   } },

   /* replace334_0 -> 739 in the cache */
   /* replace334_1 -> 1107 in the cache */
   /* replace334 -> 1111 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search335_0 -> 1101 in the cache */
   /* search335_1_0_0 -> 739 in the cache */
   /* search335_1_0 -> 1102 in the cache */
   /* search335_1_1_0 -> 1107 in the cache */
   /* search335_1_1 -> 1108 in the cache */
   /* search335_1 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1101, 1138 },
      -1,
   } },

   /* replace335_0 -> 739 in the cache */
   /* replace335_1 -> 1107 in the cache */
   /* replace335 -> 1111 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search336_0_0_0_0 -> 739 in the cache */
   /* search336_0_0_0 -> 1102 in the cache */
   /* search336_0_0_1_0 -> 1107 in the cache */
   /* search336_0_0_1 -> 1108 in the cache */
   /* search336_0_0 -> 1138 in the cache */
   /* search336_0 -> 1139 in the cache */
   /* search336_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1139, 1101 },
      -1,
   } },

   /* replace336_0_0 -> 739 in the cache */
   /* replace336_0_1 -> 1107 in the cache */
   /* replace336_0 -> 1111 in the cache */
   /* replace336 -> 1128 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search337_0 -> 1101 in the cache */
   /* search337_1_0_0 -> 739 in the cache */
   /* search337_1_0 -> 1102 in the cache */
   /* search337_1_1_0 -> 1107 in the cache */
   /* search337_1_1 -> 1108 in the cache */
   /* search337_1 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1101, 1138 },
      -1,
   } },

   /* replace337_0_0 -> 739 in the cache */
   /* replace337_0_1 -> 1107 in the cache */
   /* replace337_0 -> 1111 in the cache */
   /* replace337 -> 1128 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search338_0 -> 32 in the cache */
   /* search338_1_0 -> 32 in the cache */
   /* search338_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace338_0 -> 32 in the cache */
   /* replace338_1 -> 113 in the cache */
   /* replace338 -> 691 in the cache */

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search339_0 -> 32 in the cache */
   /* search339_1_0 -> 32 in the cache */
   /* search339_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace339_0 -> 32 in the cache */
   /* replace339_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1148 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1149, 1151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1152 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1147, 1153 },
      -1,
   } },
   /* search340_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1154, 113 },
      -1,
   } },

   /* replace340_0_0 -> 1147 in the cache */
   /* replace340_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1147, 113 },
      -1,
   } },
   /* replace340_1_0 -> 1148 in the cache */
   /* replace340_1_1 -> 1150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1148, 1150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1156, 1157 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search341_0_0 -> 0 in the cache */
   /* search341_0_1 -> 3 in the cache */
   /* search341_0 -> 274 in the cache */
   /* search341_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 274, 0 },
      -1,
   } },

   /* replace341_0 -> 3 in the cache */
   /* replace341_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 258 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search342_0_0 -> 0 in the cache */
   /* search342_0_1 -> 3 in the cache */
   /* search342_0 -> 274 in the cache */
   /* search342_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 274, 0 },
      -1,
   } },

   /* replace342_0 -> 3 in the cache */
   /* replace342_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 258 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search343_0_0 -> 0 in the cache */
   /* search343_0_1 -> 3 in the cache */
   /* search343_0 -> 215 in the cache */
   /* search343_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 215, 0 },
      -1,
   } },

   /* replace343_0 -> 3 in the cache */
   /* replace343_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 258 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search344_0_0 -> 0 in the cache */
   /* search344_0_1 -> 3 in the cache */
   /* search344_0 -> 215 in the cache */
   /* search344_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 215, 0 },
      -1,
   } },

   /* replace344_0 -> 3 in the cache */
   /* replace344_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 258 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search345_0_0 -> 128 in the cache */
   /* search345_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 128, 285 },
      0,
   } },
   /* search345_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1167, 793 },
      -1,
   } },

   /* replace345_0 -> 128 in the cache */
   /* replace345_1_0 -> 131 in the cache */
   /* replace345_1_1_0 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 131, 1169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1170 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search346_0_0_0 -> 128 in the cache */
   /* search346_0_0_1 -> 285 in the cache */
   /* search346_0_0 -> 1167 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1167 },
      0,
   } },
   /* search346_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1172, 793 },
      -1,
   } },

   /* replace346_0_0_0 -> 131 in the cache */
   /* replace346_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 131, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1174 },
      -1,
   } },
   /* replace346_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1175, 128 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search347_0_0 -> 128 in the cache */
   /* search347_0_1 -> 285 in the cache */
   /* search347_0 -> 1167 in the cache */
   /* search347_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1167, 793 },
      -1,
   } },

   /* replace347_0 -> 128 in the cache */
   /* replace347_1_0 -> 131 in the cache */
   /* replace347_1_1_0 -> 129 in the cache */
   /* replace347_1_1 -> 1169 in the cache */
   /* replace347_1 -> 1170 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1170 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search348_0_0_0 -> 128 in the cache */
   /* search348_0_0_1 -> 285 in the cache */
   /* search348_0_0 -> 1167 in the cache */
   /* search348_0 -> 1172 in the cache */
   /* search348_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1172, 793 },
      -1,
   } },

   /* replace348_0_0_0 -> 131 in the cache */
   /* replace348_0_0_1 -> 129 in the cache */
   /* replace348_0_0 -> 1174 in the cache */
   /* replace348_0 -> 1175 in the cache */
   /* replace348_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1175, 128 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search349_0_0 -> 128 in the cache */
   /* search349_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 285 },
      0,
   } },
   /* search349_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1181, 793 },
      -1,
   } },

   /* replace349_0 -> 128 in the cache */
   /* replace349_1_0 -> 131 in the cache */
   /* replace349_1_1_0 -> 129 in the cache */
   /* replace349_1_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 131, 1169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 128, 1183 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search350_0_0_0 -> 128 in the cache */
   /* search350_0_0_1 -> 285 in the cache */
   /* search350_0_0 -> 1181 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1181 },
      0,
   } },
   /* search350_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1185, 793 },
      -1,
   } },

   /* replace350_0_0_0 -> 131 in the cache */
   /* replace350_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 131, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1187 },
      -1,
   } },
   /* replace350_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1188, 128 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search351_0_0 -> 128 in the cache */
   /* search351_0_1 -> 285 in the cache */
   /* search351_0 -> 1181 in the cache */
   /* search351_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1181, 793 },
      -1,
   } },

   /* replace351_0 -> 128 in the cache */
   /* replace351_1_0 -> 131 in the cache */
   /* replace351_1_1_0 -> 129 in the cache */
   /* replace351_1_1 -> 1169 in the cache */
   /* replace351_1 -> 1183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 128, 1183 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search352_0_0_0 -> 128 in the cache */
   /* search352_0_0_1 -> 285 in the cache */
   /* search352_0_0 -> 1181 in the cache */
   /* search352_0 -> 1185 in the cache */
   /* search352_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1185, 793 },
      -1,
   } },

   /* replace352_0_0_0 -> 131 in the cache */
   /* replace352_0_0_1 -> 129 in the cache */
   /* replace352_0_0 -> 1187 in the cache */
   /* replace352_0 -> 1188 in the cache */
   /* replace352_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1188, 128 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search353_0_0 -> 0 in the cache */
   /* search353_0_1 -> 3 in the cache */
   /* search353_0 -> 210 in the cache */
   /* search353_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 210, 0 },
      -1,
   } },

   /* replace353_0 -> 3 in the cache */
   /* replace353_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search354_0_0 -> 0 in the cache */
   /* search354_0_1 -> 3 in the cache */
   /* search354_0 -> 210 in the cache */
   /* search354_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 210, 0 },
      -1,
   } },

   /* replace354_0 -> 3 in the cache */
   /* replace354_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search355_0_0 -> 739 in the cache */
   /* search355_0 -> 1102 in the cache */
   /* search355_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1102, 1101 },
      -1,
   } },

   /* replace355_0 -> 739 in the cache */
   /* replace355 -> 1104 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search356_0_0 -> 739 in the cache */
   /* search356_0 -> 1102 in the cache */
   /* search356_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1102, 1101 },
      -1,
   } },

   /* replace356 -> 739 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search357_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 739 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1200, 1201 },
      -1,
   } },

   /* replace357_0 -> 739 in the cache */
   /* replace357 -> 1104 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search358_0_0 -> 739 in the cache */
   /* search358_0 -> 1200 in the cache */
   /* search358_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1200, 1201 },
      -1,
   } },

   /* replace358 -> 739 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search359_0_0 -> 32 in the cache */
   /* search359_0 -> 104 in the cache */
   /* search359_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1101 },
      -1,
   } },

   /* replace359_0 -> 32 in the cache */
   /* replace359_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search360_0_0 -> 32 in the cache */
   /* search360_0 -> 104 in the cache */
   /* search360_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1101 },
      -1,
   } },

   /* replace360_0 -> 32 in the cache */
   /* replace360_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search361_0_0 -> 32 in the cache */
   /* search361_0 -> 104 in the cache */
   /* search361_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1101 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search362_0 -> 1101 in the cache */
   /* search362_1_0 -> 32 in the cache */
   /* search362_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1101, 104 },
      -1,
   } },

   /* replace362_0 -> 61 in the cache */
   /* replace362_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search363_0_0 -> 32 in the cache */
   /* search363_0 -> 104 in the cache */
   /* search363_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1101 },
      -1,
   } },

   /* replace363 -> 1056 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search364_0 -> 1101 in the cache */
   /* search364_1_0 -> 32 in the cache */
   /* search364_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1101, 104 },
      -1,
   } },

   /* replace364_0 -> 61 in the cache */
   /* replace364_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search365_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search365_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1215, 1101 },
      -1,
   } },

   /* replace365_0 -> 32 in the cache */
   /* replace365_1 -> 61 in the cache */
   /* replace365 -> 1205 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search366_0_0 -> 32 in the cache */
   /* search366_0 -> 1215 in the cache */
   /* search366_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1215, 1101 },
      -1,
   } },

   /* replace366_0 -> 32 in the cache */
   /* replace366_1 -> 61 in the cache */
   /* replace366 -> 1207 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search367_0_0 -> 32 in the cache */
   /* search367_0 -> 1215 in the cache */
   /* search367_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1215, 1101 },
      -1,
   } },

   /* replace367_0 -> 32 in the cache */
   /* replace367_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search368_0 -> 1101 in the cache */
   /* search368_1_0 -> 32 in the cache */
   /* search368_1 -> 1215 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1101, 1215 },
      -1,
   } },

   /* replace368_0 -> 61 in the cache */
   /* replace368_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search369_0_0 -> 32 in the cache */
   /* search369_0 -> 1215 in the cache */
   /* search369_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1215, 1101 },
      -1,
   } },

   /* replace369_0 -> 32 in the cache */
   /* replace369_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search370_0 -> 1101 in the cache */
   /* search370_1_0 -> 32 in the cache */
   /* search370_1 -> 1215 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1101, 1215 },
      -1,
   } },

   /* replace370_0 -> 61 in the cache */
   /* replace370_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search371_0 -> 113 in the cache */
   /* search371_1_0 -> 32 in the cache */
   /* search371_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace371_0 -> 32 in the cache */
   /* replace371_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search372_0_0_0 -> 32 in the cache */
   /* search372_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search372_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1228, 113 },
      -1,
   } },

   /* replace372_0 -> 32 in the cache */
   /* replace372_1 -> 113 in the cache */
   /* replace372 -> 1227 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search373_0 -> 113 in the cache */
   /* search373_1_0 -> 32 in the cache */
   /* search373_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace373_0 -> 32 in the cache */
   /* replace373_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search374_0_0_0 -> 32 in the cache */
   /* search374_0_0 -> 103 in the cache */
   /* search374_0 -> 1228 in the cache */
   /* search374_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1228, 113 },
      -1,
   } },

   /* replace374_0 -> 32 in the cache */
   /* replace374_1 -> 113 in the cache */
   /* replace374 -> 1231 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search375_0_0 -> 32 in the cache */
   /* search375_0_1 -> 113 in the cache */
   /* search375_0 -> 1146 in the cache */
   /* search375_1_0 -> 243 in the cache */
   /* search375_1_1 -> 32 in the cache */
   /* search375_1 -> 1079 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1146, 1079 },
      -1,
   } },

   /* replace375_0 -> 32 in the cache */
   /* replace375_1_0 -> 32 in the cache */
   /* replace375_1 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 219 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search376_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      0,
   } },
   /* search376_1_0 -> 1107 in the cache */
   /* search376_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1235, 1108 },
      -1,
   } },

   /* replace376_0_0 -> 739 in the cache */
   /* replace376_0_1 -> 1107 in the cache */
   /* replace376_0 -> 1111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1111 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search377_0_0_0 -> 739 in the cache */
   /* search377_0_0 -> 1235 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1235 },
      0,
   } },
   /* search377_1_0_0 -> 1107 in the cache */
   /* search377_1_0 -> 1108 in the cache */
   /* search377_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1238, 1115 },
      -1,
   } },

   /* replace377_0_0_0 -> 739 in the cache */
   /* replace377_0_0_1 -> 1107 in the cache */
   /* replace377_0_0 -> 1119 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1119 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1240 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search378_0_0 -> 739 in the cache */
   /* search378_0 -> 1235 in the cache */
   /* search378_1_0 -> 1107 in the cache */
   /* search378_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1235, 1108 },
      -1,
   } },

   /* replace378_0_0 -> 739 in the cache */
   /* replace378_0_1 -> 1107 in the cache */
   /* replace378_0 -> 1119 in the cache */
   /* replace378 -> 1240 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search379_0_0_0 -> 739 in the cache */
   /* search379_0_0 -> 1235 in the cache */
   /* search379_0 -> 1238 in the cache */
   /* search379_1_0_0 -> 1107 in the cache */
   /* search379_1_0 -> 1108 in the cache */
   /* search379_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1238, 1115 },
      -1,
   } },

   /* replace379_0_0_0 -> 739 in the cache */
   /* replace379_0_0_1 -> 1107 in the cache */
   /* replace379_0_0 -> 1111 in the cache */
   /* replace379_0 -> 1237 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1237 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search380_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search380_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1245, 800 },
      -1,
   } },

   /* replace380_0 -> 739 in the cache */
   /* replace380_1_0 -> 3 in the cache */
   /* replace380_1_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 272 },
      -1,
   } },
   /* replace380_2_0 -> 3 in the cache */
   /* replace380_2_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 1247, 1248 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search381_0_0 -> 0 in the cache */
   /* search381_0_1_0 -> 3 in the cache */
   /* search381_0_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1066 },
      0,
   } },
   /* search381_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1250, 258 },
      -1,
   } },

   /* replace381_0 -> 0 in the cache */
   /* replace381_1 -> 3 in the cache */
   /* replace381 -> 1028 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search382_0_0_0 -> 32 in the cache */
   /* search382_0_0 -> 103 in the cache */
   /* search382_0 -> 1228 in the cache */
   /* search382_1 -> 113 in the cache */
   /* search382 -> 1232 in the cache */

   /* replace382_0 -> 32 in the cache */
   /* replace382_1 -> 113 in the cache */
   /* replace382 -> 1231 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search383_0_0 -> 1090 in the cache */
   /* search383_0_1 -> 1087 in the cache */
   /* search383_0 -> 1091 in the cache */
   /* search383_1 -> 1090 in the cache */
   /* search383_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1091, 1090, 1087 },
      -1,
   } },

   /* replace383_0 -> 1087 in the cache */
   /* replace383_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search384_0_0 -> 0 in the cache */
   /* search384_0_1 -> 3 in the cache */
   /* search384_0 -> 1028 in the cache */
   /* search384_1 -> 3 in the cache */
   /* search384_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1028, 3, 0 },
      -1,
   } },

   /* replace384_0 -> 0 in the cache */
   /* replace384_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search385_0_0 -> 0 in the cache */
   /* search385_0_1 -> 3 in the cache */
   /* search385_0 -> 1025 in the cache */
   /* search385_1 -> 3 in the cache */
   /* search385_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1025, 3, 0 },
      -1,
   } },

   /* replace385_0 -> 0 in the cache */
   /* replace385_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search386_0_0 -> 1090 in the cache */
   /* search386_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },
   /* search386_1 -> 1090 in the cache */
   /* search386_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1258, 1090, 1087 },
      -1,
   } },

   /* replace386_0 -> 1087 in the cache */
   /* replace386_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search387_0_0 -> 1090 in the cache */
   /* search387_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },
   /* search387_1 -> 1090 in the cache */
   /* search387_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1261, 1090, 1087 },
      -1,
   } },

   /* replace387_0 -> 1087 in the cache */
   /* replace387_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search388_0_0 -> 0 in the cache */
   /* search388_0_1 -> 3 in the cache */
   /* search388_0 -> 1046 in the cache */
   /* search388_1 -> 3 in the cache */
   /* search388_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1046, 3, 0 },
      -1,
   } },

   /* replace388_0 -> 0 in the cache */
   /* replace388_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search389_0_0 -> 0 in the cache */
   /* search389_0_1 -> 3 in the cache */
   /* search389_0 -> 1040 in the cache */
   /* search389_1 -> 3 in the cache */
   /* search389_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1040, 3, 0 },
      -1,
   } },

   /* replace389_0 -> 0 in the cache */
   /* replace389_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search390_0_0 -> 1090 in the cache */
   /* search390_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },
   /* search390_1 -> 1090 in the cache */
   /* search390_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1268, 1090, 1087 },
      -1,
   } },

   /* replace390_0 -> 1087 in the cache */
   /* replace390_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search391_0_0 -> 1090 in the cache */
   /* search391_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },
   /* search391_1 -> 1090 in the cache */
   /* search391_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1271, 1090, 1087 },
      -1,
   } },

   /* replace391_0 -> 1087 in the cache */
   /* replace391_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search392_0_0 -> 0 in the cache */
   /* search392_0_1 -> 3 in the cache */
   /* search392_0 -> 1043 in the cache */
   /* search392_1 -> 3 in the cache */
   /* search392_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1043, 3, 0 },
      -1,
   } },

   /* replace392_0 -> 0 in the cache */
   /* replace392_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search393_0_0 -> 0 in the cache */
   /* search393_0_1 -> 3 in the cache */
   /* search393_0 -> 1037 in the cache */
   /* search393_1 -> 3 in the cache */
   /* search393_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1037, 3, 0 },
      -1,
   } },

   /* replace393_0 -> 0 in the cache */
   /* replace393_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search394_0_0 -> 1090 in the cache */
   /* search394_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1090, 1087 },
      -1,
   } },
   /* search394_1 -> 1090 in the cache */
   /* search394_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1278, 1090, 1087 },
      -1,
   } },

   /* replace394_0 -> 1087 in the cache */
   /* replace394_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 1087, 1090 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search395_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search395_1 -> 129 in the cache */
   /* search395_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1281, 129, 131 },
      -1,
   } },

   /* replace395_0_0 -> 32 in the cache */
   /* replace395_0_1 -> 61 in the cache */
   /* replace395_0 -> 1205 in the cache */
   /* replace395_1 -> 129 in the cache */
   /* replace395_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1205, 129, 131 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search396_0_0 -> 739 in the cache */
   /* search396_0 -> 1104 in the cache */
   /* search396_1 -> 129 in the cache */
   /* search396_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1104, 129, 131 },
      -1,
   } },

   /* replace396_0 -> 739 in the cache */
   /* replace396_1 -> 131 in the cache */
   /* replace396_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 131, 129 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search397_0 -> 739 in the cache */
   /* search397_1_0 -> 739 in the cache */
   /* search397_1_1 -> 152 in the cache */
   /* search397_1_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 152, 154 },
      -1,
   } },
   /* search397_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1286, 155 },
      -1,
   } },

   /* replace397_0 -> 739 in the cache */
   /* replace397_1 -> 152 in the cache */
   /* replace397_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 152, 155 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search398_0 -> 739 in the cache */
   /* search398_1 -> 152 in the cache */
   /* search398_2_0 -> 739 in the cache */
   /* search398_2_1 -> 154 in the cache */
   /* search398_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 152, 1289 },
      -1,
   } },

   /* replace398_0 -> 739 in the cache */
   /* replace398_1 -> 152 in the cache */
   /* replace398_2 -> 155 in the cache */
   /* replace398 -> 1288 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search399_0 -> 739 in the cache */
   /* search399_1_0 -> 1107 in the cache */
   /* search399_1_1 -> 732 in the cache */
   /* search399_1_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 732, 741 },
      -1,
   } },
   /* search399_2_0 -> 1107 in the cache */
   /* search399_2_1 -> 732 in the cache */
   /* search399_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 732, 743 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1291, 1292 },
      -1,
   } },

   /* replace399_0 -> 1107 in the cache */
   /* replace399_1 -> 732 in the cache */
   /* replace399_2_0 -> 739 in the cache */
   /* replace399_2_1 -> 741 in the cache */
   /* replace399_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 741, 743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 732, 1294 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search400_0 -> 739 in the cache */
   /* search400_1_0 -> 1107 in the cache */
   /* search400_1_1 -> 732 in the cache */
   /* search400_1_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 732, 741 },
      0,
   } },
   /* search400_2_0 -> 1107 in the cache */
   /* search400_2_1 -> 732 in the cache */
   /* search400_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 732, 743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1296, 1297 },
      -1,
   } },

   /* replace400_0 -> 1107 in the cache */
   /* replace400_1 -> 732 in the cache */
   /* replace400_2_0 -> 739 in the cache */
   /* replace400_2_1 -> 741 in the cache */
   /* replace400_2_2 -> 743 in the cache */
   /* replace400_2 -> 1294 in the cache */
   /* replace400 -> 1295 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search401_0 -> 739 in the cache */
   /* search401_1_0 -> 1107 in the cache */
   /* search401_1_1 -> 154 in the cache */
   /* search401_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 154, 155 },
      -1,
   } },
   /* search401_2_0 -> 1107 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search401_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 1300, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1299, 1301 },
      -1,
   } },

   /* replace401_0 -> 1107 in the cache */
   /* replace401_1_0 -> 739 in the cache */
   /* replace401_1_1 -> 154 in the cache */
   /* replace401_1_2 -> 1300 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 154, 1300 },
      -1,
   } },
   /* replace401_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 1303, 155 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search402_0 -> 739 in the cache */
   /* search402_1_0 -> 1107 in the cache */
   /* search402_1_1 -> 154 in the cache */
   /* search402_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 154, 155 },
      0,
   } },
   /* search402_2_0 -> 1107 in the cache */
   /* search402_2_1 -> 1300 in the cache */
   /* search402_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1107, 1300, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1305, 1306 },
      -1,
   } },

   /* replace402_0 -> 1107 in the cache */
   /* replace402_1_0 -> 739 in the cache */
   /* replace402_1_1 -> 154 in the cache */
   /* replace402_1_2 -> 1300 in the cache */
   /* replace402_1 -> 1303 in the cache */
   /* replace402_2 -> 155 in the cache */
   /* replace402 -> 1304 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search403_0 -> 739 in the cache */
   /* search403_1 -> 1209 in the cache */
   /* search403_2 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1209, 1107 },
      -1,
   } },

   /* replace403_0 -> 739 in the cache */
   /* replace403_1 -> 1107 in the cache */
   /* replace403 -> 1111 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search404_0 -> 739 in the cache */
   /* search404_1 -> 739 in the cache */
   /* search404_2 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 739, 1107 },
      -1,
   } },

   /* replace404_0 -> 739 in the cache */
   /* replace404_1 -> 1107 in the cache */
   /* replace404 -> 1111 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search405_0 -> 739 in the cache */
   /* search405_1 -> 1107 in the cache */
   /* search405_2 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1107, 1056 },
      -1,
   } },

   /* replace405_0 -> 739 in the cache */
   /* replace405_1 -> 1107 in the cache */
   /* replace405 -> 1119 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search406_0 -> 739 in the cache */
   /* search406_1 -> 1107 in the cache */
   /* search406_2 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1107, 739 },
      -1,
   } },

   /* replace406_0 -> 739 in the cache */
   /* replace406_1 -> 1107 in the cache */
   /* replace406 -> 1119 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search407_0 -> 32 in the cache */
   /* search407_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace407 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search408_0 -> 32 in the cache */
   /* search408_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace408 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search409_0 -> 32 in the cache */
   /* search409_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace409 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search410_0 -> 32 in the cache */
   /* search410_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace410 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search411_0 -> 32 in the cache */
   /* search411_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace411 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search412_0 -> 32 in the cache */
   /* search412_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace412 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search413_0 -> 32 in the cache */
   /* search413_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace413 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search414_0 -> 32 in the cache */
   /* search414_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace414 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search415_0 -> 32 in the cache */
   /* search415_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace415 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search416_0 -> 32 in the cache */
   /* search416_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace416 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search417_0_0 -> 0 in the cache */
   /* search417_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search417_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1322, 3 },
      -1,
   } },

   /* replace417_0 -> 0 in the cache */
   /* replace417_1 -> 3 in the cache */
   /* replace417 -> 1255 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search418_0_0 -> 0 in the cache */
   /* search418_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search418_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1324, 3 },
      -1,
   } },

   /* replace418_0 -> 0 in the cache */
   /* replace418_1 -> 3 in the cache */
   /* replace418 -> 1265 in the cache */

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search419_0_0 -> 0 in the cache */
   /* search419_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search419_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1326, 3 },
      -1,
   } },

   /* replace419_0 -> 0 in the cache */
   /* replace419_1 -> 3 in the cache */
   /* replace419 -> 1275 in the cache */

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search420_0_0 -> 0 in the cache */
   /* search420_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search420_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1328, 3 },
      -1,
   } },

   /* replace420_0 -> 0 in the cache */
   /* replace420_1 -> 3 in the cache */
   /* replace420 -> 1257 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search421_0_0 -> 0 in the cache */
   /* search421_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search421_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1330, 3 },
      -1,
   } },

   /* replace421_0 -> 0 in the cache */
   /* replace421_1 -> 3 in the cache */
   /* replace421 -> 1267 in the cache */

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search422_0_0 -> 0 in the cache */
   /* search422_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search422_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1332, 3 },
      -1,
   } },

   /* replace422_0 -> 0 in the cache */
   /* replace422_1 -> 3 in the cache */
   /* replace422 -> 1277 in the cache */

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search423_0_0_0 -> 128 in the cache */
   /* search423_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search423_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1334, 131 },
      -1,
   } },
   /* search423_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1335, 128 },
      -1,
   } },

   /* replace423_0_0 -> 128 in the cache */
   /* replace423_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace423_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1337, 131 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search424_0_0_0 -> 128 in the cache */
   /* search424_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search424_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1339, 131 },
      -1,
   } },
   /* search424_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1340, 128 },
      -1,
   } },

   /* replace424_0_0 -> 128 in the cache */
   /* replace424_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace424_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1342, 131 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search425_0_0_0 -> 128 in the cache */
   /* search425_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search425_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1344, 131 },
      -1,
   } },
   /* search425_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1345, 128 },
      -1,
   } },

   /* replace425_0_0 -> 128 in the cache */
   /* replace425_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace425_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1347, 131 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search426_0_0_0 -> 128 in the cache */
   /* search426_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search426_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1349, 131 },
      -1,
   } },
   /* search426_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1350, 128 },
      -1,
   } },

   /* replace426_0_0 -> 128 in the cache */
   /* replace426_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace426_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1352, 131 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search427_0_0_0 -> 128 in the cache */
   /* search427_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search427_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1354, 131 },
      -1,
   } },
   /* search427_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1355, 128 },
      -1,
   } },

   /* replace427_0_0 -> 128 in the cache */
   /* replace427_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace427_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1357, 131 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search428_0_0_0 -> 128 in the cache */
   /* search428_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search428_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1359, 131 },
      -1,
   } },
   /* search428_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1360, 128 },
      -1,
   } },

   /* replace428_0_0 -> 128 in the cache */
   /* replace428_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace428_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1362, 131 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search429_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search429_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1364, 1365 },
      -1,
   } },

   /* replace429_0 -> 739 in the cache */
   /* replace429_1 -> 1107 in the cache */
   /* replace429 -> 1135 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search430_0_0 -> 739 in the cache */
   /* search430_0 -> 1364 in the cache */
   /* search430_1_0 -> 1107 in the cache */
   /* search430_1 -> 1365 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1364, 1365 },
      -1,
   } },

   /* replace430_0 -> 739 in the cache */
   /* replace430_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 739, 1107 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search431_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search431_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1369, 1370 },
      -1,
   } },

   /* replace431_0 -> 739 in the cache */
   /* replace431_1 -> 1107 in the cache */
   /* replace431 -> 1135 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search432_0_0 -> 739 in the cache */
   /* search432_0 -> 1369 in the cache */
   /* search432_1_0 -> 1107 in the cache */
   /* search432_1 -> 1370 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1369, 1370 },
      -1,
   } },

   /* replace432_0 -> 739 in the cache */
   /* replace432_1 -> 1107 in the cache */
   /* replace432 -> 1368 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search433_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search433_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1373, 1374 },
      -1,
   } },

   /* replace433_0 -> 739 in the cache */
   /* replace433_1 -> 1107 in the cache */
   /* replace433 -> 1135 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search434_0_0 -> 739 in the cache */
   /* search434_0 -> 1373 in the cache */
   /* search434_1_0 -> 1107 in the cache */
   /* search434_1 -> 1374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1373, 1374 },
      -1,
   } },

   /* replace434_0 -> 739 in the cache */
   /* replace434_1 -> 1107 in the cache */
   /* replace434 -> 1368 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search435_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search435_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1377, 1378 },
      -1,
   } },

   /* replace435_0 -> 739 in the cache */
   /* replace435_1 -> 1107 in the cache */
   /* replace435 -> 1135 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search436_0_0 -> 739 in the cache */
   /* search436_0 -> 1377 in the cache */
   /* search436_1_0 -> 1107 in the cache */
   /* search436_1 -> 1378 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1377, 1378 },
      -1,
   } },

   /* replace436_0 -> 739 in the cache */
   /* replace436_1 -> 1107 in the cache */
   /* replace436 -> 1368 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search437_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search437_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1381, 1382 },
      -1,
   } },

   /* replace437_0 -> 739 in the cache */
   /* replace437_1 -> 1107 in the cache */
   /* replace437 -> 1135 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search438_0_0 -> 739 in the cache */
   /* search438_0 -> 1381 in the cache */
   /* search438_1_0 -> 1107 in the cache */
   /* search438_1 -> 1382 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1381, 1382 },
      -1,
   } },

   /* replace438_0 -> 739 in the cache */
   /* replace438_1 -> 1107 in the cache */
   /* replace438 -> 1368 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search439_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search439_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1385, 1386 },
      -1,
   } },

   /* replace439_0 -> 739 in the cache */
   /* replace439_1 -> 1107 in the cache */
   /* replace439 -> 1135 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search440_0_0 -> 739 in the cache */
   /* search440_0 -> 1385 in the cache */
   /* search440_1_0 -> 1107 in the cache */
   /* search440_1 -> 1386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1385, 1386 },
      -1,
   } },

   /* replace440_0 -> 739 in the cache */
   /* replace440_1 -> 1107 in the cache */
   /* replace440 -> 1368 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search441_0_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 739 },
      -1,
   } },
   /* search441_1_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1389, 1390 },
      -1,
   } },

   /* replace441_0 -> 739 in the cache */
   /* replace441_1 -> 1107 in the cache */
   /* replace441 -> 1135 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search442_0_0 -> 739 in the cache */
   /* search442_0 -> 1389 in the cache */
   /* search442_1_0 -> 1107 in the cache */
   /* search442_1 -> 1390 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1389, 1390 },
      -1,
   } },

   /* replace442_0 -> 739 in the cache */
   /* replace442_1 -> 1107 in the cache */
   /* replace442 -> 1368 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search443_0 -> 6 in the cache */
   /* search443_1_0_0 -> 6 in the cache */
   /* search443_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1393 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1394 },
      -1,
   } },

   /* replace443_0 -> 6 in the cache */
   /* replace443_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 814 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search444_0_0 -> 6 in the cache */
   /* search444_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search444_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1397, 814 },
      -1,
   } },

   /* replace444_0 -> 6 in the cache */
   /* replace444_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 814 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search445_0_0 -> 6 in the cache */
   /* search445_0_1 -> 7 in the cache */
   /* search445_0 -> 1397 in the cache */
   /* search445_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1397, 7 },
      -1,
   } },

   /* replace445_0 -> 6 in the cache */
   /* replace445_1 -> 814 in the cache */
   /* replace445 -> 1399 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search446_0_0 -> 6 in the cache */
   /* search446_0_1 -> 7 in the cache */
   /* search446_0 -> 1397 in the cache */
   /* search446_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1397, 814 },
      -1,
   } },

   /* replace446_0 -> 6 in the cache */
   /* replace446_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 814 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search447_0_0 -> 6 in the cache */
   /* search447_0_1 -> 7 in the cache */
   /* search447_0 -> 1397 in the cache */
   /* search447_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1397, 7 },
      -1,
   } },

   /* replace447_0 -> 6 in the cache */
   /* replace447_1 -> 814 in the cache */
   /* replace447 -> 1402 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search448_0_0 -> 6 in the cache */
   /* search448_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search448_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1404, 814 },
      -1,
   } },

   /* replace448_0 -> 6 in the cache */
   /* replace448_1 -> 814 in the cache */
   /* replace448 -> 1402 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search449_0_0 -> 6 in the cache */
   /* search449_0_1 -> 9 in the cache */
   /* search449_0 -> 1404 in the cache */
   /* search449_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1404, 814 },
      -1,
   } },

   /* replace449_0 -> 6 in the cache */
   /* replace449_1 -> 814 in the cache */
   /* replace449 -> 1399 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search450_0_0 -> 6 in the cache */
   /* search450_0_1 -> 9 in the cache */
   /* search450_0 -> 1404 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1404, 1407 },
      -1,
   } },

   /* replace450_0 -> 6 in the cache */
   /* replace450_1 -> 814 in the cache */
   /* replace450 -> 1402 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search451_0_0 -> 6 in the cache */
   /* search451_0_1 -> 9 in the cache */
   /* search451_0 -> 1404 in the cache */
   /* search451_1 -> 1407 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1404, 1407 },
      -1,
   } },

   /* replace451_0 -> 6 in the cache */
   /* replace451_1 -> 814 in the cache */
   /* replace451 -> 1399 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search452_0_0 -> 6 in the cache */
   /* search452_0_1 -> 9 in the cache */
   /* search452_0 -> 1393 in the cache */
   /* search452_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1393, 814 },
      -1,
   } },

   /* replace452_0 -> 6 in the cache */
   /* replace452_1 -> 814 in the cache */
   /* replace452 -> 1402 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search453_0_0 -> 6 in the cache */
   /* search453_0_1 -> 9 in the cache */
   /* search453_0 -> 1393 in the cache */
   /* search453_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1393, 814 },
      -1,
   } },

   /* replace453_0 -> 6 in the cache */
   /* replace453_1 -> 814 in the cache */
   /* replace453 -> 1399 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search454_0_0 -> 6 in the cache */
   /* search454_0_1 -> 9 in the cache */
   /* search454_0 -> 1393 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1393, 1412 },
      -1,
   } },

   /* replace454_0 -> 6 in the cache */
   /* replace454_1 -> 814 in the cache */
   /* replace454 -> 1402 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search455_0_0 -> 6 in the cache */
   /* search455_0_1 -> 9 in the cache */
   /* search455_0 -> 1393 in the cache */
   /* search455_1 -> 1412 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1393, 1412 },
      -1,
   } },

   /* replace455_0 -> 6 in the cache */
   /* replace455_1 -> 814 in the cache */
   /* replace455 -> 1399 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search456_0 -> 11 in the cache */
   /* search456_1_0_0 -> 11 in the cache */
   /* search456_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1416 },
      -1,
   } },

   /* replace456_0 -> 11 in the cache */
   /* replace456_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 835 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search457_0_0 -> 11 in the cache */
   /* search457_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search457_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1419, 835 },
      -1,
   } },

   /* replace457_0 -> 11 in the cache */
   /* replace457_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 835 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search458_0_0 -> 11 in the cache */
   /* search458_0_1 -> 12 in the cache */
   /* search458_0 -> 1419 in the cache */
   /* search458_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1419, 12 },
      -1,
   } },

   /* replace458_0 -> 11 in the cache */
   /* replace458_1 -> 835 in the cache */
   /* replace458 -> 1421 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search459_0_0 -> 11 in the cache */
   /* search459_0_1 -> 12 in the cache */
   /* search459_0 -> 1419 in the cache */
   /* search459_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1419, 835 },
      -1,
   } },

   /* replace459_0 -> 11 in the cache */
   /* replace459_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 835 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search460_0_0 -> 11 in the cache */
   /* search460_0_1 -> 12 in the cache */
   /* search460_0 -> 1419 in the cache */
   /* search460_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1419, 12 },
      -1,
   } },

   /* replace460_0 -> 11 in the cache */
   /* replace460_1 -> 835 in the cache */
   /* replace460 -> 1424 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search461_0_0 -> 11 in the cache */
   /* search461_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search461_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1426, 835 },
      -1,
   } },

   /* replace461_0 -> 11 in the cache */
   /* replace461_1 -> 835 in the cache */
   /* replace461 -> 1424 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search462_0_0 -> 11 in the cache */
   /* search462_0_1 -> 14 in the cache */
   /* search462_0 -> 1426 in the cache */
   /* search462_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1426, 835 },
      -1,
   } },

   /* replace462_0 -> 11 in the cache */
   /* replace462_1 -> 835 in the cache */
   /* replace462 -> 1421 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search463_0_0 -> 11 in the cache */
   /* search463_0_1 -> 14 in the cache */
   /* search463_0 -> 1426 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1426, 1429 },
      -1,
   } },

   /* replace463_0 -> 11 in the cache */
   /* replace463_1 -> 835 in the cache */
   /* replace463 -> 1424 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search464_0_0 -> 11 in the cache */
   /* search464_0_1 -> 14 in the cache */
   /* search464_0 -> 1426 in the cache */
   /* search464_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1426, 1429 },
      -1,
   } },

   /* replace464_0 -> 11 in the cache */
   /* replace464_1 -> 835 in the cache */
   /* replace464 -> 1421 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search465_0_0 -> 11 in the cache */
   /* search465_0_1 -> 14 in the cache */
   /* search465_0 -> 1415 in the cache */
   /* search465_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1415, 835 },
      -1,
   } },

   /* replace465_0 -> 11 in the cache */
   /* replace465_1 -> 835 in the cache */
   /* replace465 -> 1424 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search466_0_0 -> 11 in the cache */
   /* search466_0_1 -> 14 in the cache */
   /* search466_0 -> 1415 in the cache */
   /* search466_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1415, 835 },
      -1,
   } },

   /* replace466_0 -> 11 in the cache */
   /* replace466_1 -> 835 in the cache */
   /* replace466 -> 1421 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search467_0_0 -> 11 in the cache */
   /* search467_0_1 -> 14 in the cache */
   /* search467_0 -> 1415 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1415, 1434 },
      -1,
   } },

   /* replace467_0 -> 11 in the cache */
   /* replace467_1 -> 835 in the cache */
   /* replace467 -> 1424 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search468_0_0 -> 11 in the cache */
   /* search468_0_1 -> 14 in the cache */
   /* search468_0 -> 1415 in the cache */
   /* search468_1 -> 1434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1415, 1434 },
      -1,
   } },

   /* replace468_0 -> 11 in the cache */
   /* replace468_1 -> 835 in the cache */
   /* replace468 -> 1421 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search469_0 -> 16 in the cache */
   /* search469_1_0_0 -> 16 in the cache */
   /* search469_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1437 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1438 },
      -1,
   } },

   /* replace469_0 -> 16 in the cache */
   /* replace469_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search470_0_0 -> 16 in the cache */
   /* search470_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search470_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1441, 124 },
      -1,
   } },

   /* replace470_0 -> 16 in the cache */
   /* replace470_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search471_0_0 -> 16 in the cache */
   /* search471_0_1 -> 17 in the cache */
   /* search471_0 -> 1441 in the cache */
   /* search471_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1441, 17 },
      -1,
   } },

   /* replace471_0 -> 16 in the cache */
   /* replace471_1 -> 124 in the cache */
   /* replace471 -> 1443 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search472_0_0 -> 16 in the cache */
   /* search472_0_1 -> 17 in the cache */
   /* search472_0 -> 1441 in the cache */
   /* search472_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1441, 124 },
      -1,
   } },

   /* replace472_0 -> 16 in the cache */
   /* replace472_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search473_0_0 -> 16 in the cache */
   /* search473_0_1 -> 17 in the cache */
   /* search473_0 -> 1441 in the cache */
   /* search473_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1441, 17 },
      -1,
   } },

   /* replace473_0 -> 16 in the cache */
   /* replace473_1 -> 124 in the cache */
   /* replace473 -> 1446 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search474_0_0 -> 16 in the cache */
   /* search474_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search474_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1448, 124 },
      -1,
   } },

   /* replace474_0 -> 16 in the cache */
   /* replace474_1 -> 124 in the cache */
   /* replace474 -> 1446 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search475_0_0 -> 16 in the cache */
   /* search475_0_1 -> 19 in the cache */
   /* search475_0 -> 1448 in the cache */
   /* search475_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1448, 124 },
      -1,
   } },

   /* replace475_0 -> 16 in the cache */
   /* replace475_1 -> 124 in the cache */
   /* replace475 -> 1443 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search476_0_0 -> 16 in the cache */
   /* search476_0_1 -> 19 in the cache */
   /* search476_0 -> 1448 in the cache */
   /* search476_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1448, 398 },
      -1,
   } },

   /* replace476_0 -> 16 in the cache */
   /* replace476_1 -> 124 in the cache */
   /* replace476 -> 1446 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search477_0_0 -> 16 in the cache */
   /* search477_0_1 -> 19 in the cache */
   /* search477_0 -> 1448 in the cache */
   /* search477_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1448, 398 },
      -1,
   } },

   /* replace477_0 -> 16 in the cache */
   /* replace477_1 -> 124 in the cache */
   /* replace477 -> 1443 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search478_0_0 -> 16 in the cache */
   /* search478_0_1 -> 19 in the cache */
   /* search478_0 -> 1437 in the cache */
   /* search478_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1437, 124 },
      -1,
   } },

   /* replace478_0 -> 16 in the cache */
   /* replace478_1 -> 124 in the cache */
   /* replace478 -> 1446 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search479_0_0 -> 16 in the cache */
   /* search479_0_1 -> 19 in the cache */
   /* search479_0 -> 1437 in the cache */
   /* search479_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1437, 124 },
      -1,
   } },

   /* replace479_0 -> 16 in the cache */
   /* replace479_1 -> 124 in the cache */
   /* replace479 -> 1443 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search480_0_0 -> 16 in the cache */
   /* search480_0_1 -> 19 in the cache */
   /* search480_0 -> 1437 in the cache */
   /* search480_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1437, 126 },
      -1,
   } },

   /* replace480_0 -> 16 in the cache */
   /* replace480_1 -> 124 in the cache */
   /* replace480 -> 1446 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search481_0_0 -> 16 in the cache */
   /* search481_0_1 -> 19 in the cache */
   /* search481_0 -> 1437 in the cache */
   /* search481_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1437, 126 },
      -1,
   } },

   /* replace481_0 -> 16 in the cache */
   /* replace481_1 -> 124 in the cache */
   /* replace481 -> 1443 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search482_0 -> 21 in the cache */
   /* search482_1_0_0 -> 21 in the cache */
   /* search482_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1457 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1458 },
      -1,
   } },

   /* replace482_0 -> 21 in the cache */
   /* replace482_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 876 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search483_0_0 -> 21 in the cache */
   /* search483_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search483_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1461, 876 },
      -1,
   } },

   /* replace483_0 -> 21 in the cache */
   /* replace483_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 876 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search484_0_0 -> 21 in the cache */
   /* search484_0_1 -> 22 in the cache */
   /* search484_0 -> 1461 in the cache */
   /* search484_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1461, 22 },
      -1,
   } },

   /* replace484_0 -> 21 in the cache */
   /* replace484_1 -> 876 in the cache */
   /* replace484 -> 1463 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search485_0_0 -> 21 in the cache */
   /* search485_0_1 -> 22 in the cache */
   /* search485_0 -> 1461 in the cache */
   /* search485_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1461, 876 },
      -1,
   } },

   /* replace485_0 -> 21 in the cache */
   /* replace485_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 876 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search486_0_0 -> 21 in the cache */
   /* search486_0_1 -> 22 in the cache */
   /* search486_0 -> 1461 in the cache */
   /* search486_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1461, 22 },
      -1,
   } },

   /* replace486_0 -> 21 in the cache */
   /* replace486_1 -> 876 in the cache */
   /* replace486 -> 1466 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search487_0_0 -> 21 in the cache */
   /* search487_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search487_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1468, 876 },
      -1,
   } },

   /* replace487_0 -> 21 in the cache */
   /* replace487_1 -> 876 in the cache */
   /* replace487 -> 1466 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search488_0_0 -> 21 in the cache */
   /* search488_0_1 -> 24 in the cache */
   /* search488_0 -> 1468 in the cache */
   /* search488_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1468, 876 },
      -1,
   } },

   /* replace488_0 -> 21 in the cache */
   /* replace488_1 -> 876 in the cache */
   /* replace488 -> 1463 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search489_0_0 -> 21 in the cache */
   /* search489_0_1 -> 24 in the cache */
   /* search489_0 -> 1468 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1468, 1471 },
      -1,
   } },

   /* replace489_0 -> 21 in the cache */
   /* replace489_1 -> 876 in the cache */
   /* replace489 -> 1466 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search490_0_0 -> 21 in the cache */
   /* search490_0_1 -> 24 in the cache */
   /* search490_0 -> 1468 in the cache */
   /* search490_1 -> 1471 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1468, 1471 },
      -1,
   } },

   /* replace490_0 -> 21 in the cache */
   /* replace490_1 -> 876 in the cache */
   /* replace490 -> 1463 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search491_0_0 -> 21 in the cache */
   /* search491_0_1 -> 24 in the cache */
   /* search491_0 -> 1457 in the cache */
   /* search491_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1457, 876 },
      -1,
   } },

   /* replace491_0 -> 21 in the cache */
   /* replace491_1 -> 876 in the cache */
   /* replace491 -> 1466 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search492_0_0 -> 21 in the cache */
   /* search492_0_1 -> 24 in the cache */
   /* search492_0 -> 1457 in the cache */
   /* search492_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1457, 876 },
      -1,
   } },

   /* replace492_0 -> 21 in the cache */
   /* replace492_1 -> 876 in the cache */
   /* replace492 -> 1463 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search493_0_0 -> 21 in the cache */
   /* search493_0_1 -> 24 in the cache */
   /* search493_0 -> 1457 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1457, 1476 },
      -1,
   } },

   /* replace493_0 -> 21 in the cache */
   /* replace493_1 -> 876 in the cache */
   /* replace493 -> 1466 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search494_0_0 -> 21 in the cache */
   /* search494_0_1 -> 24 in the cache */
   /* search494_0 -> 1457 in the cache */
   /* search494_1 -> 1476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1457, 1476 },
      -1,
   } },

   /* replace494_0 -> 21 in the cache */
   /* replace494_1 -> 876 in the cache */
   /* replace494 -> 1463 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search495_0 -> 32 in the cache */
   /* search495_1_0 -> 32 in the cache */
   /* search495_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace495_0_0 -> 32 in the cache */
   /* replace495_0 -> 103 in the cache */
   /* replace495 -> 1228 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search496_0 -> 32 in the cache */
   /* search496_1_0 -> 32 in the cache */
   /* search496_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace496_0_0 -> 32 in the cache */
   /* replace496_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search497_0 -> 32 in the cache */
   /* search497_1_0_0 -> 32 in the cache */
   /* search497_1_0 -> 103 in the cache */
   /* search497_1 -> 1228 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1228 },
      -1,
   } },

   /* replace497_0_0 -> 32 in the cache */
   /* replace497_0 -> 103 in the cache */
   /* replace497 -> 1228 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search498_0 -> 32 in the cache */
   /* search498_1_0_0 -> 32 in the cache */
   /* search498_1_0 -> 106 in the cache */
   /* search498_1 -> 1481 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1481 },
      -1,
   } },

   /* replace498_0_0 -> 32 in the cache */
   /* replace498_0 -> 106 in the cache */
   /* replace498 -> 1481 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search499_0 -> 32 in the cache */
   /* search499_1_0 -> 32 in the cache */
   /* search499_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace499 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search500_0 -> 32 in the cache */
   /* search500_1_0 -> 32 in the cache */
   /* search500_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace500 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search501_0 -> 32 in the cache */
   /* search501_1_0_0 -> 32 in the cache */
   /* search501_1_0 -> 103 in the cache */
   /* search501_1 -> 1228 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1228 },
      -1,
   } },

   /* replace501 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search502_0 -> 32 in the cache */
   /* search502_1_0_0 -> 32 in the cache */
   /* search502_1_0 -> 106 in the cache */
   /* search502_1 -> 1481 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1481 },
      -1,
   } },

   /* replace502 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search503_0 -> 32 in the cache */
   /* search503_1_0 -> 32 in the cache */
   /* search503_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace503_0 -> 32 in the cache */
   /* replace503 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search504_0 -> 32 in the cache */
   /* search504_1_0 -> 32 in the cache */
   /* search504_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace504_0 -> 32 in the cache */
   /* replace504 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search505_0 -> 32 in the cache */
   /* search505_1_0 -> 32 in the cache */
   /* search505_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace505_0 -> 32 in the cache */
   /* replace505 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search506_0 -> 32 in the cache */
   /* search506_1_0 -> 32 in the cache */
   /* search506_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace506_0 -> 32 in the cache */
   /* replace506 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search507_0_0 -> 32 in the cache */
   /* search507_0 -> 103 in the cache */
   /* search507_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace507_0 -> 32 in the cache */
   /* replace507 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search508_0_0 -> 32 in the cache */
   /* search508_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search508_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1493, 243 },
      -1,
   } },

   /* replace508_0 -> 32 in the cache */
   /* replace508 -> 219 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search509_0_0 -> 32 in the cache */
   /* search509_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 243 },
      -1,
   } },
   /* search509_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1495, 113 },
      -1,
   } },

   /* replace509_0 -> 32 in the cache */
   /* replace509 -> 219 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search510_0_0 -> 32 in the cache */
   /* search510_0_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 249 },
      -1,
   } },
   /* search510_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1497, 113 },
      -1,
   } },

   /* replace510_0_0_0 -> 32 in the cache */
   /* replace510_0_0 -> 98 in the cache */
   /* replace510_0 -> 220 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 220 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search511_0_0 -> 32 in the cache */
   /* search511_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search511_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1500, 249 },
      -1,
   } },

   /* replace511_0_0_0 -> 32 in the cache */
   /* replace511_0_0 -> 98 in the cache */
   /* replace511_0 -> 220 in the cache */
   /* replace511 -> 1499 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search512_0_0 -> 32 in the cache */
   /* search512_0 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 252 },
      -1,
   } },

   /* replace512_0_0 -> 113 in the cache */
   /* replace512_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1503 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search513_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1505 },
      -1,
   } },

   /* replace513_0 -> 32 in the cache */
   /* replace513 -> 1505 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search514_0 -> 32 in the cache */
   /* search514 -> 219 in the cache */

   /* replace514_0_0 -> 32 in the cache */
   /* replace514_0_1 -> 113 in the cache */
   /* replace514_0 -> 1493 in the cache */
   /* replace514_1 -> 243 in the cache */
   /* replace514 -> 1494 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search515_0_0 -> 32 in the cache */
   /* search515_0 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 219 },
      -1,
   } },

   /* replace515_0 -> 32 in the cache */
   /* replace515 -> 219 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search516_0_0_0 -> 0 in the cache */
   /* search516_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1508 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1509 },
      -1,
   } },

   /* replace516_0_0_0 -> 0 in the cache */
   /* replace516_0_0 -> 214 in the cache */
   /* replace516_0_1_0 -> 3 in the cache */
   /* replace516_0_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 214, 1066 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1511 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search517_0_0_0 -> 0 in the cache */
   /* search517_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1513 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1514 },
      -1,
   } },

   /* replace517_0_0_0 -> 0 in the cache */
   /* replace517_0_0 -> 214 in the cache */
   /* replace517_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 214, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1516 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search518_0_0_0 -> 16 in the cache */
   /* search518_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1518 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1519 },
      -1,
   } },

   /* replace518_0_0_0 -> 16 in the cache */
   /* replace518_0_0 -> 282 in the cache */
   /* replace518_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 282, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1521 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search519_0_0_0 -> 0 in the cache */
   /* search519_0_0_1 -> 3 in the cache */
   /* search519_0_0 -> 1513 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1513 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1523 },
      -1,
   } },

   /* replace519_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace519_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1525, 1526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1527 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search520_0_0_0_0 -> 128 in the cache */
   /* search520_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search520_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1529, 131 },
      -1,
   } },
   /* search520_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1530, 129 },
      -1,
   } },
   /* search520_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1531, 131 },
      -1,
   } },

   /* replace520_0_0 -> 128 in the cache */
   /* replace520_0_1 -> 129 in the cache */
   /* replace520_0 -> 1337 in the cache */
   /* replace520_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1337, 131 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search521_0_0_0_0 -> 128 in the cache */
   /* search521_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search521_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1534, 131 },
      -1,
   } },
   /* search521_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1535, 129 },
      -1,
   } },
   /* search521_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1536, 131 },
      -1,
   } },

   /* replace521_0_0 -> 128 in the cache */
   /* replace521_0_1 -> 129 in the cache */
   /* replace521_0 -> 1347 in the cache */
   /* replace521_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1347, 131 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search522_0_0_0_0 -> 128 in the cache */
   /* search522_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search522_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1539, 131 },
      -1,
   } },
   /* search522_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1540, 129 },
      -1,
   } },
   /* search522_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1541, 131 },
      -1,
   } },

   /* replace522_0_0 -> 128 in the cache */
   /* replace522_0_1 -> 129 in the cache */
   /* replace522_0 -> 1342 in the cache */
   /* replace522_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1342, 131 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search523_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1544, 1545 },
      -1,
   } },

   /* replace523_0_0 -> 0 in the cache */
   /* replace523_0_1 -> 3 in the cache */
   /* replace523_0 -> 1255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1255 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search524_0_0 -> 0 in the cache */
   /* search524_0 -> 1544 in the cache */
   /* search524_1 -> 1545 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1544, 1545 },
      -1,
   } },

   /* replace524_0_0 -> 0 in the cache */
   /* replace524_0_1 -> 3 in the cache */
   /* replace524_0 -> 1257 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1257 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search525_0_0_0 -> 1090 in the cache */
   /* search525_0_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1090, 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1550 },
      -1,
   } },
   /* search525_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1551, 1090 },
      -1,
   } },

   /* replace525_0_0 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1090 },
      -1,
   } },
   /* replace525_1_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1553, 1554 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search526_0_0_0 -> 1090 in the cache */
   /* search526_0_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1090, 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1556 },
      -1,
   } },
   /* search526_1 -> 1090 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1557, 1090 },
      -1,
   } },

   /* replace526_0_0_0 -> 1090 in the cache */
   /* replace526_0_0 -> 1553 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1553 },
      -1,
   } },
   /* replace526_1_0 -> 1087 in the cache */
   /* replace526_1 -> 1554 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1559, 1554 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1561 },
      -1,
   } },
   /* search527_0_1 -> 1545 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1562, 1545 },
      0,
   } },
   /* search527_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1563, 258 },
      -1,
   } },

   /* replace527_0_0_0 -> 0 in the cache */
   /* replace527_0_0 -> 214 in the cache */
   /* replace527_0_1 -> 3 in the cache */
   /* replace527_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search528_0_0_0 -> 32 in the cache */
   /* search528_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1566, 1567 },
      -1,
   } },
   /* search528_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1568, 61 },
      -1,
   } },

   /* replace528_0_0 -> 32 in the cache */
   /* replace528_0_1 -> 61 in the cache */
   /* replace528_0 -> 1566 in the cache */
   /* replace528_1 -> 1567 in the cache */
   /* replace528 -> 1568 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search529_0_0 -> 128 in the cache */
   /* search529_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search529_1_0 -> 128 in the cache */
   /* search529_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1570, 1571 },
      -1,
   } },

   /* replace529_0 -> 128 in the cache */
   /* replace529_1_0 -> 129 in the cache */
   /* replace529_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1573 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search530_0_0 -> 0 in the cache */
   /* search530_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 686 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search530_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1575, 1577 },
      -1,
   } },

   /* replace530_0_0 -> 0 in the cache */
   /* replace530_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace530_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1579, 686 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search531_0_0 -> 128 in the cache */
   /* search531_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search531_1_0 -> 128 in the cache */
   /* search531_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1581, 1582 },
      -1,
   } },

   /* replace531_0 -> 128 in the cache */
   /* replace531_1_0 -> 129 in the cache */
   /* replace531_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1584 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search532_0_0 -> 0 in the cache */
   /* search532_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search532_1_0 -> 1576 in the cache */
   /* search532_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1586, 1587 },
      -1,
   } },

   /* replace532_0_0 -> 0 in the cache */
   /* replace532_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace532_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1589, 686 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search533_0_0 -> 128 in the cache */
   /* search533_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 285 },
      -1,
   } },
   /* search533_1_0 -> 128 in the cache */
   /* search533_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1591, 1592 },
      -1,
   } },

   /* replace533_0 -> 128 in the cache */
   /* replace533_1_0 -> 129 in the cache */
   /* replace533_1_1 -> 131 in the cache */
   /* replace533_1 -> 1573 in the cache */
   /* replace533 -> 1574 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search534_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1594, 686 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search534_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1596, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1595, 1597 },
      -1,
   } },

   /* replace534_0_0 -> 0 in the cache */
   /* replace534_0_1 -> 1576 in the cache */
   /* replace534_0 -> 1579 in the cache */
   /* replace534_1 -> 686 in the cache */
   /* replace534 -> 1580 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search535_0_0 -> 128 in the cache */
   /* search535_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 285 },
      -1,
   } },
   /* search535_1_0 -> 128 in the cache */
   /* search535_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1599, 1600 },
      -1,
   } },

   /* replace535_0 -> 128 in the cache */
   /* replace535_1_0 -> 129 in the cache */
   /* replace535_1_1 -> 131 in the cache */
   /* replace535_1 -> 1584 in the cache */
   /* replace535 -> 1585 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search536_0_0 -> 1594 in the cache */
   /* search536_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1594, 686 },
      -1,
   } },
   /* search536_1_0 -> 1596 in the cache */
   /* search536_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1596, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1602, 1603 },
      -1,
   } },

   /* replace536_0_0 -> 0 in the cache */
   /* replace536_0_1 -> 1576 in the cache */
   /* replace536_0 -> 1589 in the cache */
   /* replace536_1 -> 686 in the cache */
   /* replace536 -> 1590 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search537_0_0 -> 128 in the cache */
   /* search537_0_1 -> 129 in the cache */
   /* search537_0 -> 1570 in the cache */
   /* search537_1_0 -> 128 in the cache */
   /* search537_1_1 -> 131 in the cache */
   /* search537_1 -> 1571 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1570, 1571 },
      -1,
   } },

   /* replace537_0 -> 128 in the cache */
   /* replace537_1_0 -> 129 in the cache */
   /* replace537_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1606 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search538_0_0 -> 0 in the cache */
   /* search538_0_1 -> 686 in the cache */
   /* search538_0 -> 1575 in the cache */
   /* search538_1_0 -> 1576 in the cache */
   /* search538_1_1 -> 686 in the cache */
   /* search538_1 -> 1577 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1575, 1577 },
      -1,
   } },

   /* replace538_0_0 -> 0 in the cache */
   /* replace538_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace538_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1609, 686 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search539_0_0 -> 128 in the cache */
   /* search539_0_1 -> 129 in the cache */
   /* search539_0 -> 1581 in the cache */
   /* search539_1_0 -> 128 in the cache */
   /* search539_1_1 -> 131 in the cache */
   /* search539_1 -> 1582 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1581, 1582 },
      -1,
   } },

   /* replace539_0 -> 128 in the cache */
   /* replace539_1_0 -> 129 in the cache */
   /* replace539_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1612 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search540_0_0 -> 0 in the cache */
   /* search540_0_1 -> 686 in the cache */
   /* search540_0 -> 1586 in the cache */
   /* search540_1_0 -> 1576 in the cache */
   /* search540_1_1 -> 686 in the cache */
   /* search540_1 -> 1587 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1586, 1587 },
      -1,
   } },

   /* replace540_0_0 -> 0 in the cache */
   /* replace540_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace540_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1615, 686 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search541_0_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 1617 },
      -1,
   } },
   /* search541_1_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 1619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1618, 1620 },
      -1,
   } },

   /* replace541_0 -> 128 in the cache */
   /* replace541_1_0 -> 129 in the cache */
   /* replace541_1_1 -> 131 in the cache */
   /* replace541_1 -> 1606 in the cache */
   /* replace541 -> 1607 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search542_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1622, 686 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search542_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1624, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1623, 1625 },
      -1,
   } },

   /* replace542_0_0 -> 0 in the cache */
   /* replace542_0_1 -> 1576 in the cache */
   /* replace542_0 -> 1609 in the cache */
   /* replace542_1 -> 686 in the cache */
   /* replace542 -> 1610 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search543_0_0 -> 128 in the cache */
   /* search543_0_1 -> 1617 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 1617 },
      -1,
   } },
   /* search543_1_0 -> 128 in the cache */
   /* search543_1_1 -> 1619 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 1619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1627, 1628 },
      -1,
   } },

   /* replace543_0 -> 128 in the cache */
   /* replace543_1_0 -> 129 in the cache */
   /* replace543_1_1 -> 131 in the cache */
   /* replace543_1 -> 1612 in the cache */
   /* replace543 -> 1613 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search544_0_0 -> 1622 in the cache */
   /* search544_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1622, 686 },
      -1,
   } },
   /* search544_1_0 -> 1624 in the cache */
   /* search544_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1624, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1630, 1631 },
      -1,
   } },

   /* replace544_0_0 -> 0 in the cache */
   /* replace544_0_1 -> 1576 in the cache */
   /* replace544_0 -> 1615 in the cache */
   /* replace544_1 -> 686 in the cache */
   /* replace544 -> 1616 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search545_0_0 -> 128 in the cache */
   /* search545_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search545_1_0 -> 128 in the cache */
   /* search545_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1633, 1634 },
      -1,
   } },

   /* replace545_0 -> 128 in the cache */
   /* replace545_1_0 -> 129 in the cache */
   /* replace545_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 128, 1636 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search546_0_0 -> 0 in the cache */
   /* search546_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search546_1_0 -> 1576 in the cache */
   /* search546_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1638, 1639 },
      -1,
   } },

   /* replace546_0_0 -> 0 in the cache */
   /* replace546_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace546_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1641, 686 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search547_0_0 -> 128 in the cache */
   /* search547_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search547_1_0 -> 128 in the cache */
   /* search547_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1643, 1644 },
      -1,
   } },

   /* replace547_0 -> 128 in the cache */
   /* replace547_1_0 -> 129 in the cache */
   /* replace547_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 128, 1646 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search548_0_0 -> 0 in the cache */
   /* search548_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search548_1_0 -> 1576 in the cache */
   /* search548_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1648, 1649 },
      -1,
   } },

   /* replace548_0_0 -> 0 in the cache */
   /* replace548_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace548_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1651, 686 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search549_0_0 -> 128 in the cache */
   /* search549_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search549_1_0 -> 128 in the cache */
   /* search549_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1653, 1654 },
      -1,
   } },

   /* replace549_0 -> 128 in the cache */
   /* replace549_1_0 -> 129 in the cache */
   /* replace549_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 128, 1656 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search550_0_0 -> 0 in the cache */
   /* search550_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search550_1_0 -> 1576 in the cache */
   /* search550_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1658, 1659 },
      -1,
   } },

   /* replace550_0_0 -> 0 in the cache */
   /* replace550_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace550_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1661, 686 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search551_0_0 -> 128 in the cache */
   /* search551_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search551_1_0 -> 128 in the cache */
   /* search551_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1663, 1664 },
      -1,
   } },

   /* replace551_0 -> 128 in the cache */
   /* replace551_1_0 -> 129 in the cache */
   /* replace551_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 128, 1666 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search552_0_0 -> 0 in the cache */
   /* search552_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search552_1_0 -> 1576 in the cache */
   /* search552_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1576, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1668, 1669 },
      -1,
   } },

   /* replace552_0_0 -> 0 in the cache */
   /* replace552_0_1 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1576 },
      -1,
   } },
   /* replace552_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1671, 686 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search553_0_0 -> 128 in the cache */
   /* search553_0_1 -> 129 in the cache */
   /* search553_0 -> 1633 in the cache */
   /* search553_1_0 -> 128 in the cache */
   /* search553_1_1 -> 131 in the cache */
   /* search553_1 -> 1634 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1633, 1634 },
      -1,
   } },

   /* replace553_0 -> 128 in the cache */
   /* replace553_1_0 -> 129 in the cache */
   /* replace553_1_1 -> 131 in the cache */
   /* replace553_1 -> 1646 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 128, 1646 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search554_0_0 -> 0 in the cache */
   /* search554_0_1 -> 686 in the cache */
   /* search554_0 -> 1638 in the cache */
   /* search554_1_0 -> 1576 in the cache */
   /* search554_1_1 -> 686 in the cache */
   /* search554_1 -> 1639 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1638, 1639 },
      -1,
   } },

   /* replace554_0_0 -> 0 in the cache */
   /* replace554_0_1 -> 1576 in the cache */
   /* replace554_0 -> 1651 in the cache */
   /* replace554_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1651, 686 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search555_0_0 -> 128 in the cache */
   /* search555_0_1 -> 129 in the cache */
   /* search555_0 -> 1643 in the cache */
   /* search555_1_0 -> 128 in the cache */
   /* search555_1_1 -> 131 in the cache */
   /* search555_1 -> 1644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1643, 1644 },
      -1,
   } },

   /* replace555_0 -> 128 in the cache */
   /* replace555_1_0 -> 129 in the cache */
   /* replace555_1_1 -> 131 in the cache */
   /* replace555_1 -> 1636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 128, 1636 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search556_0_0 -> 0 in the cache */
   /* search556_0_1 -> 686 in the cache */
   /* search556_0 -> 1648 in the cache */
   /* search556_1_0 -> 1576 in the cache */
   /* search556_1_1 -> 686 in the cache */
   /* search556_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1648, 1649 },
      -1,
   } },

   /* replace556_0_0 -> 0 in the cache */
   /* replace556_0_1 -> 1576 in the cache */
   /* replace556_0 -> 1641 in the cache */
   /* replace556_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1641, 686 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search557_0_0 -> 128 in the cache */
   /* search557_0_1 -> 129 in the cache */
   /* search557_0 -> 1653 in the cache */
   /* search557_1_0 -> 128 in the cache */
   /* search557_1_1 -> 131 in the cache */
   /* search557_1 -> 1654 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1653, 1654 },
      -1,
   } },

   /* replace557_0 -> 128 in the cache */
   /* replace557_1_0 -> 129 in the cache */
   /* replace557_1_1 -> 131 in the cache */
   /* replace557_1 -> 1666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 128, 1666 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search558_0_0 -> 0 in the cache */
   /* search558_0_1 -> 686 in the cache */
   /* search558_0 -> 1658 in the cache */
   /* search558_1_0 -> 1576 in the cache */
   /* search558_1_1 -> 686 in the cache */
   /* search558_1 -> 1659 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1658, 1659 },
      -1,
   } },

   /* replace558_0_0 -> 0 in the cache */
   /* replace558_0_1 -> 1576 in the cache */
   /* replace558_0 -> 1671 in the cache */
   /* replace558_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1671, 686 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search559_0_0 -> 128 in the cache */
   /* search559_0_1 -> 129 in the cache */
   /* search559_0 -> 1663 in the cache */
   /* search559_1_0 -> 128 in the cache */
   /* search559_1_1 -> 131 in the cache */
   /* search559_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1663, 1664 },
      -1,
   } },

   /* replace559_0 -> 128 in the cache */
   /* replace559_1_0 -> 129 in the cache */
   /* replace559_1_1 -> 131 in the cache */
   /* replace559_1 -> 1656 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 128, 1656 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search560_0_0 -> 0 in the cache */
   /* search560_0_1 -> 686 in the cache */
   /* search560_0 -> 1668 in the cache */
   /* search560_1_0 -> 1576 in the cache */
   /* search560_1_1 -> 686 in the cache */
   /* search560_1 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1668, 1669 },
      -1,
   } },

   /* replace560_0_0 -> 0 in the cache */
   /* replace560_0_1 -> 1576 in the cache */
   /* replace560_0 -> 1661 in the cache */
   /* replace560_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1661, 686 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search561_0_0_0 -> 0 in the cache */
   /* search561_0_0_1 -> 686 in the cache */
   /* search561_0_0 -> 1575 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1575, 1689 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search561_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1691, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1690, 1692 },
      -1,
   } },

   /* replace561_0_0_0 -> 0 in the cache */
   /* replace561_0_0_1 -> 1691 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1691 },
      -1,
   } },
   /* replace561_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1694, 686 },
      -1,
   } },
   /* replace561_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1695, 1689 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search562_0_0_0 -> 0 in the cache */
   /* search562_0_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 686 },
      -1,
   } },
   /* search562_0_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1697, 1689 },
      0,
   } },
   /* search562_1_0 -> 1691 in the cache */
   /* search562_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1691, 686 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1698, 1699 },
      -1,
   } },

   /* replace562_0_0_0 -> 0 in the cache */
   /* replace562_0_0_1 -> 1691 in the cache */
   /* replace562_0_0 -> 1694 in the cache */
   /* replace562_0_1 -> 686 in the cache */
   /* replace562_0 -> 1695 in the cache */
   /* replace562_1 -> 1689 in the cache */
   /* replace562 -> 1696 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search563_0_0_0 -> 151 in the cache */
   /* search563_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 152 },
      0,
   } },
   /* search563_0_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1701, 1689 },
      0,
   } },
   /* search563_1_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1702, 1704 },
      -1,
   } },

   /* replace563_0_0 -> 151 in the cache */
   /* replace563_0_1_0 -> 152 in the cache */
   /* replace563_0_1_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 151, 1706 },
      -1,
   } },
   /* replace563_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1707, 1689 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search564_0_0_0 -> 151 in the cache */
   /* search564_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 152 },
      -1,
   } },
   /* search564_0_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1709, 1689 },
      0,
   } },
   /* search564_1_0 -> 151 in the cache */
   /* search564_1_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 1703 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1710, 1711 },
      -1,
   } },

   /* replace564_0_0 -> 151 in the cache */
   /* replace564_0_1_0 -> 152 in the cache */
   /* replace564_0_1_1 -> 1703 in the cache */
   /* replace564_0_1 -> 1706 in the cache */
   /* replace564_0 -> 1707 in the cache */
   /* replace564_1 -> 1689 in the cache */
   /* replace564 -> 1708 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search565_0_0 -> 1021 in the cache */
   /* search565_0_1 -> 1022 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1021, 1022 },
      -1,
   } },
   /* search565_1_0 -> 3 in the cache */
   /* search565_1_1 -> 0 in the cache */
   /* search565_1 -> 1057 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1713, 1057 },
      -1,
   } },

   /* replace565_0 -> 0 in the cache */
   /* replace565_1 -> 3 in the cache */
   /* replace565 -> 1031 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search566_0_0 -> 115 in the cache */
   /* search566_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search566_1_0 -> 260 in the cache */
   /* search566_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 260, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1715, 1716 },
      -1,
   } },

   /* replace566_0 -> 115 in the cache */
   /* replace566_1_0 -> 11 in the cache */
   /* replace566_1_1_0 -> 260 in the cache */
   /* replace566_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1718 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search567_0_0 -> 115 in the cache */
   /* search567_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search567_1_0 -> 260 in the cache */
   /* search567_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 260, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1720, 1721 },
      -1,
   } },

   /* replace567_0 -> 115 in the cache */
   /* replace567_1_0 -> 11 in the cache */
   /* replace567_1_1_0 -> 260 in the cache */
   /* replace567_1_1 -> 536 in the cache */
   /* replace567_1 -> 1718 in the cache */
   /* replace567 -> 1719 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search568_0_0 -> 115 in the cache */
   /* search568_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search568_1_0 -> 260 in the cache */
   /* search568_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 260, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1723, 1724 },
      -1,
   } },

   /* replace568_0 -> 115 in the cache */
   /* replace568_1_0 -> 11 in the cache */
   /* replace568_1_1_0 -> 260 in the cache */
   /* replace568_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1726 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search569_0_0 -> 115 in the cache */
   /* search569_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search569_1_0 -> 260 in the cache */
   /* search569_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 260, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1728, 1729 },
      -1,
   } },

   /* replace569_0 -> 115 in the cache */
   /* replace569_1_0 -> 11 in the cache */
   /* replace569_1_1_0 -> 260 in the cache */
   /* replace569_1_1 -> 536 in the cache */
   /* replace569_1 -> 1726 in the cache */
   /* replace569 -> 1727 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search570_0_0 -> 115 in the cache */
   /* search570_0_1 -> 11 in the cache */
   /* search570_0 -> 1715 in the cache */
   /* search570_1_0 -> 260 in the cache */
   /* search570_1_1 -> 115 in the cache */
   /* search570_1 -> 1716 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1715, 1716 },
      -1,
   } },

   /* replace570_0 -> 115 in the cache */
   /* replace570_1_0 -> 11 in the cache */
   /* replace570_1_1_0 -> 260 in the cache */
   /* replace570_1_1 -> 536 in the cache */
   /* replace570_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1726 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search571_0_0 -> 115 in the cache */
   /* search571_0_1 -> 11 in the cache */
   /* search571_0 -> 1720 in the cache */
   /* search571_1_0 -> 260 in the cache */
   /* search571_1_1 -> 115 in the cache */
   /* search571_1 -> 1721 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1720, 1721 },
      -1,
   } },

   /* replace571_0 -> 115 in the cache */
   /* replace571_1_0 -> 11 in the cache */
   /* replace571_1_1_0 -> 260 in the cache */
   /* replace571_1_1 -> 536 in the cache */
   /* replace571_1 -> 1726 in the cache */
   /* replace571 -> 1732 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search572_0_0 -> 115 in the cache */
   /* search572_0_1 -> 11 in the cache */
   /* search572_0 -> 1723 in the cache */
   /* search572_1_0 -> 260 in the cache */
   /* search572_1_1 -> 115 in the cache */
   /* search572_1 -> 1724 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1723, 1724 },
      -1,
   } },

   /* replace572_0 -> 115 in the cache */
   /* replace572_1_0 -> 11 in the cache */
   /* replace572_1_1_0 -> 260 in the cache */
   /* replace572_1_1 -> 536 in the cache */
   /* replace572_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1718 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search573_0_0 -> 115 in the cache */
   /* search573_0_1 -> 11 in the cache */
   /* search573_0 -> 1728 in the cache */
   /* search573_1_0 -> 260 in the cache */
   /* search573_1_1 -> 115 in the cache */
   /* search573_1 -> 1729 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1728, 1729 },
      -1,
   } },

   /* replace573_0 -> 115 in the cache */
   /* replace573_1_0 -> 11 in the cache */
   /* replace573_1_1_0 -> 260 in the cache */
   /* replace573_1_1 -> 536 in the cache */
   /* replace573_1 -> 1718 in the cache */
   /* replace573 -> 1735 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search574_0_0 -> 11 in the cache */
   /* search574_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search574_1 -> 483 in the cache */
   /* search574_2_0_0_0_0 -> 115 in the cache */
   /* search574_2_0_0_0_1 -> 11 in the cache */
   /* search574_2_0_0_0 -> 1720 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1720 },
      -1,
   } },
   /* search574_2_0_1_0_0_0 -> 11 in the cache */
   /* search574_2_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1738, 1741 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1742 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1737, 483, 1743 },
      -1,
   } },

   /* replace574_0_0_0_0 -> 11 in the cache */
   /* replace574_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1745 },
      -1,
   } },
   /* replace574_0_1_0_0_0 -> 11 in the cache */
   /* replace574_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1748 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1746, 1749 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1750 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search575_0 -> 739 in the cache */
   /* search575_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 260 },
      0,
   } },
   /* search575_2_0 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1752, 1753 },
      -1,
   } },

   /* replace575_0_0 -> 739 in the cache */
   /* replace575_0_1 -> 260 in the cache */
   /* replace575_0_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 260, 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1755 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search576_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1757 },
      -1,
   } },

   /* replace576_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search577_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1760 },
      -1,
   } },

   /* replace577 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search578_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1762 },
      -1,
   } },

   /* replace578 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search579_0_0 -> 11 in the cache */
   /* search579_0 -> 1760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1760 },
      -1,
   } },

   /* replace579 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search580_0_0 -> 11 in the cache */
   /* search580_0 -> 1762 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1762 },
      -1,
   } },

   /* replace580 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search581_0_0_0 -> 115 in the cache */
   /* search581_0_0_1 -> 11 in the cache */
   /* search581_0_0 -> 1720 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1720 },
      -1,
   } },
   /* search581_1_0_0_0 -> 11 in the cache */
   /* search581_1_0_0_1 -> 115 in the cache */
   /* search581_1_0_0 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1739 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1766, 1768 },
      -1,
   } },

   /* replace581_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search582_0_0_0 -> 835 in the cache */
   /* search582_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 835, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1771 },
      -1,
   } },
   /* search582_1_0_0_0 -> 11 in the cache */
   /* search582_1_0_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1773 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1774 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1772, 1775 },
      -1,
   } },

   /* replace582_0_0 -> 11 in the cache */
   /* replace582_0 -> 1770 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1770 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search583_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace583 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search584_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace584 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search585_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace585 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search586_0_0 -> 739 in the cache */
   /* search586_0 -> 1385 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1385 },
      -1,
   } },

   /* replace586_0 -> 739 in the cache */
   /* replace586 -> 1381 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search587_0_0 -> 739 in the cache */
   /* search587_0 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1373 },
      -1,
   } },

   /* replace587_0 -> 739 in the cache */
   /* replace587 -> 1369 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search588_0_0 -> 739 in the cache */
   /* search588_0 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1373 },
      -1,
   } },

   /* replace588_0 -> 739 in the cache */
   /* replace588 -> 1369 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search589_0_0 -> 11 in the cache */
   /* search589_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace589_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search590_0_0 -> 11 in the cache */
   /* search590_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace590_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search591_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace591_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search592_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1794 },
      -1,
   } },

   /* replace592_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search593_0_0 -> 11 in the cache */
   /* search593_0 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace593_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search594_0_0 -> 11 in the cache */
   /* search594_0 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace594_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search595_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1801 },
      -1,
   } },

   /* replace595 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search596_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1803 },
      -1,
   } },

   /* replace596 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search597_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1805 },
      -1,
   } },

   /* replace597 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search598_0_0 -> 739 in the cache */
   /* search598_0 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1389 },
      -1,
   } },

   /* replace598_0 -> 739 in the cache */
   /* replace598 -> 1381 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search599_0_0 -> 739 in the cache */
   /* search599_0 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1377 },
      -1,
   } },

   /* replace599_0 -> 739 in the cache */
   /* replace599 -> 1369 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search600_0_0 -> 739 in the cache */
   /* search600_0 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1377 },
      -1,
   } },

   /* replace600_0 -> 739 in the cache */
   /* replace600 -> 1369 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search601_0_0 -> 11 in the cache */
   /* search601_0 -> 1801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1801 },
      -1,
   } },

   /* replace601_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search602_0_0 -> 11 in the cache */
   /* search602_0 -> 1801 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1801 },
      -1,
   } },

   /* replace602_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search603_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* replace603_0 -> 32 in the cache */
   /* replace603 -> 1793 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search604_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1816 },
      -1,
   } },

   /* replace604_0 -> 32 in the cache */
   /* replace604 -> 1796 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search605_0_0 -> 11 in the cache */
   /* search605_0 -> 1805 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1805 },
      -1,
   } },

   /* replace605_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search606_0_0 -> 11 in the cache */
   /* search606_0 -> 1803 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1803 },
      -1,
   } },

   /* replace606_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search607_0_0 -> 117 in the cache */
   /* search607_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search607_1_0 -> 36 in the cache */
   /* search607_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1822, 1823 },
      -1,
   } },

   /* replace607_0 -> 117 in the cache */
   /* replace607_1_0 -> 16 in the cache */
   /* replace607_1_1_0 -> 36 in the cache */
   /* replace607_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1825 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search608_0_0 -> 117 in the cache */
   /* search608_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search608_1_0 -> 36 in the cache */
   /* search608_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1827, 1828 },
      -1,
   } },

   /* replace608_0 -> 117 in the cache */
   /* replace608_1_0 -> 16 in the cache */
   /* replace608_1_1_0 -> 36 in the cache */
   /* replace608_1_1 -> 602 in the cache */
   /* replace608_1 -> 1825 in the cache */
   /* replace608 -> 1826 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search609_0_0 -> 117 in the cache */
   /* search609_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search609_1_0 -> 36 in the cache */
   /* search609_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1830, 1831 },
      -1,
   } },

   /* replace609_0 -> 117 in the cache */
   /* replace609_1_0 -> 16 in the cache */
   /* replace609_1_1_0 -> 36 in the cache */
   /* replace609_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1833 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search610_0_0 -> 117 in the cache */
   /* search610_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search610_1_0 -> 36 in the cache */
   /* search610_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1835, 1836 },
      -1,
   } },

   /* replace610_0 -> 117 in the cache */
   /* replace610_1_0 -> 16 in the cache */
   /* replace610_1_1_0 -> 36 in the cache */
   /* replace610_1_1 -> 602 in the cache */
   /* replace610_1 -> 1833 in the cache */
   /* replace610 -> 1834 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search611_0_0 -> 117 in the cache */
   /* search611_0_1 -> 16 in the cache */
   /* search611_0 -> 1822 in the cache */
   /* search611_1_0 -> 36 in the cache */
   /* search611_1_1 -> 117 in the cache */
   /* search611_1 -> 1823 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1822, 1823 },
      -1,
   } },

   /* replace611_0 -> 117 in the cache */
   /* replace611_1_0 -> 16 in the cache */
   /* replace611_1_1_0 -> 36 in the cache */
   /* replace611_1_1 -> 602 in the cache */
   /* replace611_1 -> 1833 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1833 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search612_0_0 -> 117 in the cache */
   /* search612_0_1 -> 16 in the cache */
   /* search612_0 -> 1827 in the cache */
   /* search612_1_0 -> 36 in the cache */
   /* search612_1_1 -> 117 in the cache */
   /* search612_1 -> 1828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1827, 1828 },
      -1,
   } },

   /* replace612_0 -> 117 in the cache */
   /* replace612_1_0 -> 16 in the cache */
   /* replace612_1_1_0 -> 36 in the cache */
   /* replace612_1_1 -> 602 in the cache */
   /* replace612_1 -> 1833 in the cache */
   /* replace612 -> 1839 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search613_0_0 -> 117 in the cache */
   /* search613_0_1 -> 16 in the cache */
   /* search613_0 -> 1830 in the cache */
   /* search613_1_0 -> 36 in the cache */
   /* search613_1_1 -> 117 in the cache */
   /* search613_1 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1830, 1831 },
      -1,
   } },

   /* replace613_0 -> 117 in the cache */
   /* replace613_1_0 -> 16 in the cache */
   /* replace613_1_1_0 -> 36 in the cache */
   /* replace613_1_1 -> 602 in the cache */
   /* replace613_1 -> 1825 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1825 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search614_0_0 -> 117 in the cache */
   /* search614_0_1 -> 16 in the cache */
   /* search614_0 -> 1835 in the cache */
   /* search614_1_0 -> 36 in the cache */
   /* search614_1_1 -> 117 in the cache */
   /* search614_1 -> 1836 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1835, 1836 },
      -1,
   } },

   /* replace614_0 -> 117 in the cache */
   /* replace614_1_0 -> 16 in the cache */
   /* replace614_1_1_0 -> 36 in the cache */
   /* replace614_1_1 -> 602 in the cache */
   /* replace614_1 -> 1825 in the cache */
   /* replace614 -> 1842 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search615_0_0 -> 16 in the cache */
   /* search615_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search615_1 -> 245 in the cache */
   /* search615_2_0_0_0_0 -> 117 in the cache */
   /* search615_2_0_0_0_1 -> 16 in the cache */
   /* search615_2_0_0_0 -> 1827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1827 },
      -1,
   } },
   /* search615_2_0_1_0_0_0 -> 16 in the cache */
   /* search615_2_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1845, 1848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1844, 245, 1850 },
      -1,
   } },

   /* replace615_0_0_0_0 -> 16 in the cache */
   /* replace615_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1852 },
      -1,
   } },
   /* replace615_0_1_0_0_0 -> 16 in the cache */
   /* replace615_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1855 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1853, 1856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1857 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search616_0 -> 739 in the cache */
   /* search616_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search616_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1859, 1860 },
      -1,
   } },

   /* replace616_0_0 -> 739 in the cache */
   /* replace616_0_1 -> 36 in the cache */
   /* replace616_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1862 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search617_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1864 },
      -1,
   } },

   /* replace617_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search618_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1867 },
      -1,
   } },

   /* replace618 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search619_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1869 },
      -1,
   } },

   /* replace619 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search620_0_0 -> 16 in the cache */
   /* search620_0 -> 1867 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1867 },
      -1,
   } },

   /* replace620 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search621_0_0 -> 16 in the cache */
   /* search621_0 -> 1869 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1869 },
      -1,
   } },

   /* replace621 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search622_0_0_0 -> 117 in the cache */
   /* search622_0_0_1 -> 16 in the cache */
   /* search622_0_0 -> 1827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1827 },
      -1,
   } },
   /* search622_1_0_0_0 -> 16 in the cache */
   /* search622_1_0_0_1 -> 117 in the cache */
   /* search622_1_0_0 -> 1846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1874 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1873, 1875 },
      -1,
   } },

   /* replace622_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search623_0_0_0 -> 124 in the cache */
   /* search623_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1878 },
      -1,
   } },
   /* search623_1_0_0_0 -> 16 in the cache */
   /* search623_1_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1881 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1879, 1882 },
      -1,
   } },

   /* replace623_0_0 -> 16 in the cache */
   /* replace623_0 -> 1877 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1877 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search624_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1885 },
      -1,
   } },

   /* replace624 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search625_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1887 },
      -1,
   } },

   /* replace625 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search626_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1889 },
      -1,
   } },

   /* replace626 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search627_0_0 -> 739 in the cache */
   /* search627_0 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1389 },
      -1,
   } },

   /* replace627_0 -> 739 in the cache */
   /* replace627 -> 1385 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search628_0_0 -> 739 in the cache */
   /* search628_0 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1377 },
      -1,
   } },

   /* replace628_0 -> 739 in the cache */
   /* replace628 -> 1373 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search629_0_0 -> 739 in the cache */
   /* search629_0 -> 1377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1377 },
      -1,
   } },

   /* replace629_0 -> 739 in the cache */
   /* replace629 -> 1373 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search630_0_0 -> 16 in the cache */
   /* search630_0 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1885 },
      -1,
   } },

   /* replace630_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search631_0_0 -> 16 in the cache */
   /* search631_0 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1885 },
      -1,
   } },

   /* replace631_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search632_0_0 -> 32 in the cache */
   /* search632_0 -> 1814 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* replace632_0 -> 32 in the cache */
   /* replace632 -> 1791 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search633_0_0 -> 32 in the cache */
   /* search633_0 -> 1816 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1816 },
      -1,
   } },

   /* replace633_0 -> 32 in the cache */
   /* replace633 -> 1794 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search634_0_0 -> 16 in the cache */
   /* search634_0 -> 1889 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1889 },
      -1,
   } },

   /* replace634_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search635_0_0 -> 16 in the cache */
   /* search635_0 -> 1887 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1887 },
      -1,
   } },

   /* replace635_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search636_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1904, 21 },
      0,
   } },
   /* search636_1_0 -> 41 in the cache */
   /* search636_1_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1905, 1906 },
      -1,
   } },

   /* replace636_0 -> 1904 in the cache */
   /* replace636_1_0 -> 21 in the cache */
   /* replace636_1_1_0 -> 41 in the cache */
   /* replace636_1_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1904, 1908 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search637_0_0 -> 1904 in the cache */
   /* search637_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1904, 21 },
      -1,
   } },
   /* search637_1_0 -> 41 in the cache */
   /* search637_1_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1904 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1910, 1911 },
      -1,
   } },

   /* replace637_0 -> 1904 in the cache */
   /* replace637_1_0 -> 21 in the cache */
   /* replace637_1_1_0 -> 41 in the cache */
   /* replace637_1_1 -> 675 in the cache */
   /* replace637_1 -> 1908 in the cache */
   /* replace637 -> 1909 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search638_0_0 -> 1904 in the cache */
   /* search638_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1904, 21 },
      0,
   } },
   /* search638_1_0 -> 41 in the cache */
   /* search638_1_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1913, 1914 },
      -1,
   } },

   /* replace638_0 -> 1904 in the cache */
   /* replace638_1_0 -> 21 in the cache */
   /* replace638_1_1_0 -> 41 in the cache */
   /* replace638_1_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1904, 1916 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search639_0_0 -> 1904 in the cache */
   /* search639_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1904, 21 },
      -1,
   } },
   /* search639_1_0 -> 41 in the cache */
   /* search639_1_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1904 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1918, 1919 },
      -1,
   } },

   /* replace639_0 -> 1904 in the cache */
   /* replace639_1_0 -> 21 in the cache */
   /* replace639_1_1_0 -> 41 in the cache */
   /* replace639_1_1 -> 675 in the cache */
   /* replace639_1 -> 1916 in the cache */
   /* replace639 -> 1917 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search640_0_0 -> 1904 in the cache */
   /* search640_0_1 -> 21 in the cache */
   /* search640_0 -> 1905 in the cache */
   /* search640_1_0 -> 41 in the cache */
   /* search640_1_1 -> 1904 in the cache */
   /* search640_1 -> 1906 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1905, 1906 },
      -1,
   } },

   /* replace640_0 -> 1904 in the cache */
   /* replace640_1_0 -> 21 in the cache */
   /* replace640_1_1_0 -> 41 in the cache */
   /* replace640_1_1 -> 675 in the cache */
   /* replace640_1 -> 1916 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1904, 1916 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search641_0_0 -> 1904 in the cache */
   /* search641_0_1 -> 21 in the cache */
   /* search641_0 -> 1910 in the cache */
   /* search641_1_0 -> 41 in the cache */
   /* search641_1_1 -> 1904 in the cache */
   /* search641_1 -> 1911 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1910, 1911 },
      -1,
   } },

   /* replace641_0 -> 1904 in the cache */
   /* replace641_1_0 -> 21 in the cache */
   /* replace641_1_1_0 -> 41 in the cache */
   /* replace641_1_1 -> 675 in the cache */
   /* replace641_1 -> 1916 in the cache */
   /* replace641 -> 1922 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search642_0_0 -> 1904 in the cache */
   /* search642_0_1 -> 21 in the cache */
   /* search642_0 -> 1913 in the cache */
   /* search642_1_0 -> 41 in the cache */
   /* search642_1_1 -> 1904 in the cache */
   /* search642_1 -> 1914 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1913, 1914 },
      -1,
   } },

   /* replace642_0 -> 1904 in the cache */
   /* replace642_1_0 -> 21 in the cache */
   /* replace642_1_1_0 -> 41 in the cache */
   /* replace642_1_1 -> 675 in the cache */
   /* replace642_1 -> 1908 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1904, 1908 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search643_0_0 -> 1904 in the cache */
   /* search643_0_1 -> 21 in the cache */
   /* search643_0 -> 1918 in the cache */
   /* search643_1_0 -> 41 in the cache */
   /* search643_1_1 -> 1904 in the cache */
   /* search643_1 -> 1919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1918, 1919 },
      -1,
   } },

   /* replace643_0 -> 1904 in the cache */
   /* replace643_1_0 -> 21 in the cache */
   /* replace643_1_1_0 -> 41 in the cache */
   /* replace643_1_1 -> 675 in the cache */
   /* replace643_1 -> 1908 in the cache */
   /* replace643 -> 1925 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search644_0_0 -> 21 in the cache */
   /* search644_0_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 1904 },
      -1,
   } },
   /* search644_1 -> 624 in the cache */
   /* search644_2_0_0_0_0 -> 1904 in the cache */
   /* search644_2_0_0_0_1 -> 21 in the cache */
   /* search644_2_0_0_0 -> 1910 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1910 },
      -1,
   } },
   /* search644_2_0_1_0_0_0 -> 21 in the cache */
   /* search644_2_0_1_0_0_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1929 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1930 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1928, 1931 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1932 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1927, 624, 1933 },
      -1,
   } },

   /* replace644_0_0_0_0 -> 21 in the cache */
   /* replace644_0_0_0_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 1904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1935 },
      -1,
   } },
   /* replace644_0_1_0_0_0 -> 21 in the cache */
   /* replace644_0_1_0_0_1 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1937 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1936, 1939 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1940 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search645_0 -> 739 in the cache */
   /* search645_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search645_2_0 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 612 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1942, 1943 },
      -1,
   } },

   /* replace645_0_0 -> 739 in the cache */
   /* replace645_0_1 -> 41 in the cache */
   /* replace645_0_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 41, 612 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search646_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1947 },
      -1,
   } },

   /* replace646_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search647_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1950 },
      -1,
   } },

   /* replace647 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search648_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1952 },
      -1,
   } },

   /* replace648 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search649_0_0 -> 21 in the cache */
   /* search649_0 -> 1950 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1950 },
      -1,
   } },

   /* replace649 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search650_0_0 -> 21 in the cache */
   /* search650_0 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1952 },
      -1,
   } },

   /* replace650 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search651_0_0_0 -> 1904 in the cache */
   /* search651_0_0_1 -> 21 in the cache */
   /* search651_0_0 -> 1910 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1910 },
      -1,
   } },
   /* search651_1_0_0_0 -> 21 in the cache */
   /* search651_1_0_0_1 -> 1904 in the cache */
   /* search651_1_0_0 -> 1929 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1929 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1957 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1956, 1958 },
      -1,
   } },

   /* replace651_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search652_0_0_0 -> 876 in the cache */
   /* search652_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 876, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1961 },
      -1,
   } },
   /* search652_1_0_0_0 -> 21 in the cache */
   /* search652_1_0_0_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1963 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1962, 1965 },
      -1,
   } },

   /* replace652_0_0 -> 21 in the cache */
   /* replace652_0 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1960 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search653_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1968 },
      -1,
   } },

   /* replace653_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search654_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1971 },
      -1,
   } },

   /* replace654_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search655_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1974 },
      -1,
   } },

   /* replace655_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search656_0_0 -> 16 in the cache */
   /* search656_0 -> 1974 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1974 },
      -1,
   } },

   /* replace656_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search657_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1979 },
      -1,
   } },

   /* replace657_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search658_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1982 },
      -1,
   } },

   /* replace658_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search659_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 1985 },
      -1,
   } },

   /* replace659_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search660_0_0 -> 16 in the cache */
   /* search660_0 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1985 },
      -1,
   } },

   /* replace660_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search661_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1990 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1991, 1992 },
      -1,
   } },

   /* replace661_0 -> 11 in the cache */
   /* replace661_1_0 -> 260 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 260, 1994 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 1995 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search662_0_0_0 -> 11 in the cache */
   /* search662_0_0_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1992 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1997 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 1998 },
      -1,
   } },

   /* replace662_0 -> 11 in the cache */
   /* replace662_1_0 -> 260 in the cache */
   /* replace662_1_1 -> 1994 in the cache */
   /* replace662_1 -> 1995 in the cache */
   /* replace662 -> 1996 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search663_0_0_0_0 -> 11 in the cache */
   /* search663_0_0_0 -> 1990 in the cache */
   /* search663_0_0 -> 1991 in the cache */
   /* search663_0_1_0_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1991, 2001 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2002 },
      -1,
   } },

   /* replace663_0_0 -> 11 in the cache */
   /* replace663_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2004 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search664_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2006 },
      -1,
   } },
   /* search664_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2007, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2010 },
      -1,
   } },

   /* replace664_0_0 -> 16 in the cache */
   /* replace664_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2012 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search665_0_0 -> 0 in the cache */
   /* search665_0_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 800 },
      -1,
   } },
   /* search665_1_0 -> 142 in the cache */
   /* search665_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2014, 2015 },
      -1,
   } },

   /* replace665_0_0 -> 0 in the cache */
   /* replace665_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace665_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2017, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search666_0_0 -> 0 in the cache */
   /* search666_0_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 800 },
      -1,
   } },
   /* search666_1_0 -> 142 in the cache */
   /* search666_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2019, 2020 },
      -1,
   } },

   /* replace666_0_0 -> 0 in the cache */
   /* replace666_0_1 -> 142 in the cache */
   /* replace666_0 -> 2017 in the cache */
   /* replace666_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2017, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search667_0_0 -> 0 in the cache */
   /* search667_0_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 800 },
      -1,
   } },
   /* search667_1_0 -> 142 in the cache */
   /* search667_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2023, 2024 },
      -1,
   } },

   /* replace667_0_0 -> 0 in the cache */
   /* replace667_0_1 -> 142 in the cache */
   /* replace667_0 -> 2017 in the cache */
   /* replace667_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2017, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search668_0_0 -> 0 in the cache */
   /* search668_0_1 -> 800 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 800 },
      -1,
   } },
   /* search668_1_0 -> 142 in the cache */
   /* search668_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace668_0_0 -> 0 in the cache */
   /* replace668_0_1 -> 142 in the cache */
   /* replace668_0 -> 2017 in the cache */
   /* replace668_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2017, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search669_0_0 -> 128 in the cache */
   /* search669_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search669_1_0 -> 131 in the cache */
   /* search669_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace669_0_0 -> 128 in the cache */
   /* replace669_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace669_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2034, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search670_0_0 -> 128 in the cache */
   /* search670_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search670_1_0 -> 131 in the cache */
   /* search670_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2036, 2037 },
      -1,
   } },

   /* replace670_0_0 -> 128 in the cache */
   /* replace670_0_1 -> 131 in the cache */
   /* replace670_0 -> 2034 in the cache */
   /* replace670_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2034, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search671_0_0 -> 128 in the cache */
   /* search671_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search671_1_0 -> 131 in the cache */
   /* search671_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2040, 2041 },
      -1,
   } },

   /* replace671_0_0 -> 128 in the cache */
   /* replace671_0_1 -> 131 in the cache */
   /* replace671_0 -> 2034 in the cache */
   /* replace671_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2034, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search672_0_0_0_0 -> 11 in the cache */
   /* search672_0_0_0 -> 1990 in the cache */
   /* search672_0_0 -> 1991 in the cache */
   /* search672_0_1_0_0 -> 260 in the cache */
   /* search672_0_1_0 -> 2000 in the cache */
   /* search672_0_1 -> 2001 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1991, 2001 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2044 },
      -1,
   } },

   /* replace672_0_0 -> 11 in the cache */
   /* replace672_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2046 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search673_0_0_0_0 -> 16 in the cache */
   /* search673_0_0_0 -> 2006 in the cache */
   /* search673_0_0 -> 2007 in the cache */
   /* search673_0_1_0_0 -> 36 in the cache */
   /* search673_0_1_0 -> 2008 in the cache */
   /* search673_0_1 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2007, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2048 },
      -1,
   } },

   /* replace673_0_0 -> 16 in the cache */
   /* replace673_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2050 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search674_0_0 -> 0 in the cache */
   /* search674_0_1 -> 800 in the cache */
   /* search674_0 -> 2014 in the cache */
   /* search674_1_0 -> 142 in the cache */
   /* search674_1_1 -> 3 in the cache */
   /* search674_1 -> 2015 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2014, 2015 },
      -1,
   } },

   /* replace674_0_0 -> 0 in the cache */
   /* replace674_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace674_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2053, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search675_0_0 -> 0 in the cache */
   /* search675_0_1 -> 800 in the cache */
   /* search675_0 -> 2019 in the cache */
   /* search675_1_0 -> 142 in the cache */
   /* search675_1_1 -> 3 in the cache */
   /* search675_1 -> 2020 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2019, 2020 },
      -1,
   } },

   /* replace675_0_0 -> 0 in the cache */
   /* replace675_0_1 -> 142 in the cache */
   /* replace675_0 -> 2053 in the cache */
   /* replace675_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2053, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search676_0_0 -> 0 in the cache */
   /* search676_0_1 -> 800 in the cache */
   /* search676_0 -> 2023 in the cache */
   /* search676_1_0 -> 142 in the cache */
   /* search676_1_1 -> 3 in the cache */
   /* search676_1 -> 2024 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2023, 2024 },
      -1,
   } },

   /* replace676_0_0 -> 0 in the cache */
   /* replace676_0_1 -> 142 in the cache */
   /* replace676_0 -> 2053 in the cache */
   /* replace676_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2053, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search677_0_0 -> 0 in the cache */
   /* search677_0_1 -> 800 in the cache */
   /* search677_0 -> 2027 in the cache */
   /* search677_1_0 -> 142 in the cache */
   /* search677_1_1 -> 3 in the cache */
   /* search677_1 -> 2028 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace677_0_0 -> 0 in the cache */
   /* replace677_0_1 -> 142 in the cache */
   /* replace677_0 -> 2053 in the cache */
   /* replace677_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2053, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search678_0_0 -> 128 in the cache */
   /* search678_0_1 -> 33 in the cache */
   /* search678_0 -> 2031 in the cache */
   /* search678_1_0 -> 131 in the cache */
   /* search678_1_1 -> 36 in the cache */
   /* search678_1 -> 2032 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace678_0_0 -> 128 in the cache */
   /* replace678_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace678_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2062, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search679_0_0 -> 128 in the cache */
   /* search679_0_1 -> 33 in the cache */
   /* search679_0 -> 2036 in the cache */
   /* search679_1_0 -> 131 in the cache */
   /* search679_1_1 -> 36 in the cache */
   /* search679_1 -> 2037 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2036, 2037 },
      -1,
   } },

   /* replace679_0_0 -> 128 in the cache */
   /* replace679_0_1 -> 131 in the cache */
   /* replace679_0 -> 2062 in the cache */
   /* replace679_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2062, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search680_0_0 -> 128 in the cache */
   /* search680_0_1 -> 33 in the cache */
   /* search680_0 -> 2040 in the cache */
   /* search680_1_0 -> 131 in the cache */
   /* search680_1_1 -> 36 in the cache */
   /* search680_1 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2040, 2041 },
      -1,
   } },

   /* replace680_0_0 -> 128 in the cache */
   /* replace680_0_1 -> 131 in the cache */
   /* replace680_0 -> 2062 in the cache */
   /* replace680_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2062, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search681_0_0_0_0 -> 11 in the cache */
   /* search681_0_0_0 -> 1990 in the cache */
   /* search681_0_0 -> 1991 in the cache */
   /* search681_0_1_0_0 -> 260 in the cache */
   /* search681_0_1_0 -> 2000 in the cache */
   /* search681_0_1 -> 2001 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1991, 2001 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2068 },
      -1,
   } },

   /* replace681_0_0 -> 11 in the cache */
   /* replace681_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2070 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search682_0_0_0_0 -> 16 in the cache */
   /* search682_0_0_0 -> 2006 in the cache */
   /* search682_0_0 -> 2007 in the cache */
   /* search682_0_1_0_0 -> 36 in the cache */
   /* search682_0_1_0 -> 2008 in the cache */
   /* search682_0_1 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2007, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2072 },
      -1,
   } },

   /* replace682_0_0 -> 16 in the cache */
   /* replace682_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2074 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search683_0_0 -> 0 in the cache */
   /* search683_0_1 -> 800 in the cache */
   /* search683_0 -> 2014 in the cache */
   /* search683_1_0 -> 142 in the cache */
   /* search683_1_1 -> 3 in the cache */
   /* search683_1 -> 2015 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2014, 2015 },
      -1,
   } },

   /* replace683_0_0 -> 0 in the cache */
   /* replace683_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace683_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2077, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search684_0_0 -> 0 in the cache */
   /* search684_0_1 -> 800 in the cache */
   /* search684_0 -> 2019 in the cache */
   /* search684_1_0 -> 142 in the cache */
   /* search684_1_1 -> 3 in the cache */
   /* search684_1 -> 2020 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2019, 2020 },
      -1,
   } },

   /* replace684_0_0 -> 0 in the cache */
   /* replace684_0_1 -> 142 in the cache */
   /* replace684_0 -> 2077 in the cache */
   /* replace684_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2077, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search685_0_0 -> 0 in the cache */
   /* search685_0_1 -> 800 in the cache */
   /* search685_0 -> 2023 in the cache */
   /* search685_1_0 -> 142 in the cache */
   /* search685_1_1 -> 3 in the cache */
   /* search685_1 -> 2024 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2023, 2024 },
      -1,
   } },

   /* replace685_0_0 -> 0 in the cache */
   /* replace685_0_1 -> 142 in the cache */
   /* replace685_0 -> 2077 in the cache */
   /* replace685_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2077, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search686_0_0 -> 0 in the cache */
   /* search686_0_1 -> 800 in the cache */
   /* search686_0 -> 2027 in the cache */
   /* search686_1_0 -> 142 in the cache */
   /* search686_1_1 -> 3 in the cache */
   /* search686_1 -> 2028 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace686_0_0 -> 0 in the cache */
   /* replace686_0_1 -> 142 in the cache */
   /* replace686_0 -> 2077 in the cache */
   /* replace686_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2077, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search687_0_0 -> 128 in the cache */
   /* search687_0_1 -> 33 in the cache */
   /* search687_0 -> 2031 in the cache */
   /* search687_1_0 -> 131 in the cache */
   /* search687_1_1 -> 36 in the cache */
   /* search687_1 -> 2032 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace687_0_0 -> 128 in the cache */
   /* replace687_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2086, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search688_0_0 -> 128 in the cache */
   /* search688_0_1 -> 33 in the cache */
   /* search688_0 -> 2036 in the cache */
   /* search688_1_0 -> 131 in the cache */
   /* search688_1_1 -> 36 in the cache */
   /* search688_1 -> 2037 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2036, 2037 },
      -1,
   } },

   /* replace688_0_0 -> 128 in the cache */
   /* replace688_0_1 -> 131 in the cache */
   /* replace688_0 -> 2086 in the cache */
   /* replace688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2086, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search689_0_0 -> 128 in the cache */
   /* search689_0_1 -> 33 in the cache */
   /* search689_0 -> 2040 in the cache */
   /* search689_1_0 -> 131 in the cache */
   /* search689_1_1 -> 36 in the cache */
   /* search689_1 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2040, 2041 },
      -1,
   } },

   /* replace689_0_0 -> 128 in the cache */
   /* replace689_0_1 -> 131 in the cache */
   /* replace689_0 -> 2086 in the cache */
   /* replace689_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2086, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search690_0_0 -> 6 in the cache */
   /* search690_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 814 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search690_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2093, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2092, 2094 },
      -1,
   } },

   /* replace690_0_0 -> 6 in the cache */
   /* replace690_0_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2093 },
      -1,
   } },
   /* replace690_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2096, 814 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search691_0_0 -> 6 in the cache */
   /* search691_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 814 },
      -1,
   } },
   /* search691_1_0 -> 2093 in the cache */
   /* search691_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2093, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2098, 2099 },
      -1,
   } },

   /* replace691_0_0 -> 6 in the cache */
   /* replace691_0_1 -> 2093 in the cache */
   /* replace691_0 -> 2096 in the cache */
   /* replace691_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2096, 814 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search692_0_0 -> 6 in the cache */
   /* search692_0_1 -> 814 in the cache */
   /* search692_0 -> 2092 in the cache */
   /* search692_1_0 -> 2093 in the cache */
   /* search692_1_1 -> 814 in the cache */
   /* search692_1 -> 2094 in the cache */
   /* search692 -> 2095 in the cache */

   /* replace692_0_0 -> 6 in the cache */
   /* replace692_0_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2093 },
      -1,
   } },
   /* replace692_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2102, 814 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search693_0_0 -> 6 in the cache */
   /* search693_0_1 -> 814 in the cache */
   /* search693_0 -> 2092 in the cache */
   /* search693_1_0 -> 2093 in the cache */
   /* search693_1_1 -> 814 in the cache */
   /* search693_1 -> 2094 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2092, 2094 },
      -1,
   } },

   /* replace693_0_0 -> 6 in the cache */
   /* replace693_0_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2093 },
      -1,
   } },
   /* replace693_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2105, 814 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search694_0_0 -> 6 in the cache */
   /* search694_0_1 -> 814 in the cache */
   /* search694_0 -> 2098 in the cache */
   /* search694_1_0 -> 2093 in the cache */
   /* search694_1_1 -> 814 in the cache */
   /* search694_1 -> 2099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2098, 2099 },
      -1,
   } },

   /* replace694_0_0 -> 6 in the cache */
   /* replace694_0_1 -> 2093 in the cache */
   /* replace694_0 -> 2105 in the cache */
   /* replace694_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2105, 814 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search695_0_0 -> 6 in the cache */
   /* search695_0_1 -> 814 in the cache */
   /* search695_0 -> 2098 in the cache */
   /* search695_1_0 -> 2093 in the cache */
   /* search695_1_1 -> 814 in the cache */
   /* search695_1 -> 2099 in the cache */
   /* search695 -> 2100 in the cache */

   /* replace695_0_0 -> 6 in the cache */
   /* replace695_0_1 -> 2093 in the cache */
   /* replace695_0 -> 2102 in the cache */
   /* replace695_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2102, 814 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search696_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2110 },
      -1,
   } },

   /* replace696 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search697_0 -> 6 in the cache */
   /* search697_1_0 -> 9 in the cache */
   /* search697_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2112 },
      -1,
   } },

   /* replace697_0 -> 6 in the cache */
   /* replace697_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search698_0 -> 6 in the cache */
   /* search698_1_0 -> 9 in the cache */
   /* search698_1_1 -> 36 in the cache */
   /* search698_1 -> 2112 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2112 },
      -1,
   } },

   /* replace698_0 -> 6 in the cache */
   /* replace698_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search699_0 -> 6 in the cache */
   /* search699_1_0 -> 9 in the cache */
   /* search699_1_1 -> 36 in the cache */
   /* search699_1 -> 2112 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2112 },
      -1,
   } },

   /* replace699_0 -> 6 in the cache */
   /* replace699_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2)) */
   /* search700_0 -> 6 in the cache */
   /* search700_1_0_0 -> 36 in the cache */
   /* search700_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 36, 398 },
      -1,
   } },
   /* search700_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2119, 403 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2120 },
      -1,
   } },

   /* replace700_0 -> 6 in the cache */
   /* replace700_1_0 -> 36 in the cache */
   /* replace700_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2122 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search701_0_0 -> 11 in the cache */
   /* search701_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 835 },
      -1,
   } },
   /* search701_1_0 -> 260 in the cache */
   /* search701_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 260, 835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2124, 2125 },
      -1,
   } },

   /* replace701_0_0 -> 11 in the cache */
   /* replace701_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace701_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2127, 835 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search702_0_0 -> 11 in the cache */
   /* search702_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 835 },
      -1,
   } },
   /* search702_1_0 -> 260 in the cache */
   /* search702_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 260, 835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2129, 2130 },
      -1,
   } },

   /* replace702_0_0 -> 11 in the cache */
   /* replace702_0_1 -> 260 in the cache */
   /* replace702_0 -> 2127 in the cache */
   /* replace702_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2127, 835 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search703_0_0 -> 11 in the cache */
   /* search703_0_1 -> 835 in the cache */
   /* search703_0 -> 2124 in the cache */
   /* search703_1_0 -> 260 in the cache */
   /* search703_1_1 -> 835 in the cache */
   /* search703_1 -> 2125 in the cache */
   /* search703 -> 2126 in the cache */

   /* replace703_0_0 -> 11 in the cache */
   /* replace703_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace703_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2133, 835 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search704_0_0 -> 11 in the cache */
   /* search704_0_1 -> 835 in the cache */
   /* search704_0 -> 2124 in the cache */
   /* search704_1_0 -> 260 in the cache */
   /* search704_1_1 -> 835 in the cache */
   /* search704_1 -> 2125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2124, 2125 },
      -1,
   } },

   /* replace704_0_0 -> 11 in the cache */
   /* replace704_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace704_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2136, 835 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search705_0_0 -> 11 in the cache */
   /* search705_0_1 -> 835 in the cache */
   /* search705_0 -> 2129 in the cache */
   /* search705_1_0 -> 260 in the cache */
   /* search705_1_1 -> 835 in the cache */
   /* search705_1 -> 2130 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2129, 2130 },
      -1,
   } },

   /* replace705_0_0 -> 11 in the cache */
   /* replace705_0_1 -> 260 in the cache */
   /* replace705_0 -> 2136 in the cache */
   /* replace705_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2136, 835 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search706_0_0 -> 11 in the cache */
   /* search706_0_1 -> 835 in the cache */
   /* search706_0 -> 2129 in the cache */
   /* search706_1_0 -> 260 in the cache */
   /* search706_1_1 -> 835 in the cache */
   /* search706_1 -> 2130 in the cache */
   /* search706 -> 2131 in the cache */

   /* replace706_0_0 -> 11 in the cache */
   /* replace706_0_1 -> 260 in the cache */
   /* replace706_0 -> 2133 in the cache */
   /* replace706_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2133, 835 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search707_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2141 },
      -1,
   } },

   /* replace707 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search708_0 -> 11 in the cache */
   /* search708_1_0 -> 14 in the cache */
   /* search708_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2143 },
      -1,
   } },

   /* replace708_0 -> 11 in the cache */
   /* replace708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search709_0 -> 11 in the cache */
   /* search709_1_0 -> 14 in the cache */
   /* search709_1_1 -> 36 in the cache */
   /* search709_1 -> 2143 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2143 },
      -1,
   } },

   /* replace709_0 -> 11 in the cache */
   /* replace709_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search710_0 -> 11 in the cache */
   /* search710_1_0 -> 14 in the cache */
   /* search710_1_1 -> 36 in the cache */
   /* search710_1 -> 2143 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2143 },
      -1,
   } },

   /* replace710_0 -> 11 in the cache */
   /* replace710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3)) */
   /* search711_0 -> 11 in the cache */
   /* search711_1_0_0 -> 36 in the cache */
   /* search711_1_0_1 -> 398 in the cache */
   /* search711_1_0 -> 2119 in the cache */
   /* search711_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2119, 407 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2150 },
      -1,
   } },

   /* replace711_0 -> 11 in the cache */
   /* replace711_1_0 -> 36 in the cache */
   /* replace711_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2152 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search712_0_0 -> 16 in the cache */
   /* search712_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 124 },
      -1,
   } },
   /* search712_1_0 -> 36 in the cache */
   /* search712_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2154, 2155 },
      -1,
   } },

   /* replace712_0_0 -> 16 in the cache */
   /* replace712_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace712_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2157, 124 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search713_0_0 -> 16 in the cache */
   /* search713_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 124 },
      -1,
   } },
   /* search713_1_0 -> 36 in the cache */
   /* search713_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2159, 2160 },
      -1,
   } },

   /* replace713_0_0 -> 16 in the cache */
   /* replace713_0_1 -> 36 in the cache */
   /* replace713_0 -> 2157 in the cache */
   /* replace713_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2157, 124 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search714_0_0 -> 16 in the cache */
   /* search714_0_1 -> 124 in the cache */
   /* search714_0 -> 2154 in the cache */
   /* search714_1_0 -> 36 in the cache */
   /* search714_1_1 -> 124 in the cache */
   /* search714_1 -> 2155 in the cache */
   /* search714 -> 2156 in the cache */

   /* replace714_0_0 -> 16 in the cache */
   /* replace714_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace714_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2163, 124 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search715_0_0 -> 16 in the cache */
   /* search715_0_1 -> 124 in the cache */
   /* search715_0 -> 2154 in the cache */
   /* search715_1_0 -> 36 in the cache */
   /* search715_1_1 -> 124 in the cache */
   /* search715_1 -> 2155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2154, 2155 },
      -1,
   } },

   /* replace715_0_0 -> 16 in the cache */
   /* replace715_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace715_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2166, 124 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search716_0_0 -> 16 in the cache */
   /* search716_0_1 -> 124 in the cache */
   /* search716_0 -> 2159 in the cache */
   /* search716_1_0 -> 36 in the cache */
   /* search716_1_1 -> 124 in the cache */
   /* search716_1 -> 2160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2159, 2160 },
      -1,
   } },

   /* replace716_0_0 -> 16 in the cache */
   /* replace716_0_1 -> 36 in the cache */
   /* replace716_0 -> 2166 in the cache */
   /* replace716_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2166, 124 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search717_0_0 -> 16 in the cache */
   /* search717_0_1 -> 124 in the cache */
   /* search717_0 -> 2159 in the cache */
   /* search717_1_0 -> 36 in the cache */
   /* search717_1_1 -> 124 in the cache */
   /* search717_1 -> 2160 in the cache */
   /* search717 -> 2161 in the cache */

   /* replace717_0_0 -> 16 in the cache */
   /* replace717_0_1 -> 36 in the cache */
   /* replace717_0 -> 2163 in the cache */
   /* replace717_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2163, 124 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search718_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2171 },
      -1,
   } },

   /* replace718 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search719_0 -> 16 in the cache */
   /* search719_1_0 -> 19 in the cache */
   /* search719_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2173 },
      -1,
   } },

   /* replace719_0 -> 16 in the cache */
   /* replace719_1 -> 36 in the cache */
   /* replace719 -> 925 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search720_0 -> 16 in the cache */
   /* search720_1_0 -> 19 in the cache */
   /* search720_1_1 -> 36 in the cache */
   /* search720_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2173 },
      -1,
   } },

   /* replace720_0 -> 16 in the cache */
   /* replace720_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search721_0 -> 16 in the cache */
   /* search721_1_0 -> 19 in the cache */
   /* search721_1_1 -> 36 in the cache */
   /* search721_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2173 },
      -1,
   } },

   /* replace721_0 -> 16 in the cache */
   /* replace721_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4)) */
   /* search722_0 -> 16 in the cache */
   /* search722_1_0_0 -> 36 in the cache */
   /* search722_1_0_1 -> 398 in the cache */
   /* search722_1_0 -> 2119 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2119, 2179 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2180 },
      -1,
   } },

   /* replace722_0 -> 16 in the cache */
   /* replace722_1_0 -> 36 in the cache */
   /* replace722_1_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2182 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search723_0_0 -> 21 in the cache */
   /* search723_0_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 876 },
      -1,
   } },
   /* search723_1_0 -> 41 in the cache */
   /* search723_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2184, 2185 },
      -1,
   } },

   /* replace723_0_0 -> 21 in the cache */
   /* replace723_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace723_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2187, 876 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search724_0_0 -> 21 in the cache */
   /* search724_0_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 876 },
      -1,
   } },
   /* search724_1_0 -> 41 in the cache */
   /* search724_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2189, 2190 },
      -1,
   } },

   /* replace724_0_0 -> 21 in the cache */
   /* replace724_0_1 -> 41 in the cache */
   /* replace724_0 -> 2187 in the cache */
   /* replace724_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2187, 876 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search725_0_0 -> 21 in the cache */
   /* search725_0_1 -> 876 in the cache */
   /* search725_0 -> 2184 in the cache */
   /* search725_1_0 -> 41 in the cache */
   /* search725_1_1 -> 876 in the cache */
   /* search725_1 -> 2185 in the cache */
   /* search725 -> 2186 in the cache */

   /* replace725_0_0 -> 21 in the cache */
   /* replace725_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace725_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2193, 876 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search726_0_0 -> 21 in the cache */
   /* search726_0_1 -> 876 in the cache */
   /* search726_0 -> 2184 in the cache */
   /* search726_1_0 -> 41 in the cache */
   /* search726_1_1 -> 876 in the cache */
   /* search726_1 -> 2185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2184, 2185 },
      -1,
   } },

   /* replace726_0_0 -> 21 in the cache */
   /* replace726_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace726_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2196, 876 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search727_0_0 -> 21 in the cache */
   /* search727_0_1 -> 876 in the cache */
   /* search727_0 -> 2189 in the cache */
   /* search727_1_0 -> 41 in the cache */
   /* search727_1_1 -> 876 in the cache */
   /* search727_1 -> 2190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2189, 2190 },
      -1,
   } },

   /* replace727_0_0 -> 21 in the cache */
   /* replace727_0_1 -> 41 in the cache */
   /* replace727_0 -> 2196 in the cache */
   /* replace727_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2196, 876 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search728_0_0 -> 21 in the cache */
   /* search728_0_1 -> 876 in the cache */
   /* search728_0 -> 2189 in the cache */
   /* search728_1_0 -> 41 in the cache */
   /* search728_1_1 -> 876 in the cache */
   /* search728_1 -> 2190 in the cache */
   /* search728 -> 2191 in the cache */

   /* replace728_0_0 -> 21 in the cache */
   /* replace728_0_1 -> 41 in the cache */
   /* replace728_0 -> 2193 in the cache */
   /* replace728_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2193, 876 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search729_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2201 },
      -1,
   } },

   /* replace729 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search730_0 -> 21 in the cache */
   /* search730_1_0 -> 24 in the cache */
   /* search730_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2203 },
      -1,
   } },

   /* replace730_0 -> 21 in the cache */
   /* replace730_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search731_0 -> 21 in the cache */
   /* search731_1_0 -> 24 in the cache */
   /* search731_1_1 -> 36 in the cache */
   /* search731_1 -> 2203 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2203 },
      -1,
   } },

   /* replace731_0 -> 21 in the cache */
   /* replace731_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search732_0 -> 21 in the cache */
   /* search732_1_0 -> 24 in the cache */
   /* search732_1_1 -> 36 in the cache */
   /* search732_1 -> 2203 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2203 },
      -1,
   } },

   /* replace732_0 -> 21 in the cache */
   /* replace732_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5)) */
   /* search733_0 -> 21 in the cache */
   /* search733_1_0_0 -> 36 in the cache */
   /* search733_1_0_1 -> 398 in the cache */
   /* search733_1_0 -> 2119 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2119, 2210 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2211 },
      -1,
   } },

   /* replace733_0 -> 21 in the cache */
   /* replace733_1_0 -> 36 in the cache */
   /* replace733_1_1 -> 2210 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2210 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2213 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search734_0_0 -> 32 in the cache */
   /* search734_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search734_1_0 -> 32 in the cache */
   /* search734_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2215, 2216 },
      -1,
   } },

   /* replace734_0 -> 35 in the cache */
   /* replace734_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search735_0_0 -> 35 in the cache */
   /* search735_0_1 -> 32 in the cache */
   /* search735_0 -> 2218 in the cache */
   /* search735_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2218, 2220 },
      -1,
   } },

   /* replace735_0 -> 2219 in the cache */
   /* replace735_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2219, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search736_0_0 -> 2219 in the cache */
   /* search736_0_1 -> 32 in the cache */
   /* search736_0 -> 2222 in the cache */
   /* search736_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2223 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2222, 2224 },
      -1,
   } },

   /* replace736_0 -> 2223 in the cache */
   /* replace736_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2223, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search737_0 -> 739 in the cache */
   /* search737_1_0 -> 739 in the cache */
   /* search737_1_1 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 739, 1056 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 739, 2227 },
      -1,
   } },

   /* replace737 -> 1209 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search738_0_0_0 -> 739 in the cache */
   /* search738_0_0 -> 1200 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1200 },
      -1,
   } },
   /* search738_1_0_0 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2230 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace738_0 -> 739 in the cache */
   /* replace738_1 -> 1107 in the cache */
   /* replace738 -> 1368 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search739_0_0 -> 739 in the cache */
   /* search739_0_1 -> 1107 in the cache */
   /* search739_0 -> 1368 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1368 },
      -1,
   } },

   /* replace739_0_0 -> 739 in the cache */
   /* replace739_0_1 -> 1107 in the cache */
   /* replace739_0 -> 1124 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1124 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search740_0_0_0_0_0 -> 32 in the cache */
   /* search740_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search740_0_0_0_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2235, 1107 },
      -1,
   } },
   /* search740_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2236, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2237 },
      -1,
   } },
   /* search740_1_0 -> 32 in the cache */
   /* search740_1_1 -> 61 in the cache */
   /* search740_1 -> 1223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2238, 1223 },
      -1,
   } },

   /* replace740_0_0_0 -> 1107 in the cache */
   /* replace740_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1107, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2240 },
      -1,
   } },
   /* replace740_1_0 -> 32 in the cache */
   /* replace740_1_1 -> 61 in the cache */
   /* replace740_1 -> 1223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2241, 1223 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search741_0_0_0_0_0 -> 0 in the cache */
   /* search741_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search741_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2243, 86 },
      -1,
   } },
   /* search741_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2244, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2245 },
      -1,
   } },
   /* search741_1_0 -> 0 in the cache */
   /* search741_1_1 -> 86 in the cache */
   /* search741_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2246, 90 },
      -1,
   } },

   /* replace741_0_0_0_0 -> 3 in the cache */
   /* replace741_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace741_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2248, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2249 },
      -1,
   } },
   /* replace741_1_0 -> 0 in the cache */
   /* replace741_1_1 -> 86 in the cache */
   /* replace741_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2250, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search742_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search742_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2253 },
      -1,
   } },

   /* replace742_0 -> 32 in the cache */
   /* replace742_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search743_0_0 -> 0 in the cache */
   /* search743_0_1 -> 3 in the cache */
   /* search743_0 -> 1257 in the cache */
   /* search743_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1257, 0 },
      -1,
   } },

   /* replace743_0 -> 3 in the cache */
   /* replace743_1 -> 0 in the cache */
   /* replace743 -> 1057 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search744_0 -> 32 in the cache */
   /* search744_1_0 -> 2252 in the cache */
   /* search744_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2257 },
      -1,
   } },

   /* replace744 -> 1209 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search745_0_0 -> 0 in the cache */
   /* search745_0_1 -> 3 in the cache */
   /* search745_0 -> 1255 in the cache */
   /* search745_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1255, 0 },
      -1,
   } },

   /* replace745 -> 1209 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search746_0 -> 32 in the cache */
   /* search746_1_0 -> 2252 in the cache */
   /* search746_1_1 -> 32 in the cache */
   /* search746_1 -> 2257 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2257 },
      -1,
   } },

   /* replace746 -> 1056 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search747_0_0 -> 0 in the cache */
   /* search747_0_1 -> 3 in the cache */
   /* search747_0 -> 1255 in the cache */
   /* search747_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1255, 0 },
      -1,
   } },

   /* replace747 -> 1056 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search748_0 -> 32 in the cache */
   /* search748_1_0 -> 2252 in the cache */
   /* search748_1_1 -> 32 in the cache */
   /* search748_1 -> 2253 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2253 },
      -1,
   } },

   /* replace748_0 -> 32 in the cache */
   /* replace748_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search749_0_0 -> 0 in the cache */
   /* search749_0_1 -> 3 in the cache */
   /* search749_0 -> 1257 in the cache */
   /* search749_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1257, 0 },
      -1,
   } },

   /* replace749_0 -> 3 in the cache */
   /* replace749_1 -> 0 in the cache */
   /* replace749 -> 1069 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search750_0 -> 32 in the cache */
   /* search750_1_0 -> 2252 in the cache */
   /* search750_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2265 },
      -1,
   } },

   /* replace750_0 -> 32 in the cache */
   /* replace750_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search751_0_0 -> 0 in the cache */
   /* search751_0_1 -> 3 in the cache */
   /* search751_0 -> 1277 in the cache */
   /* search751_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1277, 0 },
      -1,
   } },

   /* replace751_0 -> 3 in the cache */
   /* replace751_1 -> 0 in the cache */
   /* replace751 -> 1062 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search752_0 -> 32 in the cache */
   /* search752_1_0 -> 2252 in the cache */
   /* search752_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2269 },
      -1,
   } },

   /* replace752 -> 1209 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search753_0_0 -> 0 in the cache */
   /* search753_0_1 -> 3 in the cache */
   /* search753_0 -> 1275 in the cache */
   /* search753_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1275, 0 },
      -1,
   } },

   /* replace753 -> 1209 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search754_0 -> 32 in the cache */
   /* search754_1_0 -> 2252 in the cache */
   /* search754_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2272 },
      -1,
   } },

   /* replace754_0 -> 32 in the cache */
   /* replace754_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search755_0_0 -> 0 in the cache */
   /* search755_0_1 -> 3 in the cache */
   /* search755_0 -> 1267 in the cache */
   /* search755_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1267, 0 },
      -1,
   } },

   /* replace755_0 -> 3 in the cache */
   /* replace755_1 -> 0 in the cache */
   /* replace755 -> 1064 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search756_0 -> 32 in the cache */
   /* search756_1_0 -> 2252 in the cache */
   /* search756_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2276 },
      -1,
   } },

   /* replace756 -> 1209 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search757_0_0 -> 0 in the cache */
   /* search757_0_1 -> 3 in the cache */
   /* search757_0 -> 1265 in the cache */
   /* search757_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1265, 0 },
      -1,
   } },

   /* replace757 -> 1209 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search758_0 -> 32 in the cache */
   /* search758_1_0 -> 2252 in the cache */
   /* search758_1_1 -> 32 in the cache */
   /* search758_1 -> 2269 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2269 },
      -1,
   } },

   /* replace758 -> 1056 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search759_0_0 -> 0 in the cache */
   /* search759_0_1 -> 3 in the cache */
   /* search759_0 -> 1275 in the cache */
   /* search759_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1275, 0 },
      -1,
   } },

   /* replace759 -> 1056 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search760_0 -> 32 in the cache */
   /* search760_1_0 -> 2252 in the cache */
   /* search760_1_1 -> 32 in the cache */
   /* search760_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2265 },
      -1,
   } },

   /* replace760_0 -> 32 in the cache */
   /* replace760_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search761_0_0 -> 0 in the cache */
   /* search761_0_1 -> 3 in the cache */
   /* search761_0 -> 1277 in the cache */
   /* search761_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1277, 0 },
      -1,
   } },

   /* replace761_0 -> 3 in the cache */
   /* replace761_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search762_0 -> 32 in the cache */
   /* search762_1_0 -> 2252 in the cache */
   /* search762_1_1 -> 32 in the cache */
   /* search762_1 -> 2276 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2276 },
      -1,
   } },

   /* replace762 -> 1056 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search763_0_0 -> 0 in the cache */
   /* search763_0_1 -> 3 in the cache */
   /* search763_0 -> 1265 in the cache */
   /* search763_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1265, 0 },
      -1,
   } },

   /* replace763 -> 1056 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search764_0 -> 32 in the cache */
   /* search764_1_0 -> 2252 in the cache */
   /* search764_1_1 -> 32 in the cache */
   /* search764_1 -> 2272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2272 },
      -1,
   } },

   /* replace764_0 -> 32 in the cache */
   /* replace764_1 -> 2252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2252 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   /* search765_0 -> 1267 in the cache */
   /* search765_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1267, 0 },
      -1,
   } },

   /* replace765_0 -> 3 in the cache */
   /* replace765_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search766_0 -> 32 in the cache */
   /* search766_1_0 -> 2252 in the cache */
   /* search766_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2291 },
      -1,
   } },

   /* replace766 -> 1056 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search767_0_0 -> 0 in the cache */
   /* search767_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search767_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2293, 0 },
      -1,
   } },

   /* replace767 -> 1056 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search768_0 -> 32 in the cache */
   /* search768_1_0 -> 2252 in the cache */
   /* search768_1_1 -> 32 in the cache */
   /* search768_1 -> 2291 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2291 },
      -1,
   } },

   /* replace768 -> 1209 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search769_0_0 -> 0 in the cache */
   /* search769_0_1 -> 3 in the cache */
   /* search769_0 -> 2293 in the cache */
   /* search769_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2293, 0 },
      -1,
   } },

   /* replace769 -> 1209 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search770_0 -> 284 in the cache */
   /* search770_1_0 -> 285 in the cache */
   /* search770_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 284, 2297 },
      -1,
   } },

   /* replace770_0_0 -> 128 in the cache */
   /* replace770_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace770_1_0 -> 128 in the cache */
   /* replace770_1_1 -> 131 in the cache */
   /* replace770_1 -> 1634 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2299, 1634 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search771_0_0 -> 284 in the cache */
   /* search771_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search771_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2301, 793 },
      -1,
   } },

   /* replace771_0_0 -> 128 in the cache */
   /* replace771_0_1 -> 131 in the cache */
   /* replace771_0 -> 1634 in the cache */
   /* replace771_1_0 -> 129 in the cache */
   /* replace771_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1634, 2303 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search772_0 -> 284 in the cache */
   /* search772_1_0 -> 285 in the cache */
   /* search772_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 284, 2305 },
      -1,
   } },

   /* replace772_0_0 -> 128 in the cache */
   /* replace772_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace772_1_0 -> 128 in the cache */
   /* replace772_1_1 -> 131 in the cache */
   /* replace772_1 -> 1644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2307, 1644 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search773_0_0 -> 284 in the cache */
   /* search773_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search773_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2309, 793 },
      -1,
   } },

   /* replace773_0_0 -> 128 in the cache */
   /* replace773_0_1 -> 131 in the cache */
   /* replace773_0 -> 1644 in the cache */
   /* replace773_1_0 -> 129 in the cache */
   /* replace773_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1644, 2311 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search774_0 -> 284 in the cache */
   /* search774_1_0 -> 285 in the cache */
   /* search774_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 284, 2313 },
      -1,
   } },

   /* replace774_0_0 -> 128 in the cache */
   /* replace774_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace774_1_0 -> 128 in the cache */
   /* replace774_1_1 -> 131 in the cache */
   /* replace774_1 -> 1654 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2315, 1654 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search775_0_0 -> 284 in the cache */
   /* search775_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search775_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2317, 793 },
      -1,
   } },

   /* replace775_0_0 -> 128 in the cache */
   /* replace775_0_1 -> 131 in the cache */
   /* replace775_0 -> 1654 in the cache */
   /* replace775_1_0 -> 129 in the cache */
   /* replace775_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1654, 2319 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search776_0 -> 284 in the cache */
   /* search776_1_0 -> 285 in the cache */
   /* search776_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 284, 2321 },
      -1,
   } },

   /* replace776_0_0 -> 128 in the cache */
   /* replace776_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace776_1_0 -> 128 in the cache */
   /* replace776_1_1 -> 131 in the cache */
   /* replace776_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2323, 1664 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search777_0_0 -> 284 in the cache */
   /* search777_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search777_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2325, 793 },
      -1,
   } },

   /* replace777_0_0 -> 128 in the cache */
   /* replace777_0_1 -> 131 in the cache */
   /* replace777_0 -> 1664 in the cache */
   /* replace777_1_0 -> 129 in the cache */
   /* replace777_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1664, 2327 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search778_0 -> 284 in the cache */
   /* search778_1_0 -> 285 in the cache */
   /* search778_1_1 -> 131 in the cache */
   /* search778_1 -> 2305 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 284, 2305 },
      -1,
   } },

   /* replace778_0_0 -> 128 in the cache */
   /* replace778_0_1 -> 129 in the cache */
   /* replace778_0 -> 2299 in the cache */
   /* replace778_1_0 -> 128 in the cache */
   /* replace778_1_1 -> 131 in the cache */
   /* replace778_1 -> 1634 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2299, 1634 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search779_0_0 -> 284 in the cache */
   /* search779_0_1 -> 129 in the cache */
   /* search779_0 -> 2309 in the cache */
   /* search779_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2309, 793 },
      -1,
   } },

   /* replace779_0_0 -> 128 in the cache */
   /* replace779_0_1 -> 131 in the cache */
   /* replace779_0 -> 1634 in the cache */
   /* replace779_1_0 -> 129 in the cache */
   /* replace779_1_1 -> 131 in the cache */
   /* replace779_1 -> 2303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1634, 2303 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search780_0 -> 284 in the cache */
   /* search780_1_0 -> 285 in the cache */
   /* search780_1_1 -> 131 in the cache */
   /* search780_1 -> 2297 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 284, 2297 },
      -1,
   } },

   /* replace780_0_0 -> 128 in the cache */
   /* replace780_0_1 -> 129 in the cache */
   /* replace780_0 -> 2307 in the cache */
   /* replace780_1_0 -> 128 in the cache */
   /* replace780_1_1 -> 131 in the cache */
   /* replace780_1 -> 1644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2307, 1644 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search781_0_0 -> 284 in the cache */
   /* search781_0_1 -> 129 in the cache */
   /* search781_0 -> 2301 in the cache */
   /* search781_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2301, 793 },
      -1,
   } },

   /* replace781_0_0 -> 128 in the cache */
   /* replace781_0_1 -> 131 in the cache */
   /* replace781_0 -> 1644 in the cache */
   /* replace781_1_0 -> 129 in the cache */
   /* replace781_1_1 -> 131 in the cache */
   /* replace781_1 -> 2311 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1644, 2311 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search782_0 -> 284 in the cache */
   /* search782_1_0 -> 285 in the cache */
   /* search782_1_1 -> 131 in the cache */
   /* search782_1 -> 2321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 284, 2321 },
      -1,
   } },

   /* replace782_0_0 -> 128 in the cache */
   /* replace782_0_1 -> 129 in the cache */
   /* replace782_0 -> 2315 in the cache */
   /* replace782_1_0 -> 128 in the cache */
   /* replace782_1_1 -> 131 in the cache */
   /* replace782_1 -> 1654 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2315, 1654 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search783_0_0 -> 284 in the cache */
   /* search783_0_1 -> 129 in the cache */
   /* search783_0 -> 2325 in the cache */
   /* search783_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2325, 793 },
      -1,
   } },

   /* replace783_0_0 -> 128 in the cache */
   /* replace783_0_1 -> 131 in the cache */
   /* replace783_0 -> 1654 in the cache */
   /* replace783_1_0 -> 129 in the cache */
   /* replace783_1_1 -> 131 in the cache */
   /* replace783_1 -> 2319 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1654, 2319 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search784_0 -> 284 in the cache */
   /* search784_1_0 -> 285 in the cache */
   /* search784_1_1 -> 131 in the cache */
   /* search784_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 284, 2313 },
      -1,
   } },

   /* replace784_0_0 -> 128 in the cache */
   /* replace784_0_1 -> 129 in the cache */
   /* replace784_0 -> 2323 in the cache */
   /* replace784_1_0 -> 128 in the cache */
   /* replace784_1_1 -> 131 in the cache */
   /* replace784_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2323, 1664 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search785_0_0 -> 284 in the cache */
   /* search785_0_1 -> 129 in the cache */
   /* search785_0 -> 2317 in the cache */
   /* search785_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2317, 793 },
      -1,
   } },

   /* replace785_0_0 -> 128 in the cache */
   /* replace785_0_1 -> 131 in the cache */
   /* replace785_0 -> 1664 in the cache */
   /* replace785_1_0 -> 129 in the cache */
   /* replace785_1_1 -> 131 in the cache */
   /* replace785_1 -> 2327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1664, 2327 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search786_0_0 -> 32 in the cache */
   /* search786_0_1 -> 61 in the cache */
   /* search786_0 -> 1223 in the cache */
   /* search786_1_0_0 -> 32 in the cache */
   /* search786_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2345 },
      -1,
   } },
   /* search786_2_0 -> 32 in the cache */
   /* search786_2_1 -> 36 in the cache */
   /* search786_2 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1223, 2346, 2345 },
      -1,
   } },

   /* replace786_0_0 -> 32 in the cache */
   /* replace786_0_1 -> 36 in the cache */
   /* replace786_0 -> 2345 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2345 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search787_0_0_0 -> 32 in the cache */
   /* search787_0_0 -> 106 in the cache */
   /* search787_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2349 },
      -1,
   } },

   /* replace787_0_0 -> 32 in the cache */
   /* replace787_0 -> 106 in the cache */
   /* replace787_1 -> 36 in the cache */
   /* replace787 -> 2349 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search788_0_0 -> 0 in the cache */
   /* search788_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2351 },
      -1,
   } },

   /* replace788_0 -> 0 in the cache */
   /* replace788_1 -> 3 in the cache */
   /* replace788 -> 2351 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search789_0_0 -> 0 in the cache */
   /* search789_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2353 },
      -1,
   } },

   /* replace789_0 -> 0 in the cache */
   /* replace789_1 -> 3 in the cache */
   /* replace789 -> 2353 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search790_0_0 -> 0 in the cache */
   /* search790_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2355 },
      -1,
   } },

   /* replace790_0 -> 0 in the cache */
   /* replace790_1 -> 3 in the cache */
   /* replace790 -> 2355 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search791_0_0 -> 0 in the cache */
   /* search791_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2357 },
      -1,
   } },

   /* replace791_0 -> 0 in the cache */
   /* replace791_1 -> 3 in the cache */
   /* replace791 -> 2357 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search792_0 -> 0 in the cache */
   /* search792_1 -> 3 in the cache */
   /* search792 -> 2351 in the cache */

   /* replace792_0_0 -> 0 in the cache */
   /* replace792_0_1 -> 3 in the cache */
   /* replace792_0 -> 1028 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1028 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search793_0 -> 0 in the cache */
   /* search793_1 -> 3 in the cache */
   /* search793 -> 2353 in the cache */

   /* replace793_0_0 -> 0 in the cache */
   /* replace793_0_1 -> 3 in the cache */
   /* replace793_0 -> 1025 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1025 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search794_0 -> 0 in the cache */
   /* search794_1 -> 3 in the cache */
   /* search794 -> 2355 in the cache */

   /* replace794_0_0 -> 0 in the cache */
   /* replace794_0_1 -> 3 in the cache */
   /* replace794_0 -> 1034 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1034 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search795_0 -> 0 in the cache */
   /* search795_1 -> 3 in the cache */
   /* search795 -> 2357 in the cache */

   /* replace795_0_0 -> 0 in the cache */
   /* replace795_0_1 -> 3 in the cache */
   /* replace795_0 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1031 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search796_0_0 -> 0 in the cache */
   /* search796_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search796_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2363, 272 },
      -1,
   } },

   /* replace796_0 -> 0 in the cache */
   /* replace796_1 -> 3 in the cache */
   /* replace796 -> 2355 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search797_0_0 -> 0 in the cache */
   /* search797_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search797_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2365, 272 },
      -1,
   } },

   /* replace797_0 -> 0 in the cache */
   /* replace797_1 -> 3 in the cache */
   /* replace797 -> 2357 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search798_0_0 -> 0 in the cache */
   /* search798_0_1 -> 3 in the cache */
   /* search798_0 -> 2351 in the cache */
   /* search798_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2351, 272 },
      -1,
   } },

   /* replace798_0 -> 0 in the cache */
   /* replace798_1 -> 3 in the cache */
   /* replace798 -> 2351 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search799_0_0 -> 0 in the cache */
   /* search799_0_1 -> 3 in the cache */
   /* search799_0 -> 2353 in the cache */
   /* search799_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2353, 272 },
      -1,
   } },

   /* replace799_0 -> 0 in the cache */
   /* replace799_1 -> 3 in the cache */
   /* replace799 -> 2353 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search800_0_0 -> 0 in the cache */
   /* search800_0_1 -> 3 in the cache */
   /* search800_0 -> 2363 in the cache */
   /* search800_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2363, 258 },
      -1,
   } },

   /* replace800_0 -> 0 in the cache */
   /* replace800_1 -> 3 in the cache */
   /* replace800 -> 2355 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search801_0_0 -> 0 in the cache */
   /* search801_0_1 -> 3 in the cache */
   /* search801_0 -> 2365 in the cache */
   /* search801_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2365, 258 },
      -1,
   } },

   /* replace801_0 -> 0 in the cache */
   /* replace801_1 -> 3 in the cache */
   /* replace801 -> 2357 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search802_0_0 -> 0 in the cache */
   /* search802_0_1 -> 3 in the cache */
   /* search802_0 -> 2351 in the cache */
   /* search802_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2351, 258 },
      -1,
   } },

   /* replace802_0 -> 0 in the cache */
   /* replace802_1 -> 3 in the cache */
   /* replace802 -> 2351 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search803_0_0 -> 0 in the cache */
   /* search803_0_1 -> 3 in the cache */
   /* search803_0 -> 2353 in the cache */
   /* search803_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2353, 258 },
      -1,
   } },

   /* replace803_0 -> 0 in the cache */
   /* replace803_1 -> 3 in the cache */
   /* replace803 -> 2353 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search804_0_0 -> 0 in the cache */
   /* search804_0_1 -> 3 in the cache */
   /* search804_0 -> 2363 in the cache */
   /* search804_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2363, 258 },
      -1,
   } },

   /* replace804_0 -> 0 in the cache */
   /* replace804_1 -> 3 in the cache */
   /* replace804 -> 2357 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search805_0_0 -> 0 in the cache */
   /* search805_0_1 -> 3 in the cache */
   /* search805_0 -> 2365 in the cache */
   /* search805_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2365, 258 },
      -1,
   } },

   /* replace805_0 -> 0 in the cache */
   /* replace805_1 -> 3 in the cache */
   /* replace805 -> 2355 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search806_0_0 -> 0 in the cache */
   /* search806_0_1 -> 3 in the cache */
   /* search806_0 -> 2351 in the cache */
   /* search806_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2351, 258 },
      -1,
   } },

   /* replace806_0 -> 0 in the cache */
   /* replace806_1 -> 3 in the cache */
   /* replace806 -> 2353 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search807_0_0 -> 0 in the cache */
   /* search807_0_1 -> 3 in the cache */
   /* search807_0 -> 2353 in the cache */
   /* search807_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2353, 258 },
      -1,
   } },

   /* replace807_0 -> 0 in the cache */
   /* replace807_1 -> 3 in the cache */
   /* replace807 -> 2351 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search808_0_0 -> 0 in the cache */
   /* search808_0_1 -> 3 in the cache */
   /* search808_0 -> 2363 in the cache */
   /* search808_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2363, 272 },
      -1,
   } },

   /* replace808_0 -> 0 in the cache */
   /* replace808_1 -> 3 in the cache */
   /* replace808 -> 2357 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search809_0_0 -> 0 in the cache */
   /* search809_0_1 -> 3 in the cache */
   /* search809_0 -> 2365 in the cache */
   /* search809_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2365, 272 },
      -1,
   } },

   /* replace809_0 -> 0 in the cache */
   /* replace809_1 -> 3 in the cache */
   /* replace809 -> 2355 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search810_0_0 -> 0 in the cache */
   /* search810_0_1 -> 3 in the cache */
   /* search810_0 -> 2351 in the cache */
   /* search810_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2351, 272 },
      -1,
   } },

   /* replace810_0 -> 0 in the cache */
   /* replace810_1 -> 3 in the cache */
   /* replace810 -> 2353 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search811_0_0 -> 0 in the cache */
   /* search811_0_1 -> 3 in the cache */
   /* search811_0 -> 2353 in the cache */
   /* search811_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2353, 272 },
      -1,
   } },

   /* replace811_0 -> 0 in the cache */
   /* replace811_1 -> 3 in the cache */
   /* replace811 -> 2351 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search812_0 -> 16 in the cache */
   /* search812_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2382, 2383 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2385, 2386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2384, 2387 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search813_0 -> 16 in the cache */
   /* search813_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace813_0_0 -> 16 in the cache */
   /* replace813_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace813_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2390, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search814_0 -> 16 in the cache */
   /* search814_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace814_0_0 -> 16 in the cache */
   /* replace814_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace814_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2393, 117 },
      -1,
   } },

   /* ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0) */
   /* search815_0 -> 16 in the cache */
   /* search815_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace815_0_0 -> 16 in the cache */
   /* replace815_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace815_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2396, 117 },
      -1,
   } },

   /* ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0) */
   /* search816_0 -> 16 in the cache */
   /* search816_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace816_0_0 -> 16 in the cache */
   /* replace816_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace816_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2399, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search817_0 -> 16 in the cache */
   /* search817_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace817_0_0 -> 2382 in the cache */
   /* replace817_0_1 -> 2383 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2382, 2383 },
      -1,
   } },
   /* replace817_1_0 -> 2385 in the cache */
   /* replace817_1_1 -> 2386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2385, 2386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2402, 2403 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search818_0 -> 16 in the cache */
   /* search818_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace818_0_0_0 -> 16 in the cache */
   /* replace818_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace818_0_1_0 -> 16 in the cache */
   /* replace818_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2406, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2408 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search819_0 -> 16 in the cache */
   /* search819_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace819_0_0_0 -> 16 in the cache */
   /* replace819_0_0_1 -> 36 in the cache */
   /* replace819_0_0 -> 2406 in the cache */
   /* replace819_0_1_0 -> 16 in the cache */
   /* replace819_0_1_1 -> 36 in the cache */
   /* replace819_0_1 -> 2407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2406, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2411 },
      -1,
   } },

   /* ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search820_0 -> 16 in the cache */
   /* search820_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace820_0_0_0 -> 16 in the cache */
   /* replace820_0_0_1 -> 36 in the cache */
   /* replace820_0_0 -> 2406 in the cache */
   /* replace820_0_1_0 -> 16 in the cache */
   /* replace820_0_1_1 -> 36 in the cache */
   /* replace820_0_1 -> 2407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot8,
      -1, 2,
      { 2406, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2414 },
      -1,
   } },

   /* ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search821_0 -> 16 in the cache */
   /* search821_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace821_0_0_0 -> 16 in the cache */
   /* replace821_0_0_1 -> 36 in the cache */
   /* replace821_0_0 -> 2406 in the cache */
   /* replace821_0_1_0 -> 16 in the cache */
   /* replace821_0_1_1 -> 36 in the cache */
   /* replace821_0_1 -> 2407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot16,
      -1, 2,
      { 2406, 2407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2417 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search822_0 -> 0 in the cache */
   /* search822_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace822_0_0 -> 748 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace822_1_0 -> 749 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 749, 2422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2421, 2423 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z'))) */
   /* search823_0 -> 0 in the cache */
   /* search823_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace823_0_0 -> 748 in the cache */
   /* replace823_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace823_1_0_0 -> 749 in the cache */
   /* replace823_1_0_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 749, 2422 },
      -1,
   } },
   /* replace823_1_1_0 -> 750 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 750, 2428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2427, 2429 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2426, 2430 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search824_0 -> 0 in the cache */
   /* search824_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace824_0_0_0 -> 748 in the cache */
   /* replace824_0_0_1 -> 2420 in the cache */
   /* replace824_0_0 -> 2421 in the cache */
   /* replace824_0_1_0 -> 749 in the cache */
   /* replace824_0_1_1 -> 2422 in the cache */
   /* replace824_0_1 -> 2423 in the cache */
   /* replace824_0 -> 2424 in the cache */
   /* replace824_1_0_0 -> 750 in the cache */
   /* replace824_1_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 750, 2428 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2434, 2435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2433, 2436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2424, 2437 },
      -1,
   } },

   /* ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))) */
   /* search825_0 -> 0 in the cache */
   /* search825_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace825_0_0_0_0 -> 748 in the cache */
   /* replace825_0_0_0_1 -> 2420 in the cache */
   /* replace825_0_0_0 -> 2421 in the cache */
   /* replace825_0_0_1_0 -> 749 in the cache */
   /* replace825_0_0_1_1 -> 2422 in the cache */
   /* replace825_0_0_1 -> 2423 in the cache */
   /* replace825_0_0 -> 2424 in the cache */
   /* replace825_0_1_0_0 -> 750 in the cache */
   /* replace825_0_1_0_1 -> 2428 in the cache */
   /* replace825_0_1_0 -> 2433 in the cache */
   /* replace825_0_1_1_0 -> 2434 in the cache */
   /* replace825_0_1_1_1 -> 2435 in the cache */
   /* replace825_0_1_1 -> 2436 in the cache */
   /* replace825_0_1 -> 2437 in the cache */
   /* replace825_0 -> 2438 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      4, 1,
      { 2440, 2441 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      5, 1,
      { 2443, 2444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2442, 2445 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      6, 1,
      { 2447, 2448 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      7, 1,
      { 2450, 2451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2449, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2446, 2453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2438, 2454 },
      -1,
   } },

   /* ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p'))))) */
   /* search826_0 -> 0 in the cache */
   /* search826_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace826_0_0_0_0_0 -> 748 in the cache */
   /* replace826_0_0_0_0_1 -> 2420 in the cache */
   /* replace826_0_0_0_0 -> 2421 in the cache */
   /* replace826_0_0_0_1_0 -> 749 in the cache */
   /* replace826_0_0_0_1_1 -> 2422 in the cache */
   /* replace826_0_0_0_1 -> 2423 in the cache */
   /* replace826_0_0_0 -> 2424 in the cache */
   /* replace826_0_0_1_0_0 -> 750 in the cache */
   /* replace826_0_0_1_0_1 -> 2428 in the cache */
   /* replace826_0_0_1_0 -> 2433 in the cache */
   /* replace826_0_0_1_1_0 -> 2434 in the cache */
   /* replace826_0_0_1_1_1 -> 2435 in the cache */
   /* replace826_0_0_1_1 -> 2436 in the cache */
   /* replace826_0_0_1 -> 2437 in the cache */
   /* replace826_0_0 -> 2438 in the cache */
   /* replace826_0_1_0_0_0 -> 2440 in the cache */
   /* replace826_0_1_0_0_1 -> 2441 in the cache */
   /* replace826_0_1_0_0 -> 2442 in the cache */
   /* replace826_0_1_0_1_0 -> 2443 in the cache */
   /* replace826_0_1_0_1_1 -> 2444 in the cache */
   /* replace826_0_1_0_1 -> 2445 in the cache */
   /* replace826_0_1_0 -> 2446 in the cache */
   /* replace826_0_1_1_0_0 -> 2447 in the cache */
   /* replace826_0_1_1_0_1 -> 2448 in the cache */
   /* replace826_0_1_1_0 -> 2449 in the cache */
   /* replace826_0_1_1_1_0 -> 2450 in the cache */
   /* replace826_0_1_1_1_1 -> 2451 in the cache */
   /* replace826_0_1_1_1 -> 2452 in the cache */
   /* replace826_0_1_1 -> 2453 in the cache */
   /* replace826_0_1 -> 2454 in the cache */
   /* replace826_0 -> 2455 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      8, 1,
      { 2457, 2458 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      9, 1,
      { 2460, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2459, 2462 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      10, 1,
      { 2464, 2465 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      11, 1,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2466, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2463, 2470 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      12, 1,
      { 2472, 2473 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      13, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2474, 2477 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      14, 1,
      { 2479, 2480 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      15, 1,
      { 2482, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2481, 2484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2478, 2485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2471, 2486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2455, 2487 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search827_0 -> 0 in the cache */
   /* search827_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace827_0_0 -> 748 in the cache */
   /* replace827_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace827_1_0 -> 749 in the cache */
   /* replace827_1_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 749, 2422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2490, 2491 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z'))) */
   /* search828_0 -> 0 in the cache */
   /* search828_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace828_0_0 -> 748 in the cache */
   /* replace828_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace828_1_0_0 -> 749 in the cache */
   /* replace828_1_0_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 749, 2422 },
      -1,
   } },
   /* replace828_1_1_0 -> 750 in the cache */
   /* replace828_1_1_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 750, 2428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2495, 2496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2494, 2497 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search829_0 -> 0 in the cache */
   /* search829_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace829_0_0_0 -> 748 in the cache */
   /* replace829_0_0_1 -> 2420 in the cache */
   /* replace829_0_0 -> 2490 in the cache */
   /* replace829_0_1_0 -> 749 in the cache */
   /* replace829_0_1_1 -> 2422 in the cache */
   /* replace829_0_1 -> 2491 in the cache */
   /* replace829_0 -> 2492 in the cache */
   /* replace829_1_0_0 -> 750 in the cache */
   /* replace829_1_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 750, 2428 },
      -1,
   } },
   /* replace829_1_1_0 -> 2434 in the cache */
   /* replace829_1_1_1 -> 2435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2434, 2435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2500, 2501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2492, 2502 },
      -1,
   } },

   /* ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))) */
   /* search830_0 -> 0 in the cache */
   /* search830_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace830_0_0_0_0 -> 748 in the cache */
   /* replace830_0_0_0_1 -> 2420 in the cache */
   /* replace830_0_0_0 -> 2490 in the cache */
   /* replace830_0_0_1_0 -> 749 in the cache */
   /* replace830_0_0_1_1 -> 2422 in the cache */
   /* replace830_0_0_1 -> 2491 in the cache */
   /* replace830_0_0 -> 2492 in the cache */
   /* replace830_0_1_0_0 -> 750 in the cache */
   /* replace830_0_1_0_1 -> 2428 in the cache */
   /* replace830_0_1_0 -> 2500 in the cache */
   /* replace830_0_1_1_0 -> 2434 in the cache */
   /* replace830_0_1_1_1 -> 2435 in the cache */
   /* replace830_0_1_1 -> 2501 in the cache */
   /* replace830_0_1 -> 2502 in the cache */
   /* replace830_0 -> 2503 in the cache */
   /* replace830_1_0_0_0 -> 2440 in the cache */
   /* replace830_1_0_0_1 -> 2441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      4, 1,
      { 2440, 2441 },
      -1,
   } },
   /* replace830_1_0_1_0 -> 2443 in the cache */
   /* replace830_1_0_1_1 -> 2444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      5, 1,
      { 2443, 2444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2505, 2506 },
      -1,
   } },
   /* replace830_1_1_0_0 -> 2447 in the cache */
   /* replace830_1_1_0_1 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      6, 1,
      { 2447, 2448 },
      -1,
   } },
   /* replace830_1_1_1_0 -> 2450 in the cache */
   /* replace830_1_1_1_1 -> 2451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      7, 1,
      { 2450, 2451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2508, 2509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2507, 2510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2503, 2511 },
      -1,
   } },

   /* ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p'))))) */
   /* search831_0 -> 0 in the cache */
   /* search831_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace831_0_0_0_0_0 -> 748 in the cache */
   /* replace831_0_0_0_0_1 -> 2420 in the cache */
   /* replace831_0_0_0_0 -> 2490 in the cache */
   /* replace831_0_0_0_1_0 -> 749 in the cache */
   /* replace831_0_0_0_1_1 -> 2422 in the cache */
   /* replace831_0_0_0_1 -> 2491 in the cache */
   /* replace831_0_0_0 -> 2492 in the cache */
   /* replace831_0_0_1_0_0 -> 750 in the cache */
   /* replace831_0_0_1_0_1 -> 2428 in the cache */
   /* replace831_0_0_1_0 -> 2500 in the cache */
   /* replace831_0_0_1_1_0 -> 2434 in the cache */
   /* replace831_0_0_1_1_1 -> 2435 in the cache */
   /* replace831_0_0_1_1 -> 2501 in the cache */
   /* replace831_0_0_1 -> 2502 in the cache */
   /* replace831_0_0 -> 2503 in the cache */
   /* replace831_0_1_0_0_0 -> 2440 in the cache */
   /* replace831_0_1_0_0_1 -> 2441 in the cache */
   /* replace831_0_1_0_0 -> 2505 in the cache */
   /* replace831_0_1_0_1_0 -> 2443 in the cache */
   /* replace831_0_1_0_1_1 -> 2444 in the cache */
   /* replace831_0_1_0_1 -> 2506 in the cache */
   /* replace831_0_1_0 -> 2507 in the cache */
   /* replace831_0_1_1_0_0 -> 2447 in the cache */
   /* replace831_0_1_1_0_1 -> 2448 in the cache */
   /* replace831_0_1_1_0 -> 2508 in the cache */
   /* replace831_0_1_1_1_0 -> 2450 in the cache */
   /* replace831_0_1_1_1_1 -> 2451 in the cache */
   /* replace831_0_1_1_1 -> 2509 in the cache */
   /* replace831_0_1_1 -> 2510 in the cache */
   /* replace831_0_1 -> 2511 in the cache */
   /* replace831_0 -> 2512 in the cache */
   /* replace831_1_0_0_0_0 -> 2457 in the cache */
   /* replace831_1_0_0_0_1 -> 2458 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      8, 1,
      { 2457, 2458 },
      -1,
   } },
   /* replace831_1_0_0_1_0 -> 2460 in the cache */
   /* replace831_1_0_0_1_1 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      9, 1,
      { 2460, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2514, 2515 },
      -1,
   } },
   /* replace831_1_0_1_0_0 -> 2464 in the cache */
   /* replace831_1_0_1_0_1 -> 2465 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      10, 1,
      { 2464, 2465 },
      -1,
   } },
   /* replace831_1_0_1_1_0 -> 2467 in the cache */
   /* replace831_1_0_1_1_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      11, 1,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2517, 2518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2516, 2519 },
      -1,
   } },
   /* replace831_1_1_0_0_0 -> 2472 in the cache */
   /* replace831_1_1_0_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      12, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace831_1_1_0_1_0 -> 2475 in the cache */
   /* replace831_1_1_0_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      13, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2521, 2522 },
      -1,
   } },
   /* replace831_1_1_1_0_0 -> 2479 in the cache */
   /* replace831_1_1_1_0_1 -> 2480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      14, 1,
      { 2479, 2480 },
      -1,
   } },
   /* replace831_1_1_1_1_0 -> 2482 in the cache */
   /* replace831_1_1_1_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      15, 1,
      { 2482, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2524, 2525 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2523, 2526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2520, 2527 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2512, 2528 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search832_0 -> 0 in the cache */
   /* search832_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace832_0_0 -> 748 in the cache */
   /* replace832_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace832_1_0 -> 749 in the cache */
   /* replace832_1_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 749, 2422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2531, 2532 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z'))) */
   /* search833_0 -> 0 in the cache */
   /* search833_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace833_0_0 -> 748 in the cache */
   /* replace833_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace833_1_0_0 -> 749 in the cache */
   /* replace833_1_0_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 749, 2422 },
      -1,
   } },
   /* replace833_1_1_0 -> 750 in the cache */
   /* replace833_1_1_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 750, 2428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2536, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2535, 2538 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search834_0 -> 0 in the cache */
   /* search834_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace834_0_0_0 -> 748 in the cache */
   /* replace834_0_0_1 -> 2420 in the cache */
   /* replace834_0_0 -> 2531 in the cache */
   /* replace834_0_1_0 -> 749 in the cache */
   /* replace834_0_1_1 -> 2422 in the cache */
   /* replace834_0_1 -> 2532 in the cache */
   /* replace834_0 -> 2533 in the cache */
   /* replace834_1_0_0 -> 750 in the cache */
   /* replace834_1_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 750, 2428 },
      -1,
   } },
   /* replace834_1_1_0 -> 2434 in the cache */
   /* replace834_1_1_1 -> 2435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2434, 2435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2541, 2542 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2533, 2543 },
      -1,
   } },

   /* ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))) */
   /* search835_0 -> 0 in the cache */
   /* search835_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace835_0_0_0_0 -> 748 in the cache */
   /* replace835_0_0_0_1 -> 2420 in the cache */
   /* replace835_0_0_0 -> 2531 in the cache */
   /* replace835_0_0_1_0 -> 749 in the cache */
   /* replace835_0_0_1_1 -> 2422 in the cache */
   /* replace835_0_0_1 -> 2532 in the cache */
   /* replace835_0_0 -> 2533 in the cache */
   /* replace835_0_1_0_0 -> 750 in the cache */
   /* replace835_0_1_0_1 -> 2428 in the cache */
   /* replace835_0_1_0 -> 2541 in the cache */
   /* replace835_0_1_1_0 -> 2434 in the cache */
   /* replace835_0_1_1_1 -> 2435 in the cache */
   /* replace835_0_1_1 -> 2542 in the cache */
   /* replace835_0_1 -> 2543 in the cache */
   /* replace835_0 -> 2544 in the cache */
   /* replace835_1_0_0_0 -> 2440 in the cache */
   /* replace835_1_0_0_1 -> 2441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      4, 1,
      { 2440, 2441 },
      -1,
   } },
   /* replace835_1_0_1_0 -> 2443 in the cache */
   /* replace835_1_0_1_1 -> 2444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      5, 1,
      { 2443, 2444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2546, 2547 },
      -1,
   } },
   /* replace835_1_1_0_0 -> 2447 in the cache */
   /* replace835_1_1_0_1 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      6, 1,
      { 2447, 2448 },
      -1,
   } },
   /* replace835_1_1_1_0 -> 2450 in the cache */
   /* replace835_1_1_1_1 -> 2451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      7, 1,
      { 2450, 2451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2549, 2550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2548, 2551 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2544, 2552 },
      -1,
   } },

   /* ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p'))))) */
   /* search836_0 -> 0 in the cache */
   /* search836_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace836_0_0_0_0_0 -> 748 in the cache */
   /* replace836_0_0_0_0_1 -> 2420 in the cache */
   /* replace836_0_0_0_0 -> 2531 in the cache */
   /* replace836_0_0_0_1_0 -> 749 in the cache */
   /* replace836_0_0_0_1_1 -> 2422 in the cache */
   /* replace836_0_0_0_1 -> 2532 in the cache */
   /* replace836_0_0_0 -> 2533 in the cache */
   /* replace836_0_0_1_0_0 -> 750 in the cache */
   /* replace836_0_0_1_0_1 -> 2428 in the cache */
   /* replace836_0_0_1_0 -> 2541 in the cache */
   /* replace836_0_0_1_1_0 -> 2434 in the cache */
   /* replace836_0_0_1_1_1 -> 2435 in the cache */
   /* replace836_0_0_1_1 -> 2542 in the cache */
   /* replace836_0_0_1 -> 2543 in the cache */
   /* replace836_0_0 -> 2544 in the cache */
   /* replace836_0_1_0_0_0 -> 2440 in the cache */
   /* replace836_0_1_0_0_1 -> 2441 in the cache */
   /* replace836_0_1_0_0 -> 2546 in the cache */
   /* replace836_0_1_0_1_0 -> 2443 in the cache */
   /* replace836_0_1_0_1_1 -> 2444 in the cache */
   /* replace836_0_1_0_1 -> 2547 in the cache */
   /* replace836_0_1_0 -> 2548 in the cache */
   /* replace836_0_1_1_0_0 -> 2447 in the cache */
   /* replace836_0_1_1_0_1 -> 2448 in the cache */
   /* replace836_0_1_1_0 -> 2549 in the cache */
   /* replace836_0_1_1_1_0 -> 2450 in the cache */
   /* replace836_0_1_1_1_1 -> 2451 in the cache */
   /* replace836_0_1_1_1 -> 2550 in the cache */
   /* replace836_0_1_1 -> 2551 in the cache */
   /* replace836_0_1 -> 2552 in the cache */
   /* replace836_0 -> 2553 in the cache */
   /* replace836_1_0_0_0_0 -> 2457 in the cache */
   /* replace836_1_0_0_0_1 -> 2458 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      8, 1,
      { 2457, 2458 },
      -1,
   } },
   /* replace836_1_0_0_1_0 -> 2460 in the cache */
   /* replace836_1_0_0_1_1 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      9, 1,
      { 2460, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2555, 2556 },
      -1,
   } },
   /* replace836_1_0_1_0_0 -> 2464 in the cache */
   /* replace836_1_0_1_0_1 -> 2465 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      10, 1,
      { 2464, 2465 },
      -1,
   } },
   /* replace836_1_0_1_1_0 -> 2467 in the cache */
   /* replace836_1_0_1_1_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      11, 1,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2558, 2559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2557, 2560 },
      -1,
   } },
   /* replace836_1_1_0_0_0 -> 2472 in the cache */
   /* replace836_1_1_0_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      12, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace836_1_1_0_1_0 -> 2475 in the cache */
   /* replace836_1_1_0_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      13, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2562, 2563 },
      -1,
   } },
   /* replace836_1_1_1_0_0 -> 2479 in the cache */
   /* replace836_1_1_1_0_1 -> 2480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      14, 1,
      { 2479, 2480 },
      -1,
   } },
   /* replace836_1_1_1_1_0 -> 2482 in the cache */
   /* replace836_1_1_1_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      15, 1,
      { 2482, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2565, 2566 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2564, 2567 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2561, 2568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2553, 2569 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search837_0 -> 0 in the cache */
   /* search837_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace837_0_0 -> 748 in the cache */
   /* replace837_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace837_1_0 -> 749 in the cache */
   /* replace837_1_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 749, 2422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2572, 2573 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z'))) */
   /* search838_0 -> 0 in the cache */
   /* search838_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace838_0_0 -> 748 in the cache */
   /* replace838_0_1 -> 2420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 748, 2420 },
      -1,
   } },
   /* replace838_1_0_0 -> 749 in the cache */
   /* replace838_1_0_1 -> 2422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 749, 2422 },
      -1,
   } },
   /* replace838_1_1_0 -> 750 in the cache */
   /* replace838_1_1_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 750, 2428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2577, 2578 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2576, 2579 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search839_0 -> 0 in the cache */
   /* search839_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace839_0_0_0 -> 748 in the cache */
   /* replace839_0_0_1 -> 2420 in the cache */
   /* replace839_0_0 -> 2572 in the cache */
   /* replace839_0_1_0 -> 749 in the cache */
   /* replace839_0_1_1 -> 2422 in the cache */
   /* replace839_0_1 -> 2573 in the cache */
   /* replace839_0 -> 2574 in the cache */
   /* replace839_1_0_0 -> 750 in the cache */
   /* replace839_1_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 750, 2428 },
      -1,
   } },
   /* replace839_1_1_0 -> 2434 in the cache */
   /* replace839_1_1_1 -> 2435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2434, 2435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2582, 2583 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2574, 2584 },
      -1,
   } },

   /* ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))) */
   /* search840_0 -> 0 in the cache */
   /* search840_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace840_0_0_0_0 -> 748 in the cache */
   /* replace840_0_0_0_1 -> 2420 in the cache */
   /* replace840_0_0_0 -> 2572 in the cache */
   /* replace840_0_0_1_0 -> 749 in the cache */
   /* replace840_0_0_1_1 -> 2422 in the cache */
   /* replace840_0_0_1 -> 2573 in the cache */
   /* replace840_0_0 -> 2574 in the cache */
   /* replace840_0_1_0_0 -> 750 in the cache */
   /* replace840_0_1_0_1 -> 2428 in the cache */
   /* replace840_0_1_0 -> 2582 in the cache */
   /* replace840_0_1_1_0 -> 2434 in the cache */
   /* replace840_0_1_1_1 -> 2435 in the cache */
   /* replace840_0_1_1 -> 2583 in the cache */
   /* replace840_0_1 -> 2584 in the cache */
   /* replace840_0 -> 2585 in the cache */
   /* replace840_1_0_0_0 -> 2440 in the cache */
   /* replace840_1_0_0_1 -> 2441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      4, 1,
      { 2440, 2441 },
      -1,
   } },
   /* replace840_1_0_1_0 -> 2443 in the cache */
   /* replace840_1_0_1_1 -> 2444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      5, 1,
      { 2443, 2444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2587, 2588 },
      -1,
   } },
   /* replace840_1_1_0_0 -> 2447 in the cache */
   /* replace840_1_1_0_1 -> 2448 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      6, 1,
      { 2447, 2448 },
      -1,
   } },
   /* replace840_1_1_1_0 -> 2450 in the cache */
   /* replace840_1_1_1_1 -> 2451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      7, 1,
      { 2450, 2451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2590, 2591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2589, 2592 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2585, 2593 },
      -1,
   } },

   /* ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p'))))) */
   /* search841_0 -> 0 in the cache */
   /* search841_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace841_0_0_0_0_0 -> 748 in the cache */
   /* replace841_0_0_0_0_1 -> 2420 in the cache */
   /* replace841_0_0_0_0 -> 2572 in the cache */
   /* replace841_0_0_0_1_0 -> 749 in the cache */
   /* replace841_0_0_0_1_1 -> 2422 in the cache */
   /* replace841_0_0_0_1 -> 2573 in the cache */
   /* replace841_0_0_0 -> 2574 in the cache */
   /* replace841_0_0_1_0_0 -> 750 in the cache */
   /* replace841_0_0_1_0_1 -> 2428 in the cache */
   /* replace841_0_0_1_0 -> 2582 in the cache */
   /* replace841_0_0_1_1_0 -> 2434 in the cache */
   /* replace841_0_0_1_1_1 -> 2435 in the cache */
   /* replace841_0_0_1_1 -> 2583 in the cache */
   /* replace841_0_0_1 -> 2584 in the cache */
   /* replace841_0_0 -> 2585 in the cache */
   /* replace841_0_1_0_0_0 -> 2440 in the cache */
   /* replace841_0_1_0_0_1 -> 2441 in the cache */
   /* replace841_0_1_0_0 -> 2587 in the cache */
   /* replace841_0_1_0_1_0 -> 2443 in the cache */
   /* replace841_0_1_0_1_1 -> 2444 in the cache */
   /* replace841_0_1_0_1 -> 2588 in the cache */
   /* replace841_0_1_0 -> 2589 in the cache */
   /* replace841_0_1_1_0_0 -> 2447 in the cache */
   /* replace841_0_1_1_0_1 -> 2448 in the cache */
   /* replace841_0_1_1_0 -> 2590 in the cache */
   /* replace841_0_1_1_1_0 -> 2450 in the cache */
   /* replace841_0_1_1_1_1 -> 2451 in the cache */
   /* replace841_0_1_1_1 -> 2591 in the cache */
   /* replace841_0_1_1 -> 2592 in the cache */
   /* replace841_0_1 -> 2593 in the cache */
   /* replace841_0 -> 2594 in the cache */
   /* replace841_1_0_0_0_0 -> 2457 in the cache */
   /* replace841_1_0_0_0_1 -> 2458 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      8, 1,
      { 2457, 2458 },
      -1,
   } },
   /* replace841_1_0_0_1_0 -> 2460 in the cache */
   /* replace841_1_0_0_1_1 -> 2461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      9, 1,
      { 2460, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2596, 2597 },
      -1,
   } },
   /* replace841_1_0_1_0_0 -> 2464 in the cache */
   /* replace841_1_0_1_0_1 -> 2465 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      10, 1,
      { 2464, 2465 },
      -1,
   } },
   /* replace841_1_0_1_1_0 -> 2467 in the cache */
   /* replace841_1_0_1_1_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      11, 1,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2599, 2600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2598, 2601 },
      -1,
   } },
   /* replace841_1_1_0_0_0 -> 2472 in the cache */
   /* replace841_1_1_0_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      12, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace841_1_1_0_1_0 -> 2475 in the cache */
   /* replace841_1_1_0_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      13, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2603, 2604 },
      -1,
   } },
   /* replace841_1_1_1_0_0 -> 2479 in the cache */
   /* replace841_1_1_1_0_1 -> 2480 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      14, 1,
      { 2479, 2480 },
      -1,
   } },
   /* replace841_1_1_1_1_0 -> 2482 in the cache */
   /* replace841_1_1_1_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      15, 1,
      { 2482, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2606, 2607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2605, 2608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2602, 2609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2594, 2610 },
      -1,
   } },

   /* ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search842_0_0 -> 0 in the cache */
   /* search842_0_1 -> 3 in the cache */
   /* search842_0 -> 2363 in the cache */
   /* search842_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2363, 272 },
      -1,
   } },

   /* replace842_0 -> 0 in the cache */
   /* replace842_1 -> 3 in the cache */
   /* replace842 -> 1034 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search843_0_0 -> 0 in the cache */
   /* search843_0_1 -> 3 in the cache */
   /* search843_0 -> 2365 in the cache */
   /* search843_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2365, 272 },
      -1,
   } },

   /* replace843_0 -> 0 in the cache */
   /* replace843_1 -> 3 in the cache */
   /* replace843 -> 1031 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search844_0_0 -> 0 in the cache */
   /* search844_0_1 -> 3 in the cache */
   /* search844_0 -> 2351 in the cache */
   /* search844_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2351, 272 },
      -1,
   } },

   /* replace844_0 -> 0 in the cache */
   /* replace844_1 -> 3 in the cache */
   /* replace844 -> 1028 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search845_0_0 -> 0 in the cache */
   /* search845_0_1 -> 3 in the cache */
   /* search845_0 -> 2353 in the cache */
   /* search845_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2353, 272 },
      -1,
   } },

   /* replace845_0 -> 0 in the cache */
   /* replace845_1 -> 3 in the cache */
   /* replace845 -> 1025 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search846_0_0 -> 0 in the cache */
   /* search846_0_1 -> 3 in the cache */
   /* search846_0 -> 2363 in the cache */
   /* search846_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2363, 258 },
      -1,
   } },

   /* replace846_0 -> 0 in the cache */
   /* replace846_1 -> 3 in the cache */
   /* replace846 -> 1034 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search847_0_0 -> 0 in the cache */
   /* search847_0_1 -> 3 in the cache */
   /* search847_0 -> 2365 in the cache */
   /* search847_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2365, 258 },
      -1,
   } },

   /* replace847_0 -> 0 in the cache */
   /* replace847_1 -> 3 in the cache */
   /* replace847 -> 1031 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search848_0_0 -> 0 in the cache */
   /* search848_0_1 -> 3 in the cache */
   /* search848_0 -> 2351 in the cache */
   /* search848_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2351, 258 },
      -1,
   } },

   /* replace848_0 -> 0 in the cache */
   /* replace848_1 -> 3 in the cache */
   /* replace848 -> 1028 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search849_0_0 -> 0 in the cache */
   /* search849_0_1 -> 3 in the cache */
   /* search849_0 -> 2353 in the cache */
   /* search849_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2353, 258 },
      -1,
   } },

   /* replace849_0 -> 0 in the cache */
   /* replace849_1 -> 3 in the cache */
   /* replace849 -> 1025 in the cache */

   /* ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search850_0_0 -> 0 in the cache */
   /* search850_0_1 -> 3 in the cache */
   /* search850_0 -> 2363 in the cache */
   /* search850_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2363, 258 },
      -1,
   } },

   /* replace850_0 -> 0 in the cache */
   /* replace850_1 -> 3 in the cache */
   /* replace850 -> 1031 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search851_0_0 -> 0 in the cache */
   /* search851_0_1 -> 3 in the cache */
   /* search851_0 -> 2365 in the cache */
   /* search851_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2365, 258 },
      -1,
   } },

   /* replace851_0 -> 0 in the cache */
   /* replace851_1 -> 3 in the cache */
   /* replace851 -> 1034 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search852_0_0 -> 0 in the cache */
   /* search852_0_1 -> 3 in the cache */
   /* search852_0 -> 2351 in the cache */
   /* search852_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2351, 258 },
      -1,
   } },

   /* replace852_0 -> 0 in the cache */
   /* replace852_1 -> 3 in the cache */
   /* replace852 -> 1025 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search853_0_0 -> 0 in the cache */
   /* search853_0_1 -> 3 in the cache */
   /* search853_0 -> 2353 in the cache */
   /* search853_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2353, 258 },
      -1,
   } },

   /* replace853_0 -> 0 in the cache */
   /* replace853_1 -> 3 in the cache */
   /* replace853 -> 1028 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search854_0_0 -> 0 in the cache */
   /* search854_0_1 -> 3 in the cache */
   /* search854_0 -> 2363 in the cache */
   /* search854_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2363, 272 },
      -1,
   } },

   /* replace854_0 -> 0 in the cache */
   /* replace854_1 -> 3 in the cache */
   /* replace854 -> 1031 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search855_0_0 -> 0 in the cache */
   /* search855_0_1 -> 3 in the cache */
   /* search855_0 -> 2365 in the cache */
   /* search855_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2365, 272 },
      -1,
   } },

   /* replace855_0 -> 0 in the cache */
   /* replace855_1 -> 3 in the cache */
   /* replace855 -> 1034 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search856_0_0 -> 0 in the cache */
   /* search856_0_1 -> 3 in the cache */
   /* search856_0 -> 2351 in the cache */
   /* search856_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2351, 272 },
      -1,
   } },

   /* replace856_0 -> 0 in the cache */
   /* replace856_1 -> 3 in the cache */
   /* replace856 -> 1025 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search857_0_0 -> 0 in the cache */
   /* search857_0_1 -> 3 in the cache */
   /* search857_0 -> 2353 in the cache */
   /* search857_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2353, 272 },
      -1,
   } },

   /* replace857_0 -> 0 in the cache */
   /* replace857_1 -> 3 in the cache */
   /* replace857 -> 1028 in the cache */

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search858_0_0 -> 32 in the cache */
   /* search858_0 -> 98 in the cache */
   /* search858_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace858_0 -> 32 in the cache */
   /* replace858_1 -> 113 in the cache */
   /* replace858 -> 1227 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search859_0_0 -> 32 in the cache */
   /* search859_0 -> 98 in the cache */
   /* search859_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace859_0 -> 32 in the cache */
   /* replace859_1 -> 113 in the cache */
   /* replace859 -> 1231 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search860_0_0 -> 739 in the cache */
   /* search860_0 -> 1200 in the cache */
   /* search860_1_0 -> 1107 in the cache */
   /* search860_1 -> 2230 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1200, 2230 },
      -1,
   } },

   /* replace860_0_0 -> 739 in the cache */
   /* replace860_0_1 -> 1107 in the cache */
   /* replace860_0 -> 1119 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1119 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search861_0_0 -> 739 in the cache */
   /* search861_0 -> 1200 in the cache */
   /* search861_1_0 -> 1107 in the cache */
   /* search861_1 -> 2230 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1200, 2230 },
      -1,
   } },

   /* replace861_0_0 -> 739 in the cache */
   /* replace861_0_1 -> 1107 in the cache */
   /* replace861_0 -> 1119 in the cache */
   /* replace861 -> 2631 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search862_0_0 -> 739 in the cache */
   /* search862_0 -> 1200 in the cache */
   /* search862_1_0 -> 1107 in the cache */
   /* search862_1 -> 2230 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1200, 2230 },
      -1,
   } },

   /* replace862_0_0 -> 739 in the cache */
   /* replace862_0_1 -> 1107 in the cache */
   /* replace862_0 -> 1111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1111 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search863_0_0 -> 739 in the cache */
   /* search863_0 -> 1102 in the cache */
   /* search863_1_0 -> 1107 in the cache */
   /* search863_1 -> 1108 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1102, 1108 },
      -1,
   } },

   /* replace863_0_0 -> 739 in the cache */
   /* replace863_0_1 -> 1107 in the cache */
   /* replace863_0 -> 1119 in the cache */
   /* replace863 -> 1240 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search864_0_0_0 -> 739 in the cache */
   /* search864_0_0 -> 1102 in the cache */
   /* search864_0_1_0 -> 1107 in the cache */
   /* search864_0_1 -> 1108 in the cache */
   /* search864_0 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* replace864_0_0 -> 739 in the cache */
   /* replace864_0_1 -> 1107 in the cache */
   /* replace864_0 -> 1111 in the cache */
   /* replace864 -> 1237 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search865_1 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2637, 483 },
      -1,
   } },

   /* replace865_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search866_1 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2640, 245 },
      -1,
   } },

   /* replace866_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search867_0_0_0 -> 739 in the cache */
   /* search867_0_0 -> 1102 in the cache */
   /* search867_0 -> 1105 in the cache */
   /* search867_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1105, 1201 },
      -1,
   } },

   /* replace867 -> 739 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search868_0 -> 32 in the cache */
   /* search868_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace868 -> 1056 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search869_0 -> 32 in the cache */
   /* search869_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace869 -> 1209 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search870_0 -> 32 in the cache */
   /* search870_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace870 -> 1209 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search871_0 -> 32 in the cache */
   /* search871_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace871 -> 1056 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search872_0 -> 32 in the cache */
   /* search872_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace872 -> 1056 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search873_0 -> 32 in the cache */
   /* search873_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace873 -> 1209 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search874_0 -> 32 in the cache */
   /* search874_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace874 -> 1056 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search875_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2651, 32 },
      -1,
   } },

   /* replace875 -> 1209 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search876_0 -> 2651 in the cache */
   /* search876_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2651, 32 },
      -1,
   } },

   /* replace876 -> 1209 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search877_0 -> 2651 in the cache */
   /* search877_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2651, 32 },
      -1,
   } },

   /* replace877 -> 1056 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search878_0 -> 32 in the cache */
   /* search878_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace878 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search879_0 -> 32 in the cache */
   /* search879_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace879 -> 61 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search880_0 -> 32 in the cache */
   /* search880_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace880 -> 32 in the cache */

   /* ('iand', 'a', ('inot', 'a')) => 0 */
   /* search881_0 -> 32 in the cache */
   /* search881_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 2658 },
      -1,
   } },

   /* replace881 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search882_0 -> 32 in the cache */
   /* search882_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace882 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search883_0 -> 32 in the cache */
   /* search883_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace883 -> 32 in the cache */

   /* ('ior', 'a', -1) => -1 */
   /* search884_0 -> 32 in the cache */
   /* search884_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace884 -> 63 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search885_0 -> 32 in the cache */
   /* search885_1_0 -> 32 in the cache */
   /* search885_1 -> 2658 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2658 },
      -1,
   } },

   /* replace885 -> 63 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search886_0 -> 32 in the cache */
   /* search886_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace886 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search887_0 -> 32 in the cache */
   /* search887_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace887 -> 32 in the cache */

   /* ('ixor', 'a', ('ixor', 'a', 'b')) => b */
   /* search888_0 -> 0 in the cache */
   /* search888_1_0 -> 0 in the cache */
   /* search888_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 0, 2666 },
      -1,
   } },

   /* replace888 -> 3 in the cache */

   /* ('ixor', 'a', -1) => ('inot', 'a') */
   /* search889_0 -> 32 in the cache */
   /* search889_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace889_0 -> 32 in the cache */
   /* replace889 -> 2658 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search890_0_0 -> 32 in the cache */
   /* search890_0 -> 2658 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2658 },
      -1,
   } },

   /* replace890 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search891_0_0 -> 0 in the cache */
   /* search891_0_1 -> 3 in the cache */
   /* search891_0 -> 203 in the cache */
   /* search891_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 203, 3 },
      -1,
   } },

   /* replace891 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search892_0_0 -> 0 in the cache */
   /* search892_0_1 -> 3 in the cache */
   /* search892_0 -> 84 in the cache */
   /* search892_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace892_0 -> 0 in the cache */
   /* replace892_1 -> 3 in the cache */
   /* replace892 -> 2293 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search893_0_0 -> 0 in the cache */
   /* search893_0_1 -> 3 in the cache */
   /* search893_0 -> 84 in the cache */
   /* search893_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace893 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search894_0_0 -> 0 in the cache */
   /* search894_0_1 -> 3 in the cache */
   /* search894_0 -> 203 in the cache */
   /* search894_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 203, 3 },
      -1,
   } },

   /* replace894_0 -> 0 in the cache */
   /* replace894_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search895_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search895_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2675, 2676 },
      -1,
   } },

   /* replace895_0_0 -> 0 in the cache */
   /* replace895_0_1 -> 3 in the cache */
   /* replace895_0 -> 2293 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2293 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search896_0_0 -> 0 in the cache */
   /* search896_0 -> 2675 in the cache */
   /* search896_1_0 -> 3 in the cache */
   /* search896_1 -> 2676 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2675, 2676 },
      -1,
   } },

   /* replace896_0_0 -> 0 in the cache */
   /* replace896_0_1 -> 3 in the cache */
   /* replace896_0 -> 2674 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2674 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search897_0 -> 1201 in the cache */
   /* search897_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1201, 16 },
      -1,
   } },

   /* replace897 -> 1201 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search898_0 -> 32 in the cache */
   /* search898_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace898 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search899_0 -> 1201 in the cache */
   /* search899_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1201, 16 },
      -1,
   } },

   /* replace899 -> 1201 in the cache */

   /* ('ishr', -1, 'a') => -1 */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search900_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 2684, 16 },
      -1,
   } },

   /* replace900 -> 2684 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search901_0 -> 32 in the cache */
   /* search901_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace901 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search902_0 -> 1201 in the cache */
   /* search902_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1201, 16 },
      -1,
   } },

   /* replace902 -> 1201 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search903_0 -> 32 in the cache */
   /* search903_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace903 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search904_0_0 -> 11 in the cache */
   /* search904_0_1 -> 36 in the cache */
   /* search904_0 -> 2145 in the cache */
   /* search904_1_0 -> 11 in the cache */
   /* search904_1_1_0 -> 832 in the cache */
   /* search904_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 832, 2689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2690 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2145, 2691 },
      -1,
   } },

   /* replace904_0 -> 11 in the cache */
   /* replace904_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search905_0_0 -> 11 in the cache */
   /* search905_0_1 -> 36 in the cache */
   /* search905_0 -> 2145 in the cache */
   /* search905_1_0 -> 11 in the cache */
   /* search905_1_1_0 -> 832 in the cache */
   /* search905_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 832, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2694 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2145, 2695 },
      -1,
   } },

   /* replace905_0 -> 11 in the cache */
   /* replace905_1 -> 36 in the cache */
   /* replace905 -> 2693 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search906_0_0 -> 16 in the cache */
   /* search906_0_1 -> 36 in the cache */
   /* search906_0 -> 925 in the cache */
   /* search906_1_0 -> 16 in the cache */
   /* search906_1_1_0 -> 853 in the cache */
   /* search906_1_1_1_0 -> 36 in the cache */
   /* search906_1_1_1 -> 2689 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 853, 2689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 925, 2698 },
      -1,
   } },

   /* replace906_0 -> 16 in the cache */
   /* replace906_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search907_0_0 -> 16 in the cache */
   /* search907_0_1 -> 36 in the cache */
   /* search907_0 -> 925 in the cache */
   /* search907_1_0 -> 16 in the cache */
   /* search907_1_1_0 -> 853 in the cache */
   /* search907_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 853, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 925, 2702 },
      -1,
   } },

   /* replace907_0 -> 16 in the cache */
   /* replace907_1 -> 36 in the cache */
   /* replace907 -> 2700 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search908_0_0 -> 11 in the cache */
   /* search908_0_1 -> 36 in the cache */
   /* search908_0 -> 2149 in the cache */
   /* search908_1_0 -> 11 in the cache */
   /* search908_1_1_0 -> 832 in the cache */
   /* search908_1_1_1_0 -> 36 in the cache */
   /* search908_1_1_1 -> 2689 in the cache */
   /* search908_1_1 -> 2690 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2690 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2149, 2704 },
      -1,
   } },

   /* replace908_0 -> 11 in the cache */
   /* replace908_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search909_0_0 -> 11 in the cache */
   /* search909_0_1 -> 36 in the cache */
   /* search909_0 -> 2149 in the cache */
   /* search909_1_0 -> 11 in the cache */
   /* search909_1_1_0 -> 832 in the cache */
   /* search909_1_1_1 -> 36 in the cache */
   /* search909_1_1 -> 2694 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2694 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2149, 2707 },
      -1,
   } },

   /* replace909_0 -> 11 in the cache */
   /* replace909_1 -> 36 in the cache */
   /* replace909 -> 2706 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search910_0_0 -> 16 in the cache */
   /* search910_0_1 -> 36 in the cache */
   /* search910_0 -> 2178 in the cache */
   /* search910_1_0 -> 16 in the cache */
   /* search910_1_1_0 -> 853 in the cache */
   /* search910_1_1_1_0 -> 36 in the cache */
   /* search910_1_1_1 -> 2689 in the cache */
   /* search910_1_1 -> 2697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2178, 2709 },
      -1,
   } },

   /* replace910_0 -> 16 in the cache */
   /* replace910_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search911_0_0 -> 16 in the cache */
   /* search911_0_1 -> 36 in the cache */
   /* search911_0 -> 2178 in the cache */
   /* search911_1_0 -> 16 in the cache */
   /* search911_1_1_0 -> 853 in the cache */
   /* search911_1_1_1 -> 36 in the cache */
   /* search911_1_1 -> 2701 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2178, 2712 },
      -1,
   } },

   /* replace911_0 -> 16 in the cache */
   /* replace911_1 -> 36 in the cache */
   /* replace911 -> 2711 in the cache */

   /* ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b'))) */
   /* search912_0 -> 6 in the cache */
   /* search912_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace912_0_0 -> 6 in the cache */
   /* replace912_0_1 -> 36 in the cache */
   /* replace912_0 -> 2114 in the cache */
   /* replace912_1_0 -> 6 in the cache */
   /* replace912_1_1_0 -> 810 in the cache */
   /* replace912_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 810, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2114, 2716 },
      -1,
   } },

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search913_0 -> 11 in the cache */
   /* search913_1 -> 36 in the cache */
   /* search913 -> 2693 in the cache */

   /* replace913_0_0 -> 11 in the cache */
   /* replace913_0_1 -> 36 in the cache */
   /* replace913_0 -> 2145 in the cache */
   /* replace913_1_0 -> 11 in the cache */
   /* replace913_1_1_0 -> 832 in the cache */
   /* replace913_1_1_1 -> 36 in the cache */
   /* replace913_1_1 -> 2694 in the cache */
   /* replace913_1 -> 2695 in the cache */
   /* replace913 -> 2696 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search914_0 -> 16 in the cache */
   /* search914_1 -> 36 in the cache */
   /* search914 -> 2700 in the cache */

   /* replace914_0_0 -> 16 in the cache */
   /* replace914_0_1 -> 36 in the cache */
   /* replace914_0 -> 925 in the cache */
   /* replace914_1_0 -> 16 in the cache */
   /* replace914_1_1_0 -> 853 in the cache */
   /* replace914_1_1_1 -> 36 in the cache */
   /* replace914_1_1 -> 2701 in the cache */
   /* replace914_1 -> 2702 in the cache */
   /* replace914 -> 2703 in the cache */

   /* ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b'))) */
   /* search915_0 -> 21 in the cache */
   /* search915_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace915_0_0 -> 21 in the cache */
   /* replace915_0_1 -> 36 in the cache */
   /* replace915_0 -> 2205 in the cache */
   /* replace915_1_0 -> 21 in the cache */
   /* replace915_1_1_0 -> 873 in the cache */
   /* replace915_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 873, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2205, 2720 },
      -1,
   } },

   /* ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b'))) */
   /* search916_0 -> 6 in the cache */
   /* search916_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace916_0_0 -> 6 in the cache */
   /* replace916_0_1 -> 36 in the cache */
   /* replace916_0 -> 2118 in the cache */
   /* replace916_1_0 -> 6 in the cache */
   /* replace916_1_1_0 -> 810 in the cache */
   /* replace916_1_1_1 -> 36 in the cache */
   /* replace916_1_1 -> 2715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 2715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2118, 2723 },
      -1,
   } },

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search917_0 -> 11 in the cache */
   /* search917_1 -> 36 in the cache */
   /* search917 -> 2706 in the cache */

   /* replace917_0_0 -> 11 in the cache */
   /* replace917_0_1 -> 36 in the cache */
   /* replace917_0 -> 2149 in the cache */
   /* replace917_1_0 -> 11 in the cache */
   /* replace917_1_1_0 -> 832 in the cache */
   /* replace917_1_1_1 -> 36 in the cache */
   /* replace917_1_1 -> 2694 in the cache */
   /* replace917_1 -> 2707 in the cache */
   /* replace917 -> 2708 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search918_0 -> 16 in the cache */
   /* search918_1 -> 36 in the cache */
   /* search918 -> 2711 in the cache */

   /* replace918_0_0 -> 16 in the cache */
   /* replace918_0_1 -> 36 in the cache */
   /* replace918_0 -> 2178 in the cache */
   /* replace918_1_0 -> 16 in the cache */
   /* replace918_1_1_0 -> 853 in the cache */
   /* replace918_1_1_1 -> 36 in the cache */
   /* replace918_1_1 -> 2701 in the cache */
   /* replace918_1 -> 2712 in the cache */
   /* replace918 -> 2713 in the cache */

   /* ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b'))) */
   /* search919_0 -> 21 in the cache */
   /* search919_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace919_0_0 -> 21 in the cache */
   /* replace919_0_1 -> 36 in the cache */
   /* replace919_0 -> 2209 in the cache */
   /* replace919_1_0 -> 21 in the cache */
   /* replace919_1_1_0 -> 873 in the cache */
   /* replace919_1_1_1 -> 36 in the cache */
   /* replace919_1_1 -> 2719 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2209, 2726 },
      -1,
   } },

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search920_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2728 },
      -1,
   } },

   /* replace920 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search921_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2730 },
      -1,
   } },

   /* replace921 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search922_0 -> 0 in the cache */
   /* search922_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace922_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace922_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2733, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2734 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search923_0_0_0 -> 0 in the cache */
   /* search923_0_0 -> 2733 in the cache */
   /* search923_0_1 -> 3 in the cache */
   /* search923_0 -> 2734 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2734 },
      -1,
   } },

   /* replace923_0 -> 0 in the cache */
   /* replace923_1 -> 3 in the cache */
   /* replace923 -> 2732 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search924_0_0_0_0 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 151 },
      -1,
   } },
   /* search924_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2737, 152 },
      -1,
   } },
   /* search924_0_1_0_0 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 154 },
      -1,
   } },
   /* search924_0_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2739, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2738, 2740 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2741 },
      -1,
   } },

   /* replace924_0_0 -> 151 in the cache */
   /* replace924_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 151, 152 },
      -1,
   } },
   /* replace924_1_0 -> 154 in the cache */
   /* replace924_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2743, 2744 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search925_0_0_0 -> 32 in the cache */
   /* search925_0_0 -> 2728 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2728, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2747 },
      -1,
   } },

   /* replace925_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search926_0_0_0 -> 32 in the cache */
   /* search926_0_0 -> 2728 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2728, 2750 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2751 },
      -1,
   } },

   /* replace926_0 -> 32 in the cache */
   /* replace926_1 -> 32 in the cache */
   /* replace926 -> 253 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search927_0_0_0 -> 32 in the cache */
   /* search927_0_0 -> 2728 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2728, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2754 },
      -1,
   } },

   /* replace927_0_0 -> 32 in the cache */
   /* replace927_0_1 -> 32 in the cache */
   /* replace927_0 -> 253 in the cache */
   /* replace927_1_0 -> 32 in the cache */
   /* replace927_1_1 -> 32 in the cache */
   /* replace927_1 -> 253 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 253, 253 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search928_0 -> 32 in the cache */
   /* search928_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* replace928 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search929_0 -> 32 in the cache */
   /* search929_1 -> 2750 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2750 },
      -1,
   } },

   /* replace929_0 -> 32 in the cache */
   /* replace929_1 -> 32 in the cache */
   /* replace929 -> 253 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search930_0 -> 32 in the cache */
   /* search930_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2753 },
      -1,
   } },

   /* replace930_0_0 -> 32 in the cache */
   /* replace930_0_1 -> 32 in the cache */
   /* replace930_0 -> 253 in the cache */
   /* replace930_1_0 -> 32 in the cache */
   /* replace930_1_1 -> 32 in the cache */
   /* replace930_1 -> 253 in the cache */
   /* replace930 -> 2756 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search931_0 -> 2750 in the cache */
   /* search931_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2750, 32 },
      -1,
   } },

   /* replace931_0 -> 32 in the cache */
   /* replace931 -> 2730 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search932_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2761 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2762, 2763 },
      -1,
   } },

   /* replace932 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search933_0_0_0 -> 32 in the cache */
   /* search933_0_0_1 -> 2761 in the cache */
   /* search933_0_0 -> 2762 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2762 },
      -1,
   } },
   /* search933_1 -> 2763 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2765, 2763 },
      -1,
   } },

   /* replace933_0 -> 32 in the cache */
   /* replace933 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search934_0_0 -> 32 in the cache */
   /* search934_0 -> 2730 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2730 },
      -1,
   } },

   /* replace934_0_0 -> 2746 in the cache */
   /* replace934_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2746, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2768 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search935_0_0 -> 32 in the cache */
   /* search935_0 -> 2730 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2730 },
      -1,
   } },

   /* replace935_0_0 -> 32 in the cache */
   /* replace935_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search936_0_0 -> 32 in the cache */
   /* search936_0 -> 2730 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2730 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace936_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2773, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2774 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search937_0_0 -> 32 in the cache */
   /* search937_0 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2749 },
      -1,
   } },

   /* replace937_0 -> 2746 in the cache */
   /* replace937_1_0 -> 32 in the cache */
   /* replace937_1 -> 2728 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2746, 2728 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search938_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2778 },
      -1,
   } },

   /* replace938_0_0 -> 32 in the cache */
   /* replace938_0 -> 2728 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2728 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search939_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2781 },
      -1,
   } },

   /* replace939_0 -> 2773 in the cache */
   /* replace939_1_0 -> 32 in the cache */
   /* replace939_1 -> 2728 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2773, 2728 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search940_0_0 -> 0 in the cache */
   /* search940_0_1 -> 3 in the cache */
   /* search940_0 -> 2732 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2732 },
      -1,
   } },

   /* replace940_0 -> 3 in the cache */
   /* replace940_1_0 -> 0 in the cache */
   /* replace940_1 -> 2733 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2733 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search941_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search941_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2786, 2787 },
      -1,
   } },

   /* replace941_0_0 -> 0 in the cache */
   /* replace941_0_1 -> 3 in the cache */
   /* replace941_0 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 274 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search942_0_0 -> 32 in the cache */
   /* search942_0_1 -> 113 in the cache */
   /* search942_0 -> 691 in the cache */
   /* search942_1 -> 113 in the cache */
   /* search942_2_0 -> 32 in the cache */
   /* search942_2 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 691, 113, 2749 },
      -1,
   } },

   /* replace942_0_0 -> 32 in the cache */
   /* replace942_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2791 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search943_0_0 -> 32 in the cache */
   /* search943_0 -> 2749 in the cache */
   /* search943_1_0 -> 32 in the cache */
   /* search943_1 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2749, 2749 },
      -1,
   } },

   /* replace943_0 -> 32 in the cache */
   /* replace943 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search944_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search944_1_0 -> 16 in the cache */
   /* search944_1 -> 2794 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2794, 2794 },
      -1,
   } },

   /* replace944_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search945_0 -> 243 in the cache */
   /* search945_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* replace945_0 -> 32 in the cache */
   /* replace945 -> 2778 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search946_0 -> 0 in the cache */
   /* search946_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace946_0 -> 0 in the cache */
   /* replace946_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2799 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search947_0_0 -> 32 in the cache */
   /* search947_0 -> 2778 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2778 },
      -1,
   } },

   /* replace947 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search948_0_0 -> 32 in the cache */
   /* search948_0 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2749 },
      -1,
   } },

   /* replace948_0 -> 32 in the cache */
   /* replace948 -> 2781 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search949_0 -> 32 in the cache */
   /* search949 -> 2749 in the cache */

   /* replace949_0_0 -> 32 in the cache */
   /* replace949_0 -> 2781 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2781 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search950_0_0 -> 32 in the cache */
   /* search950_0 -> 2781 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2781 },
      -1,
   } },

   /* replace950_0 -> 32 in the cache */
   /* replace950 -> 2749 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search951_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace951_0_0_0_0_0_0 -> 2750 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace951_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_0_0_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2807, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2750, 2809 },
      -1,
   } },
   /* replace951_0_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2810, 243 },
      -1,
   } },
   /* replace951_0_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_0_0_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2812, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2750, 2814 },
      -1,
   } },
   /* replace951_0_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2815, 243 },
      -1,
   } },
   /* replace951_0_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_0_0_1_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2817, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2818 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2750, 2819 },
      -1,
   } },
   /* replace951_0_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2820, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2821 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2816, 2822 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2811, 2823 },
      -1,
   } },
   /* replace951_0_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2824, 2753 },
      -1,
   } },
   /* replace951_0_1_0_0_0_0_0 -> 2750 in the cache */
   /* replace951_0_1_0_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_1_0_0_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2826, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2827 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2750, 2828 },
      -1,
   } },
   /* replace951_0_1_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2829, 243 },
      -1,
   } },
   /* replace951_0_1_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_1_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_1_0_0_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2831, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2750, 2833 },
      -1,
   } },
   /* replace951_0_1_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2834, 243 },
      -1,
   } },
   /* replace951_0_1_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_1_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_1_0_0_1_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2836, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2837 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2750, 2838 },
      -1,
   } },
   /* replace951_0_1_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2839, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2835, 2841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2830, 2842 },
      -1,
   } },
   /* replace951_0_1_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2843, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2844 },
      -1,
   } },
   /* replace951_0_2_0_0_0_0_0 -> 2750 in the cache */
   /* replace951_0_2_0_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_2_0_0_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2846, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2750, 2848 },
      -1,
   } },
   /* replace951_0_2_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2849, 243 },
      -1,
   } },
   /* replace951_0_2_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_2_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_2_0_0_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2851, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2750, 2853 },
      -1,
   } },
   /* replace951_0_2_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2854, 243 },
      -1,
   } },
   /* replace951_0_2_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace951_0_2_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_0_2_0_0_1_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2856, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2857 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2750, 2858 },
      -1,
   } },
   /* replace951_0_2_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2859, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2860 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2855, 2861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2850, 2862 },
      -1,
   } },
   /* replace951_0_2_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2863, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2825, 2845, 2865 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace951_2_0_0_0_0 -> 2750 in the cache */
   /* replace951_2_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_2_0_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2868, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2750, 2870 },
      -1,
   } },
   /* replace951_2_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2871, 243 },
      -1,
   } },
   /* replace951_2_0_1_0_0_0 -> 2750 in the cache */
   /* replace951_2_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_2_0_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2873, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2874 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2750, 2875 },
      -1,
   } },
   /* replace951_2_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2876, 243 },
      -1,
   } },
   /* replace951_2_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace951_2_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace951_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2806, 32 },
      -1,
   } },
   /* replace951_2_0_1_1_0_0_1_0_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2878, 2746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2879 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2750, 2880 },
      -1,
   } },
   /* replace951_2_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2881, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2882 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2877, 2883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2872, 2884 },
      -1,
   } },
   /* replace951_2_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2885, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2866, 2867, 2886 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search952_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace952_0_0_0_0_0_0 -> 2750 in the cache */
   /* replace952_0_0_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_0_0_0_0_1_0_0 -> 2807 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2807, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2750, 2891 },
      -1,
   } },
   /* replace952_0_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2892, 243 },
      -1,
   } },
   /* replace952_0_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_0_0_1_0_0_1_0_0 -> 2812 in the cache */
   /* replace952_0_0_0_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2812, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2894 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2750, 2895 },
      -1,
   } },
   /* replace952_0_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2896, 243 },
      -1,
   } },
   /* replace952_0_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_0_0_1_1_0_0_1_0_0 -> 2817 in the cache */
   /* replace952_0_0_0_1_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2817, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2750, 2899 },
      -1,
   } },
   /* replace952_0_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2900, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2901 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2897, 2902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2893, 2903 },
      -1,
   } },
   /* replace952_0_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2904, 2753 },
      -1,
   } },
   /* replace952_0_1_0_0_0_0_0 -> 2750 in the cache */
   /* replace952_0_1_0_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_1_0_0_0_0_1_0_0 -> 2826 in the cache */
   /* replace952_0_1_0_0_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2826, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2906 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2750, 2907 },
      -1,
   } },
   /* replace952_0_1_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2908, 243 },
      -1,
   } },
   /* replace952_0_1_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_1_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_1_0_0_1_0_0_1_0_0 -> 2831 in the cache */
   /* replace952_0_1_0_0_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2831, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2910 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2750, 2911 },
      -1,
   } },
   /* replace952_0_1_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2912, 243 },
      -1,
   } },
   /* replace952_0_1_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_1_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_1_0_0_1_1_0_0_1_0_0 -> 2836 in the cache */
   /* replace952_0_1_0_0_1_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2836, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2914 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2750, 2915 },
      -1,
   } },
   /* replace952_0_1_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2916, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2913, 2918 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2909, 2919 },
      -1,
   } },
   /* replace952_0_1_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2920, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2921 },
      -1,
   } },
   /* replace952_0_2_0_0_0_0_0 -> 2750 in the cache */
   /* replace952_0_2_0_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_2_0_0_0_0_1_0_0 -> 2846 in the cache */
   /* replace952_0_2_0_0_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2846, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2923 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2750, 2924 },
      -1,
   } },
   /* replace952_0_2_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2925, 243 },
      -1,
   } },
   /* replace952_0_2_0_0_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_2_0_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_2_0_0_1_0_0_1_0_0 -> 2851 in the cache */
   /* replace952_0_2_0_0_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2851, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2750, 2928 },
      -1,
   } },
   /* replace952_0_2_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2929, 243 },
      -1,
   } },
   /* replace952_0_2_0_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace952_0_2_0_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_0_2_0_0_1_1_0_0_1_0_0 -> 2856 in the cache */
   /* replace952_0_2_0_0_1_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2856, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2931 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2750, 2932 },
      -1,
   } },
   /* replace952_0_2_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2933, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2934 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2930, 2935 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2926, 2936 },
      -1,
   } },
   /* replace952_0_2_0_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2937, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2905, 2922, 2939 },
      -1,
   } },
   /* replace952_1 -> 2867 in the cache */
   /* replace952_2_0_0_0_0 -> 2750 in the cache */
   /* replace952_2_0_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_2_0_0_0_1_0_0 -> 2868 in the cache */
   /* replace952_2_0_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2868, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2941 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2750, 2942 },
      -1,
   } },
   /* replace952_2_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2943, 243 },
      -1,
   } },
   /* replace952_2_0_1_0_0_0 -> 2750 in the cache */
   /* replace952_2_0_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_2_0_1_0_0_1_0_0 -> 2873 in the cache */
   /* replace952_2_0_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2873, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2750, 2946 },
      -1,
   } },
   /* replace952_2_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2947, 243 },
      -1,
   } },
   /* replace952_2_0_1_1_0_0_0 -> 2750 in the cache */
   /* replace952_2_0_1_1_0_0_1_0_0_0 -> 2806 in the cache */
   /* replace952_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace952_2_0_1_1_0_0_1_0_0 -> 2878 in the cache */
   /* replace952_2_0_1_1_0_0_1_0_1 -> 2889 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2878, 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2949 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2750, 2950 },
      -1,
   } },
   /* replace952_2_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2951, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2948, 2953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2944, 2954 },
      -1,
   } },
   /* replace952_2_1 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2955, 2753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2940, 2867, 2956 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search953_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace953_0 -> 32 in the cache */
   /* replace953_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search954_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace954_0 -> 32 in the cache */
   /* replace954_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search955_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace955_0 -> 32 in the cache */
   /* replace955_1 -> 61 in the cache */
   /* replace955 -> 1205 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search956_0 -> 739 in the cache */
   /* search956_1 -> 1209 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 739, 1209 },
      -1,
   } },

   /* replace956 -> 739 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search957_0 -> 739 in the cache */
   /* search957_1 -> 1209 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 739, 1209 },
      3,
   } },

   /* replace957_0 -> 739 in the cache */
   /* replace957 -> 1104 in the cache */

   /* ('ine', 'a', False) => a */
   /* search958_0 -> 739 in the cache */
   /* search958_1 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 739, 1056 },
      -1,
   } },

   /* replace958 -> 739 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search959_0 -> 739 in the cache */
   /* search959_1 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 739, 1056 },
      3,
   } },

   /* replace959_0 -> 739 in the cache */
   /* replace959 -> 1104 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search960_0 -> 739 in the cache */
   /* search960_1 -> 1209 in the cache */
   /* search960_2 -> 1056 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1209, 1056 },
      -1,
   } },

   /* replace960 -> 739 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search961_0 -> 739 in the cache */
   /* search961_1 -> 1056 in the cache */
   /* search961_2 -> 1209 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1056, 1209 },
      -1,
   } },

   /* replace961_0 -> 739 in the cache */
   /* replace961 -> 1104 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search962_0 -> 1209 in the cache */
   /* search962_1 -> 1090 in the cache */
   /* search962_2 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1209, 1090, 686 },
      -1,
   } },

   /* replace962 -> 1090 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search963_0 -> 1056 in the cache */
   /* search963_1 -> 1090 in the cache */
   /* search963_2 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1056, 1090, 686 },
      -1,
   } },

   /* replace963 -> 686 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search964_0 -> 739 in the cache */
   /* search964_1 -> 483 in the cache */
   /* search964_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 483, 115 },
      -1,
   } },

   /* replace964_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search965_0 -> 739 in the cache */
   /* search965_1 -> 115 in the cache */
   /* search965_2 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 115, 483 },
      -1,
   } },

   /* replace965_0_0 -> 739 in the cache */
   /* replace965_0 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1104 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search966_0 -> 739 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2975, 2976 },
      -1,
   } },

   /* replace966_0_0 -> 739 in the cache */
   /* replace966_0 -> 2972 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2972 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search967_0 -> 739 in the cache */
   /* search967_1 -> 2976 in the cache */
   /* search967_2 -> 2975 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2976, 2975 },
      -1,
   } },

   /* replace967_0_0_0 -> 739 in the cache */
   /* replace967_0_0 -> 1104 in the cache */
   /* replace967_0 -> 2974 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2974 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search968_0 -> 739 in the cache */
   /* search968_1 -> 245 in the cache */
   /* search968_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 245, 117 },
      -1,
   } },

   /* replace968_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search969_0 -> 739 in the cache */
   /* search969_1 -> 117 in the cache */
   /* search969_2 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 117, 245 },
      -1,
   } },

   /* replace969_0_0 -> 739 in the cache */
   /* replace969_0 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1104 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search970_0 -> 739 in the cache */
   /* search970_1 -> 280 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 280, 2985 },
      -1,
   } },

   /* replace970_0_0 -> 739 in the cache */
   /* replace970_0 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2982 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search971_0 -> 739 in the cache */
   /* search971_1 -> 2985 in the cache */
   /* search971_2 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2985, 280 },
      -1,
   } },

   /* replace971_0_0_0 -> 739 in the cache */
   /* replace971_0_0 -> 1104 in the cache */
   /* replace971_0 -> 2984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2984 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search972_0 -> 739 in the cache */
   /* search972_1 -> 624 in the cache */
   /* search972_2 -> 1904 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 624, 1904 },
      -1,
   } },

   /* replace972_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search973_0 -> 739 in the cache */
   /* search973_1 -> 1904 in the cache */
   /* search973_2 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1904, 624 },
      -1,
   } },

   /* replace973_0_0 -> 739 in the cache */
   /* replace973_0 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1104 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search974_0 -> 739 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2994, 2995 },
      -1,
   } },

   /* replace974_0_0 -> 739 in the cache */
   /* replace974_0 -> 2991 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2991 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search975_0 -> 739 in the cache */
   /* search975_1 -> 2995 in the cache */
   /* search975_2 -> 2994 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2995, 2994 },
      -1,
   } },

   /* replace975_0_0_0 -> 739 in the cache */
   /* replace975_0_0 -> 1104 in the cache */
   /* replace975_0 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2993 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search976_0 -> 739 in the cache */
   /* search976_1 -> 3 in the cache */
   /* search976_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 3, 3 },
      -1,
   } },

   /* replace976 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search977_0 -> 16 in the cache */
   /* search977_1 -> 36 in the cache */
   /* search977_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace977 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search978_0 -> 739 in the cache */
   /* search978_1 -> 2684 in the cache */
   /* search978_2 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 2684, 1201 },
      -1,
   } },

   /* replace978_0_0 -> 739 in the cache */
   /* replace978_0 -> 1200 in the cache */
   /* replace978 -> 2229 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search979_0 -> 739 in the cache */
   /* search979_1 -> 1201 in the cache */
   /* search979_2 -> 2684 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1201, 2684 },
      -1,
   } },

   /* replace979_0_0_0 -> 739 in the cache */
   /* replace979_0_0 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1104 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3004 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search980_0 -> 739 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search980_2 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 3006, 1201 },
      -1,
   } },

   /* replace980_0 -> 739 in the cache */
   /* replace980 -> 1200 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search981_0 -> 739 in the cache */
   /* search981_1 -> 1201 in the cache */
   /* search981_2 -> 3006 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1201, 3006 },
      -1,
   } },

   /* replace981_0_0 -> 739 in the cache */
   /* replace981_0 -> 1104 in the cache */
   /* replace981 -> 3004 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search982_0_0_0 -> 739 in the cache */
   /* search982_0_0 -> 1200 in the cache */
   /* search982_0 -> 2229 in the cache */
   /* search982_1_0_0 -> 1107 in the cache */
   /* search982_1_0 -> 2230 in the cache */
   /* search982_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace982_0_0_0 -> 739 in the cache */
   /* replace982_0_0_1 -> 1107 in the cache */
   /* replace982_0_0 -> 1119 in the cache */
   /* replace982_0 -> 2631 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2631 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search983_0_0_0 -> 739 in the cache */
   /* search983_0_0 -> 1200 in the cache */
   /* search983_0 -> 2229 in the cache */
   /* search983_1_0_0 -> 1107 in the cache */
   /* search983_1_0 -> 2230 in the cache */
   /* search983_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace983_0_0_0 -> 739 in the cache */
   /* replace983_0_0_1 -> 1107 in the cache */
   /* replace983_0_0 -> 1111 in the cache */
   /* replace983_0 -> 2634 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2634 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search984_0_0_0 -> 739 in the cache */
   /* search984_0_0 -> 1200 in the cache */
   /* search984_0 -> 2229 in the cache */
   /* search984_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2229, 1201 },
      -1,
   } },

   /* replace984_0 -> 739 in the cache */
   /* replace984 -> 1104 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search985_0_0_0 -> 739 in the cache */
   /* search985_0_0 -> 1200 in the cache */
   /* search985_0 -> 2229 in the cache */
   /* search985_1 -> 2684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2229, 2684 },
      -1,
   } },

   /* replace985 -> 739 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search986_0_0_0 -> 739 in the cache */
   /* search986_0_0 -> 1200 in the cache */
   /* search986_0 -> 2229 in the cache */
   /* search986_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2229, 1201 },
      -1,
   } },

   /* replace986 -> 739 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search987_0_0_0 -> 739 in the cache */
   /* search987_0_0 -> 1200 in the cache */
   /* search987_0 -> 2229 in the cache */
   /* search987_1 -> 2684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2229, 2684 },
      -1,
   } },

   /* replace987_0 -> 739 in the cache */
   /* replace987 -> 1104 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search988_0_0_0 -> 739 in the cache */
   /* search988_0_0 -> 1200 in the cache */
   /* search988_0 -> 2229 in the cache */
   /* search988_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2229, 1201 },
      -1,
   } },

   /* replace988_0 -> 739 in the cache */
   /* replace988 -> 1104 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search989_0_0_0 -> 739 in the cache */
   /* search989_0_0 -> 1200 in the cache */
   /* search989_0 -> 2229 in the cache */
   /* search989_1 -> 1201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2229, 1201 },
      -1,
   } },

   /* replace989 -> 739 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search990_0 -> 1201 in the cache */
   /* search990_1_0_0 -> 739 in the cache */
   /* search990_1_0 -> 1200 in the cache */
   /* search990_1 -> 2229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1201, 2229 },
      -1,
   } },

   /* replace990 -> 739 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search991_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3020 },
      -1,
   } },
   /* search991_1 -> 1112 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3021, 1112 },
      -1,
   } },

   /* replace991_0 -> 32 in the cache */
   /* replace991 -> 1505 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search992_0_0_0 -> 32 in the cache */
   /* search992_0_0 -> 3020 in the cache */
   /* search992_0 -> 3021 in the cache */
   /* search992_1 -> 3006 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3021, 3006 },
      -1,
   } },

   /* replace992_0 -> 32 in the cache */
   /* replace992 -> 3020 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search993_0_0_0 -> 739 in the cache */
   /* search993_0_0 -> 1200 in the cache */
   /* search993_0 -> 2229 in the cache */
   /* search993_1_0_0 -> 1107 in the cache */
   /* search993_1_0 -> 2230 in the cache */
   /* search993_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace993_0_0_0 -> 739 in the cache */
   /* replace993_0_0_1 -> 1107 in the cache */
   /* replace993_0_0 -> 1119 in the cache */
   /* replace993_0 -> 2631 in the cache */
   /* replace993 -> 3010 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search994_0_0_0 -> 739 in the cache */
   /* search994_0_0 -> 1200 in the cache */
   /* search994_0 -> 2229 in the cache */
   /* search994_1_0_0 -> 1107 in the cache */
   /* search994_1_0 -> 2230 in the cache */
   /* search994_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace994_0_0_0 -> 739 in the cache */
   /* replace994_0_0_1 -> 1107 in the cache */
   /* replace994_0_0 -> 1111 in the cache */
   /* replace994_0 -> 2634 in the cache */
   /* replace994 -> 3012 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search995_0_0_0 -> 739 in the cache */
   /* search995_0_0 -> 1200 in the cache */
   /* search995_0 -> 2229 in the cache */
   /* search995_1_0_0 -> 1107 in the cache */
   /* search995_1_0 -> 2230 in the cache */
   /* search995_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace995_0_0_0 -> 739 in the cache */
   /* replace995_0_0_1 -> 1107 in the cache */
   /* replace995_0_0 -> 1111 in the cache */
   /* replace995_0 -> 2634 in the cache */
   /* replace995 -> 3012 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search996_0_0_0 -> 739 in the cache */
   /* search996_0_0 -> 1200 in the cache */
   /* search996_0 -> 2229 in the cache */
   /* search996_1_0_0 -> 1107 in the cache */
   /* search996_1_0 -> 2230 in the cache */
   /* search996_1 -> 2231 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2229, 2231 },
      -1,
   } },

   /* replace996_0_0_0 -> 739 in the cache */
   /* replace996_0_0_1 -> 1107 in the cache */
   /* replace996_0_0 -> 1119 in the cache */
   /* replace996_0 -> 2631 in the cache */
   /* replace996 -> 3010 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search997_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 3028 },
      -1,
   } },

   /* replace997 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search998_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 3030 },
      -1,
   } },

   /* replace998 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search999_0_0 -> 32 in the cache */
   /* search999_0 -> 690 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 690 },
      -1,
   } },

   /* replace999_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search1000_0_0 -> 32 in the cache */
   /* search1000_0 -> 690 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 690 },
      -1,
   } },

   /* replace1000_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search1001_0_0 -> 32 in the cache */
   /* search1001_0 -> 100 in the cache */
   /* search1001 -> 111 in the cache */

   /* replace1001_0 -> 32 in the cache */
   /* replace1001 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search1002_0_0 -> 32 in the cache */
   /* search1002_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace1002_0 -> 32 in the cache */
   /* replace1002 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search1003_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3037 },
      -1,
   } },

   /* replace1003_0 -> 32 in the cache */
   /* replace1003_1 -> 113 in the cache */
   /* replace1003 -> 1231 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search1004_0_0 -> 11 in the cache */
   /* search1004_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace1004 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search1005_0_0 -> 11 in the cache */
   /* search1005_0 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace1005 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search1006_0_0 -> 11 in the cache */
   /* search1006_0 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace1006 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search1007_0_0 -> 11 in the cache */
   /* search1007_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace1007_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search1008_0_0 -> 11 in the cache */
   /* search1008_0 -> 1778 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1778 },
      -1,
   } },

   /* replace1008_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search1009_0_0 -> 11 in the cache */
   /* search1009_0 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace1009_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search1010_0_0 -> 11 in the cache */
   /* search1010_0 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace1010_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search1011_0_0 -> 739 in the cache */
   /* search1011_0 -> 1385 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1385 },
      -1,
   } },

   /* replace1011_0 -> 739 in the cache */
   /* replace1011 -> 1381 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1012_0_0 -> 739 in the cache */
   /* search1012_0 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1373 },
      -1,
   } },

   /* replace1012_0 -> 739 in the cache */
   /* replace1012 -> 1369 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1013_0_0 -> 739 in the cache */
   /* search1013_0 -> 1373 in the cache */
   /* search1013 -> 3051 in the cache */

   /* replace1013_0 -> 739 in the cache */
   /* replace1013 -> 1369 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1014_0_0 -> 739 in the cache */
   /* search1014_0 -> 1385 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1385 },
      -1,
   } },

   /* replace1014_0 -> 739 in the cache */
   /* replace1014 -> 1369 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1015_0_0 -> 739 in the cache */
   /* search1015_0 -> 1385 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1385 },
      -1,
   } },

   /* replace1015_0 -> 739 in the cache */
   /* replace1015 -> 1369 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1016_0_0 -> 739 in the cache */
   /* search1016_0 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1373 },
      -1,
   } },

   /* replace1016_0 -> 739 in the cache */
   /* replace1016 -> 1381 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1017_0_0 -> 739 in the cache */
   /* search1017_0 -> 1373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1373 },
      -1,
   } },

   /* replace1017_0 -> 739 in the cache */
   /* replace1017 -> 1381 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search1018_0_0 -> 16 in the cache */
   /* search1018_0 -> 1974 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1974 },
      -1,
   } },

   /* replace1018 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search1019_0_0 -> 16 in the cache */
   /* search1019_0 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1985 },
      -1,
   } },

   /* replace1019 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search1020_0_0 -> 16 in the cache */
   /* search1020_0 -> 1985 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1985 },
      -1,
   } },

   /* replace1020 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search1021_0_0 -> 16 in the cache */
   /* search1021_0 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1984 },
      -1,
   } },

   /* replace1021_0 -> 16 in the cache */
   /* replace1021 -> 1982 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search1022_0_0 -> 16 in the cache */
   /* search1022_0 -> 1981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1981 },
      -1,
   } },

   /* replace1022_0 -> 16 in the cache */
   /* replace1022 -> 1979 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search1023_0_0 -> 16 in the cache */
   /* search1023_0 -> 1973 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1973 },
      -1,
   } },

   /* replace1023_0 -> 16 in the cache */
   /* replace1023 -> 1971 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search1024_0_0 -> 16 in the cache */
   /* search1024_0 -> 1970 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1970 },
      -1,
   } },

   /* replace1024_0 -> 16 in the cache */
   /* replace1024 -> 1968 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search1025_0_0 -> 16 in the cache */
   /* search1025_0 -> 1885 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1885 },
      -1,
   } },

   /* replace1025 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 3064 },
      -1,
   } },

   /* replace1026 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search1027_0 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 3064 },
      -1,
   } },

   /* replace1027 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search1028_0 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 3064 },
      -1,
   } },

   /* replace1028 -> 32 in the cache */

   /* ('fround_even', 'a(is_integral)') => a */
   /* search1029_0 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 3064 },
      -1,
   } },

   /* replace1029 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search1030_0 -> 3064 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 3064 },
      -1,
   } },

   /* replace1030 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3070 },
      -1,
   } },

   /* replace1031 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search1032_0 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3070 },
      -1,
   } },

   /* replace1032 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3073 },
      -1,
   } },

   /* replace1033 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search1034_0 -> 3070 in the cache */
   /* search1034_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3070, 243 },
      -1,
   } },

   /* replace1034_0 -> 32 in the cache */
   /* replace1034 -> 219 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1035_0_0_0_0 -> 32 in the cache */
   /* search1035_0_0_0 -> 219 in the cache */
   /* search1035_0_0_1_0_0 -> 32 in the cache */
   /* search1035_0_0_1_0 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 219, 3076 },
      -1,
   } },
   /* search1035_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3077, 243 },
      -1,
   } },
   /* search1035_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 3078, 113 },
      -1,
   } },

   /* replace1035 -> 1056 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1036_0_0_0_0_0 -> 32 in the cache */
   /* search1036_0_0_0_0 -> 219 in the cache */
   /* search1036_0_0_0_1_0 -> 32 in the cache */
   /* search1036_0_0_0_1 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 219, 219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3080 },
      -1,
   } },
   /* search1036_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 3081, 243 },
      -1,
   } },
   /* search1036_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3082, 113 },
      -1,
   } },

   /* replace1036 -> 1056 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search1037_0_0_0_0 -> 32 in the cache */
   /* search1037_0_0_0 -> 219 in the cache */
   /* search1037_0_0_1_0_0 -> 32 in the cache */
   /* search1037_0_0_1_0 -> 219 in the cache */
   /* search1037_0_0_1 -> 3076 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 219, 3076 },
      -1,
   } },
   /* search1037_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 3084, 243 },
      -1,
   } },
   /* search1037_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 3085, 113 },
      -1,
   } },

   /* replace1037_0_0_0 -> 32 in the cache */
   /* replace1037_0_0 -> 219 in the cache */
   /* replace1037_0_1_0_0 -> 32 in the cache */
   /* replace1037_0_1_0 -> 219 in the cache */
   /* replace1037_0_1 -> 3076 in the cache */
   /* replace1037_0 -> 3077 in the cache */
   /* replace1037_1 -> 243 in the cache */
   /* replace1037 -> 3078 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search1038_0_0_0_0_0 -> 32 in the cache */
   /* search1038_0_0_0_0 -> 219 in the cache */
   /* search1038_0_0_0_1_0 -> 32 in the cache */
   /* search1038_0_0_0_1 -> 219 in the cache */
   /* search1038_0_0_0 -> 3080 in the cache */
   /* search1038_0_0 -> 3081 in the cache */
   /* search1038_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3081, 243 },
      -1,
   } },
   /* search1038_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 3087, 113 },
      -1,
   } },

   /* replace1038_0_0_0_0 -> 32 in the cache */
   /* replace1038_0_0_0 -> 219 in the cache */
   /* replace1038_0_0_1_0 -> 32 in the cache */
   /* replace1038_0_0_1 -> 219 in the cache */
   /* replace1038_0_0 -> 3080 in the cache */
   /* replace1038_0 -> 3081 in the cache */
   /* replace1038_1 -> 243 in the cache */
   /* replace1038 -> 3082 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1039_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3089, 113 },
      -1,
   } },

   /* replace1039 -> 1209 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search1040_0 -> 3089 in the cache */
   /* search1040_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3089, 113 },
      -1,
   } },

   /* replace1040 -> 1056 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3092, 3093 },
      -1,
   } },

   /* replace1041 -> 1209 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3095, 3096 },
      -1,
   } },

   /* replace1042 -> 1056 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3098, 3099 },
      -1,
   } },

   /* replace1043 -> 1056 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1044_0 -> 1561 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1561, 3101 },
      -1,
   } },

   /* replace1044 -> 1056 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3103, 3104 },
      -1,
   } },

   /* replace1045 -> 1209 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3106, 3107 },
      -1,
   } },

   /* replace1046 -> 1209 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search1047_0 -> 3089 in the cache */
   /* search1047_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3089, 61 },
      -1,
   } },

   /* replace1047 -> 1209 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search1048_0 -> 3089 in the cache */
   /* search1048_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3089, 61 },
      -1,
   } },

   /* replace1048 -> 1056 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search1049_0 -> 1561 in the cache */
   /* search1049_1 -> 3101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1561, 3101 },
      -1,
   } },

   /* replace1049 -> 1209 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search1050_0 -> 3095 in the cache */
   /* search1050_1 -> 3096 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3095, 3096 },
      -1,
   } },

   /* replace1050 -> 1056 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search1051_0 -> 3098 in the cache */
   /* search1051_1 -> 3099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3098, 3099 },
      -1,
   } },

   /* replace1051 -> 1056 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1052_0 -> 1561 in the cache */
   /* search1052_1 -> 3101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1561, 3101 },
      -1,
   } },

   /* replace1052 -> 1056 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search1053_0 -> 3095 in the cache */
   /* search1053_1 -> 3096 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3095, 3096 },
      -1,
   } },

   /* replace1053 -> 1209 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search1054_0 -> 3098 in the cache */
   /* search1054_1 -> 3099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3098, 3099 },
      -1,
   } },

   /* replace1054 -> 1209 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search1055_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 3117 },
      -1,
   } },

   /* replace1055 -> 1209 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search1056_0 -> 32 in the cache */
   /* search1056_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace1056 -> 1056 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search1057_0_0 -> 16 in the cache */
   /* search1057_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1057 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search1058_0_0 -> 16 in the cache */
   /* search1058_0_1 -> 36 in the cache */
   /* search1058_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1058 -> 36 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x */
   /* search1059_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3123 },
      -1,
   } },

   /* replace1059 -> 2382 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y */
   /* search1060_0_0 -> 16 in the cache */
   /* search1060_0 -> 3123 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3123 },
      -1,
   } },

   /* replace1060 -> 2385 in the cache */

   /* ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a */
   /* search1061_0_0 -> 16 in the cache */
   /* search1061_0 -> 1889 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1889 },
      -1,
   } },

   /* replace1061 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0 */
   /* search1062_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1062 -> 124 in the cache */

   /* ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a */
   /* search1063_0_0 -> 16 in the cache */
   /* search1063_0 -> 1887 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1887 },
      -1,
   } },

   /* replace1063 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31) */
   /* search1064_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3130 },
      -1,
   } },

   /* replace1064_0 -> 16 in the cache */
   /* replace1064_1 -> 19 in the cache */
   /* replace1064 -> 1437 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search1065_0_0 -> 16 in the cache */
   /* search1065_0_1 -> 36 in the cache */
   /* search1065_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1065_0 -> 16 in the cache */
   /* replace1065_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1066_0_0 -> 16 in the cache */
   /* search1066_0 -> 3123 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3123 },
      -1,
   } },

   /* replace1066 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search1067_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1067 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1068_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search1068_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 3137, 3138 },
      -1,
   } },

   /* replace1068 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1069_0_0_0 -> 21 in the cache */
   /* search1069_0_0 -> 3137 in the cache */
   /* search1069_0_1_0 -> 21 in the cache */
   /* search1069_0_1 -> 3138 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3137, 3138 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3140 },
      -1,
   } },

   /* replace1069 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1070_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3142 },
      -1,
   } },

   /* replace1070 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1071_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 3144 },
      -1,
   } },

   /* replace1071 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1072_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1072_0_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3146, 1992 },
      -1,
   } },
   /* search1072_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3148, 3149 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3147, 3150 },
      -1,
   } },

   /* replace1072_0 -> 16 in the cache */
   /* replace1072_1_0 -> 260 in the cache */
   /* replace1072_1_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 260, 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3152 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1073_0 -> 11 in the cache */
   /* search1073_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 810 },
      -1,
   } },

   /* replace1073_0 -> 11 in the cache */
   /* replace1073_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1429 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1074_0 -> 16 in the cache */
   /* search1074_1 -> 991 in the cache */
   /* search1074 -> 996 in the cache */

   /* replace1074_0 -> 16 in the cache */
   /* replace1074_1 -> 407 in the cache */
   /* replace1074 -> 424 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1075_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3156 },
      -1,
   } },

   /* replace1075_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3158 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1076_0 -> 11 in the cache */
   /* search1076_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 810 },
      -1,
   } },

   /* replace1076_0 -> 11 in the cache */
   /* replace1076_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1429 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1077_0 -> 16 in the cache */
   /* search1077_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 991 },
      -1,
   } },

   /* replace1077_0 -> 16 in the cache */
   /* replace1077_1 -> 407 in the cache */
   /* replace1077 -> 408 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1078_0 -> 21 in the cache */
   /* search1078_1 -> 3156 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3156 },
      -1,
   } },

   /* replace1078_0 -> 21 in the cache */
   /* replace1078_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3158 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1079_0 -> 1567 in the cache */
   /* search1079_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1567, 32 },
      -1,
   } },

   /* replace1079_0 -> 32 in the cache */
   /* replace1079_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1080_0_0 -> 32 in the cache */
   /* search1080_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3167 },
      -1,
   } },

   /* replace1080_0_0 -> 32 in the cache */
   /* replace1080_0_1 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3169 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1081_0_0 -> 32 in the cache */
   /* search1081_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3171 },
      -1,
   } },

   /* replace1081_0_0 -> 32 in the cache */
   /* replace1081_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3173 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1082_0_0_0 -> 0 in the cache */
   /* search1082_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3175 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3176 },
      -1,
   } },

   /* replace1082_0_0 -> 0 in the cache */
   /* replace1082_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3178 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1083_0_0_0 -> 0 in the cache */
   /* search1083_0_0_1 -> 3 in the cache */
   /* search1083_0_0 -> 3175 in the cache */
   /* search1083_0 -> 3176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3176 },
      -1,
   } },

   /* replace1083_0_0 -> 0 in the cache */
   /* replace1083_0_1 -> 3 in the cache */
   /* replace1083_0 -> 3175 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3175 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1084_0 -> 16 in the cache */
   /* search1084_1 -> 124 in the cache */
   /* search1084_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 810 },
      -1,
   } },

   /* replace1084_0 -> 16 in the cache */
   /* replace1084_1 -> 124 in the cache */
   /* replace1084 -> 414 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1085_0 -> 16 in the cache */
   /* search1085_1 -> 810 in the cache */
   /* search1085_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 810, 810 },
      -1,
   } },

   /* replace1085_0 -> 16 in the cache */
   /* replace1085_1 -> 398 in the cache */
   /* replace1085 -> 417 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1086_0 -> 16 in the cache */
   /* search1086_1 -> 832 in the cache */
   /* search1086_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 832, 810 },
      -1,
   } },

   /* replace1086_0 -> 16 in the cache */
   /* replace1086_1 -> 403 in the cache */
   /* replace1086 -> 421 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1087_0 -> 16 in the cache */
   /* search1087_1 -> 991 in the cache */
   /* search1087_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 991, 810 },
      -1,
   } },

   /* replace1087_0 -> 16 in the cache */
   /* replace1087_1 -> 407 in the cache */
   /* replace1087 -> 424 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1088_0 -> 16 in the cache */
   /* search1088_1 -> 124 in the cache */
   /* search1088_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 124, 810 },
      -1,
   } },

   /* replace1088_0 -> 16 in the cache */
   /* replace1088_1 -> 124 in the cache */
   /* replace1088 -> 395 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1089_0 -> 16 in the cache */
   /* search1089_1 -> 810 in the cache */
   /* search1089_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 810, 810 },
      -1,
   } },

   /* replace1089_0 -> 16 in the cache */
   /* replace1089_1 -> 398 in the cache */
   /* replace1089 -> 399 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1090_0 -> 16 in the cache */
   /* search1090_1 -> 832 in the cache */
   /* search1090_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 832, 810 },
      -1,
   } },

   /* replace1090_0 -> 16 in the cache */
   /* replace1090_1 -> 403 in the cache */
   /* replace1090 -> 404 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1091_0 -> 16 in the cache */
   /* search1091_1 -> 991 in the cache */
   /* search1091_2 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 991, 810 },
      -1,
   } },

   /* replace1091_0 -> 16 in the cache */
   /* replace1091_1 -> 407 in the cache */
   /* replace1091 -> 408 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1092_0_0 -> 0 in the cache */
   /* search1092_0_1 -> 3 in the cache */
   /* search1092_0 -> 3178 in the cache */
   /* search1092_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3178, 86 },
      -1,
   } },

   /* replace1092_0 -> 0 in the cache */
   /* replace1092_1 -> 3 in the cache */
   /* replace1092 -> 3175 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1093_0_0 -> 0 in the cache */
   /* search1093_0_1 -> 3 in the cache */
   /* search1093_0 -> 3175 in the cache */
   /* search1093_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3175, 86 },
      -1,
   } },

   /* replace1093_0 -> 0 in the cache */
   /* replace1093_1 -> 3 in the cache */
   /* replace1093 -> 3175 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1094_0_0 -> 16 in the cache */
   /* search1094_0_1 -> 832 in the cache */
   /* search1094_0 -> 984 in the cache */
   /* search1094_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 984, 832 },
      -1,
   } },

   /* replace1094_0 -> 16 in the cache */
   /* replace1094_1 -> 124 in the cache */
   /* replace1094 -> 446 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1095_0 -> 16 in the cache */
   /* search1095_1 -> 832 in the cache */
   /* search1095 -> 987 in the cache */

   /* replace1095_0 -> 16 in the cache */
   /* replace1095_1 -> 398 in the cache */
   /* replace1095 -> 449 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1096_0_0 -> 16 in the cache */
   /* search1096_0_1 -> 832 in the cache */
   /* search1096_0 -> 984 in the cache */
   /* search1096_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 984, 832 },
      -1,
   } },

   /* replace1096_0 -> 16 in the cache */
   /* replace1096_1 -> 124 in the cache */
   /* replace1096 -> 438 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1097_0 -> 16 in the cache */
   /* search1097_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 832 },
      -1,
   } },

   /* replace1097_0 -> 16 in the cache */
   /* replace1097_1 -> 398 in the cache */
   /* replace1097 -> 441 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1098_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3195, 32 },
      -1,
   } },

   /* replace1098_0 -> 32 in the cache */
   /* replace1098_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1099_0 -> 16 in the cache */
   /* search1099_1 -> 124 in the cache */
   /* search1099_2 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 832 },
      -1,
   } },

   /* replace1099_0 -> 16 in the cache */
   /* replace1099_1 -> 124 in the cache */
   /* replace1099 -> 446 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1100_0 -> 16 in the cache */
   /* search1100_1 -> 832 in the cache */
   /* search1100_2 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 832, 832 },
      -1,
   } },

   /* replace1100_0 -> 16 in the cache */
   /* replace1100_1 -> 398 in the cache */
   /* replace1100 -> 449 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1101_0 -> 16 in the cache */
   /* search1101_1 -> 124 in the cache */
   /* search1101_2 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 124, 832 },
      -1,
   } },

   /* replace1101_0 -> 16 in the cache */
   /* replace1101_1 -> 124 in the cache */
   /* replace1101 -> 438 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1102_0 -> 16 in the cache */
   /* search1102_1 -> 832 in the cache */
   /* search1102_2 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 832, 832 },
      -1,
   } },

   /* replace1102_0 -> 16 in the cache */
   /* replace1102_1 -> 398 in the cache */
   /* replace1102 -> 441 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1103_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1103_0_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3202, 991 },
      -1,
   } },
   /* search1103_1_0_0_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2093 },
      -1,
   } },
   /* search1103_1_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3204, 832 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3206 },
      -1,
   } },
   /* search1103_1_1_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3207, 810 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3209 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 3208, 3210 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 3205, 3211 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3203, 3212 },
      -1,
   } },

   /* replace1103_0_0 -> 3209 in the cache */
   /* replace1103_0_1 -> 3206 in the cache */
   /* replace1103_0_2 -> 2093 in the cache */
   /* replace1103_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3209, 3206, 2093, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 3214 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1104_0_0 -> 0 in the cache */
   /* search1104_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1104_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3216, 86 },
      -1,
   } },

   /* replace1104_0 -> 0 in the cache */
   /* replace1104_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1105_0_0 -> 0 in the cache */
   /* search1105_0_1 -> 3 in the cache */
   /* search1105_0 -> 3218 in the cache */
   /* search1105_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3218, 86 },
      -1,
   } },

   /* replace1105_0 -> 0 in the cache */
   /* replace1105_1 -> 3 in the cache */
   /* replace1105 -> 3218 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1106_0 -> 16 in the cache */
   /* search1106_1 -> 36 in the cache */
   /* search1106 -> 3120 in the cache */

   /* replace1106_0_0 -> 16 in the cache */
   /* replace1106_0 -> 1889 in the cache */
   /* replace1106_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1106_1_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3220, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1889, 3221 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1107_0 -> 11 in the cache */
   /* search1107_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 260 },
      -1,
   } },

   /* replace1107_0_0 -> 11 in the cache */
   /* replace1107_0 -> 1782 in the cache */
   /* replace1107_1_0_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 260 },
      -1,
   } },
   /* replace1107_1_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3224, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1782, 3225 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1108_0 -> 21 in the cache */
   /* search1108 -> 3137 in the cache */

   /* replace1108_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1109_0 -> 21 in the cache */
   /* search1109 -> 3138 in the cache */

   /* replace1109_0_0 -> 21 in the cache */
   /* replace1109_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3228 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1110_0 -> 16 in the cache */
   /* search1110 -> 3146 in the cache */

   /* replace1110_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1111_0 -> 16 in the cache */
   /* search1111 -> 3148 in the cache */

   /* replace1111_0_0 -> 16 in the cache */
   /* replace1111_0_1 -> 832 in the cache */
   /* replace1111_0 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 987 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1112_0_0 -> 16 in the cache */
   /* search1112_0_1 -> 981 in the cache */
   /* search1112_0 -> 982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 982 },
      -1,
   } },

   /* replace1112_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1113_0_0 -> 16 in the cache */
   /* search1113_0_1 -> 981 in the cache */
   /* search1113_0 -> 982 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 982 },
      -1,
   } },

   /* replace1113_0 -> 16 in the cache */
   /* replace1113 -> 3146 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1114_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 3236 },
      -1,
   } },

   /* replace1114_0 -> 21 in the cache */
   /* replace1114 -> 3137 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1115_0_0 -> 16 in the cache */
   /* search1115_0_1 -> 985 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 985 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 3238 },
      -1,
   } },

   /* replace1115_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1116_0_0 -> 16 in the cache */
   /* search1116_0_1 -> 985 in the cache */
   /* search1116_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 3238 },
      -1,
   } },

   /* replace1116_0 -> 16 in the cache */
   /* replace1116 -> 3148 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1117_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3242 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3243 },
      -1,
   } },

   /* replace1117_0 -> 21 in the cache */
   /* replace1117 -> 3138 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1118_0_0 -> 16 in the cache */
   /* search1118_0_1 -> 124 in the cache */
   /* search1118_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 446 },
      -1,
   } },

   /* replace1118_0 -> 16 in the cache */
   /* replace1118 -> 3233 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1119_0_0 -> 16 in the cache */
   /* search1119_0_1 -> 398 in the cache */
   /* search1119_0 -> 449 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 449 },
      -1,
   } },

   /* replace1119_0 -> 16 in the cache */
   /* replace1119 -> 3240 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1120_0_0 -> 16 in the cache */
   /* search1120_0_1 -> 832 in the cache */
   /* search1120_0 -> 987 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 987 },
      -1,
   } },

   /* replace1120_0 -> 16 in the cache */
   /* replace1120 -> 3240 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1121_0_0 -> 16 in the cache */
   /* search1121_0_1 -> 124 in the cache */
   /* search1121_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 446 },
      -1,
   } },

   /* replace1121_0 -> 16 in the cache */
   /* replace1121 -> 3146 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1122_0_0 -> 16 in the cache */
   /* search1122_0_1 -> 398 in the cache */
   /* search1122_0 -> 449 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 449 },
      -1,
   } },

   /* replace1122_0 -> 16 in the cache */
   /* replace1122 -> 3148 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1123_0_0_0 -> 16 in the cache */
   /* search1123_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3250 },
      -1,
   } },
   /* search1123_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3251, 832 },
      -1,
   } },

   /* replace1123_0_0 -> 124 in the cache */
   /* replace1123_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3253 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1124_0_0_0 -> 124 in the cache */
   /* search1124_0_0_1 -> 16 in the cache */
   /* search1124_0_0 -> 3253 in the cache */
   /* search1124_0 -> 3254 in the cache */
   /* search1124_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3254, 832 },
      -1,
   } },

   /* replace1124_0_0 -> 16 in the cache */
   /* replace1124_0_1 -> 124 in the cache */
   /* replace1124_0 -> 3250 in the cache */
   /* replace1124 -> 3251 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1125_0_0_0 -> 16 in the cache */
   /* search1125_0_0_1 -> 124 in the cache */
   /* search1125_0_0 -> 3250 in the cache */
   /* search1125_0 -> 3251 in the cache */
   /* search1125_1_0_0 -> 124 in the cache */
   /* search1125_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3256 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3251, 3257 },
      -1,
   } },

   /* replace1125_0_0 -> 16 in the cache */
   /* replace1125_0_1 -> 36 in the cache */
   /* replace1125_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1126_0_0_0 -> 16 in the cache */
   /* search1126_0_0_1 -> 124 in the cache */
   /* search1126_0_0 -> 3250 in the cache */
   /* search1126_0 -> 3251 in the cache */
   /* search1126_1_0_0 -> 124 in the cache */
   /* search1126_1_0_1 -> 36 in the cache */
   /* search1126_1_0 -> 3256 in the cache */
   /* search1126_1 -> 3257 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3251, 3257 },
      -1,
   } },

   /* replace1126_0_0 -> 16 in the cache */
   /* replace1126_0_1 -> 36 in the cache */
   /* replace1126_0 -> 3133 in the cache */
   /* replace1126 -> 3259 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1127_0_0 -> 16 in the cache */
   /* search1127_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* search1127_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3261, 832 },
      -1,
   } },

   /* replace1127_0 -> 124 in the cache */
   /* replace1127_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 124, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1128_0_0 -> 124 in the cache */
   /* search1128_0_1 -> 16 in the cache */
   /* search1128_0 -> 3263 in the cache */
   /* search1128_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3263, 832 },
      -1,
   } },

   /* replace1128_0 -> 16 in the cache */
   /* replace1128_1 -> 124 in the cache */
   /* replace1128 -> 3261 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1129_0_0 -> 124 in the cache */
   /* search1129_0_1 -> 16 in the cache */
   /* search1129_0 -> 3263 in the cache */
   /* search1129_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3263, 398 },
      -1,
   } },

   /* replace1129_0 -> 16 in the cache */
   /* replace1129_1 -> 124 in the cache */
   /* replace1129 -> 3261 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1130_0_0 -> 16 in the cache */
   /* search1130_0_1 -> 124 in the cache */
   /* search1130_0 -> 3261 in the cache */
   /* search1130_1_0 -> 124 in the cache */
   /* search1130_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3261, 3266 },
      -1,
   } },

   /* replace1130_0 -> 16 in the cache */
   /* replace1130_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1131_0_0 -> 16 in the cache */
   /* search1131_0_1 -> 124 in the cache */
   /* search1131_0 -> 3261 in the cache */
   /* search1131_1_0 -> 124 in the cache */
   /* search1131_1_1 -> 36 in the cache */
   /* search1131_1 -> 3266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3261, 3266 },
      -1,
   } },

   /* replace1131_0 -> 16 in the cache */
   /* replace1131_1 -> 36 in the cache */
   /* replace1131 -> 3268 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1132_0_0 -> 6 in the cache */
   /* search1132_0_1 -> 2093 in the cache */
   /* search1132_0_2 -> 3206 in the cache */
   /* search1132_0_3 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2093, 3206, 3209 },
      -1,
   } },
   /* search1132_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3270, 124 },
      -1,
   } },

   /* replace1132_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1133_0_0 -> 6 in the cache */
   /* search1133_0_1 -> 2093 in the cache */
   /* search1133_0_2 -> 3206 in the cache */
   /* search1133_0_3 -> 3209 in the cache */
   /* search1133_0 -> 3270 in the cache */
   /* search1133_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3270, 398 },
      -1,
   } },

   /* replace1133_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2093 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1134_0_0 -> 6 in the cache */
   /* search1134_0_1 -> 2093 in the cache */
   /* search1134_0_2 -> 3206 in the cache */
   /* search1134_0_3 -> 3209 in the cache */
   /* search1134_0 -> 3270 in the cache */
   /* search1134_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3270, 403 },
      -1,
   } },

   /* replace1134_0 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3206 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1135_0_0 -> 6 in the cache */
   /* search1135_0_1 -> 2093 in the cache */
   /* search1135_0_2 -> 3206 in the cache */
   /* search1135_0_3 -> 3209 in the cache */
   /* search1135_0 -> 3270 in the cache */
   /* search1135_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3270, 407 },
      -1,
   } },

   /* replace1135_0 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3209 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1136_0_0 -> 6 in the cache */
   /* search1136_0_1 -> 2093 in the cache */
   /* search1136_0_2 -> 3206 in the cache */
   /* search1136_0_3 -> 3209 in the cache */
   /* search1136_0 -> 3270 in the cache */
   /* search1136_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3270, 124 },
      -1,
   } },

   /* replace1136_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1137_0_0 -> 6 in the cache */
   /* search1137_0_1 -> 2093 in the cache */
   /* search1137_0_2 -> 3206 in the cache */
   /* search1137_0_3 -> 3209 in the cache */
   /* search1137_0 -> 3270 in the cache */
   /* search1137_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3270, 398 },
      -1,
   } },

   /* replace1137_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2093 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1138_0_0 -> 6 in the cache */
   /* search1138_0_1 -> 2093 in the cache */
   /* search1138_0_2 -> 3206 in the cache */
   /* search1138_0_3 -> 3209 in the cache */
   /* search1138_0 -> 3270 in the cache */
   /* search1138_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3270, 403 },
      -1,
   } },

   /* replace1138_0 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3206 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1139_0_0 -> 6 in the cache */
   /* search1139_0_1 -> 2093 in the cache */
   /* search1139_0_2 -> 3206 in the cache */
   /* search1139_0_3 -> 3209 in the cache */
   /* search1139_0 -> 3270 in the cache */
   /* search1139_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3270, 407 },
      -1,
   } },

   /* replace1139_0 -> 3209 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3209 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1140_0_0 -> 11 in the cache */
   /* search1140_0_1 -> 810 in the cache */
   /* search1140_0 -> 3154 in the cache */
   /* search1140_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3154, 835 },
      -1,
   } },

   /* replace1140_0 -> 11 in the cache */
   /* replace1140_1 -> 1429 in the cache */
   /* replace1140 -> 3155 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1141_0_0 -> 16 in the cache */
   /* search1141_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 810 },
      -1,
   } },
   /* search1141_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3288, 124 },
      -1,
   } },

   /* replace1141_0 -> 16 in the cache */
   /* replace1141_1 -> 398 in the cache */
   /* replace1141 -> 417 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1142_0_0 -> 16 in the cache */
   /* search1142_0_1 -> 832 in the cache */
   /* search1142_0 -> 987 in the cache */
   /* search1142_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 987, 124 },
      -1,
   } },

   /* replace1142_0 -> 16 in the cache */
   /* replace1142_1 -> 403 in the cache */
   /* replace1142 -> 421 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1143_0_0 -> 16 in the cache */
   /* search1143_0_1 -> 991 in the cache */
   /* search1143_0 -> 996 in the cache */
   /* search1143_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 996, 124 },
      -1,
   } },

   /* replace1143_0 -> 16 in the cache */
   /* replace1143_1 -> 407 in the cache */
   /* replace1143 -> 424 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1144_0_0 -> 21 in the cache */
   /* search1144_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1144_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3292, 876 },
      -1,
   } },

   /* replace1144_0 -> 21 in the cache */
   /* replace1144_1 -> 1471 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1471 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1145_0_0 -> 21 in the cache */
   /* search1145_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   /* search1145_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3295, 876 },
      -1,
   } },

   /* replace1145_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3297 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1146_0_0 -> 21 in the cache */
   /* search1146_0_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 991 },
      -1,
   } },
   /* search1146_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3299, 876 },
      -1,
   } },

   /* replace1146_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3301 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1147_0_0 -> 21 in the cache */
   /* search1147_0_1 -> 853 in the cache */
   /* search1147_0 -> 3228 in the cache */
   /* search1147_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3228, 876 },
      -1,
   } },

   /* replace1147_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3304 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1148_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3306 },
      -1,
   } },
   /* search1148_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3307, 876 },
      -1,
   } },

   /* replace1148_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3309 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1149_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3311 },
      -1,
   } },
   /* search1149_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3312, 876 },
      -1,
   } },

   /* replace1149_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3314 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1150_0_0 -> 21 in the cache */
   /* search1150_0_1 -> 3156 in the cache */
   /* search1150_0 -> 3157 in the cache */
   /* search1150_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3157, 876 },
      -1,
   } },

   /* replace1150_0 -> 21 in the cache */
   /* replace1150_1 -> 3158 in the cache */
   /* replace1150 -> 3159 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1151_0_0 -> 11 in the cache */
   /* search1151_0_1 -> 810 in the cache */
   /* search1151_0 -> 3160 in the cache */
   /* search1151_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3160, 835 },
      -1,
   } },

   /* replace1151_0 -> 11 in the cache */
   /* replace1151_1 -> 1429 in the cache */
   /* replace1151 -> 3155 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1152_0_0 -> 16 in the cache */
   /* search1152_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 810 },
      -1,
   } },
   /* search1152_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3318, 124 },
      -1,
   } },

   /* replace1152_0 -> 16 in the cache */
   /* replace1152_1 -> 398 in the cache */
   /* replace1152 -> 417 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1153_0_0 -> 16 in the cache */
   /* search1153_0_1 -> 832 in the cache */
   /* search1153_0 -> 3194 in the cache */
   /* search1153_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3194, 124 },
      -1,
   } },

   /* replace1153_0 -> 16 in the cache */
   /* replace1153_1 -> 403 in the cache */
   /* replace1153 -> 421 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1154_0_0 -> 16 in the cache */
   /* search1154_0_1 -> 991 in the cache */
   /* search1154_0 -> 3162 in the cache */
   /* search1154_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3162, 124 },
      -1,
   } },

   /* replace1154_0 -> 16 in the cache */
   /* replace1154_1 -> 407 in the cache */
   /* replace1154 -> 424 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1155_0_0 -> 21 in the cache */
   /* search1155_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1155_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3322, 876 },
      -1,
   } },

   /* replace1155_0 -> 21 in the cache */
   /* replace1155_1 -> 1471 in the cache */
   /* replace1155 -> 3294 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1156_0_0 -> 21 in the cache */
   /* search1156_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   /* search1156_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3324, 876 },
      -1,
   } },

   /* replace1156_0 -> 21 in the cache */
   /* replace1156_1 -> 3297 in the cache */
   /* replace1156 -> 3298 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1157_0_0 -> 21 in the cache */
   /* search1157_0_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 991 },
      -1,
   } },
   /* search1157_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3326, 876 },
      -1,
   } },

   /* replace1157_0 -> 21 in the cache */
   /* replace1157_1 -> 3301 in the cache */
   /* replace1157 -> 3302 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1158_0_0 -> 21 in the cache */
   /* search1158_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   /* search1158_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3328, 876 },
      -1,
   } },

   /* replace1158_0 -> 21 in the cache */
   /* replace1158_1 -> 3304 in the cache */
   /* replace1158 -> 3305 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1159_0_0 -> 21 in the cache */
   /* search1159_0_1 -> 3306 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3306 },
      -1,
   } },
   /* search1159_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3330, 876 },
      -1,
   } },

   /* replace1159_0 -> 21 in the cache */
   /* replace1159_1 -> 3309 in the cache */
   /* replace1159 -> 3310 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1160_0_0 -> 21 in the cache */
   /* search1160_0_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3311 },
      -1,
   } },
   /* search1160_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3332, 876 },
      -1,
   } },

   /* replace1160_0 -> 21 in the cache */
   /* replace1160_1 -> 3314 in the cache */
   /* replace1160 -> 3315 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1161_0_0 -> 21 in the cache */
   /* search1161_0_1 -> 3156 in the cache */
   /* search1161_0 -> 3163 in the cache */
   /* search1161_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3163, 876 },
      -1,
   } },

   /* replace1161_0 -> 21 in the cache */
   /* replace1161_1 -> 3158 in the cache */
   /* replace1161 -> 3159 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1162_0_0 -> 32 in the cache */
   /* search1162_0_1 -> 35 in the cache */
   /* search1162_0 -> 3167 in the cache */
   /* search1162_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3167, 61 },
      -1,
   } },

   /* replace1162_0 -> 32 in the cache */
   /* replace1162_1 -> 2219 in the cache */
   /* replace1162 -> 3169 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1163_0_0 -> 11 in the cache */
   /* search1163_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 810 },
      -1,
   } },
   /* search1163_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3336, 1429 },
      -1,
   } },

   /* replace1163_0 -> 11 in the cache */
   /* replace1163_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 835 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1164_0_0 -> 16 in the cache */
   /* search1164_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 810 },
      -1,
   } },
   /* search1164_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3339, 407 },
      -1,
   } },

   /* replace1164_0 -> 16 in the cache */
   /* replace1164_1 -> 403 in the cache */
   /* replace1164 -> 421 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1165_0_0 -> 16 in the cache */
   /* search1165_0_1 -> 832 in the cache */
   /* search1165_0 -> 984 in the cache */
   /* search1165_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 984, 407 },
      -1,
   } },

   /* replace1165_0 -> 16 in the cache */
   /* replace1165_1 -> 398 in the cache */
   /* replace1165 -> 417 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1166_0_0 -> 16 in the cache */
   /* search1166_0_1 -> 991 in the cache */
   /* search1166_0 -> 993 in the cache */
   /* search1166_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 993, 407 },
      -1,
   } },

   /* replace1166_0 -> 16 in the cache */
   /* replace1166_1 -> 124 in the cache */
   /* replace1166 -> 414 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1167_0_0 -> 21 in the cache */
   /* search1167_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 810 },
      -1,
   } },
   /* search1167_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3343, 3158 },
      -1,
   } },

   /* replace1167_0 -> 21 in the cache */
   /* replace1167_1 -> 3314 in the cache */
   /* replace1167 -> 3315 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1168_0_0 -> 21 in the cache */
   /* search1168_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 832 },
      -1,
   } },
   /* search1168_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3345, 3158 },
      -1,
   } },

   /* replace1168_0 -> 21 in the cache */
   /* replace1168_1 -> 3309 in the cache */
   /* replace1168 -> 3310 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1169_0_0 -> 21 in the cache */
   /* search1169_0_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 991 },
      -1,
   } },
   /* search1169_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3347, 3158 },
      -1,
   } },

   /* replace1169_0 -> 21 in the cache */
   /* replace1169_1 -> 3304 in the cache */
   /* replace1169 -> 3305 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1170_0_0 -> 21 in the cache */
   /* search1170_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   /* search1170_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3349, 3158 },
      -1,
   } },

   /* replace1170_0 -> 21 in the cache */
   /* replace1170_1 -> 3301 in the cache */
   /* replace1170 -> 3302 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1171_0_0 -> 21 in the cache */
   /* search1171_0_1 -> 3306 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3306 },
      -1,
   } },
   /* search1171_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3351, 3158 },
      -1,
   } },

   /* replace1171_0 -> 21 in the cache */
   /* replace1171_1 -> 3297 in the cache */
   /* replace1171 -> 3298 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1172_0_0 -> 21 in the cache */
   /* search1172_0_1 -> 3311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3311 },
      -1,
   } },
   /* search1172_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3353, 3158 },
      -1,
   } },

   /* replace1172_0 -> 21 in the cache */
   /* replace1172_1 -> 1471 in the cache */
   /* replace1172 -> 3294 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1173_0_0 -> 21 in the cache */
   /* search1173_0_1 -> 3156 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3156 },
      -1,
   } },
   /* search1173_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3355, 3158 },
      -1,
   } },

   /* replace1173_0 -> 21 in the cache */
   /* replace1173_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 876 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1174_0_0 -> 11 in the cache */
   /* search1174_0_1 -> 810 in the cache */
   /* search1174_0 -> 3336 in the cache */
   /* search1174_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3336, 1429 },
      -1,
   } },

   /* replace1174_0 -> 11 in the cache */
   /* replace1174_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 835 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1175_0_0 -> 16 in the cache */
   /* search1175_0_1 -> 810 in the cache */
   /* search1175_0 -> 3339 in the cache */
   /* search1175_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3339, 407 },
      -1,
   } },

   /* replace1175_0 -> 16 in the cache */
   /* replace1175_1 -> 403 in the cache */
   /* replace1175 -> 404 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1176_0_0 -> 16 in the cache */
   /* search1176_0_1 -> 832 in the cache */
   /* search1176_0 -> 984 in the cache */
   /* search1176_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 984, 407 },
      -1,
   } },

   /* replace1176_0 -> 16 in the cache */
   /* replace1176_1 -> 398 in the cache */
   /* replace1176 -> 399 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1177_0_0 -> 16 in the cache */
   /* search1177_0_1 -> 991 in the cache */
   /* search1177_0 -> 993 in the cache */
   /* search1177_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 993, 407 },
      -1,
   } },

   /* replace1177_0 -> 16 in the cache */
   /* replace1177_1 -> 124 in the cache */
   /* replace1177 -> 395 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1178_0_0 -> 21 in the cache */
   /* search1178_0_1 -> 810 in the cache */
   /* search1178_0 -> 3343 in the cache */
   /* search1178_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3343, 3158 },
      -1,
   } },

   /* replace1178_0 -> 21 in the cache */
   /* replace1178_1 -> 3314 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3314 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1179_0_0 -> 21 in the cache */
   /* search1179_0_1 -> 832 in the cache */
   /* search1179_0 -> 3345 in the cache */
   /* search1179_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3345, 3158 },
      -1,
   } },

   /* replace1179_0 -> 21 in the cache */
   /* replace1179_1 -> 3309 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3309 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1180_0_0 -> 21 in the cache */
   /* search1180_0_1 -> 991 in the cache */
   /* search1180_0 -> 3347 in the cache */
   /* search1180_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3347, 3158 },
      -1,
   } },

   /* replace1180_0 -> 21 in the cache */
   /* replace1180_1 -> 3304 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3304 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1181_0_0 -> 21 in the cache */
   /* search1181_0_1 -> 853 in the cache */
   /* search1181_0 -> 3349 in the cache */
   /* search1181_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3349, 3158 },
      -1,
   } },

   /* replace1181_0 -> 21 in the cache */
   /* replace1181_1 -> 3301 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3301 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1182_0_0 -> 21 in the cache */
   /* search1182_0_1 -> 3306 in the cache */
   /* search1182_0 -> 3351 in the cache */
   /* search1182_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3351, 3158 },
      -1,
   } },

   /* replace1182_0 -> 21 in the cache */
   /* replace1182_1 -> 3297 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3297 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1183_0_0 -> 21 in the cache */
   /* search1183_0_1 -> 3311 in the cache */
   /* search1183_0 -> 3353 in the cache */
   /* search1183_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3353, 3158 },
      -1,
   } },

   /* replace1183_0 -> 21 in the cache */
   /* replace1183_1 -> 1471 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1471 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1184_0_0 -> 21 in the cache */
   /* search1184_0_1 -> 3156 in the cache */
   /* search1184_0 -> 3355 in the cache */
   /* search1184_1 -> 3158 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3355, 3158 },
      -1,
   } },

   /* replace1184_0 -> 21 in the cache */
   /* replace1184_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 876 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1185_0 -> 16 in the cache */
   /* search1185_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* replace1185 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1186_0 -> 16 in the cache */
   /* search1186_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 126 },
      -1,
   } },

   /* replace1186 -> 124 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1187_0 -> 0 in the cache */
   /* search1187_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1187_0 -> 0 in the cache */
   /* replace1187_1_0 -> 3 in the cache */
   /* replace1187_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1066 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1188_0 -> 0 in the cache */
   /* search1188_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1188_0 -> 0 in the cache */
   /* replace1188_1_0 -> 3 in the cache */
   /* replace1188_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1189_0 -> 0 in the cache */
   /* search1189_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1189_0_0 -> 0 in the cache */
   /* replace1189_0_1 -> 3 in the cache */
   /* replace1189_0 -> 1046 in the cache */
   /* replace1189_1_0_0 -> 0 in the cache */
   /* replace1189_1_0_1 -> 3 in the cache */
   /* replace1189_1_0 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3381 },
      -1,
   } },
   /* replace1189_2_0 -> 0 in the cache */
   /* replace1189_2_1 -> 3 in the cache */
   /* replace1189_2 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1046, 3384, 3381 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1190_0 -> 0 in the cache */
   /* search1190_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1190_0_0 -> 0 in the cache */
   /* replace1190_0_1 -> 3 in the cache */
   /* replace1190_0 -> 1043 in the cache */
   /* replace1190_1_0_0 -> 0 in the cache */
   /* replace1190_1_0_1 -> 3 in the cache */
   /* replace1190_1_0 -> 3381 in the cache */
   /* replace1190_1 -> 3384 in the cache */
   /* replace1190_2_0 -> 0 in the cache */
   /* replace1190_2_1 -> 3 in the cache */
   /* replace1190_2 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1043, 3384, 3381 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1191_0_0 -> 0 in the cache */
   /* search1191_0 -> 214 in the cache */
   /* search1191_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 214, 3 },
      4,
   } },

   /* replace1191_0_0 -> 0 in the cache */
   /* replace1191_0_1 -> 3 in the cache */
   /* replace1191_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1192_0_0 -> 16 in the cache */
   /* search1192_0 -> 282 in the cache */
   /* search1192_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 282, 36 },
      4,
   } },

   /* replace1192_0_0 -> 16 in the cache */
   /* replace1192_0_1 -> 36 in the cache */
   /* replace1192_0 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 271 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1193_0_0 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 128 },
      -1,
   } },
   /* search1193_1_0 -> 129 in the cache */
   /* search1193_1 -> 1169 in the cache */
   /* search1193_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3392, 1169, 131 },
      -1,
   } },

   /* replace1193_0 -> 128 in the cache */
   /* replace1193_1 -> 129 in the cache */
   /* replace1193_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 128, 129, 131 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1194_0_0 -> 16 in the cache */
   /* search1194_0 -> 282 in the cache */
   /* search1194_1_0 -> 36 in the cache */
   /* search1194_1 -> 602 in the cache */
   /* search1194_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 282, 602, 137 },
      -1,
   } },

   /* replace1194_0 -> 16 in the cache */
   /* replace1194_1 -> 36 in the cache */
   /* replace1194_2 -> 137 in the cache */
   /* replace1194 -> 389 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1195_0_0 -> 0 in the cache */
   /* search1195_0 -> 209 in the cache */
   /* search1195_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 209, 3 },
      -1,
   } },

   /* replace1195_0_0 -> 0 in the cache */
   /* replace1195_0_1 -> 3 in the cache */
   /* replace1195_0 -> 930 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 930 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3398, 3399 },
      0,
   } },
   /* search1196_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3400, 793 },
      0,
   } },

   /* replace1196_0_0 -> 128 in the cache */
   /* replace1196_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1196_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3402, 129 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1197_0_0 -> 330 in the cache */
   /* search1197_0_1 -> 340 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 330, 340 },
      0,
   } },
   /* search1197_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3404, 311 },
      0,
   } },

   /* replace1197_0_0 -> 16 in the cache */
   /* replace1197_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 137 },
      -1,
   } },
   /* replace1197_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3406, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1198_0_0 -> 330 in the cache */
   /* search1198_0_1 -> 340 in the cache */
   /* search1198_0 -> 3404 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3404, 3408 },
      0,
   } },

   /* replace1198_0_0 -> 16 in the cache */
   /* replace1198_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 137 },
      -1,
   } },
   /* replace1198_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3410, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1199_0_0 -> 3398 in the cache */
   /* search1199_0_1 -> 3399 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3398, 3399 },
      0,
   } },
   /* search1199_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3412, 793 },
      0,
   } },

   /* replace1199_0_0 -> 128 in the cache */
   /* replace1199_0_1 -> 131 in the cache */
   /* replace1199_0 -> 1004 in the cache */
   /* replace1199_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1004, 129 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3415, 3416 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1200_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3417, 3418, 155 },
      -1,
   } },

   /* replace1200_0_0 -> 151 in the cache */
   /* replace1200_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 154 },
      -1,
   } },
   /* replace1200_1 -> 152 in the cache */
   /* replace1200_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3420, 152, 155 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1201_0_0 -> 330 in the cache */
   /* search1201_0_1 -> 340 in the cache */
   /* search1201_0 -> 3404 in the cache */
   /* search1201_1 -> 311 in the cache */
   /* search1201_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3404, 311, 165 },
      -1,
   } },

   /* replace1201_0_0 -> 16 in the cache */
   /* replace1201_0_1 -> 137 in the cache */
   /* replace1201_0 -> 3406 in the cache */
   /* replace1201_1 -> 36 in the cache */
   /* replace1201_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3406, 36, 165 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1202_0_0 -> 330 in the cache */
   /* search1202_0_1 -> 340 in the cache */
   /* search1202_0 -> 3404 in the cache */
   /* search1202_1 -> 3408 in the cache */
   /* search1202_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3404, 3408, 165 },
      -1,
   } },

   /* replace1202_0_0 -> 16 in the cache */
   /* replace1202_0_1 -> 137 in the cache */
   /* replace1202_0 -> 3410 in the cache */
   /* replace1202_1 -> 36 in the cache */
   /* replace1202_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3410, 36, 165 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1203_0_0 -> 3398 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3398, 3426 },
      0,
   } },
   /* search1203_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3427, 793 },
      0,
   } },

   /* replace1203_0_0 -> 128 in the cache */
   /* replace1203_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1203_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3429, 129 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1204_0_0 -> 3398 in the cache */
   /* search1204_0_1 -> 3399 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3398, 3399 },
      0,
   } },
   /* search1204_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3431, 793 },
      0,
   } },

   /* replace1204_0_0 -> 128 in the cache */
   /* replace1204_0_1 -> 131 in the cache */
   /* replace1204_0 -> 3429 in the cache */
   /* replace1204_1 -> 129 in the cache */
   /* replace1204 -> 3430 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1205_0_0 -> 3415 in the cache */
   /* search1205_0_1 -> 152 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3415, 152, 3433 },
      0,
   } },
   /* search1205_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3434, 1010 },
      0,
   } },

   /* replace1205_0_0 -> 151 in the cache */
   /* replace1205_0_1 -> 152 in the cache */
   /* replace1205_0_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 151, 152, 155 },
      -1,
   } },
   /* replace1205_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3436, 154 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1206_0_0 -> 330 in the cache */
   /* search1206_0_1 -> 36 in the cache */
   /* search1206_0_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 330, 36, 349 },
      0,
   } },
   /* search1206_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3438, 313 },
      0,
   } },

   /* replace1206_0_0 -> 16 in the cache */
   /* replace1206_0_1 -> 36 in the cache */
   /* replace1206_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 165 },
      -1,
   } },
   /* replace1206_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3440, 137 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1207_0_0 -> 3398 in the cache */
   /* search1207_0_1 -> 3399 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3398, 3399 },
      0,
   } },
   /* search1207_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3442, 793 },
      0,
   } },

   /* replace1207_0_0 -> 128 in the cache */
   /* replace1207_0_1 -> 131 in the cache */
   /* replace1207_0 -> 1018 in the cache */
   /* replace1207_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1018, 129 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1208_0 -> 284 in the cache */
   /* search1208_1_0 -> 3399 in the cache */
   /* search1208_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 284, 3445 },
      -1,
   } },

   /* replace1208_0_0 -> 128 in the cache */
   /* replace1208_0_1 -> 131 in the cache */
   /* replace1208_0 -> 3402 in the cache */
   /* replace1208_1 -> 129 in the cache */
   /* replace1208 -> 3403 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1209_0 -> 288 in the cache */
   /* search1209_1_0 -> 340 in the cache */
   /* search1209_1_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 340, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 288, 3447 },
      -1,
   } },

   /* replace1209_0_0 -> 16 in the cache */
   /* replace1209_0_1 -> 137 in the cache */
   /* replace1209_0 -> 3406 in the cache */
   /* replace1209_1 -> 36 in the cache */
   /* replace1209 -> 3407 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1210_1_0 -> 340 in the cache */
   /* search1210_1_1 -> 311 in the cache */
   /* search1210_1 -> 3447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3449, 3447 },
      -1,
   } },

   /* replace1210_0_0 -> 16 in the cache */
   /* replace1210_0_1 -> 137 in the cache */
   /* replace1210_0 -> 3410 in the cache */
   /* replace1210_1 -> 36 in the cache */
   /* replace1210 -> 3411 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1211_1_0 -> 3416 in the cache */
   /* search1211_1_1 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3416, 3418 },
      -1,
   } },
   /* search1211_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3451, 3452, 155 },
      -1,
   } },

   /* replace1211_0_0 -> 151 in the cache */
   /* replace1211_0_1 -> 154 in the cache */
   /* replace1211_0 -> 3420 in the cache */
   /* replace1211_1 -> 152 in the cache */
   /* replace1211_2 -> 155 in the cache */
   /* replace1211 -> 3421 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1212_0 -> 288 in the cache */
   /* search1212_1_0 -> 340 in the cache */
   /* search1212_1_1 -> 311 in the cache */
   /* search1212_1 -> 3447 in the cache */
   /* search1212_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 288, 3447, 165 },
      -1,
   } },

   /* replace1212_0_0 -> 16 in the cache */
   /* replace1212_0_1 -> 137 in the cache */
   /* replace1212_0 -> 3406 in the cache */
   /* replace1212_1 -> 36 in the cache */
   /* replace1212_2 -> 165 in the cache */
   /* replace1212 -> 3423 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1213_0 -> 3449 in the cache */
   /* search1213_1_0 -> 340 in the cache */
   /* search1213_1_1 -> 311 in the cache */
   /* search1213_1 -> 3447 in the cache */
   /* search1213_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3449, 3447, 165 },
      -1,
   } },

   /* replace1213_0_0 -> 16 in the cache */
   /* replace1213_0_1 -> 137 in the cache */
   /* replace1213_0 -> 3410 in the cache */
   /* replace1213_1 -> 36 in the cache */
   /* replace1213_2 -> 165 in the cache */
   /* replace1213 -> 3425 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1214_0 -> 284 in the cache */
   /* search1214_1_0 -> 3399 in the cache */
   /* search1214_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 284, 3456 },
      -1,
   } },

   /* replace1214_0_0 -> 128 in the cache */
   /* replace1214_0_1 -> 131 in the cache */
   /* replace1214_0 -> 1004 in the cache */
   /* replace1214_1 -> 129 in the cache */
   /* replace1214 -> 3414 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1215_0 -> 284 in the cache */
   /* search1215_1_0 -> 3399 in the cache */
   /* search1215_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 284, 3458 },
      -1,
   } },

   /* replace1215_0_0 -> 128 in the cache */
   /* replace1215_0_1 -> 131 in the cache */
   /* replace1215_0 -> 3429 in the cache */
   /* replace1215_1 -> 129 in the cache */
   /* replace1215 -> 3430 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1216_0 -> 284 in the cache */
   /* search1216_1_0_0 -> 3399 in the cache */
   /* search1216_1_0_1 -> 793 in the cache */
   /* search1216_1_0 -> 3458 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3458 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 284, 3460 },
      -1,
   } },

   /* replace1216_0_0 -> 128 in the cache */
   /* replace1216_0_1_0 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 3462 },
      -1,
   } },
   /* replace1216_1_0 -> 129 in the cache */
   /* replace1216_1 -> 1169 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3463, 1169 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1217_0 -> 3451 in the cache */
   /* search1217_1_0 -> 3416 in the cache */
   /* search1217_1_1 -> 3433 in the cache */
   /* search1217_1_2 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3416, 3433, 1010 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3451, 3465 },
      -1,
   } },

   /* replace1217_0 -> 152 in the cache */
   /* replace1217_1 -> 154 in the cache */
   /* replace1217_2_0 -> 151 in the cache */
   /* replace1217_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 151, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 152, 154, 3467 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1218_0 -> 3451 in the cache */
   /* search1218_1_0_0 -> 3416 in the cache */
   /* search1218_1_0_1 -> 3433 in the cache */
   /* search1218_1_0_2 -> 1010 in the cache */
   /* search1218_1_0 -> 3465 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3451, 3469 },
      -1,
   } },

   /* replace1218_0_0 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 152 },
      -1,
   } },
   /* replace1218_1 -> 154 in the cache */
   /* replace1218_2_0 -> 151 in the cache */
   /* replace1218_2_1_0 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 151, 3472 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3471, 154, 3473 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1219_0 -> 288 in the cache */
   /* search1219_1_0 -> 340 in the cache */
   /* search1219_1_1 -> 349 in the cache */
   /* search1219_1_2 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 340, 349, 313 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 288, 3475 },
      -1,
   } },

   /* replace1219_0 -> 36 in the cache */
   /* replace1219_1 -> 137 in the cache */
   /* replace1219_2_0 -> 16 in the cache */
   /* replace1219_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 137, 3477 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1220_0 -> 288 in the cache */
   /* search1220_1_0_0 -> 340 in the cache */
   /* search1220_1_0_1 -> 349 in the cache */
   /* search1220_1_0_2 -> 313 in the cache */
   /* search1220_1_0 -> 3475 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 288, 3479 },
      -1,
   } },

   /* replace1220_0_0 -> 36 in the cache */
   /* replace1220_0 -> 602 in the cache */
   /* replace1220_1 -> 137 in the cache */
   /* replace1220_2_0 -> 16 in the cache */
   /* replace1220_2_1_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3481 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 602, 137, 3482 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1221_0 -> 284 in the cache */
   /* search1221_1_0 -> 3399 in the cache */
   /* search1221_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 284, 3484 },
      -1,
   } },

   /* replace1221_0_0 -> 128 in the cache */
   /* replace1221_0_1 -> 131 in the cache */
   /* replace1221_0 -> 1018 in the cache */
   /* replace1221_1 -> 129 in the cache */
   /* replace1221 -> 3444 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1222_0 -> 284 in the cache */
   /* search1222_1_0 -> 3399 in the cache */
   /* search1222_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 284, 3486 },
      -1,
   } },

   /* replace1222_0_0 -> 128 in the cache */
   /* replace1222_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1222_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3488, 129 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1223_0 -> 284 in the cache */
   /* search1223_1_0 -> 3399 in the cache */
   /* search1223_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 284, 3490 },
      -1,
   } },

   /* replace1223_0_0 -> 128 in the cache */
   /* replace1223_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1223_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3492, 129 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1224_0 -> 284 in the cache */
   /* search1224_1_0 -> 3399 in the cache */
   /* search1224_1_1 -> 793 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3399, 793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 284, 3494 },
      -1,
   } },

   /* replace1224_0_0 -> 128 in the cache */
   /* replace1224_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1224_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3496, 129 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1225_0_1 -> 3426 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3498, 3426 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3499, 3500 },
      -1,
   } },

   /* replace1225_0_0 -> 128 in the cache */
   /* replace1225_0_1 -> 131 in the cache */
   /* replace1225_0 -> 3429 in the cache */
   /* replace1225_1 -> 129 in the cache */
   /* replace1225 -> 3430 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1226_0_0 -> 0 in the cache */
   /* search1226_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1226_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3502, 3 },
      -1,
   } },

   /* replace1226 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1227_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1227_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3504, 124 },
      -1,
   } },
   /* search1227_1_0 -> 32 in the cache */
   /* search1227_1 -> 3504 in the cache */
   /* search1227_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3505, 3504, 126 },
      -1,
   } },

   /* replace1227_0 -> 32 in the cache */
   /* replace1227 -> 3504 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1228_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1228_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3507, 124 },
      -1,
   } },
   /* search1228_1_0 -> 16 in the cache */
   /* search1228_1 -> 3507 in the cache */
   /* search1228_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3508, 3507, 126 },
      -1,
   } },

   /* replace1228_0 -> 16 in the cache */
   /* replace1228 -> 3507 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1229_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1229_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3510, 124 },
      -1,
   } },
   /* search1229_1_0 -> 32 in the cache */
   /* search1229_1 -> 3510 in the cache */
   /* search1229_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3511, 3510, 126 },
      -1,
   } },

   /* replace1229_0 -> 32 in the cache */
   /* replace1229 -> 3510 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1230_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1230_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3513, 124 },
      -1,
   } },
   /* search1230_1_0 -> 32 in the cache */
   /* search1230_1 -> 3513 in the cache */
   /* search1230_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3514, 3513, 126 },
      -1,
   } },

   /* replace1230_0 -> 32 in the cache */
   /* replace1230 -> 3513 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1231_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1231_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3516, 124 },
      -1,
   } },
   /* search1231_1_0 -> 32 in the cache */
   /* search1231_1 -> 3516 in the cache */
   /* search1231_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3517, 3516, 126 },
      -1,
   } },

   /* replace1231_0 -> 32 in the cache */
   /* replace1231 -> 3516 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1232_0_0 -> 32 in the cache */
   /* search1232_0_1 -> 61 in the cache */
   /* search1232_0 -> 1205 in the cache */
   /* search1232_1_0 -> 32 in the cache */
   /* search1232_1 -> 3504 in the cache */
   /* search1232_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1205, 3504, 126 },
      -1,
   } },

   /* replace1232_0 -> 32 in the cache */
   /* replace1232 -> 3504 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1233_0_0 -> 16 in the cache */
   /* search1233_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 124 },
      -1,
   } },
   /* search1233_1_0 -> 16 in the cache */
   /* search1233_1 -> 3507 in the cache */
   /* search1233_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3520, 3507, 126 },
      -1,
   } },

   /* replace1233_0 -> 16 in the cache */
   /* replace1233 -> 3507 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1234_0_0 -> 32 in the cache */
   /* search1234_0_1 -> 61 in the cache */
   /* search1234_0 -> 1205 in the cache */
   /* search1234_1_0 -> 32 in the cache */
   /* search1234_1 -> 3510 in the cache */
   /* search1234_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1205, 3510, 126 },
      -1,
   } },

   /* replace1234_0 -> 32 in the cache */
   /* replace1234 -> 3510 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1235_0_0 -> 32 in the cache */
   /* search1235_0_1 -> 61 in the cache */
   /* search1235_0 -> 1205 in the cache */
   /* search1235_1_0 -> 32 in the cache */
   /* search1235_1 -> 3513 in the cache */
   /* search1235_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1205, 3513, 126 },
      -1,
   } },

   /* replace1235_0 -> 32 in the cache */
   /* replace1235 -> 3513 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1236_0_0 -> 32 in the cache */
   /* search1236_0_1 -> 61 in the cache */
   /* search1236_0 -> 1205 in the cache */
   /* search1236_1_0 -> 32 in the cache */
   /* search1236_1 -> 3516 in the cache */
   /* search1236_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1205, 3516, 126 },
      -1,
   } },

   /* replace1236_0 -> 32 in the cache */
   /* replace1236 -> 3516 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1237_0_0 -> 16 in the cache */
   /* search1237_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 126 },
      -1,
   } },
   /* search1237_1_0 -> 16 in the cache */
   /* search1237_1 -> 3507 in the cache */
   /* search1237_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3525, 3507, 126 },
      -1,
   } },

   /* replace1237_0 -> 16 in the cache */
   /* replace1237 -> 3507 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1238_0_0 -> 32 in the cache */
   /* search1238_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 63 },
      -1,
   } },
   /* search1238_1_0 -> 32 in the cache */
   /* search1238_1 -> 3513 in the cache */
   /* search1238_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3527, 3513, 126 },
      -1,
   } },

   /* replace1238_0 -> 32 in the cache */
   /* replace1238 -> 3513 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a') */
   /* search1239_0_0_0 -> 16 in the cache */
   /* search1239_0_0 -> 3507 in the cache */
   /* search1239_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3507, 126 },
      -1,
   } },
   /* search1239_1_0 -> 19 in the cache */
   /* search1239_1_1_0_0 -> 16 in the cache */
   /* search1239_1_1_0 -> 3507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3530 },
      -1,
   } },
   /* search1239_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3529, 3531, 126 },
      -1,
   } },

   /* replace1239_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1240_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1240_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3534, 126 },
      -1,
   } },
   /* search1240_1_0 -> 19 in the cache */
   /* search1240_1_1_0_0 -> 16 in the cache */
   /* search1240_1_1_0 -> 3534 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3536 },
      -1,
   } },
   /* search1240_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3535, 3537, 126 },
      -1,
   } },

   /* replace1240_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1241_0_0_0 -> 16 in the cache */
   /* search1241_0_0 -> 3507 in the cache */
   /* search1241_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3507, 126 },
      -1,
   } },
   /* search1241_1 -> 126 in the cache */
   /* search1241_2_0 -> 19 in the cache */
   /* search1241_2_1_0_0 -> 16 in the cache */
   /* search1241_2_1_0 -> 3507 in the cache */
   /* search1241_2_1 -> 3530 in the cache */
   /* search1241_2 -> 3531 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3540, 126, 3531 },
      -1,
   } },

   /* replace1241_0 -> 16 in the cache */
   /* replace1241 -> 3533 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1242_0_0_0 -> 16 in the cache */
   /* search1242_0_0 -> 3534 in the cache */
   /* search1242_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3534, 126 },
      -1,
   } },
   /* search1242_1 -> 126 in the cache */
   /* search1242_2_0 -> 19 in the cache */
   /* search1242_2_1_0_0 -> 16 in the cache */
   /* search1242_2_1_0 -> 3534 in the cache */
   /* search1242_2_1 -> 3536 in the cache */
   /* search1242_2 -> 3537 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3542, 126, 3537 },
      -1,
   } },

   /* replace1242_0 -> 16 in the cache */
   /* replace1242 -> 3539 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a') */
   /* search1243_0_0_0 -> 16 in the cache */
   /* search1243_0_0 -> 3507 in the cache */
   /* search1243_0_1 -> 126 in the cache */
   /* search1243_0 -> 3529 in the cache */
   /* search1243_1_0 -> 19 in the cache */
   /* search1243_1_1_0_0 -> 16 in the cache */
   /* search1243_1_1_0 -> 3507 in the cache */
   /* search1243_1_1 -> 3530 in the cache */
   /* search1243_1 -> 3531 in the cache */
   /* search1243_2_0 -> 16 in the cache */
   /* search1243_2 -> 3507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3529, 3531, 3507 },
      -1,
   } },

   /* replace1243_0 -> 16 in the cache */
   /* replace1243 -> 3533 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1244_0_0_0 -> 16 in the cache */
   /* search1244_0_0 -> 3534 in the cache */
   /* search1244_0_1 -> 126 in the cache */
   /* search1244_0 -> 3535 in the cache */
   /* search1244_1_0 -> 19 in the cache */
   /* search1244_1_1_0_0 -> 16 in the cache */
   /* search1244_1_1_0 -> 3534 in the cache */
   /* search1244_1_1 -> 3536 in the cache */
   /* search1244_1 -> 3537 in the cache */
   /* search1244_2_0 -> 16 in the cache */
   /* search1244_2 -> 3534 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3535, 3537, 3534 },
      -1,
   } },

   /* replace1244_0 -> 16 in the cache */
   /* replace1244 -> 3539 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1245_0_0_0 -> 16 in the cache */
   /* search1245_0_0 -> 3507 in the cache */
   /* search1245_0_1 -> 126 in the cache */
   /* search1245_0 -> 3540 in the cache */
   /* search1245_1_0 -> 16 in the cache */
   /* search1245_1 -> 3507 in the cache */
   /* search1245_2_0 -> 19 in the cache */
   /* search1245_2_1_0_0 -> 16 in the cache */
   /* search1245_2_1_0 -> 3507 in the cache */
   /* search1245_2_1 -> 3530 in the cache */
   /* search1245_2 -> 3531 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3540, 3507, 3531 },
      -1,
   } },

   /* replace1245_0 -> 16 in the cache */
   /* replace1245 -> 3533 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1246_0_0_0 -> 16 in the cache */
   /* search1246_0_0 -> 3534 in the cache */
   /* search1246_0_1 -> 126 in the cache */
   /* search1246_0 -> 3542 in the cache */
   /* search1246_1_0 -> 16 in the cache */
   /* search1246_1 -> 3534 in the cache */
   /* search1246_2_0 -> 19 in the cache */
   /* search1246_2_1_0_0 -> 16 in the cache */
   /* search1246_2_1_0 -> 3534 in the cache */
   /* search1246_2_1 -> 3536 in the cache */
   /* search1246_2 -> 3537 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3542, 3534, 3537 },
      -1,
   } },

   /* replace1246_0 -> 16 in the cache */
   /* replace1246 -> 3539 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1247_0_0 -> 16 in the cache */
   /* search1247_0_1 -> 124 in the cache */
   /* search1247_0 -> 3520 in the cache */
   /* search1247_1_0 -> 19 in the cache */
   /* search1247_1_1_0_0 -> 16 in the cache */
   /* search1247_1_1_0 -> 3534 in the cache */
   /* search1247_1_1 -> 3536 in the cache */
   /* search1247_1 -> 3537 in the cache */
   /* search1247_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3520, 3537, 126 },
      -1,
   } },

   /* replace1247_0 -> 16 in the cache */
   /* replace1247 -> 3539 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1248_0_0 -> 16 in the cache */
   /* search1248_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 124 },
      -1,
   } },
   /* search1248_1 -> 126 in the cache */
   /* search1248_2_0 -> 19 in the cache */
   /* search1248_2_1_0_0 -> 16 in the cache */
   /* search1248_2_1_0 -> 3534 in the cache */
   /* search1248_2_1 -> 3536 in the cache */
   /* search1248_2 -> 3537 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3549, 126, 3537 },
      -1,
   } },

   /* replace1248_0 -> 16 in the cache */
   /* replace1248 -> 3539 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1249_0_0 -> 16 in the cache */
   /* search1249_0_1 -> 124 in the cache */
   /* search1249_0 -> 3520 in the cache */
   /* search1249_1_0 -> 19 in the cache */
   /* search1249_1_1_0_0 -> 16 in the cache */
   /* search1249_1_1_0 -> 3534 in the cache */
   /* search1249_1_1 -> 3536 in the cache */
   /* search1249_1 -> 3537 in the cache */
   /* search1249_2_0 -> 16 in the cache */
   /* search1249_2 -> 3534 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3520, 3537, 3534 },
      -1,
   } },

   /* replace1249_0 -> 16 in the cache */
   /* replace1249 -> 3539 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1250_0_0 -> 16 in the cache */
   /* search1250_0_1 -> 124 in the cache */
   /* search1250_0 -> 3549 in the cache */
   /* search1250_1_0 -> 16 in the cache */
   /* search1250_1 -> 3534 in the cache */
   /* search1250_2_0 -> 19 in the cache */
   /* search1250_2_1_0_0 -> 16 in the cache */
   /* search1250_2_1_0 -> 3534 in the cache */
   /* search1250_2_1 -> 3536 in the cache */
   /* search1250_2 -> 3537 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3549, 3534, 3537 },
      -1,
   } },

   /* replace1250_0 -> 16 in the cache */
   /* replace1250 -> 3539 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a') */
   /* search1251_0_0_0 -> 16 in the cache */
   /* search1251_0_0 -> 3533 in the cache */
   /* search1251_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3533, 126 },
      -1,
   } },
   /* search1251_1_0 -> 19 in the cache */
   /* search1251_1_1_0_0 -> 16 in the cache */
   /* search1251_1_1_0 -> 3533 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3554 },
      -1,
   } },
   /* search1251_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3553, 3555, 126 },
      -1,
   } },

   /* replace1251_0 -> 16 in the cache */
   /* replace1251 -> 3507 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1252_0_0_0 -> 16 in the cache */
   /* search1252_0_0 -> 3539 in the cache */
   /* search1252_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3539, 126 },
      -1,
   } },
   /* search1252_1_0 -> 19 in the cache */
   /* search1252_1_1_0_0 -> 16 in the cache */
   /* search1252_1_1_0 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3539 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3558 },
      -1,
   } },
   /* search1252_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 3559, 126 },
      -1,
   } },

   /* replace1252_0 -> 16 in the cache */
   /* replace1252 -> 3534 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1253_0_0_0 -> 16 in the cache */
   /* search1253_0_0 -> 3533 in the cache */
   /* search1253_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3533, 126 },
      -1,
   } },
   /* search1253_1 -> 126 in the cache */
   /* search1253_2_0 -> 19 in the cache */
   /* search1253_2_1_0_0 -> 16 in the cache */
   /* search1253_2_1_0 -> 3533 in the cache */
   /* search1253_2_1 -> 3554 in the cache */
   /* search1253_2 -> 3555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3561, 126, 3555 },
      -1,
   } },

   /* replace1253_0 -> 16 in the cache */
   /* replace1253 -> 3507 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1254_0_0_0 -> 16 in the cache */
   /* search1254_0_0 -> 3539 in the cache */
   /* search1254_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3539, 126 },
      -1,
   } },
   /* search1254_1 -> 126 in the cache */
   /* search1254_2_0 -> 19 in the cache */
   /* search1254_2_1_0_0 -> 16 in the cache */
   /* search1254_2_1_0 -> 3539 in the cache */
   /* search1254_2_1 -> 3558 in the cache */
   /* search1254_2 -> 3559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3563, 126, 3559 },
      -1,
   } },

   /* replace1254_0 -> 16 in the cache */
   /* replace1254 -> 3534 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a') */
   /* search1255_0_0_0 -> 16 in the cache */
   /* search1255_0_0 -> 3533 in the cache */
   /* search1255_0_1 -> 126 in the cache */
   /* search1255_0 -> 3553 in the cache */
   /* search1255_1_0 -> 19 in the cache */
   /* search1255_1_1_0_0 -> 16 in the cache */
   /* search1255_1_1_0 -> 3533 in the cache */
   /* search1255_1_1 -> 3554 in the cache */
   /* search1255_1 -> 3555 in the cache */
   /* search1255_2_0 -> 16 in the cache */
   /* search1255_2 -> 3533 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3553, 3555, 3533 },
      -1,
   } },

   /* replace1255_0 -> 16 in the cache */
   /* replace1255 -> 3507 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1256_0_0_0 -> 16 in the cache */
   /* search1256_0_0 -> 3539 in the cache */
   /* search1256_0_1 -> 126 in the cache */
   /* search1256_0 -> 3557 in the cache */
   /* search1256_1_0 -> 19 in the cache */
   /* search1256_1_1_0_0 -> 16 in the cache */
   /* search1256_1_1_0 -> 3539 in the cache */
   /* search1256_1_1 -> 3558 in the cache */
   /* search1256_1 -> 3559 in the cache */
   /* search1256_2_0 -> 16 in the cache */
   /* search1256_2 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 3559, 3539 },
      -1,
   } },

   /* replace1256_0 -> 16 in the cache */
   /* replace1256 -> 3534 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1257_0_0_0 -> 16 in the cache */
   /* search1257_0_0 -> 3533 in the cache */
   /* search1257_0_1 -> 126 in the cache */
   /* search1257_0 -> 3561 in the cache */
   /* search1257_1_0 -> 16 in the cache */
   /* search1257_1 -> 3533 in the cache */
   /* search1257_2_0 -> 19 in the cache */
   /* search1257_2_1_0_0 -> 16 in the cache */
   /* search1257_2_1_0 -> 3533 in the cache */
   /* search1257_2_1 -> 3554 in the cache */
   /* search1257_2 -> 3555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3561, 3533, 3555 },
      -1,
   } },

   /* replace1257_0 -> 16 in the cache */
   /* replace1257 -> 3507 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1258_0_0_0 -> 16 in the cache */
   /* search1258_0_0 -> 3539 in the cache */
   /* search1258_0_1 -> 126 in the cache */
   /* search1258_0 -> 3563 in the cache */
   /* search1258_1_0 -> 16 in the cache */
   /* search1258_1 -> 3539 in the cache */
   /* search1258_2_0 -> 19 in the cache */
   /* search1258_2_1_0_0 -> 16 in the cache */
   /* search1258_2_1_0 -> 3539 in the cache */
   /* search1258_2_1 -> 3558 in the cache */
   /* search1258_2 -> 3559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3563, 3539, 3559 },
      -1,
   } },

   /* replace1258_0 -> 16 in the cache */
   /* replace1258 -> 3534 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1259_0_0 -> 16 in the cache */
   /* search1259_0_1 -> 124 in the cache */
   /* search1259_0 -> 3520 in the cache */
   /* search1259_1_0 -> 19 in the cache */
   /* search1259_1_1_0_0 -> 16 in the cache */
   /* search1259_1_1_0 -> 3539 in the cache */
   /* search1259_1_1 -> 3558 in the cache */
   /* search1259_1 -> 3559 in the cache */
   /* search1259_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3520, 3559, 126 },
      -1,
   } },

   /* replace1259_0 -> 16 in the cache */
   /* replace1259 -> 3534 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1260_0_0 -> 16 in the cache */
   /* search1260_0_1 -> 124 in the cache */
   /* search1260_0 -> 3549 in the cache */
   /* search1260_1 -> 126 in the cache */
   /* search1260_2_0 -> 19 in the cache */
   /* search1260_2_1_0_0 -> 16 in the cache */
   /* search1260_2_1_0 -> 3539 in the cache */
   /* search1260_2_1 -> 3558 in the cache */
   /* search1260_2 -> 3559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3549, 126, 3559 },
      -1,
   } },

   /* replace1260_0 -> 16 in the cache */
   /* replace1260 -> 3534 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1261_0_0 -> 16 in the cache */
   /* search1261_0_1 -> 124 in the cache */
   /* search1261_0 -> 3520 in the cache */
   /* search1261_1_0 -> 19 in the cache */
   /* search1261_1_1_0_0 -> 16 in the cache */
   /* search1261_1_1_0 -> 3539 in the cache */
   /* search1261_1_1 -> 3558 in the cache */
   /* search1261_1 -> 3559 in the cache */
   /* search1261_2_0 -> 16 in the cache */
   /* search1261_2 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3520, 3559, 3539 },
      -1,
   } },

   /* replace1261_0 -> 16 in the cache */
   /* replace1261 -> 3534 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1262_0_0 -> 16 in the cache */
   /* search1262_0_1 -> 124 in the cache */
   /* search1262_0 -> 3549 in the cache */
   /* search1262_1_0 -> 16 in the cache */
   /* search1262_1 -> 3539 in the cache */
   /* search1262_2_0 -> 19 in the cache */
   /* search1262_2_1_0_0 -> 16 in the cache */
   /* search1262_2_1_0 -> 3539 in the cache */
   /* search1262_2_1 -> 3558 in the cache */
   /* search1262_2 -> 3559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3549, 3539, 3559 },
      -1,
   } },

   /* replace1262_0 -> 16 in the cache */
   /* replace1262 -> 3534 in the cache */

   /* ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1263_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3573 },
      -1,
   } },

   /* replace1263_0 -> 16 in the cache */
   /* replace1263 -> 3539 in the cache */

   /* ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a') */
   /* search1264_0_0 -> 16 in the cache */
   /* search1264_0 -> 3573 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3573 },
      -1,
   } },

   /* replace1264_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1265_0_0 -> 523 in the cache */
   /* search1265_0_1 -> 277 in the cache */
   /* search1265_0_2 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 277, 272 },
      0,
   } },
   /* search1265_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3577, 3 },
      -1,
   } },

   /* replace1265_0 -> 523 in the cache */
   /* replace1265_1_0 -> 3 in the cache */
   /* replace1265_1 -> 1066 in the cache */
   /* replace1265_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 1066, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1266_0_0 -> 523 in the cache */
   /* search1266_0_1 -> 272 in the cache */
   /* search1266_0_2 -> 277 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 272, 277 },
      0,
   } },
   /* search1266_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3580, 3 },
      -1,
   } },

   /* replace1266_0 -> 523 in the cache */
   /* replace1266_1 -> 3 in the cache */
   /* replace1266_2_0 -> 3 in the cache */
   /* replace1266_2 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 3, 1066 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1267_0_0 -> 523 in the cache */
   /* search1267_0_1 -> 280 in the cache */
   /* search1267_0_2 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 280, 245 },
      0,
   } },
   /* search1267_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3583, 36 },
      -1,
   } },

   /* replace1267_0 -> 523 in the cache */
   /* replace1267_1_0 -> 36 in the cache */
   /* replace1267_1 -> 602 in the cache */
   /* replace1267_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 602, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1268_0_0 -> 523 in the cache */
   /* search1268_0_1 -> 245 in the cache */
   /* search1268_0_2 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 245, 280 },
      0,
   } },
   /* search1268_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3586, 36 },
      -1,
   } },

   /* replace1268_0 -> 523 in the cache */
   /* replace1268_1 -> 36 in the cache */
   /* replace1268_2_0 -> 36 in the cache */
   /* replace1268_2 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 36, 602 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1269_0_1_0 -> 1087 in the cache */
   /* search1269_0_1 -> 1554 in the cache */
   /* search1269_0_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3589, 1554, 1087 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3590 },
      -1,
   } },

   /* replace1269_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1087 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a') */
   /* search1270_0_0 -> 3589 in the cache */
   /* search1270_0_1 -> 1087 in the cache */
   /* search1270_0_2_0 -> 1087 in the cache */
   /* search1270_0_2 -> 1554 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3589, 1087, 1554 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3593 },
      -1,
   } },

   /* replace1270_0 -> 1087 in the cache */
   /* replace1270 -> 3592 in the cache */

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1271_0_0 -> 32 in the cache */
   /* search1271_0_1 -> 113 in the cache */
   /* search1271_0 -> 691 in the cache */
   /* search1271_1_0 -> 32 in the cache */
   /* search1271_1 -> 98 in the cache */
   /* search1271_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 691, 98, 32 },
      -1,
   } },

   /* replace1271_0 -> 32 in the cache */
   /* replace1271 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1272_0 -> 739 in the cache */
   /* search1272_1_0 -> 1107 in the cache */
   /* search1272_1_1 -> 154 in the cache */
   /* search1272_1_2 -> 155 in the cache */
   /* search1272_1 -> 1299 in the cache */
   /* search1272_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1299, 155 },
      -1,
   } },

   /* replace1272_0_0 -> 739 in the cache */
   /* replace1272_0_1 -> 1107 in the cache */
   /* replace1272_0 -> 1119 in the cache */
   /* replace1272_1 -> 154 in the cache */
   /* replace1272_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1119, 154, 155 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1273_0 -> 739 in the cache */
   /* search1273_1 -> 152 in the cache */
   /* search1273_2_0 -> 466 in the cache */
   /* search1273_2_1 -> 152 in the cache */
   /* search1273_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 152, 3598 },
      -1,
   } },

   /* replace1273_0_0 -> 739 in the cache */
   /* replace1273_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 739, 466 },
      -1,
   } },
   /* replace1273_1 -> 152 in the cache */
   /* replace1273_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3600, 152, 155 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1274_0 -> 0 in the cache */
   /* search1274_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1274_0 -> 0 in the cache */
   /* replace1274_1_0 -> 3 in the cache */
   /* replace1274_1_1_0_0 -> 0 in the cache */
   /* replace1274_1_1_0_1 -> 3 in the cache */
   /* replace1274_1_1_0 -> 2798 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3604 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1275_0 -> 0 in the cache */
   /* search1275_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1275_0 -> 0 in the cache */
   /* replace1275_1_0 -> 3 in the cache */
   /* replace1275_1_1_0_0 -> 0 in the cache */
   /* replace1275_1_1_0_1 -> 3 in the cache */
   /* replace1275_1_1_0 -> 2798 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3608 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1276_0 -> 0 in the cache */
   /* search1276_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1276_0_0_0 -> 0 in the cache */
   /* replace1276_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1276_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3611, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3612 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1277_0 -> 0 in the cache */
   /* search1277_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1277_0_0 -> 0 in the cache */
   /* replace1277_0_1 -> 3 in the cache */
   /* replace1277_0 -> 1046 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1046 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3616, 3617, 3618, 3619 },
      -1,
   } },

   /* replace1278_0_0 -> 19 in the cache */
   /* replace1278_0_1 -> 3619 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3619 },
      -1,
   } },
   /* replace1278_1 -> 3617 in the cache */
   /* replace1278_2_0_0 -> 3619 in the cache */
   /* replace1278_2_0_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3619, 3618 },
      -1,
   } },
   /* replace1278_2_1 -> 3617 in the cache */
   /* replace1278_2_2 -> 3616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3622, 3617, 3616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3621, 3617, 3623 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1279_0 -> 0 in the cache */
   /* search1279_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1279_0_0 -> 0 in the cache */
   /* replace1279_0_1 -> 3 in the cache */
   /* replace1279_0 -> 203 in the cache */
   /* replace1279_1_0_0 -> 0 in the cache */
   /* replace1279_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1279_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3626, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 203, 3627 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1280_0 -> 0 in the cache */
   /* search1280_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1280_0_0 -> 0 in the cache */
   /* replace1280_0_1 -> 3 in the cache */
   /* replace1280_0 -> 203 in the cache */
   /* replace1280_1_0_0 -> 0 in the cache */
   /* replace1280_1_0_1 -> 3 in the cache */
   /* replace1280_1_0 -> 3626 in the cache */
   /* replace1280_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3626, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 203, 3630 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1281_0 -> 0 in the cache */
   /* search1281_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1281_0_0 -> 0 in the cache */
   /* replace1281_0_1 -> 3 in the cache */
   /* replace1281_0 -> 2293 in the cache */
   /* replace1281_1_0_0 -> 0 in the cache */
   /* replace1281_1_0_1 -> 3 in the cache */
   /* replace1281_1_0 -> 2666 in the cache */
   /* replace1281_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2666, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2293, 3633 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1282_0 -> 0 in the cache */
   /* search1282_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1282_0_0 -> 0 in the cache */
   /* replace1282_0_1 -> 3 in the cache */
   /* replace1282_0 -> 2293 in the cache */
   /* replace1282_1_0_0 -> 0 in the cache */
   /* replace1282_1_0_1 -> 3 in the cache */
   /* replace1282_1_0 -> 2666 in the cache */
   /* replace1282_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2666, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2293, 3636 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1283_0 -> 21 in the cache */
   /* search1283_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1283_0_0 -> 21 in the cache */
   /* replace1283_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1283_1_0_0 -> 21 in the cache */
   /* replace1283_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1283_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3640, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3639, 3641 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1284_0 -> 21 in the cache */
   /* search1284_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1284_0_0 -> 21 in the cache */
   /* replace1284_0_1 -> 41 in the cache */
   /* replace1284_0 -> 3639 in the cache */
   /* replace1284_1_0_0 -> 21 in the cache */
   /* replace1284_1_0_1 -> 41 in the cache */
   /* replace1284_1_0 -> 3640 in the cache */
   /* replace1284_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3640, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3639, 3644 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1285_0 -> 21 in the cache */
   /* search1285_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1285_0_0 -> 21 in the cache */
   /* replace1285_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1285_1_0_0 -> 21 in the cache */
   /* replace1285_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1285_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3648, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3647, 3649 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1286_0 -> 21 in the cache */
   /* search1286_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1286_0_0 -> 21 in the cache */
   /* replace1286_0_1 -> 41 in the cache */
   /* replace1286_0 -> 3647 in the cache */
   /* replace1286_1_0_0 -> 21 in the cache */
   /* replace1286_1_0_1 -> 41 in the cache */
   /* replace1286_1_0 -> 3648 in the cache */
   /* replace1286_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3648, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3647, 3652 },
      -1,
   } },

   /* ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0)) */
   /* search1287_0 -> 16 in the cache */
   /* search1287_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1287_0 -> 16 in the cache */
   /* replace1287_1_0 -> 36 in the cache */
   /* replace1287_1_1 -> 124 in the cache */
   /* replace1287_1 -> 439 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 439 },
      -1,
   } },

   /* ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0)) */
   /* search1288_0 -> 16 in the cache */
   /* search1288_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1288_0 -> 16 in the cache */
   /* replace1288_1_0 -> 36 in the cache */
   /* replace1288_1_1 -> 124 in the cache */
   /* replace1288_1 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 447 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1289_0 -> 21 in the cache */
   /* search1289_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1289_0_0_0 -> 21 in the cache */
   /* replace1289_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1289_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3659, 21 },
      -1,
   } },
   /* replace1289_1 -> 1476 in the cache */
   /* replace1289_2_0 -> 21 in the cache */
   /* replace1289_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3660, 1476, 3661 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1290_0 -> 0 in the cache */
   /* search1290_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1290_0_0_0 -> 0 in the cache */
   /* replace1290_0_0_1 -> 3 in the cache */
   /* replace1290_0_0 -> 3611 in the cache */
   /* replace1290_0_1 -> 0 in the cache */
   /* replace1290_0 -> 3612 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1290_2_0 -> 0 in the cache */
   /* replace1290_2_1 -> 3 in the cache */
   /* replace1290_2 -> 210 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3612, 3664, 210 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1291_0 -> 0 in the cache */
   /* search1291_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1291_0_0 -> 0 in the cache */
   /* replace1291_0_1 -> 3 in the cache */
   /* replace1291_0 -> 1046 in the cache */
   /* replace1291_1 -> 86 in the cache */
   /* replace1291_2_0 -> 0 in the cache */
   /* replace1291_2_1 -> 3 in the cache */
   /* replace1291_2 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1046, 86, 3381 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1292_0 -> 21 in the cache */
   /* search1292_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1292_0_0 -> 21 in the cache */
   /* replace1292_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1292_1 -> 876 in the cache */
   /* replace1292_2_0 -> 21 in the cache */
   /* replace1292_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3669, 876, 3670 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1293_0 -> 21 in the cache */
   /* search1293_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1293_0_0_0_0 -> 21 in the cache */
   /* replace1293_0_0_0_1 -> 876 in the cache */
   /* replace1293_0_0_0 -> 1466 in the cache */
   /* replace1293_0_0_1_0 -> 41 in the cache */
   /* replace1293_0_0_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1466, 3673 },
      -1,
   } },
   /* replace1293_0_1_0_0 -> 21 in the cache */
   /* replace1293_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1293_0_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3675, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3674, 3676 },
      -1,
   } },
   /* replace1293_1 -> 22 in the cache */
   /* replace1293_2_0_0_0_0 -> 21 in the cache */
   /* replace1293_2_0_0_0_1 -> 876 in the cache */
   /* replace1293_2_0_0_0 -> 1466 in the cache */
   /* replace1293_2_0_0_1_0 -> 41 in the cache */
   /* replace1293_2_0_0_1_1 -> 876 in the cache */
   /* replace1293_2_0_0_1 -> 3673 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1466, 3673 },
      -1,
   } },
   /* replace1293_2_0_1_0_0 -> 21 in the cache */
   /* replace1293_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1293_2_0_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3679, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3678, 3680 },
      -1,
   } },
   /* replace1293_2_1_0 -> 21 in the cache */
   /* replace1293_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3681, 3682, 3683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3677, 22, 3684 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1294_0 -> 21 in the cache */
   /* search1294_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1294_0_0_0_0 -> 21 in the cache */
   /* replace1294_0_0_0_1 -> 876 in the cache */
   /* replace1294_0_0_0 -> 1466 in the cache */
   /* replace1294_0_0_1_0 -> 41 in the cache */
   /* replace1294_0_0_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1466, 3687 },
      -1,
   } },
   /* replace1294_0_1_0_0 -> 21 in the cache */
   /* replace1294_0_1_0_1 -> 41 in the cache */
   /* replace1294_0_1_0 -> 3670 in the cache */
   /* replace1294_0_1_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3670, 876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3688, 3689 },
      -1,
   } },
   /* replace1294_1 -> 22 in the cache */
   /* replace1294_2_0_0_0_0 -> 21 in the cache */
   /* replace1294_2_0_0_0_1 -> 876 in the cache */
   /* replace1294_2_0_0_0 -> 1466 in the cache */
   /* replace1294_2_0_0_1_0 -> 41 in the cache */
   /* replace1294_2_0_0_1_1 -> 876 in the cache */
   /* replace1294_2_0_0_1 -> 3687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1466, 3687 },
      -1,
   } },
   /* replace1294_2_0_1_0_0 -> 21 in the cache */
   /* replace1294_2_0_1_0_1 -> 41 in the cache */
   /* replace1294_2_0_1_0 -> 3670 in the cache */
   /* replace1294_2_0_1_1 -> 876 in the cache */
   /* replace1294_2_0_1 -> 3689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3691, 3689 },
      -1,
   } },
   /* replace1294_2_1_0 -> 21 in the cache */
   /* replace1294_2_1_1 -> 41 in the cache */
   /* replace1294_2_1 -> 3670 in the cache */
   /* replace1294_2_2 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3692, 3670, 3683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3690, 22, 3693 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1295_0_0 -> 21 in the cache */
   /* search1295_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1295_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3695, 876 },
      -1,
   } },

   /* replace1295_0_0_0 -> 21 in the cache */
   /* replace1295_0_0 -> 3138 in the cache */
   /* replace1295_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 3138, 3697 },
      -1,
   } },
   /* replace1295_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3698, 124 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1296_0_0 -> 21 in the cache */
   /* search1296_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1296_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3700, 876 },
      -1,
   } },

   /* replace1296_0_0_0 -> 21 in the cache */
   /* replace1296_0_0 -> 3138 in the cache */
   /* replace1296_0_1_0 -> 41 in the cache */
   /* replace1296_0_1 -> 3697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 3138, 3697 },
      -1,
   } },
   /* replace1296_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3702, 124 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1297_0_0 -> 21 in the cache */
   /* search1297_0_1 -> 41 in the cache */
   /* search1297_0 -> 3695 in the cache */
   /* search1297_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3695, 876 },
      -1,
   } },

   /* replace1297_0_0_0 -> 21 in the cache */
   /* replace1297_0_0 -> 3138 in the cache */
   /* replace1297_0_1_0 -> 41 in the cache */
   /* replace1297_0_1 -> 3697 in the cache */
   /* replace1297_0 -> 3698 in the cache */
   /* replace1297_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3698, 124 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1298_0_0 -> 21 in the cache */
   /* search1298_0_1 -> 41 in the cache */
   /* search1298_0 -> 3700 in the cache */
   /* search1298_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3700, 876 },
      -1,
   } },

   /* replace1298_0_0_0 -> 21 in the cache */
   /* replace1298_0_0 -> 3138 in the cache */
   /* replace1298_0_1_0 -> 41 in the cache */
   /* replace1298_0_1 -> 3697 in the cache */
   /* replace1298_0 -> 3702 in the cache */
   /* replace1298_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3702, 124 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1299_0 -> 21 in the cache */
   /* search1299_1 -> 876 in the cache */
   /* search1299 -> 1466 in the cache */

   /* replace1299_0_0 -> 21 in the cache */
   /* replace1299_0 -> 3138 in the cache */
   /* replace1299_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3138, 124 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1300_0 -> 21 in the cache */
   /* search1300_1 -> 876 in the cache */
   /* search1300 -> 1463 in the cache */

   /* replace1300_0_0 -> 21 in the cache */
   /* replace1300_0 -> 3138 in the cache */
   /* replace1300_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3138, 124 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1301_0 -> 21 in the cache */
   /* search1301_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 876 },
      -1,
   } },

   /* replace1301_0_0_0 -> 21 in the cache */
   /* replace1301_0_0 -> 3137 in the cache */
   /* replace1301_0_1_0 -> 21 in the cache */
   /* replace1301_0_1 -> 3138 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3137, 3138 },
      -1,
   } },
   /* replace1301_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3711, 124 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1302_0 -> 21 in the cache */
   /* search1302_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 876 },
      -1,
   } },

   /* replace1302_0_0_0 -> 21 in the cache */
   /* replace1302_0_0 -> 3137 in the cache */
   /* replace1302_0_1_0 -> 21 in the cache */
   /* replace1302_0_1 -> 3138 in the cache */
   /* replace1302_0 -> 3711 in the cache */
   /* replace1302_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3711, 124 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1303_0 -> 876 in the cache */
   /* search1303_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 876, 21 },
      -1,
   } },

   /* replace1303_0_0_0 -> 21 in the cache */
   /* replace1303_0_0 -> 3137 in the cache */
   /* replace1303_0_1_0 -> 21 in the cache */
   /* replace1303_0_1 -> 3138 in the cache */
   /* replace1303_0 -> 3711 in the cache */
   /* replace1303_1 -> 124 in the cache */
   /* replace1303 -> 3712 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1304_0 -> 3616 in the cache */
   /* search1304_1 -> 3617 in the cache */
   /* search1304_2 -> 3618 in the cache */
   /* search1304_3 -> 3619 in the cache */
   /* search1304 -> 3620 in the cache */

   /* replace1304_0_0 -> 19 in the cache */
   /* replace1304_0_1 -> 3619 in the cache */
   /* replace1304_0 -> 3621 in the cache */
   /* replace1304_1 -> 3617 in the cache */
   /* replace1304_2_0_0 -> 3616 in the cache */
   /* replace1304_2_0_1_0_0_0_0 -> 398 in the cache */
   /* replace1304_2_0_1_0_0_0_1 -> 3619 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 398, 3619 },
      -1,
   } },
   /* replace1304_2_0_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3716, 398 },
      -1,
   } },
   /* replace1304_2_0_1_0_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3717, 3618 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3616, 3719 },
      -1,
   } },
   /* replace1304_2_1_0_0 -> 3617 in the cache */
   /* replace1304_2_1_0_1 -> 3618 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3617, 3618 },
      -1,
   } },
   /* replace1304_2_1_1_0_0_0 -> 398 in the cache */
   /* replace1304_2_1_1_0_0_1 -> 3619 in the cache */
   /* replace1304_2_1_1_0_0 -> 3716 in the cache */
   /* replace1304_2_1_1_0_1 -> 398 in the cache */
   /* replace1304_2_1_1_0 -> 3717 in the cache */
   /* replace1304_2_1_1_1 -> 3618 in the cache */
   /* replace1304_2_1_1 -> 3718 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3721, 3718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3720, 3722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3621, 3617, 3723 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1305_0 -> 3616 in the cache */
   /* search1305_1 -> 3617 in the cache */
   /* search1305_2 -> 3618 in the cache */
   /* search1305_3 -> 3619 in the cache */
   /* search1305 -> 3620 in the cache */

   /* replace1305_0_0 -> 19 in the cache */
   /* replace1305_0_1 -> 3619 in the cache */
   /* replace1305_0 -> 3621 in the cache */
   /* replace1305_1 -> 3617 in the cache */
   /* replace1305_2_0_0 -> 3619 in the cache */
   /* replace1305_2_0_1 -> 3618 in the cache */
   /* replace1305_2_0 -> 3622 in the cache */
   /* replace1305_2_1_0 -> 3617 in the cache */
   /* replace1305_2_1_1 -> 3618 in the cache */
   /* replace1305_2_1 -> 3721 in the cache */
   /* replace1305_2_2 -> 3616 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3622, 3721, 3616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3621, 3617, 3725 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3727, 3728, 3729 },
      -1,
   } },

   /* replace1306_0_0 -> 19 in the cache */
   /* replace1306_0_1 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3729 },
      -1,
   } },
   /* replace1306_1 -> 3727 in the cache */
   /* replace1306_2_0 -> 3727 in the cache */
   /* replace1306_2_1 -> 3728 in the cache */
   /* replace1306_2_2 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3727, 3728, 3729 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3731, 3727, 3732 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1307_0 -> 3727 in the cache */
   /* search1307_1 -> 3728 in the cache */
   /* search1307_2 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3727, 3728, 3729 },
      -1,
   } },

   /* replace1307_0_0 -> 19 in the cache */
   /* replace1307_0_1 -> 3729 in the cache */
   /* replace1307_0 -> 3731 in the cache */
   /* replace1307_1 -> 3727 in the cache */
   /* replace1307_2_0 -> 3727 in the cache */
   /* replace1307_2_1 -> 3728 in the cache */
   /* replace1307_2_2 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3727, 3728, 3729 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3731, 3727, 3735 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1308_0 -> 0 in the cache */
   /* search1308_1 -> 3 in the cache */
   /* search1308_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1308_0 -> 0 in the cache */
   /* replace1308_1 -> 3 in the cache */
   /* replace1308 -> 2674 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1309_0 -> 128 in the cache */
   /* search1309_1_0 -> 128 in the cache */
   /* search1309_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 128, 129 },
      -1,
   } },
   /* search1309_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 128, 3738, 131 },
      -1,
   } },

   /* replace1309_0 -> 128 in the cache */
   /* replace1309_1 -> 129 in the cache */
   /* replace1309_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 128, 129, 131 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1310_0 -> 3727 in the cache */
   /* search1310_1 -> 3728 in the cache */
   /* search1310_2_0 -> 19 in the cache */
   /* search1310_2_1 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3729 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3727, 3728, 3741 },
      -1,
   } },

   /* replace1310_0 -> 3727 in the cache */
   /* replace1310_1 -> 3728 in the cache */
   /* replace1310_2 -> 3729 in the cache */
   /* replace1310 -> 3735 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1311_0 -> 3727 in the cache */
   /* search1311_1_0 -> 19 in the cache */
   /* search1311_1_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3728 },
      -1,
   } },
   /* search1311_2 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3727, 3743, 3729 },
      -1,
   } },

   /* replace1311_0 -> 3727 in the cache */
   /* replace1311_1 -> 3728 in the cache */
   /* replace1311_2 -> 3729 in the cache */
   /* replace1311 -> 3735 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1312_0 -> 3727 in the cache */
   /* search1312_1 -> 3728 in the cache */
   /* search1312_2_0 -> 19 in the cache */
   /* search1312_2_1 -> 3729 in the cache */
   /* search1312_2 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3727, 3728, 3741 },
      -1,
   } },

   /* replace1312_0 -> 3727 in the cache */
   /* replace1312_1 -> 3728 in the cache */
   /* replace1312_2 -> 3729 in the cache */
   /* replace1312 -> 3732 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1313_0 -> 3727 in the cache */
   /* search1313_1_0 -> 19 in the cache */
   /* search1313_1_1 -> 3728 in the cache */
   /* search1313_1 -> 3743 in the cache */
   /* search1313_2 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3727, 3743, 3729 },
      -1,
   } },

   /* replace1313_0 -> 3727 in the cache */
   /* replace1313_1 -> 3728 in the cache */
   /* replace1313_2 -> 3729 in the cache */
   /* replace1313 -> 3732 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1314_1_0 -> 19 in the cache */
   /* search1314_1_1 -> 3728 in the cache */
   /* search1314_1 -> 3743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3747, 3743 },
      -1,
   } },

   /* replace1314_0 -> 3747 in the cache */
   /* replace1314_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3747, 3728 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1315_0_0 -> 19 in the cache */
   /* search1315_0_1 -> 3747 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3747 },
      -1,
   } },
   /* search1315_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3750, 3728 },
      -1,
   } },

   /* replace1315_0 -> 3747 in the cache */
   /* replace1315_1 -> 3728 in the cache */
   /* replace1315 -> 3749 in the cache */

   /* ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False */
   /* search1316_0 -> 128 in the cache */
   /* search1316_1_0_0 -> 128 in the cache */
   /* search1316_1_0_1 -> 129 in the cache */
   /* search1316_1_0 -> 196 in the cache */
   /* search1316_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 196, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 2,
      { 128, 3752 },
      -1,
   } },

   /* replace1316 -> 1056 in the cache */

   /* ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* bits */
      true,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1317_1_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 3755, 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3754, 3756 },
      -1,
   } },

   /* replace1317 -> 1056 in the cache */

   /* ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width') */
   /* search1318_0 -> 3727 in the cache */
   /* search1318_1 -> 3728 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1318_2_1_0 -> 853 in the cache */
   /* search1318_2_1_1_0_0 -> 19 in the cache */
   /* search1318_2_1_1_0_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 19, 3728 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 3759 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 853, 3760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3758, 3761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 3,
      { 3727, 3728, 3762 },
      -1,
   } },

   /* replace1318_0 -> 3727 in the cache */
   /* replace1318_1 -> 3728 in the cache */
   /* replace1318_2 -> 3758 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3727, 3728, 3758 },
      -1,
   } },

   /* ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width') */
   /* search1319_0 -> 3727 in the cache */
   /* search1319_1 -> 3728 in the cache */
   /* search1319_2_0 -> 3758 in the cache */
   /* search1319_2_1_0 -> 853 in the cache */
   /* search1319_2_1_1_0_0 -> 19 in the cache */
   /* search1319_2_1_1_0_1 -> 3728 in the cache */
   /* search1319_2_1_1_0 -> 3759 in the cache */
   /* search1319_2_1_1 -> 3760 in the cache */
   /* search1319_2_1 -> 3761 in the cache */
   /* search1319_2 -> 3762 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 3,
      { 3727, 3728, 3762 },
      -1,
   } },

   /* replace1319_0 -> 3727 in the cache */
   /* replace1319_1 -> 3728 in the cache */
   /* replace1319_2 -> 3758 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3727, 3728, 3758 },
      -1,
   } },

   /* ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1320_0_1_0 -> 853 in the cache */
   /* search1320_0_1_1_0_0 -> 19 in the cache */
   /* search1320_0_1_1_0_1 -> 3728 in the cache */
   /* search1320_0_1_1_0 -> 3759 in the cache */
   /* search1320_0_1_1 -> 3760 in the cache */
   /* search1320_0_1 -> 3761 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3767, 3761 },
      -1,
   } },
   /* search1320_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 3,
      { 3768, 3728 },
      -1,
   } },

   /* replace1320_0 -> 3767 in the cache */
   /* replace1320_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3767, 3728 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1321_0 -> 16 in the cache */
   /* search1321_1 -> 36 in the cache */
   /* search1321_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1321 -> 124 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1322_0 -> 16 in the cache */
   /* search1322_1 -> 36 in the cache */
   /* search1322_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1322 -> 124 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1323_0 -> 16 in the cache */
   /* search1323_1 -> 124 in the cache */
   /* search1323_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 33 },
      -1,
   } },

   /* replace1323_0 -> 16 in the cache */
   /* replace1323_1_0 -> 906 in the cache */
   /* replace1323_1_1_0 -> 36 in the cache */
   /* replace1323_1_1 -> 2689 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 906, 2689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3774 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1324_0_0_0 -> 16 in the cache */
   /* search1324_0_0_1 -> 36 in the cache */
   /* search1324_0_0_2 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3776 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3777 },
      -1,
   } },

   /* replace1324_0 -> 16 in the cache */
   /* replace1324_1 -> 36 in the cache */
   /* replace1324_2 -> 398 in the cache */
   /* replace1324 -> 3776 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1325_0_0_0 -> 16 in the cache */
   /* search1325_0_0_1 -> 36 in the cache */
   /* search1325_0_0_2 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3780 },
      -1,
   } },

   /* replace1325_0 -> 16 in the cache */
   /* replace1325_1 -> 36 in the cache */
   /* replace1325_2 -> 398 in the cache */
   /* replace1325 -> 3776 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1326_0_0 -> 16 in the cache */
   /* search1326_0_1 -> 33 in the cache */
   /* search1326_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 311 },
      0,
   } },
   /* search1326_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3782, 124 },
      -1,
   } },

   /* replace1326_0_0 -> 16 in the cache */
   /* replace1326_0_1_0_0 -> 906 in the cache */
   /* replace1326_0_1_0_1_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 906, 3784 },
      -1,
   } },
   /* replace1326_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3785, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3786 },
      -1,
   } },
   /* replace1326_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3787, 124 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1327_0_0 -> 16 in the cache */
   /* search1327_0_1 -> 33 in the cache */
   /* search1327_0_2 -> 311 in the cache */
   /* search1327_0 -> 3782 in the cache */
   /* search1327_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3782, 124 },
      -1,
   } },

   /* replace1327_0_0 -> 16 in the cache */
   /* replace1327_0_1_0_0 -> 906 in the cache */
   /* replace1327_0_1_0_1_0 -> 137 in the cache */
   /* replace1327_0_1_0_1 -> 3784 in the cache */
   /* replace1327_0_1_0 -> 3785 in the cache */
   /* replace1327_0_1_1 -> 36 in the cache */
   /* replace1327_0_1 -> 3786 in the cache */
   /* replace1327_0 -> 3787 in the cache */
   /* replace1327_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3787, 124 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1328_0_0 -> 16 in the cache */
   /* search1328_0_1 -> 33 in the cache */
   /* search1328_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 311 },
      0,
   } },
   /* search1328_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3791, 124 },
      -1,
   } },

   /* replace1328_0_0 -> 16 in the cache */
   /* replace1328_0_1_0_0 -> 906 in the cache */
   /* replace1328_0_1_0_1_0 -> 137 in the cache */
   /* replace1328_0_1_0_1 -> 3784 in the cache */
   /* replace1328_0_1_0 -> 3785 in the cache */
   /* replace1328_0_1_1 -> 36 in the cache */
   /* replace1328_0_1 -> 3786 in the cache */
   /* replace1328_0 -> 3787 in the cache */
   /* replace1328_1 -> 124 in the cache */
   /* replace1328 -> 3788 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1329_0_0 -> 16 in the cache */
   /* search1329_0_1 -> 33 in the cache */
   /* search1329_0_2 -> 311 in the cache */
   /* search1329_0 -> 3791 in the cache */
   /* search1329_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3791, 124 },
      -1,
   } },

   /* replace1329_0_0 -> 16 in the cache */
   /* replace1329_0_1_0_0 -> 906 in the cache */
   /* replace1329_0_1_0_1_0 -> 137 in the cache */
   /* replace1329_0_1_0_1 -> 3784 in the cache */
   /* replace1329_0_1_0 -> 3785 in the cache */
   /* replace1329_0_1_1 -> 36 in the cache */
   /* replace1329_0_1 -> 3786 in the cache */
   /* replace1329_0 -> 3787 in the cache */
   /* replace1329_1 -> 124 in the cache */
   /* replace1329 -> 3790 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1330_0 -> 3727 in the cache */
   /* search1330_1 -> 3728 in the cache */
   /* search1330_2 -> 3729 in the cache */
   /* search1330 -> 3730 in the cache */

   /* replace1330_0_0 -> 124 in the cache */
   /* replace1330_0_1 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 124, 3729 },
      -1,
   } },
   /* replace1330_1 -> 124 in the cache */
   /* replace1330_2_0_0 -> 3727 in the cache */
   /* replace1330_2_0_1_0_0 -> 853 in the cache */
   /* replace1330_2_0_1_0_1 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 853, 3729 },
      -1,
   } },
   /* replace1330_2_0_1_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3795, 3728 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3727, 3796 },
      -1,
   } },
   /* replace1330_2_1_0 -> 853 in the cache */
   /* replace1330_2_1_1 -> 3729 in the cache */
   /* replace1330_2_1 -> 3795 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3797, 3795 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3794, 124, 3798 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1331_0 -> 3727 in the cache */
   /* search1331_1 -> 3728 in the cache */
   /* search1331_2 -> 3729 in the cache */
   /* search1331 -> 3734 in the cache */

   /* replace1331_0_0 -> 3727 in the cache */
   /* replace1331_0_1 -> 3728 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3727, 3728 },
      -1,
   } },
   /* replace1331_1_0_0 -> 3729 in the cache */
   /* replace1331_1_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3729, 853 },
      -1,
   } },
   /* replace1331_1_1 -> 906 in the cache */
   /* replace1331_1_2_0_0 -> 398 in the cache */
   /* replace1331_1_2_0_1 -> 3729 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 398, 3729 },
      -1,
   } },
   /* replace1331_1_2_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3802, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3801, 906, 3803 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3800, 3804 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1332_0 -> 3727 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3727 },
      -1,
   } },

   /* replace1332_0_0_0 -> 3727 in the cache */
   /* replace1332_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3727, 124 },
      -1,
   } },
   /* replace1332_0_1_0 -> 3727 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3727 },
      -1,
   } },
   /* replace1332_0_2 -> 3727 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3807, 3808, 3727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3809 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1333_0 -> 3727 in the cache */
   /* search1333 -> 3806 in the cache */

   /* replace1333_0_0_0 -> 3727 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3727 },
      -1,
   } },
   /* replace1333_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3811, 124 },
      -1,
   } },
   /* replace1333_1_0 -> 19 in the cache */
   /* replace1333_1_1_0 -> 3727 in the cache */
   /* replace1333_1_1 -> 3811 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3811 },
      -1,
   } },
   /* replace1333_2_0 -> 3727 in the cache */
   /* replace1333_2 -> 3811 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3812, 3813, 3811 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3815 },
      -1,
   } },

   /* replace1334_0_0_0 -> 3815 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3815 },
      -1,
   } },
   /* replace1334_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3817, 124 },
      -1,
   } },
   /* replace1334_1_0 -> 19 in the cache */
   /* replace1334_1_1_0 -> 3815 in the cache */
   /* replace1334_1_1 -> 3817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3817 },
      -1,
   } },
   /* replace1334_2_0 -> 3815 in the cache */
   /* replace1334_2 -> 3817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3818, 3819, 3817 },
      -1,
   } },

   /* ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a')) */
   /* search1335_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uclz,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1335_0 -> 853 in the cache */
   /* replace1335_1_0 -> 16 in the cache */
   /* replace1335_1 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 853, 3539 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1336_0 -> 3815 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3815 },
      -1,
   } },

   /* replace1336_0_0 -> 3815 in the cache */
   /* replace1336_0_1_0 -> 3815 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3815, 3824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3825 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1337_0 -> 16 in the cache */
   /* search1337_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1337_0_0 -> 16 in the cache */
   /* replace1337_0_1_0_0 -> 407 in the cache */
   /* replace1337_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 407, 36 },
      -1,
   } },
   /* replace1337_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3828, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3829 },
      -1,
   } },
   /* replace1337_1 -> 991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3830, 991 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1338_0 -> 16 in the cache */
   /* search1338_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1338_0_0 -> 16 in the cache */
   /* replace1338_0_1_0 -> 36 in the cache */
   /* replace1338_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3833 },
      -1,
   } },
   /* replace1338_1 -> 989 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3834, 989 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1339_0 -> 16 in the cache */
   /* search1339_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1339_0_0 -> 16 in the cache */
   /* replace1339_0_1_0_0 -> 398 in the cache */
   /* replace1339_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 398, 36 },
      -1,
   } },
   /* replace1339_0_1_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3837, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3838 },
      -1,
   } },
   /* replace1339_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3839, 832 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1340_0 -> 16 in the cache */
   /* search1340_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1340_0_0 -> 16 in the cache */
   /* replace1340_0_1_0 -> 36 in the cache */
   /* replace1340_0_1_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3842 },
      -1,
   } },
   /* replace1340_1 -> 981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3843, 981 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1341_0_0_0_0_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3845 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3847, 3848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3850 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3851 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1342_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1342_0_0_0_0_0 -> 3845 in the cache */
   /* replace1342_0_0_0_0 -> 3847 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3847, 3854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3855 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3857 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1343_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1343_0_0_0_0_0 -> 245 in the cache */
   /* replace1343_0_0_0_0_1_0 -> 280 in the cache */
   /* replace1343_0_0_0_0_1_1 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 280, 3845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 245, 3860 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3861, 3862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3865 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1344_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1344_0_0_0_0_0 -> 245 in the cache */
   /* replace1344_0_0_0_0_1_0 -> 280 in the cache */
   /* replace1344_0_0_0_0_1_1 -> 3845 in the cache */
   /* replace1344_0_0_0_0_1 -> 3860 in the cache */
   /* replace1344_0_0_0_0 -> 3861 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3861, 3868 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3869 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3870 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3871 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1345_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1345_0_0_0_0 -> 3845 in the cache */
   /* replace1345_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3845, 124 },
      -1,
   } },
   /* replace1345_0_0_1_0 -> 3845 in the cache */
   /* replace1345_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3845, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3874, 3875 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3876 },
      -1,
   } },
   /* replace1345_1 -> 3848 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3877, 3848 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1346_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1346_0_0_0_0 -> 3845 in the cache */
   /* replace1346_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3845, 124 },
      -1,
   } },
   /* replace1346_0_0_1_0 -> 3845 in the cache */
   /* replace1346_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3845, 398 },
      -1,
   } },
   /* replace1346_0_0_2_0 -> 3845 in the cache */
   /* replace1346_0_0_2_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3845, 403 },
      -1,
   } },
   /* replace1346_0_0_3_0 -> 3845 in the cache */
   /* replace1346_0_0_3_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3845, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3880, 3881, 3882, 3883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3884 },
      -1,
   } },
   /* replace1346_1 -> 3854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3885, 3854 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1347_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1347_0 -> 245 in the cache */
   /* replace1347_1_0 -> 280 in the cache */
   /* replace1347_1_1_0_0_0_0 -> 3845 in the cache */
   /* replace1347_1_1_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3845, 124 },
      -1,
   } },
   /* replace1347_1_1_0_0_1_0 -> 3845 in the cache */
   /* replace1347_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3845, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3888, 3889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3890 },
      -1,
   } },
   /* replace1347_1_1_1 -> 3862 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3891, 3862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 280, 3892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 245, 3893 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1348_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1348_0 -> 245 in the cache */
   /* replace1348_1_0 -> 280 in the cache */
   /* replace1348_1_1_0_0_0_0 -> 3845 in the cache */
   /* replace1348_1_1_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3845, 124 },
      -1,
   } },
   /* replace1348_1_1_0_0_1_0 -> 3845 in the cache */
   /* replace1348_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3845, 398 },
      -1,
   } },
   /* replace1348_1_1_0_0_2_0 -> 3845 in the cache */
   /* replace1348_1_1_0_0_2_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3845, 403 },
      -1,
   } },
   /* replace1348_1_1_0_0_3_0 -> 3845 in the cache */
   /* replace1348_1_1_0_0_3_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3845, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3896, 3897, 3898, 3899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3900 },
      -1,
   } },
   /* replace1348_1_1_1 -> 3868 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3901, 3868 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 280, 3902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 245, 3903 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1349_0 -> 16 in the cache */
   /* search1349_1 -> 36 in the cache */
   /* search1349 -> 3268 in the cache */

   /* replace1349_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3905 },
      -1,
   } },
   /* replace1349_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3906, 832 },
      -1,
   } },
   /* replace1349_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3908 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3907, 3909 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1350_0 -> 16 in the cache */
   /* search1350 -> 3233 in the cache */

   /* replace1350_0_0 -> 16 in the cache */
   /* replace1350_0 -> 3230 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3230 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1351_0 -> 16 in the cache */
   /* search1351 -> 3240 in the cache */

   /* replace1351_0_0_0 -> 16 in the cache */
   /* replace1351_0_0_1 -> 832 in the cache */
   /* replace1351_0_0 -> 987 in the cache */
   /* replace1351_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1352_0 -> 11 in the cache */
   /* search1352_1 -> 260 in the cache */
   /* search1352 -> 3223 in the cache */

   /* replace1352_0_0_0 -> 260 in the cache */
   /* replace1352_0_0 -> 3224 in the cache */
   /* replace1352_0_1 -> 832 in the cache */
   /* replace1352_0 -> 3225 in the cache */
   /* replace1352_1_0 -> 11 in the cache */
   /* replace1352_1 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3225, 1782 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1353_0 -> 16 in the cache */
   /* search1353 -> 3146 in the cache */

   /* replace1353_0 -> 16 in the cache */
   /* replace1353 -> 3230 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1354_0 -> 16 in the cache */
   /* search1354 -> 3148 in the cache */

   /* replace1354_0_0 -> 16 in the cache */
   /* replace1354_0_1 -> 832 in the cache */
   /* replace1354_0 -> 987 in the cache */
   /* replace1354 -> 3231 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1355_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1355_0_0 -> 32 in the cache */
   /* replace1355_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1355_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 3915, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1356_0_0 -> 32 in the cache */
   /* search1356_0_1 -> 63 in the cache */
   /* search1356_0 -> 3915 in the cache */
   /* search1356_1 -> 35 in the cache */
   /* search1356 -> 3916 in the cache */

   /* replace1356_0 -> 32 in the cache */
   /* replace1356 -> 3914 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1357_0_0 -> 32 in the cache */
   /* search1357_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1357_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 3917, 63 },
      -1,
   } },

   /* replace1357_0 -> 32 in the cache */
   /* replace1357 -> 3914 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1358_0 -> 32 in the cache */
   /* search1358 -> 252 in the cache */

   /* replace1358_0_0_0 -> 113 in the cache */
   /* replace1358_0_0_1 -> 32 in the cache */
   /* replace1358_0_0 -> 1503 in the cache */
   /* replace1358_0 -> 1504 in the cache */
   /* replace1358_1_0_0 -> 32 in the cache */
   /* replace1358_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1504, 3920 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1359_0 -> 0 in the cache */
   /* search1359_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1359_0 -> 0 in the cache */
   /* replace1359_1 -> 3 in the cache */
   /* replace1359 -> 930 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1360_0 -> 16 in the cache */
   /* search1360_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1360_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3924 },
      -1,
   } },
   /* replace1360_1_0 -> 36 in the cache */
   /* replace1360_1_1 -> 3924 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 3924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 3925, 3926 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1361_0 -> 16 in the cache */
   /* search1361_1 -> 36 in the cache */
   /* search1361_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace1361_0_0_0 -> 16 in the cache */
   /* replace1361_0_0_1 -> 3924 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 3924 },
      -1,
   } },
   /* replace1361_0_1_0 -> 36 in the cache */
   /* replace1361_0_1_1 -> 3924 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 3924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 3929, 3930 },
      -1,
   } },
   /* replace1361_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 3931, 137 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1362_0 -> 16 in the cache */
   /* search1362_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1362_0 -> 16 in the cache */
   /* replace1362_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1363_0 -> 16 in the cache */
   /* search1363_1 -> 36 in the cache */
   /* search1363 -> 3933 in the cache */

   /* replace1363_0 -> 16 in the cache */
   /* replace1363_1 -> 36 in the cache */
   /* replace1363 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1364_0 -> 16 in the cache */
   /* search1364_1 -> 36 in the cache */
   /* search1364_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace1364_0 -> 16 in the cache */
   /* replace1364_1 -> 36 in the cache */
   /* replace1364_2 -> 137 in the cache */
   /* replace1364 -> 3928 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1365_0 -> 16 in the cache */
   /* search1365_1 -> 36 in the cache */
   /* search1365_2 -> 137 in the cache */
   /* search1365 -> 3935 in the cache */

   /* replace1365_0_0 -> 16 in the cache */
   /* replace1365_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1365_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3936, 137 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1366_0 -> 16 in the cache */
   /* search1366_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1366_0 -> 16 in the cache */
   /* replace1366_1 -> 36 in the cache */
   /* replace1366 -> 3923 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1367_0 -> 16 in the cache */
   /* search1367_1 -> 36 in the cache */
   /* search1367 -> 3938 in the cache */

   /* replace1367_0 -> 16 in the cache */
   /* replace1367_1 -> 36 in the cache */
   /* replace1367 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1368_0 -> 16 in the cache */
   /* search1368_1 -> 36 in the cache */
   /* search1368_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1368_0 -> 16 in the cache */
   /* replace1368_1 -> 36 in the cache */
   /* replace1368 -> 3934 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1369_0 -> 16 in the cache */
   /* search1369_1 -> 124 in the cache */
   /* search1369_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 124, 557 },
      -1,
   } },

   /* replace1369 -> 557 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1370_0 -> 16 in the cache */
   /* search1370_1 -> 398 in the cache */
   /* search1370_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 398, 557 },
      -1,
   } },

   /* replace1370_0 -> 16 in the cache */
   /* replace1370_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 557 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1371_0 -> 288 in the cache */
   /* search1371_1 -> 33 in the cache */
   /* search1371_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 288, 33, 137 },
      -1,
   } },

   /* replace1371_0_0 -> 16 in the cache */
   /* replace1371_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1371_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3944, 137 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1372_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3946 },
      -1,
   } },

   /* replace1372_0 -> 16 in the cache */
   /* replace1372_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3948 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1373_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3950 },
      -1,
   } },

   /* replace1373_0_0 -> 16 in the cache */
   /* replace1373_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3953 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3954 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1374_0 -> 16 in the cache */
   /* search1374_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace1374 -> 124 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1375_0 -> 6 in the cache */
   /* search1375_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2093 },
      -1,
   } },

   /* replace1375_0_0 -> 2093 in the cache */
   /* replace1375_0_1 -> 1407 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2093, 1407 },
      -1,
   } },
   /* replace1375_1_0_0_0 -> 6 in the cache */
   /* replace1375_1_0_0_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2093 },
      -1,
   } },
   /* replace1375_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3959, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1375_1_2_0 -> 6 in the cache */
   /* replace1375_1_2_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3960, 3961, 3962 },
      -1,
   } },
   /* replace1375_2_0_0 -> 6 in the cache */
   /* replace1375_2_0_1_0 -> 6 in the cache */
   /* replace1375_2_0_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 3964 },
      -1,
   } },
   /* replace1375_2_1 -> 7 in the cache */
   /* replace1375_2_2_0 -> 6 in the cache */
   /* replace1375_2_2_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3965, 7, 3966 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3958, 3963, 3967 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1376_0 -> 6 in the cache */
   /* search1376_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2093 },
      -1,
   } },

   /* replace1376_0_0 -> 2093 in the cache */
   /* replace1376_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2093, 814 },
      -1,
   } },
   /* replace1376_1_0_0_0 -> 6 in the cache */
   /* replace1376_1_0_0_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2093 },
      -1,
   } },
   /* replace1376_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3971, 6 },
      -1,
   } },
   /* replace1376_1_1 -> 3961 in the cache */
   /* replace1376_1_2_0 -> 6 in the cache */
   /* replace1376_1_2_1 -> 2093 in the cache */
   /* replace1376_1_2 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3972, 3961, 3971 },
      -1,
   } },
   /* replace1376_2_0_0 -> 6 in the cache */
   /* replace1376_2_0_1_0 -> 6 in the cache */
   /* replace1376_2_0_1_1 -> 2093 in the cache */
   /* replace1376_2_0_1 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3971 },
      -1,
   } },
   /* replace1376_2_1 -> 7 in the cache */
   /* replace1376_2_2_0 -> 6 in the cache */
   /* replace1376_2_2_1 -> 2093 in the cache */
   /* replace1376_2_2 -> 3971 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3974, 7, 3971 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3970, 3973, 3975 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1377_0 -> 11 in the cache */
   /* search1377_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* replace1377_0_0 -> 260 in the cache */
   /* replace1377_0_1 -> 1429 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 260, 1429 },
      -1,
   } },
   /* replace1377_1_0_0_0 -> 11 in the cache */
   /* replace1377_1_0_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 260 },
      -1,
   } },
   /* replace1377_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3979, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1377_1_2_0 -> 11 in the cache */
   /* replace1377_1_2_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3980, 3981, 3982 },
      -1,
   } },
   /* replace1377_2_0_0 -> 11 in the cache */
   /* replace1377_2_0_1_0 -> 11 in the cache */
   /* replace1377_2_0_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 3984 },
      -1,
   } },
   /* replace1377_2_1 -> 12 in the cache */
   /* replace1377_2_2_0 -> 11 in the cache */
   /* replace1377_2_2_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3985, 12, 3986 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3978, 3983, 3987 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1378_0 -> 11 in the cache */
   /* search1378_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 260 },
      -1,
   } },

   /* replace1378_0_0 -> 260 in the cache */
   /* replace1378_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 260, 835 },
      -1,
   } },
   /* replace1378_1_0_0_0 -> 11 in the cache */
   /* replace1378_1_0_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 260 },
      -1,
   } },
   /* replace1378_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3991, 11 },
      -1,
   } },
   /* replace1378_1_1 -> 3981 in the cache */
   /* replace1378_1_2_0 -> 11 in the cache */
   /* replace1378_1_2_1 -> 260 in the cache */
   /* replace1378_1_2 -> 3991 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3992, 3981, 3991 },
      -1,
   } },
   /* replace1378_2_0_0 -> 11 in the cache */
   /* replace1378_2_0_1_0 -> 11 in the cache */
   /* replace1378_2_0_1_1 -> 260 in the cache */
   /* replace1378_2_0_1 -> 3991 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3991 },
      -1,
   } },
   /* replace1378_2_1 -> 12 in the cache */
   /* replace1378_2_2_0 -> 11 in the cache */
   /* replace1378_2_2_1 -> 260 in the cache */
   /* replace1378_2_2 -> 3991 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3994, 12, 3991 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3990, 3993, 3995 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1379_0 -> 16 in the cache */
   /* search1379_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1379_0_0 -> 36 in the cache */
   /* replace1379_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   /* replace1379_1_0_0_0 -> 16 in the cache */
   /* replace1379_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1379_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3999, 16 },
      -1,
   } },
   /* replace1379_1_1 -> 967 in the cache */
   /* replace1379_1_2_0 -> 16 in the cache */
   /* replace1379_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4000, 967, 4001 },
      -1,
   } },
   /* replace1379_2_0_0 -> 16 in the cache */
   /* replace1379_2_0_1_0 -> 16 in the cache */
   /* replace1379_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 4003 },
      -1,
   } },
   /* replace1379_2_1 -> 17 in the cache */
   /* replace1379_2_2_0 -> 16 in the cache */
   /* replace1379_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4004, 17, 4005 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3998, 4002, 4006 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1380_0 -> 16 in the cache */
   /* search1380_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1380_0_0 -> 36 in the cache */
   /* replace1380_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   /* replace1380_1_0_0_0 -> 16 in the cache */
   /* replace1380_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1380_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4010, 16 },
      -1,
   } },
   /* replace1380_1_1 -> 967 in the cache */
   /* replace1380_1_2_0 -> 16 in the cache */
   /* replace1380_1_2_1 -> 36 in the cache */
   /* replace1380_1_2 -> 4010 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4011, 967, 4010 },
      -1,
   } },
   /* replace1380_2_0_0 -> 16 in the cache */
   /* replace1380_2_0_1_0 -> 16 in the cache */
   /* replace1380_2_0_1_1 -> 36 in the cache */
   /* replace1380_2_0_1 -> 4010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4010 },
      -1,
   } },
   /* replace1380_2_1 -> 17 in the cache */
   /* replace1380_2_2_0 -> 16 in the cache */
   /* replace1380_2_2_1 -> 36 in the cache */
   /* replace1380_2_2 -> 4010 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4013, 17, 4010 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4009, 4012, 4014 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1381_0 -> 21 in the cache */
   /* search1381_1 -> 41 in the cache */
   /* search1381 -> 3672 in the cache */

   /* replace1381_0_0 -> 41 in the cache */
   /* replace1381_0_1 -> 1471 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1471 },
      -1,
   } },
   /* replace1381_1_0_0_0 -> 21 in the cache */
   /* replace1381_1_0_0_1 -> 41 in the cache */
   /* replace1381_1_0_0 -> 3659 in the cache */
   /* replace1381_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3659, 21 },
      -1,
   } },
   /* replace1381_1_1 -> 3683 in the cache */
   /* replace1381_1_2_0 -> 21 in the cache */
   /* replace1381_1_2_1 -> 41 in the cache */
   /* replace1381_1_2 -> 3661 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4017, 3683, 3661 },
      -1,
   } },
   /* replace1381_2_0_0 -> 21 in the cache */
   /* replace1381_2_0_1_0 -> 21 in the cache */
   /* replace1381_2_0_1_1 -> 41 in the cache */
   /* replace1381_2_0_1 -> 3675 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3675 },
      -1,
   } },
   /* replace1381_2_1 -> 22 in the cache */
   /* replace1381_2_2_0 -> 21 in the cache */
   /* replace1381_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4019, 22, 4020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4016, 4018, 4021 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1382_0 -> 21 in the cache */
   /* search1382_1 -> 41 in the cache */
   /* search1382 -> 3686 in the cache */

   /* replace1382_0_0 -> 41 in the cache */
   /* replace1382_0_1 -> 876 in the cache */
   /* replace1382_0 -> 3673 in the cache */
   /* replace1382_1_0_0_0 -> 21 in the cache */
   /* replace1382_1_0_0_1 -> 41 in the cache */
   /* replace1382_1_0_0 -> 3670 in the cache */
   /* replace1382_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3670, 21 },
      -1,
   } },
   /* replace1382_1_1 -> 3683 in the cache */
   /* replace1382_1_2_0 -> 21 in the cache */
   /* replace1382_1_2_1 -> 41 in the cache */
   /* replace1382_1_2 -> 3670 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4023, 3683, 3670 },
      -1,
   } },
   /* replace1382_2_0_0 -> 21 in the cache */
   /* replace1382_2_0_1_0 -> 21 in the cache */
   /* replace1382_2_0_1_1 -> 41 in the cache */
   /* replace1382_2_0_1 -> 3670 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3670 },
      -1,
   } },
   /* replace1382_2_1 -> 22 in the cache */
   /* replace1382_2_2_0 -> 21 in the cache */
   /* replace1382_2_2_1 -> 41 in the cache */
   /* replace1382_2_2 -> 3670 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4025, 22, 3670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3673, 4024, 4026 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1383_0_0_0 -> 0 in the cache */
   /* search1383_0_0_1 -> 3 in the cache */
   /* search1383_0_0 -> 1053 in the cache */
   /* search1383_0_1_0 -> 154 in the cache */
   /* search1383_0_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1053, 4028 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4029 },
      -1,
   } },

   /* replace1383_0_0 -> 0 in the cache */
   /* replace1383_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1383_1_0 -> 154 in the cache */
   /* replace1383_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4031, 4032 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1384_0_0_0 -> 0 in the cache */
   /* search1384_0_0_1 -> 3 in the cache */
   /* search1384_0_0 -> 1053 in the cache */
   /* search1384_0_1_0 -> 154 in the cache */
   /* search1384_0_1_1 -> 155 in the cache */
   /* search1384_0_1 -> 4028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1053, 4028 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4034 },
      -1,
   } },

   /* replace1384_0_0 -> 0 in the cache */
   /* replace1384_0_1 -> 3 in the cache */
   /* replace1384_0 -> 4031 in the cache */
   /* replace1384_1_0 -> 154 in the cache */
   /* replace1384_1_1 -> 155 in the cache */
   /* replace1384_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4031, 4032 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1385_0_0_0 -> 0 in the cache */
   /* search1385_0_0_1 -> 3 in the cache */
   /* search1385_0_0 -> 1053 in the cache */
   /* search1385_0_1_0 -> 154 in the cache */
   /* search1385_0_1_1 -> 155 in the cache */
   /* search1385_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1053, 4032 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4037 },
      -1,
   } },

   /* replace1385_0_0 -> 0 in the cache */
   /* replace1385_0_1 -> 3 in the cache */
   /* replace1385_0 -> 4031 in the cache */
   /* replace1385_1_0 -> 154 in the cache */
   /* replace1385_1_1 -> 155 in the cache */
   /* replace1385_1 -> 4028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4031, 4028 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1386_0_0_0 -> 0 in the cache */
   /* search1386_0_0_1 -> 3 in the cache */
   /* search1386_0_0 -> 1053 in the cache */
   /* search1386_0_1_0 -> 154 in the cache */
   /* search1386_0_1_1 -> 155 in the cache */
   /* search1386_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1053, 4032 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4040 },
      -1,
   } },

   /* replace1386_0_0 -> 0 in the cache */
   /* replace1386_0_1 -> 3 in the cache */
   /* replace1386_0 -> 4031 in the cache */
   /* replace1386_1_0 -> 154 in the cache */
   /* replace1386_1_1 -> 155 in the cache */
   /* replace1386_1 -> 4028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4031, 4028 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1387_0_0_0 -> 0 in the cache */
   /* search1387_0_0_1 -> 3 in the cache */
   /* search1387_0_0 -> 4031 in the cache */
   /* search1387_0_1_0 -> 154 in the cache */
   /* search1387_0_1_1 -> 155 in the cache */
   /* search1387_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4031, 4032 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4043 },
      -1,
   } },

   /* replace1387_0_0 -> 0 in the cache */
   /* replace1387_0_1 -> 3 in the cache */
   /* replace1387_0 -> 1053 in the cache */
   /* replace1387_1_0 -> 154 in the cache */
   /* replace1387_1_1 -> 155 in the cache */
   /* replace1387_1 -> 4028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1053, 4028 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1388_0_0_0 -> 0 in the cache */
   /* search1388_0_0_1 -> 3 in the cache */
   /* search1388_0_0 -> 4031 in the cache */
   /* search1388_0_1_0 -> 154 in the cache */
   /* search1388_0_1_1 -> 155 in the cache */
   /* search1388_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4031, 4032 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4046 },
      -1,
   } },

   /* replace1388_0_0 -> 0 in the cache */
   /* replace1388_0_1 -> 3 in the cache */
   /* replace1388_0 -> 1053 in the cache */
   /* replace1388_1_0 -> 154 in the cache */
   /* replace1388_1_1 -> 155 in the cache */
   /* replace1388_1 -> 4028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1053, 4028 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1389_0_0 -> 739 in the cache */
   /* search1389_0 -> 1102 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1102 },
      -1,
   } },

   /* replace1389 -> 739 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1390_0_0 -> 739 in the cache */
   /* search1390_0 -> 1200 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 1200 },
      -1,
   } },

   /* replace1390 -> 739 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1391_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 4051 },
      -1,
   } },

   /* replace1391 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1392_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2b8,
      -1, 0,
      { 4053 },
      -1,
   } },

   /* replace1392 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1393_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 4055 },
      -1,
   } },

   /* replace1393 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1394_0_0 -> 11 in the cache */
   /* search1394_0 -> 3028 in the cache */
   /* search1394 -> 3029 in the cache */

   /* replace1394 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1395_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 4057 },
      -1,
   } },

   /* replace1395 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1396_0_0 -> 16 in the cache */
   /* search1396_0 -> 3030 in the cache */
   /* search1396 -> 3031 in the cache */

   /* replace1396 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1397_0_0 -> 32 in the cache */
   /* search1397_0 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1505 },
      -1,
   } },

   /* replace1397_0 -> 32 in the cache */
   /* replace1397 -> 1505 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1398_0_0 -> 32 in the cache */
   /* search1398_0 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1505 },
      -1,
   } },

   /* replace1398_0 -> 32 in the cache */
   /* replace1398 -> 3020 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1399_0_0 -> 32 in the cache */
   /* search1399_0 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1505 },
      -1,
   } },

   /* replace1399_0 -> 32 in the cache */
   /* replace1399 -> 3020 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1400_0_0 -> 32 in the cache */
   /* search1400_0 -> 3020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 3020 },
      -1,
   } },

   /* replace1400_0 -> 32 in the cache */
   /* replace1400 -> 1505 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1401_0_0 -> 32 in the cache */
   /* search1401_0 -> 3020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3020 },
      -1,
   } },

   /* replace1401_0 -> 32 in the cache */
   /* replace1401 -> 3020 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1402_0_0 -> 32 in the cache */
   /* search1402_0 -> 3020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3020 },
      -1,
   } },

   /* replace1402_0 -> 32 in the cache */
   /* replace1402 -> 1505 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1403_0_0 -> 32 in the cache */
   /* search1403_0 -> 3020 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3020 },
      -1,
   } },

   /* replace1403_0 -> 32 in the cache */
   /* replace1403 -> 3020 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1404_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 739 },
      -1,
   } },

   /* replace1404 -> 739 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1405_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1405 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1406_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1406 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1407_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1407 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1408_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1408 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1409_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 739 },
      -1,
   } },

   /* replace1409 -> 739 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1410_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1410 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1411_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1411 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1412_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1412 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1413_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1413 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1414_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1414 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1415_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1415 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1416_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1416 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1417_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 739 },
      -1,
   } },

   /* replace1417 -> 739 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1418_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1418 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1419_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1419 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1420_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1420 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1421_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4083 },
      -1,
   } },

   /* replace1421_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1422_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4086 },
      -1,
   } },

   /* replace1422_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1423_0_0 -> 32 in the cache */
   /* search1423_0 -> 4083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4083 },
      -1,
   } },

   /* replace1423_0 -> 32 in the cache */
   /* replace1423 -> 4085 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1424_0_0 -> 32 in the cache */
   /* search1424_0 -> 4086 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4086 },
      -1,
   } },

   /* replace1424_0 -> 32 in the cache */
   /* replace1424 -> 4088 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1425_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1425_0 -> 32 in the cache */
   /* replace1425 -> 4085 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1426_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4093 },
      -1,
   } },

   /* replace1426_0 -> 32 in the cache */
   /* replace1426 -> 4088 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1427_0_0 -> 32 in the cache */
   /* search1427_0 -> 4091 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1427_0 -> 32 in the cache */
   /* replace1427 -> 4085 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1428_0_0 -> 32 in the cache */
   /* search1428_0 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4093 },
      -1,
   } },

   /* replace1428_0 -> 32 in the cache */
   /* replace1428 -> 4088 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1429_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1429_0 -> 32 in the cache */
   /* replace1429 -> 4085 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1430_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1430_0 -> 32 in the cache */
   /* replace1430 -> 4088 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1431_0_0 -> 32 in the cache */
   /* search1431_0 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1431_0 -> 32 in the cache */
   /* replace1431 -> 4085 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1432_0_0 -> 32 in the cache */
   /* search1432_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1432_0 -> 32 in the cache */
   /* replace1432 -> 4088 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1433_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1433_0 -> 32 in the cache */
   /* replace1433 -> 4085 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1434_0_0 -> 32 in the cache */
   /* search1434_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1434_0 -> 32 in the cache */
   /* replace1434 -> 4088 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1435_0_0 -> 32 in the cache */
   /* search1435_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1435_0 -> 32 in the cache */
   /* replace1435 -> 4085 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1436_0_0 -> 32 in the cache */
   /* search1436_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1436_0 -> 32 in the cache */
   /* replace1436 -> 4088 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1437_0_0 -> 739 in the cache */
   /* search1437_0 -> 4066 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4066 },
      -1,
   } },

   /* replace1437_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1438_0_0 -> 739 in the cache */
   /* search1438_0 -> 4071 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4071 },
      -1,
   } },

   /* replace1438_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1439_0_0 -> 32 in the cache */
   /* search1439_0 -> 4091 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1439_0 -> 32 in the cache */
   /* replace1439 -> 4083 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1440_0_0 -> 32 in the cache */
   /* search1440_0 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4093 },
      -1,
   } },

   /* replace1440_0 -> 32 in the cache */
   /* replace1440 -> 4086 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1441_0_0 -> 32 in the cache */
   /* search1441_0 -> 4091 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1441_0 -> 32 in the cache */
   /* replace1441 -> 4083 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1442_0_0 -> 32 in the cache */
   /* search1442_0 -> 4093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4093 },
      -1,
   } },

   /* replace1442_0 -> 32 in the cache */
   /* replace1442 -> 4086 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1443_0_0 -> 32 in the cache */
   /* search1443_0 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1443_0 -> 32 in the cache */
   /* replace1443 -> 4083 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1444_0_0 -> 32 in the cache */
   /* search1444_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1444_0 -> 32 in the cache */
   /* replace1444 -> 4086 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1445_0_0 -> 32 in the cache */
   /* search1445_0 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1445_0 -> 32 in the cache */
   /* replace1445 -> 4083 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1446_0_0 -> 32 in the cache */
   /* search1446_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1446_0 -> 32 in the cache */
   /* replace1446 -> 4086 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1447_0_0 -> 32 in the cache */
   /* search1447_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1447_0 -> 32 in the cache */
   /* replace1447 -> 4083 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1448_0_0 -> 32 in the cache */
   /* search1448_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1448_0 -> 32 in the cache */
   /* replace1448 -> 4086 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1449_0_0 -> 32 in the cache */
   /* search1449_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1449_0 -> 32 in the cache */
   /* replace1449 -> 4083 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1450_0_0 -> 32 in the cache */
   /* search1450_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1450_0 -> 32 in the cache */
   /* replace1450 -> 4086 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1451_0_0 -> 739 in the cache */
   /* search1451_0 -> 4066 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4066 },
      -1,
   } },

   /* replace1451_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1452_0_0 -> 739 in the cache */
   /* search1452_0 -> 4071 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4071 },
      -1,
   } },

   /* replace1452_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1453_0_0 -> 739 in the cache */
   /* search1453_0 -> 4109 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4109 },
      -1,
   } },

   /* replace1453_0 -> 739 in the cache */
   /* replace1453 -> 4125 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1454_0_0 -> 739 in the cache */
   /* search1454_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1454_0 -> 739 in the cache */
   /* replace1454 -> 4127 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1455_0_0 -> 6 in the cache */
   /* search1455_0 -> 4067 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4067 },
      -1,
   } },

   /* replace1455_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1456_0_0 -> 6 in the cache */
   /* search1456_0 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4072 },
      -1,
   } },

   /* replace1456_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1457_0_0 -> 32 in the cache */
   /* search1457_0 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1457_0 -> 32 in the cache */
   /* replace1457 -> 4091 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1458_0_0 -> 32 in the cache */
   /* search1458_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1458_0 -> 32 in the cache */
   /* replace1458 -> 4093 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1459_0_0 -> 32 in the cache */
   /* search1459_0 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4097 },
      -1,
   } },

   /* replace1459_0 -> 32 in the cache */
   /* replace1459 -> 4091 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1460_0_0 -> 32 in the cache */
   /* search1460_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1460_0 -> 32 in the cache */
   /* replace1460 -> 4093 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1461_0_0 -> 32 in the cache */
   /* search1461_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1461_0 -> 32 in the cache */
   /* replace1461 -> 4091 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1462_0_0 -> 32 in the cache */
   /* search1462_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1462_0 -> 32 in the cache */
   /* replace1462 -> 4093 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1463_0_0 -> 32 in the cache */
   /* search1463_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1463_0 -> 32 in the cache */
   /* replace1463 -> 4091 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1464_0_0 -> 32 in the cache */
   /* search1464_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1464_0 -> 32 in the cache */
   /* replace1464 -> 4093 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1465_0_0 -> 739 in the cache */
   /* search1465_0 -> 4066 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4066 },
      -1,
   } },

   /* replace1465_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1466_0_0 -> 739 in the cache */
   /* search1466_0 -> 4071 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4071 },
      -1,
   } },

   /* replace1466_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1467_0_0 -> 739 in the cache */
   /* search1467_0 -> 4109 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4109 },
      -1,
   } },

   /* replace1467_0 -> 739 in the cache */
   /* replace1467 -> 4143 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1468_0_0 -> 739 in the cache */
   /* search1468_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1468_0 -> 739 in the cache */
   /* replace1468 -> 4145 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1469_0_0 -> 6 in the cache */
   /* search1469_0 -> 4067 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4067 },
      -1,
   } },

   /* replace1469_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1470_0_0 -> 6 in the cache */
   /* search1470_0 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4072 },
      -1,
   } },

   /* replace1470_0 -> 6 in the cache */
   /* replace1470 -> 3202 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1471_0_0 -> 739 in the cache */
   /* search1471_0 -> 4125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4125 },
      -1,
   } },

   /* replace1471_0 -> 739 in the cache */
   /* replace1471 -> 4143 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1472_0_0 -> 739 in the cache */
   /* search1472_0 -> 4127 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4127 },
      -1,
   } },

   /* replace1472_0 -> 739 in the cache */
   /* replace1472 -> 4145 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1473_0_0 -> 6 in the cache */
   /* search1473_0 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4131 },
      -1,
   } },

   /* replace1473_0 -> 6 in the cache */
   /* replace1473 -> 4149 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1474_0_0 -> 6 in the cache */
   /* search1474_0 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4133 },
      -1,
   } },

   /* replace1474_0 -> 6 in the cache */
   /* replace1474 -> 3202 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1475_0_0 -> 11 in the cache */
   /* search1475_0 -> 4068 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4068 },
      -1,
   } },

   /* replace1475_0 -> 11 in the cache */
   /* replace1475 -> 1780 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1476_0_0 -> 11 in the cache */
   /* search1476_0 -> 4073 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4073 },
      -1,
   } },

   /* replace1476_0 -> 11 in the cache */
   /* replace1476 -> 1782 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1477_0_0 -> 32 in the cache */
   /* search1477_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1477_0 -> 32 in the cache */
   /* replace1477 -> 4097 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1478_0_0 -> 32 in the cache */
   /* search1478_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1478_0 -> 32 in the cache */
   /* replace1478 -> 4099 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1479_0_0 -> 32 in the cache */
   /* search1479_0 -> 4103 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4103 },
      -1,
   } },

   /* replace1479_0 -> 32 in the cache */
   /* replace1479 -> 4097 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1480_0_0 -> 32 in the cache */
   /* search1480_0 -> 3127 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3127 },
      -1,
   } },

   /* replace1480_0 -> 32 in the cache */
   /* replace1480 -> 4099 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1481_0_0 -> 739 in the cache */
   /* search1481_0 -> 4066 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4066 },
      -1,
   } },

   /* replace1481_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1482_0_0 -> 739 in the cache */
   /* search1482_0 -> 4071 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4071 },
      -1,
   } },

   /* replace1482_0 -> 739 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 739 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1483_0_0 -> 739 in the cache */
   /* search1483_0 -> 4109 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4109 },
      -1,
   } },

   /* replace1483_0 -> 739 in the cache */
   /* replace1483 -> 4162 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1484_0_0 -> 739 in the cache */
   /* search1484_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1484_0 -> 739 in the cache */
   /* replace1484 -> 4164 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1485_0_0 -> 6 in the cache */
   /* search1485_0 -> 4067 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4067 },
      -1,
   } },

   /* replace1485_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1486_0_0 -> 6 in the cache */
   /* search1486_0 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4072 },
      -1,
   } },

   /* replace1486_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1487_0_0 -> 739 in the cache */
   /* search1487_0 -> 4125 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4125 },
      -1,
   } },

   /* replace1487_0 -> 739 in the cache */
   /* replace1487 -> 4162 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1488_0_0 -> 739 in the cache */
   /* search1488_0 -> 4127 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4127 },
      -1,
   } },

   /* replace1488_0 -> 739 in the cache */
   /* replace1488 -> 4164 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1489_0_0 -> 6 in the cache */
   /* search1489_0 -> 4131 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4131 },
      -1,
   } },

   /* replace1489_0 -> 6 in the cache */
   /* replace1489 -> 4168 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1490_0_0 -> 6 in the cache */
   /* search1490_0 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4133 },
      -1,
   } },

   /* replace1490_0 -> 6 in the cache */
   /* replace1490 -> 4170 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1491_0_0 -> 11 in the cache */
   /* search1491_0 -> 4068 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4068 },
      -1,
   } },

   /* replace1491_0 -> 11 in the cache */
   /* replace1491 -> 1803 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1492_0_0 -> 11 in the cache */
   /* search1492_0 -> 4073 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4073 },
      -1,
   } },

   /* replace1492_0 -> 11 in the cache */
   /* replace1492 -> 1805 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1493_0_0 -> 739 in the cache */
   /* search1493_0 -> 4143 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4143 },
      -1,
   } },

   /* replace1493_0 -> 739 in the cache */
   /* replace1493 -> 4162 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1494_0_0 -> 739 in the cache */
   /* search1494_0 -> 4145 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4145 },
      -1,
   } },

   /* replace1494_0 -> 739 in the cache */
   /* replace1494 -> 4164 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1495_0_0 -> 6 in the cache */
   /* search1495_0 -> 4149 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4149 },
      -1,
   } },

   /* replace1495_0 -> 6 in the cache */
   /* replace1495 -> 4168 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1496_0_0 -> 6 in the cache */
   /* search1496_0 -> 3202 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3202 },
      -1,
   } },

   /* replace1496_0 -> 6 in the cache */
   /* replace1496 -> 4170 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1497_0_0 -> 11 in the cache */
   /* search1497_0 -> 1780 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* replace1497_0 -> 11 in the cache */
   /* replace1497 -> 1803 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1498_0_0 -> 11 in the cache */
   /* search1498_0 -> 1782 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace1498_0 -> 11 in the cache */
   /* replace1498 -> 1805 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1499_0_0 -> 16 in the cache */
   /* search1499_0 -> 4069 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4069 },
      -1,
   } },

   /* replace1499_0 -> 16 in the cache */
   /* replace1499 -> 1887 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1500_0_0 -> 16 in the cache */
   /* search1500_0 -> 4074 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4074 },
      -1,
   } },

   /* replace1500_0 -> 16 in the cache */
   /* replace1500 -> 1889 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1501_0_0 -> 16 in the cache */
   /* search1501_0_1 -> 36 in the cache */
   /* search1501_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1501_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1502_0_0 -> 16 in the cache */
   /* search1502_0_1 -> 36 in the cache */
   /* search1502_0 -> 3120 in the cache */
   /* search1502 -> 4185 in the cache */

   /* replace1502_0 -> 16 in the cache */
   /* replace1502 -> 4186 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1503_0_0 -> 16 in the cache */
   /* search1503_0_1 -> 36 in the cache */
   /* search1503_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1503_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1504_0_0 -> 16 in the cache */
   /* search1504_0_1 -> 36 in the cache */
   /* search1504_0 -> 3120 in the cache */
   /* search1504 -> 4187 in the cache */

   /* replace1504_0 -> 16 in the cache */
   /* replace1504 -> 4188 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1505_0_0 -> 16 in the cache */
   /* search1505_0_1 -> 36 in the cache */
   /* search1505_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1505_0 -> 16 in the cache */
   /* replace1505 -> 4069 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1506_0_0 -> 16 in the cache */
   /* search1506_0_1 -> 36 in the cache */
   /* search1506_0 -> 3120 in the cache */
   /* search1506 -> 4189 in the cache */

   /* replace1506_0 -> 16 in the cache */
   /* replace1506 -> 4069 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1507_0_0 -> 16 in the cache */
   /* search1507_0_1 -> 36 in the cache */
   /* search1507_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1507_0 -> 16 in the cache */
   /* replace1507 -> 2006 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1508_0_0 -> 16 in the cache */
   /* search1508_0_1 -> 36 in the cache */
   /* search1508_0 -> 3120 in the cache */
   /* search1508 -> 4190 in the cache */

   /* replace1508_0 -> 16 in the cache */
   /* replace1508 -> 2006 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1509_0_0 -> 16 in the cache */
   /* search1509_0_1 -> 36 in the cache */
   /* search1509_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1509_0 -> 16 in the cache */
   /* replace1509 -> 3230 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1510_0_0 -> 16 in the cache */
   /* search1510_0_1 -> 36 in the cache */
   /* search1510_0 -> 3120 in the cache */
   /* search1510 -> 4191 in the cache */

   /* replace1510_0 -> 16 in the cache */
   /* replace1510 -> 3230 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1511_0_0 -> 16 in the cache */
   /* search1511_0_1 -> 36 in the cache */
   /* search1511_0 -> 3120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3120 },
      -1,
   } },

   /* replace1511_0 -> 16 in the cache */
   /* replace1511 -> 4074 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1512_0_0 -> 16 in the cache */
   /* search1512_0_1 -> 36 in the cache */
   /* search1512_0 -> 3120 in the cache */
   /* search1512 -> 4192 in the cache */

   /* replace1512_0 -> 16 in the cache */
   /* replace1512 -> 4074 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1513_0_0 -> 6 in the cache */
   /* search1513_0 -> 4131 in the cache */
   /* search1513_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4131, 4193 },
      -1,
   } },

   /* replace1513_0 -> 6 in the cache */
   /* replace1513_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4195 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1514_0_0 -> 6 in the cache */
   /* search1514_0 -> 4131 in the cache */
   /* search1514_1_0 -> 2093 in the cache */
   /* search1514_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4131, 4193 },
      -1,
   } },

   /* replace1514_0 -> 6 in the cache */
   /* replace1514_1_0 -> 2093 in the cache */
   /* replace1514_1 -> 4195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4195 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1515_0_0 -> 6 in the cache */
   /* search1515_0 -> 4131 in the cache */
   /* search1515_1_0 -> 2093 in the cache */
   /* search1515_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4131, 4193 },
      -1,
   } },

   /* replace1515_0 -> 6 in the cache */
   /* replace1515_1_0 -> 2093 in the cache */
   /* replace1515_1 -> 4195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4195 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1516_0_0 -> 6 in the cache */
   /* search1516_0 -> 4131 in the cache */
   /* search1516_1_0 -> 2093 in the cache */
   /* search1516_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4131, 4193 },
      -1,
   } },

   /* replace1516_0 -> 6 in the cache */
   /* replace1516_1_0 -> 2093 in the cache */
   /* replace1516_1 -> 4195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4195 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4203 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4204, 4206 },
      -1,
   } },

   /* replace1517_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* replace1517_1 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4208, 4205 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1518_0_0 -> 4203 in the cache */
   /* search1518_0 -> 4204 in the cache */
   /* search1518_1_0 -> 4205 in the cache */
   /* search1518_1 -> 4206 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4204, 4206 },
      -1,
   } },

   /* replace1518_0_0 -> 4203 in the cache */
   /* replace1518_0 -> 4208 in the cache */
   /* replace1518_1 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4208, 4205 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1519_0_0 -> 6 in the cache */
   /* search1519_0 -> 4131 in the cache */
   /* search1519_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4131, 1992 },
      -1,
   } },

   /* replace1519_0_0 -> 6 in the cache */
   /* replace1519_0_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4213 },
      -1,
   } },
   /* replace1519_1_0_0_0 -> 260 in the cache */
   /* replace1519_1_0_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4213 },
      -1,
   } },
   /* replace1519_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4215, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4214, 4216 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1520_0_0 -> 6 in the cache */
   /* search1520_0 -> 4131 in the cache */
   /* search1520_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4131, 1992 },
      -1,
   } },

   /* replace1520_0_0 -> 6 in the cache */
   /* replace1520_0_1_0 -> 260 in the cache */
   /* replace1520_0_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4213 },
      -1,
   } },
   /* replace1520_1_0_0_0 -> 260 in the cache */
   /* replace1520_1_0_0 -> 4213 in the cache */
   /* replace1520_1_0 -> 4215 in the cache */
   /* replace1520_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4215, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4219, 4220 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1521_0_0 -> 6 in the cache */
   /* search1521_0 -> 4131 in the cache */
   /* search1521_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4131, 1992 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1521_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4223, 260 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1521_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4225, 260 },
      -1,
   } },
   /* replace1521_1_1_0 -> 6 in the cache */
   /* replace1521_1_1_1_0 -> 260 in the cache */
   /* replace1521_1_1_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4226, 4227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4224, 4228 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1522_1_0 -> 2093 in the cache */
   /* search1522_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4230, 4193 },
      -1,
   } },

   /* replace1522_0_0 -> 11 in the cache */
   /* replace1522_0_1 -> 4225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4225 },
      -1,
   } },
   /* replace1522_1_0_0 -> 11 in the cache */
   /* replace1522_1_0_1 -> 4223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4223 },
      -1,
   } },
   /* replace1522_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1522_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4234, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4233, 4235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4232, 4236 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1523_0_0 -> 6 in the cache */
   /* search1523_0 -> 4131 in the cache */
   /* search1523_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4131, 1992 },
      -1,
   } },

   /* replace1523_0_0 -> 4225 in the cache */
   /* replace1523_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4225, 260 },
      -1,
   } },
   /* replace1523_1_0_0 -> 4223 in the cache */
   /* replace1523_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4223, 260 },
      -1,
   } },
   /* replace1523_1_1_0 -> 6 in the cache */
   /* replace1523_1_1_1_0 -> 260 in the cache */
   /* replace1523_1_1_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4240, 4241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4239, 4242 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1524_0 -> 4230 in the cache */
   /* search1524_1_0 -> 2093 in the cache */
   /* search1524_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4230, 4193 },
      -1,
   } },

   /* replace1524_0_0 -> 11 in the cache */
   /* replace1524_0_1 -> 4223 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4223 },
      -1,
   } },
   /* replace1524_1_0_0 -> 11 in the cache */
   /* replace1524_1_0_1 -> 4225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4225 },
      -1,
   } },
   /* replace1524_1_1_0_0 -> 11 in the cache */
   /* replace1524_1_1_0 -> 4234 in the cache */
   /* replace1524_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4234, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4246, 4247 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4245, 4248 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1525_0_0 -> 6 in the cache */
   /* search1525_0 -> 4149 in the cache */
   /* search1525_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4149, 4250 },
      -1,
   } },

   /* replace1525_0 -> 6 in the cache */
   /* replace1525_1_0 -> 2093 in the cache */
   /* replace1525_1 -> 4195 in the cache */
   /* replace1525 -> 4196 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1526_0_0 -> 6 in the cache */
   /* search1526_0 -> 4149 in the cache */
   /* search1526_1_0 -> 2093 in the cache */
   /* search1526_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4149, 4250 },
      -1,
   } },

   /* replace1526_0 -> 6 in the cache */
   /* replace1526_1_0 -> 2093 in the cache */
   /* replace1526_1 -> 4195 in the cache */
   /* replace1526 -> 4198 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1527_0_0 -> 6 in the cache */
   /* search1527_0 -> 4149 in the cache */
   /* search1527_1_0 -> 2093 in the cache */
   /* search1527_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4149, 4250 },
      -1,
   } },

   /* replace1527_0 -> 6 in the cache */
   /* replace1527_1_0 -> 2093 in the cache */
   /* replace1527_1 -> 4195 in the cache */
   /* replace1527 -> 4200 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1528_0_0 -> 6 in the cache */
   /* search1528_0 -> 4149 in the cache */
   /* search1528_1_0 -> 2093 in the cache */
   /* search1528_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4149, 4250 },
      -1,
   } },

   /* replace1528_0 -> 6 in the cache */
   /* replace1528_1_0 -> 2093 in the cache */
   /* replace1528_1 -> 4195 in the cache */
   /* replace1528 -> 4202 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1529_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* search1529_1_0 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4255, 4256 },
      -1,
   } },

   /* replace1529_0_0 -> 4203 in the cache */
   /* replace1529_0 -> 4208 in the cache */
   /* replace1529_1 -> 4205 in the cache */
   /* replace1529 -> 4209 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1530_0_0 -> 4203 in the cache */
   /* search1530_0 -> 4255 in the cache */
   /* search1530_1_0 -> 4205 in the cache */
   /* search1530_1 -> 4256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4255, 4256 },
      -1,
   } },

   /* replace1530_0_0 -> 4203 in the cache */
   /* replace1530_0 -> 4208 in the cache */
   /* replace1530_1 -> 4205 in the cache */
   /* replace1530 -> 4211 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1531_0_0 -> 6 in the cache */
   /* search1531_0 -> 4149 in the cache */
   /* search1531_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4149, 33 },
      -1,
   } },

   /* replace1531_0_0 -> 6 in the cache */
   /* replace1531_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4260 },
      -1,
   } },
   /* replace1531_1_0_0_0 -> 36 in the cache */
   /* replace1531_1_0_0 -> 4260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4260 },
      -1,
   } },
   /* replace1531_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4262, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4261, 4263 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1532_0_0 -> 6 in the cache */
   /* search1532_0 -> 4149 in the cache */
   /* search1532_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4149, 33 },
      -1,
   } },

   /* replace1532_0_0 -> 6 in the cache */
   /* replace1532_0_1_0 -> 36 in the cache */
   /* replace1532_0_1 -> 4260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4260 },
      -1,
   } },
   /* replace1532_1_0_0_0 -> 36 in the cache */
   /* replace1532_1_0_0 -> 4260 in the cache */
   /* replace1532_1_0 -> 4262 in the cache */
   /* replace1532_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4262, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4266, 4267 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1533_0_0 -> 6 in the cache */
   /* search1533_0 -> 4149 in the cache */
   /* search1533_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4149, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1533_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4270, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1533_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4272, 36 },
      -1,
   } },
   /* replace1533_1_1_0 -> 6 in the cache */
   /* replace1533_1_1_1_0 -> 36 in the cache */
   /* replace1533_1_1_1 -> 4260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4273, 4274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4271, 4275 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1534_0 -> 288 in the cache */
   /* search1534_1_0 -> 2093 in the cache */
   /* search1534_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 288, 4250 },
      -1,
   } },

   /* replace1534_0_0 -> 16 in the cache */
   /* replace1534_0_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4272 },
      -1,
   } },
   /* replace1534_1_0_0 -> 16 in the cache */
   /* replace1534_1_0_1 -> 4270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4270 },
      -1,
   } },
   /* replace1534_1_1_0_0 -> 16 in the cache */
   /* replace1534_1_1_0 -> 4186 in the cache */
   /* replace1534_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4186, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4279, 4280 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4278, 4281 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1535_0_0 -> 6 in the cache */
   /* search1535_0 -> 4149 in the cache */
   /* search1535_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4149, 33 },
      -1,
   } },

   /* replace1535_0_0 -> 4272 in the cache */
   /* replace1535_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4272, 36 },
      -1,
   } },
   /* replace1535_1_0_0 -> 4270 in the cache */
   /* replace1535_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4270, 36 },
      -1,
   } },
   /* replace1535_1_1_0 -> 6 in the cache */
   /* replace1535_1_1_1_0 -> 36 in the cache */
   /* replace1535_1_1_1 -> 4260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4285, 4286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4284, 4287 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1536_0 -> 288 in the cache */
   /* search1536_1_0 -> 2093 in the cache */
   /* search1536_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 288, 4250 },
      -1,
   } },

   /* replace1536_0_0 -> 16 in the cache */
   /* replace1536_0_1 -> 4270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4270 },
      -1,
   } },
   /* replace1536_1_0_0 -> 16 in the cache */
   /* replace1536_1_0_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4272 },
      -1,
   } },
   /* replace1536_1_1_0_0 -> 16 in the cache */
   /* replace1536_1_1_0 -> 4186 in the cache */
   /* replace1536_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4186, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4291, 4292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4290, 4293 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1537_0_0 -> 6 in the cache */
   /* search1537_0 -> 4168 in the cache */
   /* search1537_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4168, 4295 },
      -1,
   } },

   /* replace1537_0 -> 6 in the cache */
   /* replace1537_1_0 -> 2093 in the cache */
   /* replace1537_1 -> 4195 in the cache */
   /* replace1537 -> 4196 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1538_0_0 -> 6 in the cache */
   /* search1538_0 -> 4168 in the cache */
   /* search1538_1_0 -> 2093 in the cache */
   /* search1538_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4168, 4295 },
      -1,
   } },

   /* replace1538_0 -> 6 in the cache */
   /* replace1538_1_0 -> 2093 in the cache */
   /* replace1538_1 -> 4195 in the cache */
   /* replace1538 -> 4198 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1539_0_0 -> 6 in the cache */
   /* search1539_0 -> 4168 in the cache */
   /* search1539_1_0 -> 2093 in the cache */
   /* search1539_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4168, 4295 },
      -1,
   } },

   /* replace1539_0 -> 6 in the cache */
   /* replace1539_1_0 -> 2093 in the cache */
   /* replace1539_1 -> 4195 in the cache */
   /* replace1539 -> 4200 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1540_0_0 -> 6 in the cache */
   /* search1540_0 -> 4168 in the cache */
   /* search1540_1_0 -> 2093 in the cache */
   /* search1540_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4168, 4295 },
      -1,
   } },

   /* replace1540_0 -> 6 in the cache */
   /* replace1540_1_0 -> 2093 in the cache */
   /* replace1540_1 -> 4195 in the cache */
   /* replace1540 -> 4202 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1541_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* search1541_1_0 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4300, 4301 },
      -1,
   } },

   /* replace1541_0_0 -> 4203 in the cache */
   /* replace1541_0 -> 4208 in the cache */
   /* replace1541_1 -> 4205 in the cache */
   /* replace1541 -> 4209 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1542_0_0 -> 4203 in the cache */
   /* search1542_0 -> 4300 in the cache */
   /* search1542_1_0 -> 4205 in the cache */
   /* search1542_1 -> 4301 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4300, 4301 },
      -1,
   } },

   /* replace1542_0_0 -> 4203 in the cache */
   /* replace1542_0 -> 4208 in the cache */
   /* replace1542_1 -> 4205 in the cache */
   /* replace1542 -> 4211 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1543_0_0 -> 6 in the cache */
   /* search1543_0 -> 4168 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4168, 4304 },
      -1,
   } },

   /* replace1543_0_0 -> 6 in the cache */
   /* replace1543_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4306 },
      -1,
   } },
   /* replace1543_1_0_0_0 -> 41 in the cache */
   /* replace1543_1_0_0 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4306 },
      -1,
   } },
   /* replace1543_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4308, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4307, 4309 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1544_0_0 -> 6 in the cache */
   /* search1544_0 -> 4168 in the cache */
   /* search1544_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4168, 4304 },
      -1,
   } },

   /* replace1544_0_0 -> 6 in the cache */
   /* replace1544_0_1_0 -> 41 in the cache */
   /* replace1544_0_1 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4306 },
      -1,
   } },
   /* replace1544_1_0_0_0 -> 41 in the cache */
   /* replace1544_1_0_0 -> 4306 in the cache */
   /* replace1544_1_0 -> 4308 in the cache */
   /* replace1544_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4308, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4312, 4313 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1545_0_0 -> 6 in the cache */
   /* search1545_0 -> 4168 in the cache */
   /* search1545_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4168, 4304 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1545_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4316, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1545_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4318, 41 },
      -1,
   } },
   /* replace1545_1_1_0 -> 6 in the cache */
   /* replace1545_1_1_1_0 -> 41 in the cache */
   /* replace1545_1_1_1 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4306 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4319, 4320 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4317, 4321 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1546_1_0 -> 2093 in the cache */
   /* search1546_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4323, 4295 },
      -1,
   } },

   /* replace1546_0_0 -> 21 in the cache */
   /* replace1546_0_1 -> 4318 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4318 },
      -1,
   } },
   /* replace1546_1_0_0 -> 21 in the cache */
   /* replace1546_1_0_1 -> 4316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4316 },
      -1,
   } },
   /* replace1546_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1546_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4327, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4326, 4328 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4325, 4329 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1547_0_0 -> 6 in the cache */
   /* search1547_0 -> 4168 in the cache */
   /* search1547_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4168, 4304 },
      -1,
   } },

   /* replace1547_0_0 -> 4318 in the cache */
   /* replace1547_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4318, 41 },
      -1,
   } },
   /* replace1547_1_0_0 -> 4316 in the cache */
   /* replace1547_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4316, 41 },
      -1,
   } },
   /* replace1547_1_1_0 -> 6 in the cache */
   /* replace1547_1_1_1_0 -> 41 in the cache */
   /* replace1547_1_1_1 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4306 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4333, 4334 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4332, 4335 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1548_0 -> 4323 in the cache */
   /* search1548_1_0 -> 2093 in the cache */
   /* search1548_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4323, 4295 },
      -1,
   } },

   /* replace1548_0_0 -> 21 in the cache */
   /* replace1548_0_1 -> 4316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4316 },
      -1,
   } },
   /* replace1548_1_0_0 -> 21 in the cache */
   /* replace1548_1_0_1 -> 4318 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4318 },
      -1,
   } },
   /* replace1548_1_1_0_0 -> 21 in the cache */
   /* replace1548_1_1_0 -> 4327 in the cache */
   /* replace1548_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4327, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4339, 4340 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4338, 4341 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1549_0_0 -> 11 in the cache */
   /* search1549_0 -> 1780 in the cache */
   /* search1549_1_0 -> 2093 in the cache */
   /* search1549_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1780, 4250 },
      -1,
   } },

   /* replace1549_0 -> 11 in the cache */
   /* replace1549_1_0 -> 2093 in the cache */
   /* replace1549_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4193 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1550_0_0 -> 11 in the cache */
   /* search1550_0 -> 1780 in the cache */
   /* search1550_1_0 -> 2093 in the cache */
   /* search1550_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1780, 4250 },
      -1,
   } },

   /* replace1550_0 -> 11 in the cache */
   /* replace1550_1_0 -> 2093 in the cache */
   /* replace1550_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4193 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1551_0_0 -> 11 in the cache */
   /* search1551_0 -> 1780 in the cache */
   /* search1551_1_0 -> 2093 in the cache */
   /* search1551_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1780, 4250 },
      -1,
   } },

   /* replace1551_0 -> 11 in the cache */
   /* replace1551_1_0 -> 2093 in the cache */
   /* replace1551_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4193 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1552_0_0 -> 11 in the cache */
   /* search1552_0 -> 1780 in the cache */
   /* search1552_1_0 -> 2093 in the cache */
   /* search1552_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1780, 4250 },
      -1,
   } },

   /* replace1552_0 -> 11 in the cache */
   /* replace1552_1_0 -> 2093 in the cache */
   /* replace1552_1 -> 4193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4193 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1553_0_0 -> 4203 in the cache */
   /* search1553_0 -> 4255 in the cache */
   /* search1553_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4255, 4351 },
      -1,
   } },

   /* replace1553_0_0 -> 4203 in the cache */
   /* replace1553_0 -> 4204 in the cache */
   /* replace1553_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4204, 528 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1554_0_0 -> 4203 in the cache */
   /* search1554_0 -> 4255 in the cache */
   /* search1554_1_0 -> 528 in the cache */
   /* search1554_1 -> 4351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4255, 4351 },
      -1,
   } },

   /* replace1554_0_0 -> 4203 in the cache */
   /* replace1554_0 -> 4204 in the cache */
   /* replace1554_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4204, 528 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1555_0_0 -> 11 in the cache */
   /* search1555_0 -> 1780 in the cache */
   /* search1555_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1780, 4356 },
      -1,
   } },

   /* replace1555_0 -> 11 in the cache */
   /* replace1555_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4358 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1556_0_0 -> 11 in the cache */
   /* search1556_0 -> 1780 in the cache */
   /* search1556_1_0 -> 260 in the cache */
   /* search1556_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1780, 4356 },
      -1,
   } },

   /* replace1556_0 -> 11 in the cache */
   /* replace1556_1_0 -> 260 in the cache */
   /* replace1556_1 -> 4358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4358 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1557_0_0 -> 11 in the cache */
   /* search1557_0 -> 1780 in the cache */
   /* search1557_1_0 -> 260 in the cache */
   /* search1557_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1780, 4356 },
      -1,
   } },

   /* replace1557_0 -> 11 in the cache */
   /* replace1557_1_0 -> 260 in the cache */
   /* replace1557_1 -> 4358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4358 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1558_0_0 -> 11 in the cache */
   /* search1558_0 -> 1780 in the cache */
   /* search1558_1_0 -> 260 in the cache */
   /* search1558_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1780, 4356 },
      -1,
   } },

   /* replace1558_0 -> 11 in the cache */
   /* replace1558_1_0 -> 260 in the cache */
   /* replace1558_1 -> 4358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4358 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1559_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1559_1_0 -> 528 in the cache */
   /* search1559_1 -> 4351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4366, 4351 },
      -1,
   } },

   /* replace1559_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1559_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4368, 528 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1560_0_0 -> 517 in the cache */
   /* search1560_0 -> 4366 in the cache */
   /* search1560_1_0 -> 528 in the cache */
   /* search1560_1 -> 4351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4366, 4351 },
      -1,
   } },

   /* replace1560_0_0 -> 517 in the cache */
   /* replace1560_0 -> 4368 in the cache */
   /* replace1560_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4368, 528 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1561_0_0 -> 11 in the cache */
   /* search1561_0 -> 1780 in the cache */
   /* search1561_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1780, 33 },
      -1,
   } },

   /* replace1561_0_0 -> 11 in the cache */
   /* replace1561_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4373 },
      -1,
   } },
   /* replace1561_1_0_0_0 -> 36 in the cache */
   /* replace1561_1_0_0 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4373 },
      -1,
   } },
   /* replace1561_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4375, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4374, 4376 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1562_0_0 -> 11 in the cache */
   /* search1562_0 -> 1780 in the cache */
   /* search1562_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1780, 33 },
      -1,
   } },

   /* replace1562_0_0 -> 11 in the cache */
   /* replace1562_0_1_0 -> 36 in the cache */
   /* replace1562_0_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4373 },
      -1,
   } },
   /* replace1562_1_0_0_0 -> 36 in the cache */
   /* replace1562_1_0_0 -> 4373 in the cache */
   /* replace1562_1_0 -> 4375 in the cache */
   /* replace1562_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4375, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4379, 4380 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1563_0_0 -> 11 in the cache */
   /* search1563_0 -> 1780 in the cache */
   /* search1563_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1780, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1563_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4383, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1563_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4385, 36 },
      -1,
   } },
   /* replace1563_1_1_0 -> 11 in the cache */
   /* replace1563_1_1_1_0 -> 36 in the cache */
   /* replace1563_1_1_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4373 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4386, 4387 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4384, 4388 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1564_0 -> 288 in the cache */
   /* search1564_1_0 -> 260 in the cache */
   /* search1564_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 288, 4356 },
      -1,
   } },

   /* replace1564_0_0 -> 16 in the cache */
   /* replace1564_0_1 -> 4385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4385 },
      -1,
   } },
   /* replace1564_1_0_0 -> 16 in the cache */
   /* replace1564_1_0_1 -> 4383 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4383 },
      -1,
   } },
   /* replace1564_1_1_0_0 -> 16 in the cache */
   /* replace1564_1_1_0 -> 4188 in the cache */
   /* replace1564_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4188, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4392, 4393 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4391, 4394 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1565_0_0 -> 11 in the cache */
   /* search1565_0 -> 1780 in the cache */
   /* search1565_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1780, 33 },
      -1,
   } },

   /* replace1565_0_0 -> 4385 in the cache */
   /* replace1565_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4385, 36 },
      -1,
   } },
   /* replace1565_1_0_0 -> 4383 in the cache */
   /* replace1565_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4383, 36 },
      -1,
   } },
   /* replace1565_1_1_0 -> 11 in the cache */
   /* replace1565_1_1_1_0 -> 36 in the cache */
   /* replace1565_1_1_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4373 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4398, 4399 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4397, 4400 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1566_0 -> 288 in the cache */
   /* search1566_1_0 -> 260 in the cache */
   /* search1566_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 288, 4356 },
      -1,
   } },

   /* replace1566_0_0 -> 16 in the cache */
   /* replace1566_0_1 -> 4383 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4383 },
      -1,
   } },
   /* replace1566_1_0_0 -> 16 in the cache */
   /* replace1566_1_0_1 -> 4385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4385 },
      -1,
   } },
   /* replace1566_1_1_0_0 -> 16 in the cache */
   /* replace1566_1_1_0 -> 4188 in the cache */
   /* replace1566_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4188, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4404, 4405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4403, 4406 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1803 in the cache */
   /* search1567_1_0 -> 2093 in the cache */
   /* search1567_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1803, 4295 },
      -1,
   } },

   /* replace1567_0 -> 11 in the cache */
   /* replace1567_1_0 -> 2093 in the cache */
   /* replace1567_1 -> 4193 in the cache */
   /* replace1567 -> 4344 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1568_0_0 -> 11 in the cache */
   /* search1568_0 -> 1803 in the cache */
   /* search1568_1_0 -> 2093 in the cache */
   /* search1568_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1803, 4295 },
      -1,
   } },

   /* replace1568_0 -> 11 in the cache */
   /* replace1568_1_0 -> 2093 in the cache */
   /* replace1568_1 -> 4193 in the cache */
   /* replace1568 -> 4346 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1569_0_0 -> 11 in the cache */
   /* search1569_0 -> 1803 in the cache */
   /* search1569_1_0 -> 2093 in the cache */
   /* search1569_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1803, 4295 },
      -1,
   } },

   /* replace1569_0 -> 11 in the cache */
   /* replace1569_1_0 -> 2093 in the cache */
   /* replace1569_1 -> 4193 in the cache */
   /* replace1569 -> 4348 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1570_0_0 -> 11 in the cache */
   /* search1570_0 -> 1803 in the cache */
   /* search1570_1_0 -> 2093 in the cache */
   /* search1570_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1803, 4295 },
      -1,
   } },

   /* replace1570_0 -> 11 in the cache */
   /* replace1570_1_0 -> 2093 in the cache */
   /* replace1570_1 -> 4193 in the cache */
   /* replace1570 -> 4350 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1571_0_0 -> 4203 in the cache */
   /* search1571_0 -> 4300 in the cache */
   /* search1571_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4300, 4412 },
      -1,
   } },

   /* replace1571_0_0 -> 4203 in the cache */
   /* replace1571_0 -> 4204 in the cache */
   /* replace1571_1 -> 528 in the cache */
   /* replace1571 -> 4353 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1572_0_0 -> 4203 in the cache */
   /* search1572_0 -> 4300 in the cache */
   /* search1572_1_0 -> 528 in the cache */
   /* search1572_1 -> 4412 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4300, 4412 },
      -1,
   } },

   /* replace1572_0_0 -> 4203 in the cache */
   /* replace1572_0 -> 4204 in the cache */
   /* replace1572_1 -> 528 in the cache */
   /* replace1572 -> 4355 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1573_0_0 -> 11 in the cache */
   /* search1573_0 -> 1803 in the cache */
   /* search1573_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1803, 4415 },
      -1,
   } },

   /* replace1573_0 -> 11 in the cache */
   /* replace1573_1_0 -> 260 in the cache */
   /* replace1573_1 -> 4358 in the cache */
   /* replace1573 -> 4359 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1574_0_0 -> 11 in the cache */
   /* search1574_0 -> 1803 in the cache */
   /* search1574_1_0 -> 260 in the cache */
   /* search1574_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1803, 4415 },
      -1,
   } },

   /* replace1574_0 -> 11 in the cache */
   /* replace1574_1_0 -> 260 in the cache */
   /* replace1574_1 -> 4358 in the cache */
   /* replace1574 -> 4361 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1575_0_0 -> 11 in the cache */
   /* search1575_0 -> 1803 in the cache */
   /* search1575_1_0 -> 260 in the cache */
   /* search1575_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1803, 4415 },
      -1,
   } },

   /* replace1575_0 -> 11 in the cache */
   /* replace1575_1_0 -> 260 in the cache */
   /* replace1575_1 -> 4358 in the cache */
   /* replace1575 -> 4363 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1576_0_0 -> 11 in the cache */
   /* search1576_0 -> 1803 in the cache */
   /* search1576_1_0 -> 260 in the cache */
   /* search1576_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1803, 4415 },
      -1,
   } },

   /* replace1576_0 -> 11 in the cache */
   /* replace1576_1_0 -> 260 in the cache */
   /* replace1576_1 -> 4358 in the cache */
   /* replace1576 -> 4365 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1577_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1577_1_0 -> 528 in the cache */
   /* search1577_1 -> 4412 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4420, 4412 },
      -1,
   } },

   /* replace1577_0_0 -> 517 in the cache */
   /* replace1577_0 -> 4368 in the cache */
   /* replace1577_1 -> 528 in the cache */
   /* replace1577 -> 4369 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1578_0_0 -> 517 in the cache */
   /* search1578_0 -> 4420 in the cache */
   /* search1578_1_0 -> 528 in the cache */
   /* search1578_1 -> 4412 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4420, 4412 },
      -1,
   } },

   /* replace1578_0_0 -> 517 in the cache */
   /* replace1578_0 -> 4368 in the cache */
   /* replace1578_1 -> 528 in the cache */
   /* replace1578 -> 4371 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1579_0_0 -> 11 in the cache */
   /* search1579_0 -> 1803 in the cache */
   /* search1579_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1803, 4304 },
      -1,
   } },

   /* replace1579_0_0 -> 11 in the cache */
   /* replace1579_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4424 },
      -1,
   } },
   /* replace1579_1_0_0_0 -> 41 in the cache */
   /* replace1579_1_0_0 -> 4424 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4424 },
      -1,
   } },
   /* replace1579_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4426, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4425, 4427 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1580_0_0 -> 11 in the cache */
   /* search1580_0 -> 1803 in the cache */
   /* search1580_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1803, 4304 },
      -1,
   } },

   /* replace1580_0_0 -> 11 in the cache */
   /* replace1580_0_1_0 -> 41 in the cache */
   /* replace1580_0_1 -> 4424 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4424 },
      -1,
   } },
   /* replace1580_1_0_0_0 -> 41 in the cache */
   /* replace1580_1_0_0 -> 4424 in the cache */
   /* replace1580_1_0 -> 4426 in the cache */
   /* replace1580_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4426, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4430, 4431 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1581_0_0 -> 11 in the cache */
   /* search1581_0 -> 1803 in the cache */
   /* search1581_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1803, 4304 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1581_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4434, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1581_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4436, 41 },
      -1,
   } },
   /* replace1581_1_1_0 -> 11 in the cache */
   /* replace1581_1_1_1_0 -> 41 in the cache */
   /* replace1581_1_1_1 -> 4424 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4437, 4438 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4435, 4439 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1582_0 -> 4323 in the cache */
   /* search1582_1_0 -> 260 in the cache */
   /* search1582_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4323, 4415 },
      -1,
   } },

   /* replace1582_0_0 -> 21 in the cache */
   /* replace1582_0_1 -> 4436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4436 },
      -1,
   } },
   /* replace1582_1_0_0 -> 21 in the cache */
   /* replace1582_1_0_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4434 },
      -1,
   } },
   /* replace1582_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1582_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4444, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4443, 4445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4442, 4446 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1583_0_0 -> 11 in the cache */
   /* search1583_0 -> 1803 in the cache */
   /* search1583_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1803, 4304 },
      -1,
   } },

   /* replace1583_0_0 -> 4436 in the cache */
   /* replace1583_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4436, 41 },
      -1,
   } },
   /* replace1583_1_0_0 -> 4434 in the cache */
   /* replace1583_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4434, 41 },
      -1,
   } },
   /* replace1583_1_1_0 -> 11 in the cache */
   /* replace1583_1_1_1_0 -> 41 in the cache */
   /* replace1583_1_1_1 -> 4424 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4450, 4451 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4449, 4452 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1584_0 -> 4323 in the cache */
   /* search1584_1_0 -> 260 in the cache */
   /* search1584_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4323, 4415 },
      -1,
   } },

   /* replace1584_0_0 -> 21 in the cache */
   /* replace1584_0_1 -> 4434 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4434 },
      -1,
   } },
   /* replace1584_1_0_0 -> 21 in the cache */
   /* replace1584_1_0_1 -> 4436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4436 },
      -1,
   } },
   /* replace1584_1_1_0_0 -> 21 in the cache */
   /* replace1584_1_1_0 -> 4444 in the cache */
   /* replace1584_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4444, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4456, 4457 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4455, 4458 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1585_0_0 -> 16 in the cache */
   /* search1585_0 -> 1887 in the cache */
   /* search1585_1_0 -> 2093 in the cache */
   /* search1585_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1887, 4295 },
      -1,
   } },

   /* replace1585_0 -> 16 in the cache */
   /* replace1585_1_0 -> 2093 in the cache */
   /* replace1585_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4250 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1586_0_0 -> 16 in the cache */
   /* search1586_0 -> 1887 in the cache */
   /* search1586_1_0 -> 2093 in the cache */
   /* search1586_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1887, 4295 },
      -1,
   } },

   /* replace1586_0 -> 16 in the cache */
   /* replace1586_1_0 -> 2093 in the cache */
   /* replace1586_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4250 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1587_0_0 -> 16 in the cache */
   /* search1587_0 -> 1887 in the cache */
   /* search1587_1_0 -> 2093 in the cache */
   /* search1587_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1887, 4295 },
      -1,
   } },

   /* replace1587_0 -> 16 in the cache */
   /* replace1587_1_0 -> 2093 in the cache */
   /* replace1587_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4250 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1588_0_0 -> 16 in the cache */
   /* search1588_0 -> 1887 in the cache */
   /* search1588_1_0 -> 2093 in the cache */
   /* search1588_1 -> 4295 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1887, 4295 },
      -1,
   } },

   /* replace1588_0 -> 16 in the cache */
   /* replace1588_1_0 -> 2093 in the cache */
   /* replace1588_1 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4250 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1589_0_0 -> 4203 in the cache */
   /* search1589_0 -> 4300 in the cache */
   /* search1589_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4300, 4468 },
      -1,
   } },

   /* replace1589_0_0 -> 4203 in the cache */
   /* replace1589_0 -> 4255 in the cache */
   /* replace1589_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4255, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1590_0_0 -> 4203 in the cache */
   /* search1590_0 -> 4300 in the cache */
   /* search1590_1_0 -> 185 in the cache */
   /* search1590_1 -> 4468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4300, 4468 },
      -1,
   } },

   /* replace1590_0_0 -> 4203 in the cache */
   /* replace1590_0 -> 4255 in the cache */
   /* replace1590_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4255, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1591_0_0 -> 16 in the cache */
   /* search1591_0 -> 1887 in the cache */
   /* search1591_1_0 -> 260 in the cache */
   /* search1591_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1887, 4415 },
      -1,
   } },

   /* replace1591_0 -> 16 in the cache */
   /* replace1591_1_0 -> 260 in the cache */
   /* replace1591_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4356 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1592_0_0 -> 16 in the cache */
   /* search1592_0 -> 1887 in the cache */
   /* search1592_1_0 -> 260 in the cache */
   /* search1592_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1887, 4415 },
      -1,
   } },

   /* replace1592_0 -> 16 in the cache */
   /* replace1592_1_0 -> 260 in the cache */
   /* replace1592_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4356 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1593_0_0 -> 16 in the cache */
   /* search1593_0 -> 1887 in the cache */
   /* search1593_1_0 -> 260 in the cache */
   /* search1593_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1887, 4415 },
      -1,
   } },

   /* replace1593_0 -> 16 in the cache */
   /* replace1593_1_0 -> 260 in the cache */
   /* replace1593_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4356 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1594_0_0 -> 16 in the cache */
   /* search1594_0 -> 1887 in the cache */
   /* search1594_1_0 -> 260 in the cache */
   /* search1594_1 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1887, 4415 },
      -1,
   } },

   /* replace1594_0 -> 16 in the cache */
   /* replace1594_1_0 -> 260 in the cache */
   /* replace1594_1 -> 4356 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4356 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1595_0_0 -> 517 in the cache */
   /* search1595_0 -> 4420 in the cache */
   /* search1595_1_0 -> 185 in the cache */
   /* search1595_1 -> 4468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4420, 4468 },
      -1,
   } },

   /* replace1595_0_0 -> 517 in the cache */
   /* replace1595_0 -> 4366 in the cache */
   /* replace1595_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4366, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1596_0_0 -> 517 in the cache */
   /* search1596_0 -> 4420 in the cache */
   /* search1596_1_0 -> 185 in the cache */
   /* search1596_1 -> 4468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4420, 4468 },
      -1,
   } },

   /* replace1596_0_0 -> 517 in the cache */
   /* replace1596_0 -> 4366 in the cache */
   /* replace1596_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4366, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1597_0_0 -> 16 in the cache */
   /* search1597_0 -> 1887 in the cache */
   /* search1597_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1887, 4485 },
      -1,
   } },

   /* replace1597_0 -> 16 in the cache */
   /* replace1597_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4487 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1598_0_0 -> 16 in the cache */
   /* search1598_0 -> 1887 in the cache */
   /* search1598_1_0 -> 36 in the cache */
   /* search1598_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1887, 4485 },
      -1,
   } },

   /* replace1598_0 -> 16 in the cache */
   /* replace1598_1_0 -> 36 in the cache */
   /* replace1598_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4487 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1599_0_0 -> 16 in the cache */
   /* search1599_0 -> 1887 in the cache */
   /* search1599_1_0 -> 36 in the cache */
   /* search1599_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1887, 4485 },
      -1,
   } },

   /* replace1599_0 -> 16 in the cache */
   /* replace1599_1_0 -> 36 in the cache */
   /* replace1599_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4487 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1600_0_0 -> 16 in the cache */
   /* search1600_0 -> 1887 in the cache */
   /* search1600_1_0 -> 36 in the cache */
   /* search1600_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1887, 4485 },
      -1,
   } },

   /* replace1600_0 -> 16 in the cache */
   /* replace1600_1_0 -> 36 in the cache */
   /* replace1600_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4487 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1601_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1601_1_0 -> 185 in the cache */
   /* search1601_1 -> 4468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4495, 4468 },
      -1,
   } },

   /* replace1601_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1601_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4497, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1602_0_0 -> 375 in the cache */
   /* search1602_0 -> 4495 in the cache */
   /* search1602_1_0 -> 185 in the cache */
   /* search1602_1 -> 4468 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4495, 4468 },
      -1,
   } },

   /* replace1602_0_0 -> 375 in the cache */
   /* replace1602_0 -> 4497 in the cache */
   /* replace1602_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4497, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1603_0_0 -> 16 in the cache */
   /* search1603_0 -> 1887 in the cache */
   /* search1603_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1887, 4304 },
      -1,
   } },

   /* replace1603_0_0 -> 16 in the cache */
   /* replace1603_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4502 },
      -1,
   } },
   /* replace1603_1_0_0_0 -> 41 in the cache */
   /* replace1603_1_0_0 -> 4502 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4502 },
      -1,
   } },
   /* replace1603_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4504, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4503, 4505 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1604_0_0 -> 16 in the cache */
   /* search1604_0 -> 1887 in the cache */
   /* search1604_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1887, 4304 },
      -1,
   } },

   /* replace1604_0_0 -> 16 in the cache */
   /* replace1604_0_1_0 -> 41 in the cache */
   /* replace1604_0_1 -> 4502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4502 },
      -1,
   } },
   /* replace1604_1_0_0_0 -> 41 in the cache */
   /* replace1604_1_0_0 -> 4502 in the cache */
   /* replace1604_1_0 -> 4504 in the cache */
   /* replace1604_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4504, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4508, 4509 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1605_0_0 -> 16 in the cache */
   /* search1605_0 -> 1887 in the cache */
   /* search1605_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1887, 4304 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1605_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4512, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1605_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4514, 41 },
      -1,
   } },
   /* replace1605_1_1_0 -> 16 in the cache */
   /* replace1605_1_1_1_0 -> 41 in the cache */
   /* replace1605_1_1_1 -> 4502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4515, 4516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4513, 4517 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1606_0 -> 4323 in the cache */
   /* search1606_1_0 -> 36 in the cache */
   /* search1606_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4323, 4485 },
      -1,
   } },

   /* replace1606_0_0 -> 21 in the cache */
   /* replace1606_0_1 -> 4514 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4514 },
      -1,
   } },
   /* replace1606_1_0_0 -> 21 in the cache */
   /* replace1606_1_0_1 -> 4512 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4512 },
      -1,
   } },
   /* replace1606_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1606_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4522, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4521, 4523 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4520, 4524 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1607_0_0 -> 16 in the cache */
   /* search1607_0 -> 1887 in the cache */
   /* search1607_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1887, 4304 },
      -1,
   } },

   /* replace1607_0_0 -> 4514 in the cache */
   /* replace1607_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4514, 41 },
      -1,
   } },
   /* replace1607_1_0_0 -> 4512 in the cache */
   /* replace1607_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4512, 41 },
      -1,
   } },
   /* replace1607_1_1_0 -> 16 in the cache */
   /* replace1607_1_1_1_0 -> 41 in the cache */
   /* replace1607_1_1_1 -> 4502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4528, 4529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4527, 4530 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1608_0 -> 4323 in the cache */
   /* search1608_1_0 -> 36 in the cache */
   /* search1608_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4323, 4485 },
      -1,
   } },

   /* replace1608_0_0 -> 21 in the cache */
   /* replace1608_0_1 -> 4512 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4512 },
      -1,
   } },
   /* replace1608_1_0_0 -> 21 in the cache */
   /* replace1608_1_0_1 -> 4514 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4514 },
      -1,
   } },
   /* replace1608_1_1_0_0 -> 21 in the cache */
   /* replace1608_1_1_0 -> 4522 in the cache */
   /* replace1608_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4522, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4534, 4535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4533, 4536 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1609_0_0 -> 6 in the cache */
   /* search1609_0 -> 4133 in the cache */
   /* search1609_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4133, 4538 },
      -1,
   } },

   /* replace1609_0 -> 6 in the cache */
   /* replace1609_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4540 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1610_0_0 -> 6 in the cache */
   /* search1610_0 -> 4133 in the cache */
   /* search1610_1_0 -> 2093 in the cache */
   /* search1610_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4133, 4538 },
      -1,
   } },

   /* replace1610_0 -> 6 in the cache */
   /* replace1610_1_0 -> 2093 in the cache */
   /* replace1610_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4540 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1611_0_0 -> 6 in the cache */
   /* search1611_0 -> 4133 in the cache */
   /* search1611_1_0 -> 2093 in the cache */
   /* search1611_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4133, 4538 },
      -1,
   } },

   /* replace1611_0 -> 6 in the cache */
   /* replace1611_1_0 -> 2093 in the cache */
   /* replace1611_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4540 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1612_0_0 -> 6 in the cache */
   /* search1612_0 -> 4133 in the cache */
   /* search1612_1_0 -> 2093 in the cache */
   /* search1612_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4133, 4538 },
      -1,
   } },

   /* replace1612_0 -> 6 in the cache */
   /* replace1612_1_0 -> 2093 in the cache */
   /* replace1612_1 -> 4540 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4540 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1613_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* search1613_1_0 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4548, 4549 },
      -1,
   } },

   /* replace1613_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* replace1613_1 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4551, 4205 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1614_0_0 -> 4203 in the cache */
   /* search1614_0 -> 4548 in the cache */
   /* search1614_1_0 -> 4205 in the cache */
   /* search1614_1 -> 4549 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4548, 4549 },
      -1,
   } },

   /* replace1614_0_0 -> 4203 in the cache */
   /* replace1614_0 -> 4551 in the cache */
   /* replace1614_1 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4551, 4205 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1615_0_0 -> 6 in the cache */
   /* search1615_0 -> 4133 in the cache */
   /* search1615_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4133, 1992 },
      -1,
   } },

   /* replace1615_0_0 -> 6 in the cache */
   /* replace1615_0_1_0 -> 260 in the cache */
   /* replace1615_0_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2000 },
      -1,
   } },
   /* replace1615_1_0_0_0 -> 260 in the cache */
   /* replace1615_1_0_0 -> 2000 in the cache */
   /* replace1615_1_0 -> 2001 in the cache */
   /* replace1615_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2001, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4556, 4557 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1616_0_0 -> 6 in the cache */
   /* search1616_0 -> 4133 in the cache */
   /* search1616_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4133, 1992 },
      -1,
   } },

   /* replace1616_0_0 -> 6 in the cache */
   /* replace1616_0_1_0 -> 260 in the cache */
   /* replace1616_0_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2000 },
      -1,
   } },
   /* replace1616_1_0_0_0 -> 260 in the cache */
   /* replace1616_1_0_0 -> 2000 in the cache */
   /* replace1616_1_0 -> 2001 in the cache */
   /* replace1616_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2001, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4560, 4561 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1617_0_0 -> 6 in the cache */
   /* search1617_0 -> 4133 in the cache */
   /* search1617_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4133, 1992 },
      -1,
   } },

   /* replace1617_0_0 -> 835 in the cache */
   /* replace1617_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 835, 260 },
      -1,
   } },
   /* replace1617_1_0_0 -> 1994 in the cache */
   /* replace1617_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1994, 260 },
      -1,
   } },
   /* replace1617_1_1_0 -> 6 in the cache */
   /* replace1617_1_1_1_0 -> 260 in the cache */
   /* replace1617_1_1_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4565, 4566 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4564, 4567 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1618_0 -> 4230 in the cache */
   /* search1618_1_0 -> 2093 in the cache */
   /* search1618_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4230, 4538 },
      -1,
   } },

   /* replace1618_0_0 -> 11 in the cache */
   /* replace1618_0_1 -> 1994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 1994 },
      -1,
   } },
   /* replace1618_1_0_0 -> 11 in the cache */
   /* replace1618_1_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 835 },
      -1,
   } },
   /* replace1618_1_1_0_0 -> 11 in the cache */
   /* replace1618_1_1_0 -> 1990 in the cache */
   /* replace1618_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1990, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4571, 4572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4570, 4573 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1619_0_0 -> 6 in the cache */
   /* search1619_0 -> 4133 in the cache */
   /* search1619_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4133, 1992 },
      -1,
   } },

   /* replace1619_0_0 -> 1994 in the cache */
   /* replace1619_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1994, 260 },
      -1,
   } },
   /* replace1619_1_0_0 -> 835 in the cache */
   /* replace1619_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 835, 260 },
      -1,
   } },
   /* replace1619_1_1_0 -> 6 in the cache */
   /* replace1619_1_1_1_0 -> 260 in the cache */
   /* replace1619_1_1_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4577, 4578 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4576, 4579 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1620_0 -> 4230 in the cache */
   /* search1620_1_0 -> 2093 in the cache */
   /* search1620_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4230, 4538 },
      -1,
   } },

   /* replace1620_0_0 -> 11 in the cache */
   /* replace1620_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 835 },
      -1,
   } },
   /* replace1620_1_0_0 -> 11 in the cache */
   /* replace1620_1_0_1 -> 1994 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 1994 },
      -1,
   } },
   /* replace1620_1_1_0_0 -> 11 in the cache */
   /* replace1620_1_1_0 -> 1990 in the cache */
   /* replace1620_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1990, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4583, 4584 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4582, 4585 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1621_0_0 -> 6 in the cache */
   /* search1621_0 -> 3202 in the cache */
   /* search1621_1_0 -> 2093 in the cache */
   /* search1621_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3202, 3204 },
      -1,
   } },

   /* replace1621_0 -> 6 in the cache */
   /* replace1621_1_0 -> 2093 in the cache */
   /* replace1621_1 -> 4540 in the cache */
   /* replace1621 -> 4541 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1622_0_0 -> 6 in the cache */
   /* search1622_0 -> 3202 in the cache */
   /* search1622_1_0 -> 2093 in the cache */
   /* search1622_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3202, 3204 },
      -1,
   } },

   /* replace1622_0 -> 6 in the cache */
   /* replace1622_1_0 -> 2093 in the cache */
   /* replace1622_1 -> 4540 in the cache */
   /* replace1622 -> 4543 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1623_0_0 -> 6 in the cache */
   /* search1623_0 -> 3202 in the cache */
   /* search1623_1_0 -> 2093 in the cache */
   /* search1623_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3202, 3204 },
      -1,
   } },

   /* replace1623_0 -> 6 in the cache */
   /* replace1623_1_0 -> 2093 in the cache */
   /* replace1623_1 -> 4540 in the cache */
   /* replace1623 -> 4545 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1624_0_0 -> 6 in the cache */
   /* search1624_0 -> 3202 in the cache */
   /* search1624_1_0 -> 2093 in the cache */
   /* search1624_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3202, 3204 },
      -1,
   } },

   /* replace1624_0 -> 6 in the cache */
   /* replace1624_1_0 -> 2093 in the cache */
   /* replace1624_1 -> 4540 in the cache */
   /* replace1624 -> 4547 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1625_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* search1625_1_0 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4591, 4592 },
      -1,
   } },

   /* replace1625_0_0 -> 4203 in the cache */
   /* replace1625_0 -> 4551 in the cache */
   /* replace1625_1 -> 4205 in the cache */
   /* replace1625 -> 4552 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1626_0_0 -> 4203 in the cache */
   /* search1626_0 -> 4591 in the cache */
   /* search1626_1_0 -> 4205 in the cache */
   /* search1626_1 -> 4592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4591, 4592 },
      -1,
   } },

   /* replace1626_0_0 -> 4203 in the cache */
   /* replace1626_0 -> 4551 in the cache */
   /* replace1626_1 -> 4205 in the cache */
   /* replace1626 -> 4554 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1627_0_0 -> 6 in the cache */
   /* search1627_0 -> 3202 in the cache */
   /* search1627_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3202, 33 },
      -1,
   } },

   /* replace1627_0_0 -> 6 in the cache */
   /* replace1627_0_1_0 -> 36 in the cache */
   /* replace1627_0_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2008 },
      -1,
   } },
   /* replace1627_1_0_0_0 -> 36 in the cache */
   /* replace1627_1_0_0 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2008 },
      -1,
   } },
   /* replace1627_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4597, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4596, 4598 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1628_0_0 -> 6 in the cache */
   /* search1628_0 -> 3202 in the cache */
   /* search1628_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3202, 33 },
      -1,
   } },

   /* replace1628_0_0 -> 6 in the cache */
   /* replace1628_0_1_0 -> 36 in the cache */
   /* replace1628_0_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2008 },
      -1,
   } },
   /* replace1628_1_0_0_0 -> 36 in the cache */
   /* replace1628_1_0_0 -> 2008 in the cache */
   /* replace1628_1_0 -> 4597 in the cache */
   /* replace1628_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4597, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4601, 4602 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1629_0_0 -> 6 in the cache */
   /* search1629_0 -> 3202 in the cache */
   /* search1629_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3202, 33 },
      -1,
   } },

   /* replace1629_0_0 -> 124 in the cache */
   /* replace1629_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   /* replace1629_1_0_0 -> 989 in the cache */
   /* replace1629_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 989, 36 },
      -1,
   } },
   /* replace1629_1_1_0 -> 6 in the cache */
   /* replace1629_1_1_1_0 -> 36 in the cache */
   /* replace1629_1_1_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4606, 4607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4605, 4608 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1630_0 -> 288 in the cache */
   /* search1630_1_0 -> 2093 in the cache */
   /* search1630_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 288, 3204 },
      -1,
   } },

   /* replace1630_0_0 -> 16 in the cache */
   /* replace1630_0_1 -> 989 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 989 },
      -1,
   } },
   /* replace1630_1_0_0 -> 16 in the cache */
   /* replace1630_1_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace1630_1_1_0_0 -> 16 in the cache */
   /* replace1630_1_1_0 -> 2006 in the cache */
   /* replace1630_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2006, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4612, 4613 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4611, 4614 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1631_0_0 -> 6 in the cache */
   /* search1631_0 -> 3202 in the cache */
   /* search1631_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3202, 33 },
      -1,
   } },

   /* replace1631_0_0 -> 989 in the cache */
   /* replace1631_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 989, 36 },
      -1,
   } },
   /* replace1631_1_0_0 -> 124 in the cache */
   /* replace1631_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   /* replace1631_1_1_0 -> 6 in the cache */
   /* replace1631_1_1_1_0 -> 36 in the cache */
   /* replace1631_1_1_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4618, 4619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4617, 4620 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1632_0 -> 288 in the cache */
   /* search1632_1_0 -> 2093 in the cache */
   /* search1632_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 288, 3204 },
      -1,
   } },

   /* replace1632_0_0 -> 16 in the cache */
   /* replace1632_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace1632_1_0_0 -> 16 in the cache */
   /* replace1632_1_0_1 -> 989 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 989 },
      -1,
   } },
   /* replace1632_1_1_0_0 -> 16 in the cache */
   /* replace1632_1_1_0 -> 2006 in the cache */
   /* replace1632_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2006, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4624, 4625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4623, 4626 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1633_0_0 -> 6 in the cache */
   /* search1633_0 -> 4170 in the cache */
   /* search1633_1_0 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4170, 4628 },
      -1,
   } },

   /* replace1633_0 -> 6 in the cache */
   /* replace1633_1_0 -> 2093 in the cache */
   /* replace1633_1 -> 4540 in the cache */
   /* replace1633 -> 4541 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1634_0_0 -> 6 in the cache */
   /* search1634_0 -> 4170 in the cache */
   /* search1634_1_0 -> 2093 in the cache */
   /* search1634_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4170, 4628 },
      -1,
   } },

   /* replace1634_0 -> 6 in the cache */
   /* replace1634_1_0 -> 2093 in the cache */
   /* replace1634_1 -> 4540 in the cache */
   /* replace1634 -> 4543 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1635_0_0 -> 6 in the cache */
   /* search1635_0 -> 4170 in the cache */
   /* search1635_1_0 -> 2093 in the cache */
   /* search1635_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4170, 4628 },
      -1,
   } },

   /* replace1635_0 -> 6 in the cache */
   /* replace1635_1_0 -> 2093 in the cache */
   /* replace1635_1 -> 4540 in the cache */
   /* replace1635 -> 4545 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1636_0_0 -> 6 in the cache */
   /* search1636_0 -> 4170 in the cache */
   /* search1636_1_0 -> 2093 in the cache */
   /* search1636_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4170, 4628 },
      -1,
   } },

   /* replace1636_0 -> 6 in the cache */
   /* replace1636_1_0 -> 2093 in the cache */
   /* replace1636_1 -> 4540 in the cache */
   /* replace1636 -> 4547 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1637_0_0 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4203 },
      -1,
   } },
   /* search1637_1_0 -> 4205 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4633, 4634 },
      -1,
   } },

   /* replace1637_0_0 -> 4203 in the cache */
   /* replace1637_0 -> 4551 in the cache */
   /* replace1637_1 -> 4205 in the cache */
   /* replace1637 -> 4552 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1638_0_0 -> 4203 in the cache */
   /* search1638_0 -> 4633 in the cache */
   /* search1638_1_0 -> 4205 in the cache */
   /* search1638_1 -> 4634 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4633, 4634 },
      -1,
   } },

   /* replace1638_0_0 -> 4203 in the cache */
   /* replace1638_0 -> 4551 in the cache */
   /* replace1638_1 -> 4205 in the cache */
   /* replace1638 -> 4554 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1639_0_0 -> 6 in the cache */
   /* search1639_0 -> 4170 in the cache */
   /* search1639_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4170, 4304 },
      -1,
   } },

   /* replace1639_0_0 -> 6 in the cache */
   /* replace1639_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4638 },
      -1,
   } },
   /* replace1639_1_0_0_0 -> 41 in the cache */
   /* replace1639_1_0_0 -> 4638 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4638 },
      -1,
   } },
   /* replace1639_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4640, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4639, 4641 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1640_0_0 -> 6 in the cache */
   /* search1640_0 -> 4170 in the cache */
   /* search1640_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4170, 4304 },
      -1,
   } },

   /* replace1640_0_0 -> 6 in the cache */
   /* replace1640_0_1_0 -> 41 in the cache */
   /* replace1640_0_1 -> 4638 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4638 },
      -1,
   } },
   /* replace1640_1_0_0_0 -> 41 in the cache */
   /* replace1640_1_0_0 -> 4638 in the cache */
   /* replace1640_1_0 -> 4640 in the cache */
   /* replace1640_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4640, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4644, 4645 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1641_0_0 -> 6 in the cache */
   /* search1641_0 -> 4170 in the cache */
   /* search1641_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4170, 4304 },
      -1,
   } },

   /* replace1641_0_0 -> 876 in the cache */
   /* replace1641_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 876, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1641_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4649, 41 },
      -1,
   } },
   /* replace1641_1_1_0 -> 6 in the cache */
   /* replace1641_1_1_1_0 -> 41 in the cache */
   /* replace1641_1_1_1 -> 4638 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4650, 4651 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4648, 4652 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1642_0 -> 4323 in the cache */
   /* search1642_1_0 -> 2093 in the cache */
   /* search1642_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4323, 4628 },
      -1,
   } },

   /* replace1642_0_0 -> 21 in the cache */
   /* replace1642_0_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4649 },
      -1,
   } },
   /* replace1642_1_0_0 -> 21 in the cache */
   /* replace1642_1_0_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 876 },
      -1,
   } },
   /* replace1642_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1642_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4657, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4656, 4658 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4655, 4659 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1643_0_0 -> 6 in the cache */
   /* search1643_0 -> 4170 in the cache */
   /* search1643_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4170, 4304 },
      -1,
   } },

   /* replace1643_0_0 -> 4649 in the cache */
   /* replace1643_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4649, 41 },
      -1,
   } },
   /* replace1643_1_0_0 -> 876 in the cache */
   /* replace1643_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 876, 41 },
      -1,
   } },
   /* replace1643_1_1_0 -> 6 in the cache */
   /* replace1643_1_1_1_0 -> 41 in the cache */
   /* replace1643_1_1_1 -> 4638 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4663, 4664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4662, 4665 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1644_0 -> 4323 in the cache */
   /* search1644_1_0 -> 2093 in the cache */
   /* search1644_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4323, 4628 },
      -1,
   } },

   /* replace1644_0_0 -> 21 in the cache */
   /* replace1644_0_1 -> 876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 876 },
      -1,
   } },
   /* replace1644_1_0_0 -> 21 in the cache */
   /* replace1644_1_0_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4649 },
      -1,
   } },
   /* replace1644_1_1_0_0 -> 21 in the cache */
   /* replace1644_1_1_0 -> 4657 in the cache */
   /* replace1644_1_1_1 -> 2093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4657, 2093 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4669, 4670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4668, 4671 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1645_0_0 -> 11 in the cache */
   /* search1645_0 -> 1782 in the cache */
   /* search1645_1_0 -> 2093 in the cache */
   /* search1645_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1782, 3204 },
      -1,
   } },

   /* replace1645_0 -> 11 in the cache */
   /* replace1645_1_0 -> 2093 in the cache */
   /* replace1645_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4538 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1646_0_0 -> 11 in the cache */
   /* search1646_0 -> 1782 in the cache */
   /* search1646_1_0 -> 2093 in the cache */
   /* search1646_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1782, 3204 },
      -1,
   } },

   /* replace1646_0 -> 11 in the cache */
   /* replace1646_1_0 -> 2093 in the cache */
   /* replace1646_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4538 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1647_0_0 -> 11 in the cache */
   /* search1647_0 -> 1782 in the cache */
   /* search1647_1_0 -> 2093 in the cache */
   /* search1647_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1782, 3204 },
      -1,
   } },

   /* replace1647_0 -> 11 in the cache */
   /* replace1647_1_0 -> 2093 in the cache */
   /* replace1647_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4538 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1648_0_0 -> 11 in the cache */
   /* search1648_0 -> 1782 in the cache */
   /* search1648_1_0 -> 2093 in the cache */
   /* search1648_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1782, 3204 },
      -1,
   } },

   /* replace1648_0 -> 11 in the cache */
   /* replace1648_1_0 -> 2093 in the cache */
   /* replace1648_1 -> 4538 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4538 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1649_0_0 -> 4203 in the cache */
   /* search1649_0 -> 4591 in the cache */
   /* search1649_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4591, 4681 },
      -1,
   } },

   /* replace1649_0_0 -> 4203 in the cache */
   /* replace1649_0 -> 4548 in the cache */
   /* replace1649_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4548, 528 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1650_0_0 -> 4203 in the cache */
   /* search1650_0 -> 4591 in the cache */
   /* search1650_1_0 -> 528 in the cache */
   /* search1650_1 -> 4681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4591, 4681 },
      -1,
   } },

   /* replace1650_0_0 -> 4203 in the cache */
   /* replace1650_0 -> 4548 in the cache */
   /* replace1650_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4548, 528 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1651_0_0 -> 11 in the cache */
   /* search1651_0 -> 1782 in the cache */
   /* search1651_1_0 -> 260 in the cache */
   /* search1651_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1782, 3224 },
      -1,
   } },

   /* replace1651_0 -> 11 in the cache */
   /* replace1651_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4687 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1652_0_0 -> 11 in the cache */
   /* search1652_0 -> 1782 in the cache */
   /* search1652_1_0 -> 260 in the cache */
   /* search1652_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1782, 3224 },
      -1,
   } },

   /* replace1652_0 -> 11 in the cache */
   /* replace1652_1_0 -> 260 in the cache */
   /* replace1652_1 -> 4687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4687 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1653_0_0 -> 11 in the cache */
   /* search1653_0 -> 1782 in the cache */
   /* search1653_1_0 -> 260 in the cache */
   /* search1653_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1782, 3224 },
      -1,
   } },

   /* replace1653_0 -> 11 in the cache */
   /* replace1653_1_0 -> 260 in the cache */
   /* replace1653_1 -> 4687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4687 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1654_0_0 -> 11 in the cache */
   /* search1654_0 -> 1782 in the cache */
   /* search1654_1_0 -> 260 in the cache */
   /* search1654_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1782, 3224 },
      -1,
   } },

   /* replace1654_0 -> 11 in the cache */
   /* replace1654_1_0 -> 260 in the cache */
   /* replace1654_1 -> 4687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4687 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1655_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1655_1_0 -> 528 in the cache */
   /* search1655_1 -> 4681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4695, 4681 },
      -1,
   } },

   /* replace1655_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1655_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4697, 528 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1656_0_0 -> 517 in the cache */
   /* search1656_0 -> 4695 in the cache */
   /* search1656_1_0 -> 528 in the cache */
   /* search1656_1 -> 4681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4695, 4681 },
      -1,
   } },

   /* replace1656_0_0 -> 517 in the cache */
   /* replace1656_0 -> 4697 in the cache */
   /* replace1656_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4697, 528 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1657_0_0 -> 11 in the cache */
   /* search1657_0 -> 1782 in the cache */
   /* search1657_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1782, 33 },
      -1,
   } },

   /* replace1657_0_0 -> 11 in the cache */
   /* replace1657_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4702 },
      -1,
   } },
   /* replace1657_1_0_0_0 -> 36 in the cache */
   /* replace1657_1_0_0 -> 4702 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4702 },
      -1,
   } },
   /* replace1657_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4704, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4703, 4705 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1658_0_0 -> 11 in the cache */
   /* search1658_0 -> 1782 in the cache */
   /* search1658_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1782, 33 },
      -1,
   } },

   /* replace1658_0_0 -> 11 in the cache */
   /* replace1658_0_1_0 -> 36 in the cache */
   /* replace1658_0_1 -> 4702 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4702 },
      -1,
   } },
   /* replace1658_1_0_0_0 -> 36 in the cache */
   /* replace1658_1_0_0 -> 4702 in the cache */
   /* replace1658_1_0 -> 4704 in the cache */
   /* replace1658_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4704, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4708, 4709 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1659_0_0 -> 11 in the cache */
   /* search1659_0 -> 1782 in the cache */
   /* search1659_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1782, 33 },
      -1,
   } },

   /* replace1659_0_0 -> 124 in the cache */
   /* replace1659_0_1 -> 36 in the cache */
   /* replace1659_0 -> 4605 in the cache */
   /* replace1659_1_0_0 -> 981 in the cache */
   /* replace1659_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 981, 36 },
      -1,
   } },
   /* replace1659_1_1_0 -> 11 in the cache */
   /* replace1659_1_1_1_0 -> 36 in the cache */
   /* replace1659_1_1_1 -> 4702 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4712, 4713 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4605, 4714 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1660_0 -> 288 in the cache */
   /* search1660_1_0 -> 260 in the cache */
   /* search1660_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 288, 3224 },
      -1,
   } },

   /* replace1660_0_0 -> 16 in the cache */
   /* replace1660_0_1 -> 981 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 981 },
      -1,
   } },
   /* replace1660_1_0_0 -> 16 in the cache */
   /* replace1660_1_0_1 -> 124 in the cache */
   /* replace1660_1_0 -> 4612 in the cache */
   /* replace1660_1_1_0_0 -> 16 in the cache */
   /* replace1660_1_1_0 -> 3230 in the cache */
   /* replace1660_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3230, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4612, 4718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4717, 4719 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1661_0_0 -> 11 in the cache */
   /* search1661_0 -> 1782 in the cache */
   /* search1661_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1782, 33 },
      -1,
   } },

   /* replace1661_0_0 -> 981 in the cache */
   /* replace1661_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 981, 36 },
      -1,
   } },
   /* replace1661_1_0_0 -> 124 in the cache */
   /* replace1661_1_0_1 -> 36 in the cache */
   /* replace1661_1_0 -> 4618 in the cache */
   /* replace1661_1_1_0 -> 11 in the cache */
   /* replace1661_1_1_1_0 -> 36 in the cache */
   /* replace1661_1_1_1 -> 4702 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4618, 4723 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4722, 4724 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1662_0 -> 288 in the cache */
   /* search1662_1_0 -> 260 in the cache */
   /* search1662_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 288, 3224 },
      -1,
   } },

   /* replace1662_0_0 -> 16 in the cache */
   /* replace1662_0_1 -> 124 in the cache */
   /* replace1662_0 -> 4623 in the cache */
   /* replace1662_1_0_0 -> 16 in the cache */
   /* replace1662_1_0_1 -> 981 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 981 },
      -1,
   } },
   /* replace1662_1_1_0_0 -> 16 in the cache */
   /* replace1662_1_1_0 -> 3230 in the cache */
   /* replace1662_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3230, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4727, 4728 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4623, 4729 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1663_0_0 -> 11 in the cache */
   /* search1663_0 -> 1805 in the cache */
   /* search1663_1_0 -> 2093 in the cache */
   /* search1663_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1805, 4628 },
      -1,
   } },

   /* replace1663_0 -> 11 in the cache */
   /* replace1663_1_0 -> 2093 in the cache */
   /* replace1663_1 -> 4538 in the cache */
   /* replace1663 -> 4674 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1664_0_0 -> 11 in the cache */
   /* search1664_0 -> 1805 in the cache */
   /* search1664_1_0 -> 2093 in the cache */
   /* search1664_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1805, 4628 },
      -1,
   } },

   /* replace1664_0 -> 11 in the cache */
   /* replace1664_1_0 -> 2093 in the cache */
   /* replace1664_1 -> 4538 in the cache */
   /* replace1664 -> 4676 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1665_0_0 -> 11 in the cache */
   /* search1665_0 -> 1805 in the cache */
   /* search1665_1_0 -> 2093 in the cache */
   /* search1665_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1805, 4628 },
      -1,
   } },

   /* replace1665_0 -> 11 in the cache */
   /* replace1665_1_0 -> 2093 in the cache */
   /* replace1665_1 -> 4538 in the cache */
   /* replace1665 -> 4678 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1666_0_0 -> 11 in the cache */
   /* search1666_0 -> 1805 in the cache */
   /* search1666_1_0 -> 2093 in the cache */
   /* search1666_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1805, 4628 },
      -1,
   } },

   /* replace1666_0 -> 11 in the cache */
   /* replace1666_1_0 -> 2093 in the cache */
   /* replace1666_1 -> 4538 in the cache */
   /* replace1666 -> 4680 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1667_0_0 -> 4203 in the cache */
   /* search1667_0 -> 4633 in the cache */
   /* search1667_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4633, 4735 },
      -1,
   } },

   /* replace1667_0_0 -> 4203 in the cache */
   /* replace1667_0 -> 4548 in the cache */
   /* replace1667_1 -> 528 in the cache */
   /* replace1667 -> 4683 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1668_0_0 -> 4203 in the cache */
   /* search1668_0 -> 4633 in the cache */
   /* search1668_1_0 -> 528 in the cache */
   /* search1668_1 -> 4735 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4633, 4735 },
      -1,
   } },

   /* replace1668_0_0 -> 4203 in the cache */
   /* replace1668_0 -> 4548 in the cache */
   /* replace1668_1 -> 528 in the cache */
   /* replace1668 -> 4685 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1669_0_0 -> 11 in the cache */
   /* search1669_0 -> 1805 in the cache */
   /* search1669_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1805, 4738 },
      -1,
   } },

   /* replace1669_0 -> 11 in the cache */
   /* replace1669_1_0 -> 260 in the cache */
   /* replace1669_1 -> 4687 in the cache */
   /* replace1669 -> 4688 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1670_0_0 -> 11 in the cache */
   /* search1670_0 -> 1805 in the cache */
   /* search1670_1_0 -> 260 in the cache */
   /* search1670_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1805, 4738 },
      -1,
   } },

   /* replace1670_0 -> 11 in the cache */
   /* replace1670_1_0 -> 260 in the cache */
   /* replace1670_1 -> 4687 in the cache */
   /* replace1670 -> 4690 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1671_0_0 -> 11 in the cache */
   /* search1671_0 -> 1805 in the cache */
   /* search1671_1_0 -> 260 in the cache */
   /* search1671_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1805, 4738 },
      -1,
   } },

   /* replace1671_0 -> 11 in the cache */
   /* replace1671_1_0 -> 260 in the cache */
   /* replace1671_1 -> 4687 in the cache */
   /* replace1671 -> 4692 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1672_0_0 -> 11 in the cache */
   /* search1672_0 -> 1805 in the cache */
   /* search1672_1_0 -> 260 in the cache */
   /* search1672_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1805, 4738 },
      -1,
   } },

   /* replace1672_0 -> 11 in the cache */
   /* replace1672_1_0 -> 260 in the cache */
   /* replace1672_1 -> 4687 in the cache */
   /* replace1672 -> 4694 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1673_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1673_1_0 -> 528 in the cache */
   /* search1673_1 -> 4735 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4743, 4735 },
      -1,
   } },

   /* replace1673_0_0 -> 517 in the cache */
   /* replace1673_0 -> 4697 in the cache */
   /* replace1673_1 -> 528 in the cache */
   /* replace1673 -> 4698 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1674_0_0 -> 517 in the cache */
   /* search1674_0 -> 4743 in the cache */
   /* search1674_1_0 -> 528 in the cache */
   /* search1674_1 -> 4735 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4743, 4735 },
      -1,
   } },

   /* replace1674_0_0 -> 517 in the cache */
   /* replace1674_0 -> 4697 in the cache */
   /* replace1674_1 -> 528 in the cache */
   /* replace1674 -> 4700 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1675_0_0 -> 11 in the cache */
   /* search1675_0 -> 1805 in the cache */
   /* search1675_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1805, 4304 },
      -1,
   } },

   /* replace1675_0_0 -> 11 in the cache */
   /* replace1675_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4747 },
      -1,
   } },
   /* replace1675_1_0_0_0 -> 41 in the cache */
   /* replace1675_1_0_0 -> 4747 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4747 },
      -1,
   } },
   /* replace1675_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4749, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4748, 4750 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1676_0_0 -> 11 in the cache */
   /* search1676_0 -> 1805 in the cache */
   /* search1676_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1805, 4304 },
      -1,
   } },

   /* replace1676_0_0 -> 11 in the cache */
   /* replace1676_0_1_0 -> 41 in the cache */
   /* replace1676_0_1 -> 4747 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4747 },
      -1,
   } },
   /* replace1676_1_0_0_0 -> 41 in the cache */
   /* replace1676_1_0_0 -> 4747 in the cache */
   /* replace1676_1_0 -> 4749 in the cache */
   /* replace1676_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4749, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4753, 4754 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1677_0_0 -> 11 in the cache */
   /* search1677_0 -> 1805 in the cache */
   /* search1677_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1805, 4304 },
      -1,
   } },

   /* replace1677_0_0 -> 876 in the cache */
   /* replace1677_0_1 -> 41 in the cache */
   /* replace1677_0 -> 4648 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1677_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4757, 41 },
      -1,
   } },
   /* replace1677_1_1_0 -> 11 in the cache */
   /* replace1677_1_1_1_0 -> 41 in the cache */
   /* replace1677_1_1_1 -> 4747 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4758, 4759 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4648, 4760 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1678_0 -> 4323 in the cache */
   /* search1678_1_0 -> 260 in the cache */
   /* search1678_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4323, 4738 },
      -1,
   } },

   /* replace1678_0_0 -> 21 in the cache */
   /* replace1678_0_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4757 },
      -1,
   } },
   /* replace1678_1_0_0 -> 21 in the cache */
   /* replace1678_1_0_1 -> 876 in the cache */
   /* replace1678_1_0 -> 4656 in the cache */
   /* replace1678_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1678_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4764, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4656, 4765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4763, 4766 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1679_0_0 -> 11 in the cache */
   /* search1679_0 -> 1805 in the cache */
   /* search1679_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1805, 4304 },
      -1,
   } },

   /* replace1679_0_0 -> 4757 in the cache */
   /* replace1679_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4757, 41 },
      -1,
   } },
   /* replace1679_1_0_0 -> 876 in the cache */
   /* replace1679_1_0_1 -> 41 in the cache */
   /* replace1679_1_0 -> 4663 in the cache */
   /* replace1679_1_1_0 -> 11 in the cache */
   /* replace1679_1_1_1_0 -> 41 in the cache */
   /* replace1679_1_1_1 -> 4747 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4663, 4770 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4769, 4771 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1680_0 -> 4323 in the cache */
   /* search1680_1_0 -> 260 in the cache */
   /* search1680_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4323, 4738 },
      -1,
   } },

   /* replace1680_0_0 -> 21 in the cache */
   /* replace1680_0_1 -> 876 in the cache */
   /* replace1680_0 -> 4668 in the cache */
   /* replace1680_1_0_0 -> 21 in the cache */
   /* replace1680_1_0_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4757 },
      -1,
   } },
   /* replace1680_1_1_0_0 -> 21 in the cache */
   /* replace1680_1_1_0 -> 4764 in the cache */
   /* replace1680_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4764, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4774, 4775 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4668, 4776 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1681_0_0 -> 16 in the cache */
   /* search1681_0 -> 1889 in the cache */
   /* search1681_1_0 -> 2093 in the cache */
   /* search1681_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1889, 4628 },
      -1,
   } },

   /* replace1681_0 -> 16 in the cache */
   /* replace1681_1_0 -> 2093 in the cache */
   /* replace1681_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3204 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1682_0_0 -> 16 in the cache */
   /* search1682_0 -> 1889 in the cache */
   /* search1682_1_0 -> 2093 in the cache */
   /* search1682_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1889, 4628 },
      -1,
   } },

   /* replace1682_0 -> 16 in the cache */
   /* replace1682_1_0 -> 2093 in the cache */
   /* replace1682_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3204 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1683_0_0 -> 16 in the cache */
   /* search1683_0 -> 1889 in the cache */
   /* search1683_1_0 -> 2093 in the cache */
   /* search1683_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1889, 4628 },
      -1,
   } },

   /* replace1683_0 -> 16 in the cache */
   /* replace1683_1_0 -> 2093 in the cache */
   /* replace1683_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3204 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1684_0_0 -> 16 in the cache */
   /* search1684_0 -> 1889 in the cache */
   /* search1684_1_0 -> 2093 in the cache */
   /* search1684_1 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1889, 4628 },
      -1,
   } },

   /* replace1684_0 -> 16 in the cache */
   /* replace1684_1_0 -> 2093 in the cache */
   /* replace1684_1 -> 3204 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3204 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1685_0_0 -> 4203 in the cache */
   /* search1685_0 -> 4633 in the cache */
   /* search1685_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4633, 4786 },
      -1,
   } },

   /* replace1685_0_0 -> 4203 in the cache */
   /* replace1685_0 -> 4591 in the cache */
   /* replace1685_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4591, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1686_0_0 -> 4203 in the cache */
   /* search1686_0 -> 4633 in the cache */
   /* search1686_1_0 -> 185 in the cache */
   /* search1686_1 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4633, 4786 },
      -1,
   } },

   /* replace1686_0_0 -> 4203 in the cache */
   /* replace1686_0 -> 4591 in the cache */
   /* replace1686_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4591, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1687_0_0 -> 16 in the cache */
   /* search1687_0 -> 1889 in the cache */
   /* search1687_1_0 -> 260 in the cache */
   /* search1687_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1889, 4738 },
      -1,
   } },

   /* replace1687_0 -> 16 in the cache */
   /* replace1687_1_0 -> 260 in the cache */
   /* replace1687_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3224 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1688_0_0 -> 16 in the cache */
   /* search1688_0 -> 1889 in the cache */
   /* search1688_1_0 -> 260 in the cache */
   /* search1688_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1889, 4738 },
      -1,
   } },

   /* replace1688_0 -> 16 in the cache */
   /* replace1688_1_0 -> 260 in the cache */
   /* replace1688_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3224 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1689_0_0 -> 16 in the cache */
   /* search1689_0 -> 1889 in the cache */
   /* search1689_1_0 -> 260 in the cache */
   /* search1689_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1889, 4738 },
      -1,
   } },

   /* replace1689_0 -> 16 in the cache */
   /* replace1689_1_0 -> 260 in the cache */
   /* replace1689_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3224 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1690_0_0 -> 16 in the cache */
   /* search1690_0 -> 1889 in the cache */
   /* search1690_1_0 -> 260 in the cache */
   /* search1690_1 -> 4738 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1889, 4738 },
      -1,
   } },

   /* replace1690_0 -> 16 in the cache */
   /* replace1690_1_0 -> 260 in the cache */
   /* replace1690_1 -> 3224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3224 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1691_0_0 -> 517 in the cache */
   /* search1691_0 -> 4743 in the cache */
   /* search1691_1_0 -> 185 in the cache */
   /* search1691_1 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4743, 4786 },
      -1,
   } },

   /* replace1691_0_0 -> 517 in the cache */
   /* replace1691_0 -> 4695 in the cache */
   /* replace1691_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4695, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1692_0_0 -> 517 in the cache */
   /* search1692_0 -> 4743 in the cache */
   /* search1692_1_0 -> 185 in the cache */
   /* search1692_1 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4743, 4786 },
      -1,
   } },

   /* replace1692_0_0 -> 517 in the cache */
   /* replace1692_0 -> 4695 in the cache */
   /* replace1692_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4695, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1693_0_0 -> 16 in the cache */
   /* search1693_0 -> 1889 in the cache */
   /* search1693_1_0 -> 36 in the cache */
   /* search1693_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1889, 3220 },
      -1,
   } },

   /* replace1693_0 -> 16 in the cache */
   /* replace1693_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4804 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1694_0_0 -> 16 in the cache */
   /* search1694_0 -> 1889 in the cache */
   /* search1694_1_0 -> 36 in the cache */
   /* search1694_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1889, 3220 },
      -1,
   } },

   /* replace1694_0 -> 16 in the cache */
   /* replace1694_1_0 -> 36 in the cache */
   /* replace1694_1 -> 4804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4804 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1695_0_0 -> 16 in the cache */
   /* search1695_0 -> 1889 in the cache */
   /* search1695_1_0 -> 36 in the cache */
   /* search1695_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1889, 3220 },
      -1,
   } },

   /* replace1695_0 -> 16 in the cache */
   /* replace1695_1_0 -> 36 in the cache */
   /* replace1695_1 -> 4804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4804 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1696_0_0 -> 16 in the cache */
   /* search1696_0 -> 1889 in the cache */
   /* search1696_1_0 -> 36 in the cache */
   /* search1696_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1889, 3220 },
      -1,
   } },

   /* replace1696_0 -> 16 in the cache */
   /* replace1696_1_0 -> 36 in the cache */
   /* replace1696_1 -> 4804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4804 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1697_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1697_1_0 -> 185 in the cache */
   /* search1697_1 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4812, 4786 },
      -1,
   } },

   /* replace1697_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1697_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4814, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1698_0_0 -> 375 in the cache */
   /* search1698_0 -> 4812 in the cache */
   /* search1698_1_0 -> 185 in the cache */
   /* search1698_1 -> 4786 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4812, 4786 },
      -1,
   } },

   /* replace1698_0_0 -> 375 in the cache */
   /* replace1698_0 -> 4814 in the cache */
   /* replace1698_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4814, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1699_0_0 -> 16 in the cache */
   /* search1699_0 -> 1889 in the cache */
   /* search1699_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1889, 4304 },
      -1,
   } },

   /* replace1699_0_0 -> 16 in the cache */
   /* replace1699_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4819 },
      -1,
   } },
   /* replace1699_1_0_0_0 -> 41 in the cache */
   /* replace1699_1_0_0 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4819 },
      -1,
   } },
   /* replace1699_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4821, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4820, 4822 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1700_0_0 -> 16 in the cache */
   /* search1700_0 -> 1889 in the cache */
   /* search1700_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1889, 4304 },
      -1,
   } },

   /* replace1700_0_0 -> 16 in the cache */
   /* replace1700_0_1_0 -> 41 in the cache */
   /* replace1700_0_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4819 },
      -1,
   } },
   /* replace1700_1_0_0_0 -> 41 in the cache */
   /* replace1700_1_0_0 -> 4819 in the cache */
   /* replace1700_1_0 -> 4821 in the cache */
   /* replace1700_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4821, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4825, 4826 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1701_0_0 -> 16 in the cache */
   /* search1701_0 -> 1889 in the cache */
   /* search1701_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1889, 4304 },
      -1,
   } },

   /* replace1701_0_0 -> 876 in the cache */
   /* replace1701_0_1 -> 41 in the cache */
   /* replace1701_0 -> 4648 in the cache */
   /* replace1701_1_0_0 -> 3235 in the cache */
   /* replace1701_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3235, 41 },
      -1,
   } },
   /* replace1701_1_1_0 -> 16 in the cache */
   /* replace1701_1_1_1_0 -> 41 in the cache */
   /* replace1701_1_1_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4829, 4830 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4648, 4831 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1702_0 -> 4323 in the cache */
   /* search1702_1_0 -> 36 in the cache */
   /* search1702_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4323, 3220 },
      -1,
   } },

   /* replace1702_0_0 -> 21 in the cache */
   /* replace1702_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 3235 },
      -1,
   } },
   /* replace1702_1_0_0 -> 21 in the cache */
   /* replace1702_1_0_1 -> 876 in the cache */
   /* replace1702_1_0 -> 4656 in the cache */
   /* replace1702_1_1_0_0 -> 21 in the cache */
   /* replace1702_1_1_0 -> 3227 in the cache */
   /* replace1702_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3227, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4656, 4835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4834, 4836 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1703_0_0 -> 16 in the cache */
   /* search1703_0 -> 1889 in the cache */
   /* search1703_1 -> 4304 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1889, 4304 },
      -1,
   } },

   /* replace1703_0_0 -> 3235 in the cache */
   /* replace1703_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3235, 41 },
      -1,
   } },
   /* replace1703_1_0_0 -> 876 in the cache */
   /* replace1703_1_0_1 -> 41 in the cache */
   /* replace1703_1_0 -> 4663 in the cache */
   /* replace1703_1_1_0 -> 16 in the cache */
   /* replace1703_1_1_1_0 -> 41 in the cache */
   /* replace1703_1_1_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4663, 4840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4839, 4841 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1704_0 -> 4323 in the cache */
   /* search1704_1_0 -> 36 in the cache */
   /* search1704_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4323, 3220 },
      -1,
   } },

   /* replace1704_0_0 -> 21 in the cache */
   /* replace1704_0_1 -> 876 in the cache */
   /* replace1704_0 -> 4668 in the cache */
   /* replace1704_1_0_0 -> 21 in the cache */
   /* replace1704_1_0_1 -> 3235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 3235 },
      -1,
   } },
   /* replace1704_1_1_0_0 -> 21 in the cache */
   /* replace1704_1_1_0 -> 3227 in the cache */
   /* replace1704_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3227, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4844, 4845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4668, 4846 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1705_0_0 -> 11 in the cache */
   /* search1705_0 -> 1778 in the cache */
   /* search1705_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1778, 4848 },
      -1,
   } },

   /* replace1705_0 -> 11 in the cache */
   /* replace1705_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 4850 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1706_0_0 -> 11 in the cache */
   /* search1706_0 -> 1778 in the cache */
   /* search1706_1_0 -> 260 in the cache */
   /* search1706_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1778, 4848 },
      -1,
   } },

   /* replace1706_0 -> 11 in the cache */
   /* replace1706_1_0 -> 260 in the cache */
   /* replace1706_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 4850 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1707_0_0 -> 11 in the cache */
   /* search1707_0 -> 1778 in the cache */
   /* search1707_1_0 -> 260 in the cache */
   /* search1707_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1778, 4848 },
      -1,
   } },

   /* replace1707_0 -> 11 in the cache */
   /* replace1707_1_0 -> 260 in the cache */
   /* replace1707_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 4850 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1708_0_0 -> 11 in the cache */
   /* search1708_0 -> 1778 in the cache */
   /* search1708_1_0 -> 260 in the cache */
   /* search1708_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1778, 4848 },
      -1,
   } },

   /* replace1708_0 -> 11 in the cache */
   /* replace1708_1_0 -> 260 in the cache */
   /* replace1708_1 -> 4850 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 4850 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1709_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1709_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4858, 4859 },
      -1,
   } },

   /* replace1709_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1709_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4861, 528 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1710_0_0 -> 517 in the cache */
   /* search1710_0 -> 4858 in the cache */
   /* search1710_1_0 -> 528 in the cache */
   /* search1710_1 -> 4859 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4858, 4859 },
      -1,
   } },

   /* replace1710_0_0 -> 517 in the cache */
   /* replace1710_0 -> 4861 in the cache */
   /* replace1710_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4861, 528 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1711_0_0 -> 11 in the cache */
   /* search1711_0 -> 1801 in the cache */
   /* search1711_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1801, 4865 },
      -1,
   } },

   /* replace1711_0 -> 11 in the cache */
   /* replace1711_1_0 -> 260 in the cache */
   /* replace1711_1 -> 4850 in the cache */
   /* replace1711 -> 4851 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1712_0_0 -> 11 in the cache */
   /* search1712_0 -> 1801 in the cache */
   /* search1712_1_0 -> 260 in the cache */
   /* search1712_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1801, 4865 },
      -1,
   } },

   /* replace1712_0 -> 11 in the cache */
   /* replace1712_1_0 -> 260 in the cache */
   /* replace1712_1 -> 4850 in the cache */
   /* replace1712 -> 4853 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1713_0_0 -> 11 in the cache */
   /* search1713_0 -> 1801 in the cache */
   /* search1713_1_0 -> 260 in the cache */
   /* search1713_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1801, 4865 },
      -1,
   } },

   /* replace1713_0 -> 11 in the cache */
   /* replace1713_1_0 -> 260 in the cache */
   /* replace1713_1 -> 4850 in the cache */
   /* replace1713 -> 4855 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1714_0_0 -> 11 in the cache */
   /* search1714_0 -> 1801 in the cache */
   /* search1714_1_0 -> 260 in the cache */
   /* search1714_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1801, 4865 },
      -1,
   } },

   /* replace1714_0 -> 11 in the cache */
   /* replace1714_1_0 -> 260 in the cache */
   /* replace1714_1 -> 4850 in the cache */
   /* replace1714 -> 4857 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1715_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1715_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4870, 4871 },
      -1,
   } },

   /* replace1715_0_0 -> 517 in the cache */
   /* replace1715_0 -> 4861 in the cache */
   /* replace1715_1 -> 528 in the cache */
   /* replace1715 -> 4862 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1716_0_0 -> 517 in the cache */
   /* search1716_0 -> 4870 in the cache */
   /* search1716_1_0 -> 528 in the cache */
   /* search1716_1 -> 4871 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4870, 4871 },
      -1,
   } },

   /* replace1716_0_0 -> 517 in the cache */
   /* replace1716_0 -> 4861 in the cache */
   /* replace1716_1 -> 528 in the cache */
   /* replace1716 -> 4864 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1717_0_0 -> 16 in the cache */
   /* search1717_0 -> 1885 in the cache */
   /* search1717_1_0 -> 260 in the cache */
   /* search1717_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1885, 4865 },
      -1,
   } },

   /* replace1717_0 -> 16 in the cache */
   /* replace1717_1_0 -> 260 in the cache */
   /* replace1717_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4848 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1718_0_0 -> 16 in the cache */
   /* search1718_0 -> 1885 in the cache */
   /* search1718_1_0 -> 260 in the cache */
   /* search1718_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1885, 4865 },
      -1,
   } },

   /* replace1718_0 -> 16 in the cache */
   /* replace1718_1_0 -> 260 in the cache */
   /* replace1718_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4848 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1719_0_0 -> 16 in the cache */
   /* search1719_0 -> 1885 in the cache */
   /* search1719_1_0 -> 260 in the cache */
   /* search1719_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1885, 4865 },
      -1,
   } },

   /* replace1719_0 -> 16 in the cache */
   /* replace1719_1_0 -> 260 in the cache */
   /* replace1719_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4848 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1720_0_0 -> 16 in the cache */
   /* search1720_0 -> 1885 in the cache */
   /* search1720_1_0 -> 260 in the cache */
   /* search1720_1 -> 4865 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1885, 4865 },
      -1,
   } },

   /* replace1720_0 -> 16 in the cache */
   /* replace1720_1_0 -> 260 in the cache */
   /* replace1720_1 -> 4848 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4848 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1721_0_0 -> 517 in the cache */
   /* search1721_0 -> 4870 in the cache */
   /* search1721_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4870, 4882 },
      -1,
   } },

   /* replace1721_0_0 -> 517 in the cache */
   /* replace1721_0 -> 4858 in the cache */
   /* replace1721_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4858, 185 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1722_0_0 -> 517 in the cache */
   /* search1722_0 -> 4870 in the cache */
   /* search1722_1_0 -> 185 in the cache */
   /* search1722_1 -> 4882 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4870, 4882 },
      -1,
   } },

   /* replace1722_0_0 -> 517 in the cache */
   /* replace1722_0 -> 4858 in the cache */
   /* replace1722_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4858, 185 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1723_0_0 -> 16 in the cache */
   /* search1723_0 -> 1885 in the cache */
   /* search1723_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1885, 4887 },
      -1,
   } },

   /* replace1723_0 -> 16 in the cache */
   /* replace1723_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4889 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1724_0_0 -> 16 in the cache */
   /* search1724_0 -> 1885 in the cache */
   /* search1724_1_0 -> 36 in the cache */
   /* search1724_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1885, 4887 },
      -1,
   } },

   /* replace1724_0 -> 16 in the cache */
   /* replace1724_1_0 -> 36 in the cache */
   /* replace1724_1 -> 4889 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4889 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1725_0_0 -> 16 in the cache */
   /* search1725_0 -> 1885 in the cache */
   /* search1725_1_0 -> 36 in the cache */
   /* search1725_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1885, 4887 },
      -1,
   } },

   /* replace1725_0 -> 16 in the cache */
   /* replace1725_1_0 -> 36 in the cache */
   /* replace1725_1 -> 4889 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4889 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1726_0_0 -> 16 in the cache */
   /* search1726_0 -> 1885 in the cache */
   /* search1726_1_0 -> 36 in the cache */
   /* search1726_1 -> 4887 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1885, 4887 },
      -1,
   } },

   /* replace1726_0 -> 16 in the cache */
   /* replace1726_1_0 -> 36 in the cache */
   /* replace1726_1 -> 4889 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4889 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1727_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1727_1_0 -> 185 in the cache */
   /* search1727_1 -> 4882 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4897, 4882 },
      -1,
   } },

   /* replace1727_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1727_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4899, 185 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1728_0_0 -> 375 in the cache */
   /* search1728_0 -> 4897 in the cache */
   /* search1728_1_0 -> 185 in the cache */
   /* search1728_1 -> 4882 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4897, 4882 },
      -1,
   } },

   /* replace1728_0_0 -> 375 in the cache */
   /* replace1728_0 -> 4899 in the cache */
   /* replace1728_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4899, 185 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1729_0_0 -> 21 in the cache */
   /* search1729_0_1 -> 3235 in the cache */
   /* search1729_0 -> 3236 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 3236 },
      -1,
   } },

   /* replace1729_0 -> 21 in the cache */
   /* replace1729 -> 3227 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1730_0_0 -> 16 in the cache */
   /* search1730_0_1 -> 981 in the cache */
   /* search1730_0 -> 982 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 982 },
      -1,
   } },

   /* replace1730_0 -> 16 in the cache */
   /* replace1730 -> 3230 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1731_0_0 -> 21 in the cache */
   /* search1731_0_1 -> 4757 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 4905 },
      -1,
   } },

   /* replace1731_0 -> 21 in the cache */
   /* replace1731 -> 4764 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1732_0_0 -> 11 in the cache */
   /* search1732_0_1 -> 1994 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1994 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4907 },
      -1,
   } },

   /* replace1732_0 -> 11 in the cache */
   /* replace1732 -> 1990 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1733_0_0 -> 16 in the cache */
   /* search1733_0_1 -> 989 in the cache */
   /* search1733_0 -> 990 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 990 },
      -1,
   } },

   /* replace1733_0 -> 16 in the cache */
   /* replace1733 -> 2006 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1734_0_0 -> 21 in the cache */
   /* search1734_0_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4649 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4910 },
      -1,
   } },

   /* replace1734_0 -> 21 in the cache */
   /* replace1734 -> 4657 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1735_0_0 -> 11 in the cache */
   /* search1735_0 -> 1990 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1990 },
      6,
   } },

   /* replace1735 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1736_0 -> 11 in the cache */
   /* search1736_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 835 },
      6,
   } },

   /* replace1736 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1737_0 -> 523 in the cache */
   /* search1737_1_0_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4914 },
      -1,
   } },
   /* search1737_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4915, 490 },
      6,
   } },

   /* replace1737_0 -> 523 in the cache */
   /* replace1737_1 -> 528 in the cache */
   /* replace1737_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 528, 490 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1738_0 -> 523 in the cache */
   /* search1738_1_0_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4918 },
      -1,
   } },
   /* search1738_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4919, 490 },
      6,
   } },

   /* replace1738_0 -> 523 in the cache */
   /* replace1738_1 -> 528 in the cache */
   /* replace1738_2 -> 490 in the cache */
   /* replace1738 -> 4917 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1739_0 -> 523 in the cache */
   /* search1739_1_0 -> 528 in the cache */
   /* search1739_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 528, 835 },
      -1,
   } },
   /* search1739_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4921, 490 },
      6,
   } },

   /* replace1739_0 -> 523 in the cache */
   /* replace1739_1 -> 528 in the cache */
   /* replace1739_2 -> 490 in the cache */
   /* replace1739 -> 4917 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1740_0_0_0 -> 11 in the cache */
   /* search1740_0_0 -> 1990 in the cache */
   /* search1740_0 -> 1991 in the cache */
   /* search1740_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1991, 260 },
      6,
   } },

   /* replace1740_0 -> 11 in the cache */
   /* replace1740_1 -> 260 in the cache */
   /* replace1740 -> 3979 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1741_0_0_0 -> 11 in the cache */
   /* search1741_0_0 -> 4234 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4234 },
      -1,
   } },
   /* search1741_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4924, 260 },
      6,
   } },

   /* replace1741_0 -> 11 in the cache */
   /* replace1741_1 -> 260 in the cache */
   /* replace1741 -> 3979 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1742_0_0 -> 11 in the cache */
   /* search1742_0_1 -> 835 in the cache */
   /* search1742_0 -> 3338 in the cache */
   /* search1742_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3338, 260 },
      6,
   } },

   /* replace1742_0 -> 11 in the cache */
   /* replace1742_1 -> 260 in the cache */
   /* replace1742 -> 3979 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1743_0_0_0 -> 11 in the cache */
   /* search1743_0_0 -> 1990 in the cache */
   /* search1743_0 -> 1991 in the cache */
   /* search1743_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1991, 260 },
      6,
   } },

   /* replace1743_0 -> 11 in the cache */
   /* replace1743_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1744_0_0_0 -> 11 in the cache */
   /* search1744_0_0 -> 4234 in the cache */
   /* search1744_0 -> 4924 in the cache */
   /* search1744_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4924, 260 },
      6,
   } },

   /* replace1744_0 -> 11 in the cache */
   /* replace1744_1 -> 260 in the cache */
   /* replace1744 -> 4928 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1745_0_0 -> 11 in the cache */
   /* search1745_0_1 -> 835 in the cache */
   /* search1745_0 -> 3338 in the cache */
   /* search1745_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3338, 260 },
      6,
   } },

   /* replace1745_0 -> 11 in the cache */
   /* replace1745_1 -> 260 in the cache */
   /* replace1745 -> 4928 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1746_0_0_0 -> 11 in the cache */
   /* search1746_0_0 -> 1990 in the cache */
   /* search1746_0 -> 1991 in the cache */
   /* search1746_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1991, 260 },
      6,
   } },

   /* replace1746_0 -> 11 in the cache */
   /* replace1746_1 -> 260 in the cache */
   /* replace1746 -> 2004 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1747_0_0_0 -> 11 in the cache */
   /* search1747_0_0 -> 4234 in the cache */
   /* search1747_0 -> 4924 in the cache */
   /* search1747_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4924, 260 },
      6,
   } },

   /* replace1747_0 -> 11 in the cache */
   /* replace1747_1 -> 260 in the cache */
   /* replace1747 -> 2004 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1748_0_0 -> 11 in the cache */
   /* search1748_0_1 -> 835 in the cache */
   /* search1748_0 -> 3338 in the cache */
   /* search1748_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3338, 260 },
      6,
   } },

   /* replace1748_0 -> 11 in the cache */
   /* replace1748_1 -> 260 in the cache */
   /* replace1748 -> 2004 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1749_0_0_0 -> 11 in the cache */
   /* search1749_0_0 -> 1990 in the cache */
   /* search1749_0 -> 1991 in the cache */
   /* search1749_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1991, 260 },
      6,
   } },

   /* replace1749_0 -> 11 in the cache */
   /* replace1749_1 -> 260 in the cache */
   /* replace1749 -> 2046 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1750_0_0_0 -> 11 in the cache */
   /* search1750_0_0 -> 4234 in the cache */
   /* search1750_0 -> 4924 in the cache */
   /* search1750_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4924, 260 },
      6,
   } },

   /* replace1750_0 -> 11 in the cache */
   /* replace1750_1 -> 260 in the cache */
   /* replace1750 -> 2046 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1751_0_0 -> 11 in the cache */
   /* search1751_0_1 -> 835 in the cache */
   /* search1751_0 -> 3338 in the cache */
   /* search1751_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3338, 260 },
      6,
   } },

   /* replace1751_0 -> 11 in the cache */
   /* replace1751_1 -> 260 in the cache */
   /* replace1751 -> 2046 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1752_0_0_0 -> 11 in the cache */
   /* search1752_0_0 -> 1990 in the cache */
   /* search1752_0 -> 1991 in the cache */
   /* search1752_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1991, 260 },
      6,
   } },

   /* replace1752_0 -> 11 in the cache */
   /* replace1752_1 -> 260 in the cache */
   /* replace1752 -> 2070 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1753_0_0_0 -> 11 in the cache */
   /* search1753_0_0 -> 4234 in the cache */
   /* search1753_0 -> 4924 in the cache */
   /* search1753_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4924, 260 },
      6,
   } },

   /* replace1753_0 -> 11 in the cache */
   /* replace1753_1 -> 260 in the cache */
   /* replace1753 -> 2070 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1754_0_0 -> 11 in the cache */
   /* search1754_0_1 -> 835 in the cache */
   /* search1754_0 -> 3338 in the cache */
   /* search1754_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3338, 260 },
      6,
   } },

   /* replace1754_0 -> 11 in the cache */
   /* replace1754_1 -> 260 in the cache */
   /* replace1754 -> 2070 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1755_0_0 -> 11 in the cache */
   /* search1755_0 -> 1990 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1990 },
      6,
   } },

   /* replace1755 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1756_0 -> 11 in the cache */
   /* search1756_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 835 },
      6,
   } },

   /* replace1756 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1757_0 -> 523 in the cache */
   /* search1757_1_0_0 -> 528 in the cache */
   /* search1757_1_0 -> 4914 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4914 },
      -1,
   } },
   /* search1757_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4942, 490 },
      6,
   } },

   /* replace1757_0 -> 523 in the cache */
   /* replace1757_1 -> 528 in the cache */
   /* replace1757_2 -> 490 in the cache */
   /* replace1757 -> 4917 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1758_0 -> 523 in the cache */
   /* search1758_1_0_0 -> 528 in the cache */
   /* search1758_1_0 -> 4918 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4918 },
      -1,
   } },
   /* search1758_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4944, 490 },
      6,
   } },

   /* replace1758_0 -> 523 in the cache */
   /* replace1758_1 -> 528 in the cache */
   /* replace1758_2 -> 490 in the cache */
   /* replace1758 -> 4917 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1759_0 -> 523 in the cache */
   /* search1759_1_0 -> 528 in the cache */
   /* search1759_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 528, 835 },
      -1,
   } },
   /* search1759_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4946, 490 },
      6,
   } },

   /* replace1759_0 -> 523 in the cache */
   /* replace1759_1 -> 528 in the cache */
   /* replace1759_2 -> 490 in the cache */
   /* replace1759 -> 4917 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1760_0_0_0 -> 11 in the cache */
   /* search1760_0_0 -> 1990 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1990 },
      -1,
   } },
   /* search1760_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4948, 260 },
      6,
   } },

   /* replace1760_0 -> 11 in the cache */
   /* replace1760_1 -> 260 in the cache */
   /* replace1760 -> 3979 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1761_0_0_0 -> 11 in the cache */
   /* search1761_0_0 -> 4234 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4234 },
      -1,
   } },
   /* search1761_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4950, 260 },
      6,
   } },

   /* replace1761_0 -> 11 in the cache */
   /* replace1761_1 -> 260 in the cache */
   /* replace1761 -> 3979 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1762_0_0 -> 11 in the cache */
   /* search1762_0_1 -> 835 in the cache */
   /* search1762_0 -> 3359 in the cache */
   /* search1762_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3359, 260 },
      6,
   } },

   /* replace1762_0 -> 11 in the cache */
   /* replace1762_1 -> 260 in the cache */
   /* replace1762 -> 3979 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1763_0_0_0 -> 11 in the cache */
   /* search1763_0_0 -> 1990 in the cache */
   /* search1763_0 -> 4948 in the cache */
   /* search1763_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4948, 260 },
      6,
   } },

   /* replace1763_0 -> 11 in the cache */
   /* replace1763_1 -> 260 in the cache */
   /* replace1763 -> 4928 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1764_0_0_0 -> 11 in the cache */
   /* search1764_0_0 -> 4234 in the cache */
   /* search1764_0 -> 4950 in the cache */
   /* search1764_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4950, 260 },
      6,
   } },

   /* replace1764_0 -> 11 in the cache */
   /* replace1764_1 -> 260 in the cache */
   /* replace1764 -> 4928 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1765_0_0 -> 11 in the cache */
   /* search1765_0_1 -> 835 in the cache */
   /* search1765_0 -> 3359 in the cache */
   /* search1765_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3359, 260 },
      6,
   } },

   /* replace1765_0 -> 11 in the cache */
   /* replace1765_1 -> 260 in the cache */
   /* replace1765 -> 4928 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1766_0_0_0 -> 11 in the cache */
   /* search1766_0_0 -> 1990 in the cache */
   /* search1766_0 -> 4948 in the cache */
   /* search1766_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4948, 260 },
      6,
   } },

   /* replace1766_0 -> 11 in the cache */
   /* replace1766_1 -> 260 in the cache */
   /* replace1766 -> 2004 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1767_0_0_0 -> 11 in the cache */
   /* search1767_0_0 -> 4234 in the cache */
   /* search1767_0 -> 4950 in the cache */
   /* search1767_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4950, 260 },
      6,
   } },

   /* replace1767_0 -> 11 in the cache */
   /* replace1767_1 -> 260 in the cache */
   /* replace1767 -> 2004 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1768_0_0 -> 11 in the cache */
   /* search1768_0_1 -> 835 in the cache */
   /* search1768_0 -> 3359 in the cache */
   /* search1768_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3359, 260 },
      6,
   } },

   /* replace1768_0 -> 11 in the cache */
   /* replace1768_1 -> 260 in the cache */
   /* replace1768 -> 2004 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1769_0_0_0 -> 11 in the cache */
   /* search1769_0_0 -> 1990 in the cache */
   /* search1769_0 -> 4948 in the cache */
   /* search1769_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4948, 260 },
      6,
   } },

   /* replace1769_0 -> 11 in the cache */
   /* replace1769_1 -> 260 in the cache */
   /* replace1769 -> 2046 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1770_0_0_0 -> 11 in the cache */
   /* search1770_0_0 -> 4234 in the cache */
   /* search1770_0 -> 4950 in the cache */
   /* search1770_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4950, 260 },
      6,
   } },

   /* replace1770_0 -> 11 in the cache */
   /* replace1770_1 -> 260 in the cache */
   /* replace1770 -> 2046 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1771_0_0 -> 11 in the cache */
   /* search1771_0_1 -> 835 in the cache */
   /* search1771_0 -> 3359 in the cache */
   /* search1771_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3359, 260 },
      6,
   } },

   /* replace1771_0 -> 11 in the cache */
   /* replace1771_1 -> 260 in the cache */
   /* replace1771 -> 2046 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1772_0_0_0 -> 11 in the cache */
   /* search1772_0_0 -> 1990 in the cache */
   /* search1772_0 -> 4948 in the cache */
   /* search1772_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4948, 260 },
      6,
   } },

   /* replace1772_0 -> 11 in the cache */
   /* replace1772_1 -> 260 in the cache */
   /* replace1772 -> 2070 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1773_0_0_0 -> 11 in the cache */
   /* search1773_0_0 -> 4234 in the cache */
   /* search1773_0 -> 4950 in the cache */
   /* search1773_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4950, 260 },
      6,
   } },

   /* replace1773_0 -> 11 in the cache */
   /* replace1773_1 -> 260 in the cache */
   /* replace1773 -> 2070 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1774_0_0 -> 11 in the cache */
   /* search1774_0_1 -> 835 in the cache */
   /* search1774_0 -> 3359 in the cache */
   /* search1774_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3359, 260 },
      6,
   } },

   /* replace1774_0 -> 11 in the cache */
   /* replace1774_1 -> 260 in the cache */
   /* replace1774 -> 2070 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1775_0_0 -> 16 in the cache */
   /* search1775_0 -> 2006 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2006 },
      6,
   } },

   /* replace1775 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1776_0 -> 16 in the cache */
   /* search1776_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 124 },
      6,
   } },

   /* replace1776 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1777_0 -> 523 in the cache */
   /* search1777_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4967 },
      -1,
   } },
   /* search1777_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4968, 561 },
      6,
   } },

   /* replace1777_0 -> 523 in the cache */
   /* replace1777_1 -> 185 in the cache */
   /* replace1777_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 185, 561 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1778_0 -> 523 in the cache */
   /* search1778_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4971 },
      -1,
   } },
   /* search1778_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4972, 561 },
      6,
   } },

   /* replace1778_0 -> 523 in the cache */
   /* replace1778_1 -> 185 in the cache */
   /* replace1778_2 -> 561 in the cache */
   /* replace1778 -> 4970 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1779_0 -> 523 in the cache */
   /* search1779_1_0 -> 185 in the cache */
   /* search1779_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1779_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4974, 561 },
      6,
   } },

   /* replace1779_0 -> 523 in the cache */
   /* replace1779_1 -> 185 in the cache */
   /* replace1779_2 -> 561 in the cache */
   /* replace1779 -> 4970 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1780_0_0_0 -> 16 in the cache */
   /* search1780_0_0 -> 2006 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2006 },
      -1,
   } },
   /* search1780_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4976, 36 },
      6,
   } },

   /* replace1780_0 -> 16 in the cache */
   /* replace1780_1 -> 36 in the cache */
   /* replace1780 -> 3999 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1781_0_0_0 -> 16 in the cache */
   /* search1781_0_0 -> 4186 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4186 },
      -1,
   } },
   /* search1781_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4978, 36 },
      6,
   } },

   /* replace1781_0 -> 16 in the cache */
   /* replace1781_1 -> 36 in the cache */
   /* replace1781 -> 3999 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1782_0_0 -> 16 in the cache */
   /* search1782_0_1 -> 124 in the cache */
   /* search1782_0 -> 414 in the cache */
   /* search1782_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1782_0 -> 16 in the cache */
   /* replace1782_1 -> 36 in the cache */
   /* replace1782 -> 3999 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1783_0_0_0 -> 16 in the cache */
   /* search1783_0_0 -> 2006 in the cache */
   /* search1783_0 -> 4976 in the cache */
   /* search1783_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4976, 36 },
      6,
   } },

   /* replace1783_0 -> 16 in the cache */
   /* replace1783_1 -> 36 in the cache */
   /* replace1783 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1784_0_0_0 -> 16 in the cache */
   /* search1784_0_0 -> 4186 in the cache */
   /* search1784_0 -> 4978 in the cache */
   /* search1784_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4978, 36 },
      6,
   } },

   /* replace1784_0 -> 16 in the cache */
   /* replace1784_1 -> 36 in the cache */
   /* replace1784 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1785_0_0 -> 16 in the cache */
   /* search1785_0_1 -> 124 in the cache */
   /* search1785_0 -> 414 in the cache */
   /* search1785_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1785_0 -> 16 in the cache */
   /* replace1785_1 -> 36 in the cache */
   /* replace1785 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1786_0_0_0 -> 16 in the cache */
   /* search1786_0_0 -> 2006 in the cache */
   /* search1786_0 -> 4976 in the cache */
   /* search1786_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4976, 36 },
      6,
   } },

   /* replace1786_0 -> 16 in the cache */
   /* replace1786_1 -> 36 in the cache */
   /* replace1786 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1787_0_0_0 -> 16 in the cache */
   /* search1787_0_0 -> 4186 in the cache */
   /* search1787_0 -> 4978 in the cache */
   /* search1787_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4978, 36 },
      6,
   } },

   /* replace1787_0 -> 16 in the cache */
   /* replace1787_1 -> 36 in the cache */
   /* replace1787 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1788_0_0 -> 16 in the cache */
   /* search1788_0_1 -> 124 in the cache */
   /* search1788_0 -> 414 in the cache */
   /* search1788_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1788_0 -> 16 in the cache */
   /* replace1788_1 -> 36 in the cache */
   /* replace1788 -> 2012 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1789_0_0_0 -> 16 in the cache */
   /* search1789_0_0 -> 2006 in the cache */
   /* search1789_0 -> 4976 in the cache */
   /* search1789_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4976, 36 },
      6,
   } },

   /* replace1789_0 -> 16 in the cache */
   /* replace1789_1 -> 36 in the cache */
   /* replace1789 -> 2050 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1790_0_0_0 -> 16 in the cache */
   /* search1790_0_0 -> 4186 in the cache */
   /* search1790_0 -> 4978 in the cache */
   /* search1790_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4978, 36 },
      6,
   } },

   /* replace1790_0 -> 16 in the cache */
   /* replace1790_1 -> 36 in the cache */
   /* replace1790 -> 2050 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1791_0_0 -> 16 in the cache */
   /* search1791_0_1 -> 124 in the cache */
   /* search1791_0 -> 414 in the cache */
   /* search1791_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1791_0 -> 16 in the cache */
   /* replace1791_1 -> 36 in the cache */
   /* replace1791 -> 2050 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1792_0_0_0 -> 16 in the cache */
   /* search1792_0_0 -> 2006 in the cache */
   /* search1792_0 -> 4976 in the cache */
   /* search1792_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4976, 36 },
      6,
   } },

   /* replace1792_0 -> 16 in the cache */
   /* replace1792_1 -> 36 in the cache */
   /* replace1792 -> 2074 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1793_0_0_0 -> 16 in the cache */
   /* search1793_0_0 -> 4186 in the cache */
   /* search1793_0 -> 4978 in the cache */
   /* search1793_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4978, 36 },
      6,
   } },

   /* replace1793_0 -> 16 in the cache */
   /* replace1793_1 -> 36 in the cache */
   /* replace1793 -> 2074 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1794_0_0 -> 16 in the cache */
   /* search1794_0_1 -> 124 in the cache */
   /* search1794_0 -> 414 in the cache */
   /* search1794_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1794_0 -> 16 in the cache */
   /* replace1794_1 -> 36 in the cache */
   /* replace1794 -> 2074 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1795_0_0 -> 16 in the cache */
   /* search1795_0 -> 2006 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2006 },
      6,
   } },

   /* replace1795 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1796_0 -> 16 in the cache */
   /* search1796_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 124 },
      6,
   } },

   /* replace1796 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1797_0 -> 523 in the cache */
   /* search1797_1_0_0 -> 185 in the cache */
   /* search1797_1_0 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4967 },
      -1,
   } },
   /* search1797_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4995, 561 },
      6,
   } },

   /* replace1797_0 -> 523 in the cache */
   /* replace1797_1 -> 185 in the cache */
   /* replace1797_2 -> 561 in the cache */
   /* replace1797 -> 4970 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1798_0 -> 523 in the cache */
   /* search1798_1_0_0 -> 185 in the cache */
   /* search1798_1_0 -> 4971 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4971 },
      -1,
   } },
   /* search1798_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4997, 561 },
      6,
   } },

   /* replace1798_0 -> 523 in the cache */
   /* replace1798_1 -> 185 in the cache */
   /* replace1798_2 -> 561 in the cache */
   /* replace1798 -> 4970 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1799_0 -> 523 in the cache */
   /* search1799_1_0 -> 185 in the cache */
   /* search1799_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1799_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4999, 561 },
      6,
   } },

   /* replace1799_0 -> 523 in the cache */
   /* replace1799_1 -> 185 in the cache */
   /* replace1799_2 -> 561 in the cache */
   /* replace1799 -> 4970 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1800_0_0_0 -> 16 in the cache */
   /* search1800_0_0 -> 2006 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2006 },
      -1,
   } },
   /* search1800_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5001, 36 },
      6,
   } },

   /* replace1800_0 -> 16 in the cache */
   /* replace1800_1 -> 36 in the cache */
   /* replace1800 -> 3999 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1801_0_0_0 -> 16 in the cache */
   /* search1801_0_0 -> 4186 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4186 },
      -1,
   } },
   /* search1801_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5003, 36 },
      6,
   } },

   /* replace1801_0 -> 16 in the cache */
   /* replace1801_1 -> 36 in the cache */
   /* replace1801 -> 3999 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1802_0_0 -> 16 in the cache */
   /* search1802_0_1 -> 124 in the cache */
   /* search1802_0 -> 395 in the cache */
   /* search1802_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1802_0 -> 16 in the cache */
   /* replace1802_1 -> 36 in the cache */
   /* replace1802 -> 3999 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1803_0_0_0 -> 16 in the cache */
   /* search1803_0_0 -> 2006 in the cache */
   /* search1803_0 -> 5001 in the cache */
   /* search1803_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5001, 36 },
      6,
   } },

   /* replace1803_0 -> 16 in the cache */
   /* replace1803_1 -> 36 in the cache */
   /* replace1803 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1804_0_0_0 -> 16 in the cache */
   /* search1804_0_0 -> 4186 in the cache */
   /* search1804_0 -> 5003 in the cache */
   /* search1804_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5003, 36 },
      6,
   } },

   /* replace1804_0 -> 16 in the cache */
   /* replace1804_1 -> 36 in the cache */
   /* replace1804 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1805_0_0 -> 16 in the cache */
   /* search1805_0_1 -> 124 in the cache */
   /* search1805_0 -> 395 in the cache */
   /* search1805_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1805_0 -> 16 in the cache */
   /* replace1805_1 -> 36 in the cache */
   /* replace1805 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1806_0_0_0 -> 16 in the cache */
   /* search1806_0_0 -> 2006 in the cache */
   /* search1806_0 -> 5001 in the cache */
   /* search1806_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5001, 36 },
      6,
   } },

   /* replace1806_0 -> 16 in the cache */
   /* replace1806_1 -> 36 in the cache */
   /* replace1806 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1807_0_0_0 -> 16 in the cache */
   /* search1807_0_0 -> 4186 in the cache */
   /* search1807_0 -> 5003 in the cache */
   /* search1807_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5003, 36 },
      6,
   } },

   /* replace1807_0 -> 16 in the cache */
   /* replace1807_1 -> 36 in the cache */
   /* replace1807 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1808_0_0 -> 16 in the cache */
   /* search1808_0_1 -> 124 in the cache */
   /* search1808_0 -> 395 in the cache */
   /* search1808_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1808_0 -> 16 in the cache */
   /* replace1808_1 -> 36 in the cache */
   /* replace1808 -> 2012 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1809_0_0_0 -> 16 in the cache */
   /* search1809_0_0 -> 2006 in the cache */
   /* search1809_0 -> 5001 in the cache */
   /* search1809_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5001, 36 },
      6,
   } },

   /* replace1809_0 -> 16 in the cache */
   /* replace1809_1 -> 36 in the cache */
   /* replace1809 -> 2050 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1810_0_0_0 -> 16 in the cache */
   /* search1810_0_0 -> 4186 in the cache */
   /* search1810_0 -> 5003 in the cache */
   /* search1810_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5003, 36 },
      6,
   } },

   /* replace1810_0 -> 16 in the cache */
   /* replace1810_1 -> 36 in the cache */
   /* replace1810 -> 2050 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1811_0_0 -> 16 in the cache */
   /* search1811_0_1 -> 124 in the cache */
   /* search1811_0 -> 395 in the cache */
   /* search1811_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1811_0 -> 16 in the cache */
   /* replace1811_1 -> 36 in the cache */
   /* replace1811 -> 2050 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1812_0_0_0 -> 16 in the cache */
   /* search1812_0_0 -> 2006 in the cache */
   /* search1812_0 -> 5001 in the cache */
   /* search1812_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5001, 36 },
      6,
   } },

   /* replace1812_0 -> 16 in the cache */
   /* replace1812_1 -> 36 in the cache */
   /* replace1812 -> 2074 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1813_0_0_0 -> 16 in the cache */
   /* search1813_0_0 -> 4186 in the cache */
   /* search1813_0 -> 5003 in the cache */
   /* search1813_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5003, 36 },
      6,
   } },

   /* replace1813_0 -> 16 in the cache */
   /* replace1813_1 -> 36 in the cache */
   /* replace1813 -> 2074 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1814_0_0 -> 16 in the cache */
   /* search1814_0_1 -> 124 in the cache */
   /* search1814_0 -> 395 in the cache */
   /* search1814_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1814_0 -> 16 in the cache */
   /* replace1814_1 -> 36 in the cache */
   /* replace1814 -> 2074 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1815_0_0 -> 16 in the cache */
   /* search1815_0 -> 3230 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3230 },
      7,
   } },

   /* replace1815 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1816_0 -> 16 in the cache */
   /* search1816_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 124 },
      7,
   } },

   /* replace1816 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1817_0 -> 523 in the cache */
   /* search1817_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5020 },
      -1,
   } },
   /* search1817_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5021, 561 },
      7,
   } },

   /* replace1817_0 -> 523 in the cache */
   /* replace1817_1 -> 185 in the cache */
   /* replace1817_2 -> 561 in the cache */
   /* replace1817 -> 4970 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1818_0 -> 523 in the cache */
   /* search1818_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5023 },
      -1,
   } },
   /* search1818_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5024, 561 },
      7,
   } },

   /* replace1818_0 -> 523 in the cache */
   /* replace1818_1 -> 185 in the cache */
   /* replace1818_2 -> 561 in the cache */
   /* replace1818 -> 4970 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1819_0 -> 523 in the cache */
   /* search1819_1_0 -> 185 in the cache */
   /* search1819_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1819_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5026, 561 },
      7,
   } },

   /* replace1819_0 -> 523 in the cache */
   /* replace1819_1 -> 185 in the cache */
   /* replace1819_2 -> 561 in the cache */
   /* replace1819 -> 4970 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1820_0_0_0 -> 16 in the cache */
   /* search1820_0_0 -> 3230 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3230 },
      -1,
   } },
   /* search1820_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5028, 36 },
      7,
   } },

   /* replace1820_0 -> 16 in the cache */
   /* replace1820_1 -> 36 in the cache */
   /* replace1820 -> 3999 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1821_0_0_0 -> 16 in the cache */
   /* search1821_0_0 -> 4188 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4188 },
      -1,
   } },
   /* search1821_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5030, 36 },
      7,
   } },

   /* replace1821_0 -> 16 in the cache */
   /* replace1821_1 -> 36 in the cache */
   /* replace1821 -> 3999 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1822_0_0 -> 16 in the cache */
   /* search1822_0_1 -> 124 in the cache */
   /* search1822_0 -> 446 in the cache */
   /* search1822_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1822_0 -> 16 in the cache */
   /* replace1822_1 -> 36 in the cache */
   /* replace1822 -> 3999 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1823_0_0_0 -> 16 in the cache */
   /* search1823_0_0 -> 3230 in the cache */
   /* search1823_0 -> 5028 in the cache */
   /* search1823_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5028, 36 },
      7,
   } },

   /* replace1823_0 -> 16 in the cache */
   /* replace1823_1 -> 36 in the cache */
   /* replace1823 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1824_0_0_0 -> 16 in the cache */
   /* search1824_0_0 -> 4188 in the cache */
   /* search1824_0 -> 5030 in the cache */
   /* search1824_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5030, 36 },
      7,
   } },

   /* replace1824_0 -> 16 in the cache */
   /* replace1824_1 -> 36 in the cache */
   /* replace1824 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1825_0_0 -> 16 in the cache */
   /* search1825_0_1 -> 124 in the cache */
   /* search1825_0 -> 446 in the cache */
   /* search1825_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1825_0 -> 16 in the cache */
   /* replace1825_1 -> 36 in the cache */
   /* replace1825 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1826_0_0_0 -> 16 in the cache */
   /* search1826_0_0 -> 3230 in the cache */
   /* search1826_0 -> 5028 in the cache */
   /* search1826_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5028, 36 },
      7,
   } },

   /* replace1826_0 -> 16 in the cache */
   /* replace1826_1 -> 36 in the cache */
   /* replace1826 -> 2012 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1827_0_0_0 -> 16 in the cache */
   /* search1827_0_0 -> 4188 in the cache */
   /* search1827_0 -> 5030 in the cache */
   /* search1827_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5030, 36 },
      7,
   } },

   /* replace1827_0 -> 16 in the cache */
   /* replace1827_1 -> 36 in the cache */
   /* replace1827 -> 2012 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1828_0_0 -> 16 in the cache */
   /* search1828_0_1 -> 124 in the cache */
   /* search1828_0 -> 446 in the cache */
   /* search1828_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1828_0 -> 16 in the cache */
   /* replace1828_1 -> 36 in the cache */
   /* replace1828 -> 2012 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1829_0_0_0 -> 16 in the cache */
   /* search1829_0_0 -> 3230 in the cache */
   /* search1829_0 -> 5028 in the cache */
   /* search1829_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5028, 36 },
      7,
   } },

   /* replace1829_0 -> 16 in the cache */
   /* replace1829_1 -> 36 in the cache */
   /* replace1829 -> 2050 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1830_0_0_0 -> 16 in the cache */
   /* search1830_0_0 -> 4188 in the cache */
   /* search1830_0 -> 5030 in the cache */
   /* search1830_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5030, 36 },
      7,
   } },

   /* replace1830_0 -> 16 in the cache */
   /* replace1830_1 -> 36 in the cache */
   /* replace1830 -> 2050 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1831_0_0 -> 16 in the cache */
   /* search1831_0_1 -> 124 in the cache */
   /* search1831_0 -> 446 in the cache */
   /* search1831_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1831_0 -> 16 in the cache */
   /* replace1831_1 -> 36 in the cache */
   /* replace1831 -> 2050 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1832_0_0_0 -> 16 in the cache */
   /* search1832_0_0 -> 3230 in the cache */
   /* search1832_0 -> 5028 in the cache */
   /* search1832_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5028, 36 },
      7,
   } },

   /* replace1832_0 -> 16 in the cache */
   /* replace1832_1 -> 36 in the cache */
   /* replace1832 -> 2074 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1833_0_0_0 -> 16 in the cache */
   /* search1833_0_0 -> 4188 in the cache */
   /* search1833_0 -> 5030 in the cache */
   /* search1833_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5030, 36 },
      7,
   } },

   /* replace1833_0 -> 16 in the cache */
   /* replace1833_1 -> 36 in the cache */
   /* replace1833 -> 2074 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1834_0_0 -> 16 in the cache */
   /* search1834_0_1 -> 124 in the cache */
   /* search1834_0 -> 446 in the cache */
   /* search1834_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1834_0 -> 16 in the cache */
   /* replace1834_1 -> 36 in the cache */
   /* replace1834 -> 2074 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1835_0_0 -> 16 in the cache */
   /* search1835_0 -> 3230 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3230 },
      7,
   } },

   /* replace1835 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1836_0 -> 16 in the cache */
   /* search1836_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 124 },
      7,
   } },

   /* replace1836 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1837_0 -> 523 in the cache */
   /* search1837_1_0_0 -> 185 in the cache */
   /* search1837_1_0 -> 5020 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5020 },
      -1,
   } },
   /* search1837_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5047, 561 },
      7,
   } },

   /* replace1837_0 -> 523 in the cache */
   /* replace1837_1 -> 185 in the cache */
   /* replace1837_2 -> 561 in the cache */
   /* replace1837 -> 4970 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1838_0 -> 523 in the cache */
   /* search1838_1_0_0 -> 185 in the cache */
   /* search1838_1_0 -> 5023 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5023 },
      -1,
   } },
   /* search1838_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5049, 561 },
      7,
   } },

   /* replace1838_0 -> 523 in the cache */
   /* replace1838_1 -> 185 in the cache */
   /* replace1838_2 -> 561 in the cache */
   /* replace1838 -> 4970 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1839_0 -> 523 in the cache */
   /* search1839_1_0 -> 185 in the cache */
   /* search1839_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1839_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5051, 561 },
      7,
   } },

   /* replace1839_0 -> 523 in the cache */
   /* replace1839_1 -> 185 in the cache */
   /* replace1839_2 -> 561 in the cache */
   /* replace1839 -> 4970 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1840_0_0_0 -> 16 in the cache */
   /* search1840_0_0 -> 3230 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3230 },
      -1,
   } },
   /* search1840_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5053, 36 },
      7,
   } },

   /* replace1840_0 -> 16 in the cache */
   /* replace1840_1 -> 36 in the cache */
   /* replace1840 -> 3999 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1841_0_0_0 -> 16 in the cache */
   /* search1841_0_0 -> 4188 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4188 },
      -1,
   } },
   /* search1841_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5055, 36 },
      7,
   } },

   /* replace1841_0 -> 16 in the cache */
   /* replace1841_1 -> 36 in the cache */
   /* replace1841 -> 3999 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1842_0_0 -> 16 in the cache */
   /* search1842_0_1 -> 124 in the cache */
   /* search1842_0 -> 438 in the cache */
   /* search1842_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1842_0 -> 16 in the cache */
   /* replace1842_1 -> 36 in the cache */
   /* replace1842 -> 3999 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1843_0_0_0 -> 16 in the cache */
   /* search1843_0_0 -> 3230 in the cache */
   /* search1843_0 -> 5053 in the cache */
   /* search1843_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5053, 36 },
      7,
   } },

   /* replace1843_0 -> 16 in the cache */
   /* replace1843_1 -> 36 in the cache */
   /* replace1843 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1844_0_0_0 -> 16 in the cache */
   /* search1844_0_0 -> 4188 in the cache */
   /* search1844_0 -> 5055 in the cache */
   /* search1844_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5055, 36 },
      7,
   } },

   /* replace1844_0 -> 16 in the cache */
   /* replace1844_1 -> 36 in the cache */
   /* replace1844 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1845_0_0 -> 16 in the cache */
   /* search1845_0_1 -> 124 in the cache */
   /* search1845_0 -> 438 in the cache */
   /* search1845_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1845_0 -> 16 in the cache */
   /* replace1845_1 -> 36 in the cache */
   /* replace1845 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1846_0_0_0 -> 16 in the cache */
   /* search1846_0_0 -> 3230 in the cache */
   /* search1846_0 -> 5053 in the cache */
   /* search1846_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5053, 36 },
      7,
   } },

   /* replace1846_0 -> 16 in the cache */
   /* replace1846_1 -> 36 in the cache */
   /* replace1846 -> 2012 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1847_0_0_0 -> 16 in the cache */
   /* search1847_0_0 -> 4188 in the cache */
   /* search1847_0 -> 5055 in the cache */
   /* search1847_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5055, 36 },
      7,
   } },

   /* replace1847_0 -> 16 in the cache */
   /* replace1847_1 -> 36 in the cache */
   /* replace1847 -> 2012 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1848_0_0 -> 16 in the cache */
   /* search1848_0_1 -> 124 in the cache */
   /* search1848_0 -> 438 in the cache */
   /* search1848_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1848_0 -> 16 in the cache */
   /* replace1848_1 -> 36 in the cache */
   /* replace1848 -> 2012 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1849_0_0_0 -> 16 in the cache */
   /* search1849_0_0 -> 3230 in the cache */
   /* search1849_0 -> 5053 in the cache */
   /* search1849_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5053, 36 },
      7,
   } },

   /* replace1849_0 -> 16 in the cache */
   /* replace1849_1 -> 36 in the cache */
   /* replace1849 -> 2050 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1850_0_0_0 -> 16 in the cache */
   /* search1850_0_0 -> 4188 in the cache */
   /* search1850_0 -> 5055 in the cache */
   /* search1850_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5055, 36 },
      7,
   } },

   /* replace1850_0 -> 16 in the cache */
   /* replace1850_1 -> 36 in the cache */
   /* replace1850 -> 2050 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1851_0_0 -> 16 in the cache */
   /* search1851_0_1 -> 124 in the cache */
   /* search1851_0 -> 438 in the cache */
   /* search1851_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1851_0 -> 16 in the cache */
   /* replace1851_1 -> 36 in the cache */
   /* replace1851 -> 2050 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1852_0_0_0 -> 16 in the cache */
   /* search1852_0_0 -> 3230 in the cache */
   /* search1852_0 -> 5053 in the cache */
   /* search1852_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5053, 36 },
      7,
   } },

   /* replace1852_0 -> 16 in the cache */
   /* replace1852_1 -> 36 in the cache */
   /* replace1852 -> 2074 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1853_0_0_0 -> 16 in the cache */
   /* search1853_0_0 -> 4188 in the cache */
   /* search1853_0 -> 5055 in the cache */
   /* search1853_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5055, 36 },
      7,
   } },

   /* replace1853_0 -> 16 in the cache */
   /* replace1853_1 -> 36 in the cache */
   /* replace1853 -> 2074 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1854_0_0 -> 16 in the cache */
   /* search1854_0_1 -> 124 in the cache */
   /* search1854_0 -> 438 in the cache */
   /* search1854_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1854_0 -> 16 in the cache */
   /* replace1854_1 -> 36 in the cache */
   /* replace1854 -> 2074 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5070, 5071 },
      -1,
   } },

   /* replace1855_0_0 -> 5070 in the cache */
   /* replace1855_0_1_0_0_0_0_0_0 -> 5071 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5071, 5073 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5074, 5075 },
      -1,
   } },
   /* replace1855_0_1_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5076, 398 },
      -1,
   } },
   /* replace1855_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5077, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5078, 5079 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 5080 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5070, 5081 },
      -1,
   } },
   /* replace1855_1_0_0_0_0_0_0 -> 5071 in the cache */
   /* replace1855_1_0_0_0_0_0_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5071, 5073 },
      -1,
   } },
   /* replace1855_1_0_0_0_0_1 -> 5075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5083, 5075 },
      -1,
   } },
   /* replace1855_1_0_0_0_1_0_0_0 -> 5071 in the cache */
   /* replace1855_1_0_0_0_1_0_0_1 -> 5073 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5071, 5073 },
      -1,
   } },
   /* replace1855_1_0_0_0_1_0_1 -> 5075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5085, 5075 },
      -1,
   } },
   /* replace1855_1_0_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5086, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5084, 5087 },
      -1,
   } },
   /* replace1855_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5088, 14 },
      -1,
   } },
   /* replace1855_1_0_1 -> 5079 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5089, 5079 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 5090 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5082, 5091 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1856_1 -> 5071 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5093, 5071 },
      -1,
   } },

   /* replace1856_0_0 -> 5093 in the cache */
   /* replace1856_0_1_0_0_0_0_0 -> 5071 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5071, 5095 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5096, 5097 },
      -1,
   } },
   /* replace1856_0_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5098, 398 },
      -1,
   } },
   /* replace1856_0_1_0_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5099, 4272 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5100, 5101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5093, 5102 },
      -1,
   } },
   /* replace1856_1_0_0_0_0_0 -> 5071 in the cache */
   /* replace1856_1_0_0_0_0_1 -> 5095 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5071, 5095 },
      -1,
   } },
   /* replace1856_1_0_0_0_1 -> 5097 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5104, 5097 },
      -1,
   } },
   /* replace1856_1_0_0_1_0_0_0 -> 5071 in the cache */
   /* replace1856_1_0_0_1_0_0_1 -> 5095 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5071, 5095 },
      -1,
   } },
   /* replace1856_1_0_0_1_0_1 -> 5097 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5106, 5097 },
      -1,
   } },
   /* replace1856_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5107, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5105, 5108 },
      -1,
   } },
   /* replace1856_1_0_1 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5109, 4272 },
      -1,
   } },
   /* replace1856_1_1 -> 5101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5110, 5101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5103, 5111 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1857_1 -> 5071 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5113, 5071 },
      -1,
   } },

   /* replace1857_0_0 -> 5113 in the cache */
   /* replace1857_0_1_0 -> 124 in the cache */
   /* replace1857_0_1_1_0_0_0_0_0 -> 5071 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5071, 5115 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5116, 5117 },
      -1,
   } },
   /* replace1857_0_1_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5118, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5119, 5120 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5121, 5122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 124, 5123 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5113, 5124 },
      -1,
   } },
   /* replace1857_1_0 -> 124 in the cache */
   /* replace1857_1_1_0_0_0_0_0 -> 5071 in the cache */
   /* replace1857_1_1_0_0_0_0_1 -> 5115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5071, 5115 },
      -1,
   } },
   /* replace1857_1_1_0_0_0_1 -> 5117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5126, 5117 },
      -1,
   } },
   /* replace1857_1_1_0_0_1_0_0_0 -> 5071 in the cache */
   /* replace1857_1_1_0_0_1_0_0_1 -> 5115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5071, 5115 },
      -1,
   } },
   /* replace1857_1_1_0_0_1_0_1 -> 5117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5128, 5117 },
      -1,
   } },
   /* replace1857_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5129, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5127, 5130 },
      -1,
   } },
   /* replace1857_1_1_0_1 -> 5120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5131, 5120 },
      -1,
   } },
   /* replace1857_1_1_1 -> 5122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5132, 5122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 124, 5133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5125, 5134 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1858_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 5093, 832 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 5093, 832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 5136, 5137 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5138, 5139 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5140, 810 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 5136, 5137 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5142, 5143 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5144, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5141, 5145 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5146, 5147 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5148, 2179 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5150, 5139 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5151, 810 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5153, 5143 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5154, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5152, 5155 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5156, 5157 },
      -1,
   } },
   /* search1858_0_0_0_0_0_0_1_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5158, 2179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5149, 5159 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5160, 5161 },
      -1,
   } },
   /* search1858_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5162, 403 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5164, 5139 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5165, 810 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5167, 5143 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5168, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5166, 5169 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5170, 5147 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5171, 2179 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5173, 5139 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5174, 810 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5176, 5143 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5177, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5175, 5178 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_0_1 -> 5157 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5179, 5157 },
      -1,
   } },
   /* search1858_0_0_0_1_0_0_1_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5180, 2179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5172, 5181 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5182, 5183 },
      -1,
   } },
   /* search1858_0_0_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5184, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5163, 5185 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5186, 5187 },
      -1,
   } },
   /* search1858_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 5188, 398 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5190, 5139 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5191, 810 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5193, 5143 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5194, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5192, 5195 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5196, 5147 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5197, 2179 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5199, 5139 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5200, 810 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5202, 5143 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5203, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5201, 5204 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_0_1 -> 5157 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5205, 5157 },
      -1,
   } },
   /* search1858_1_0_0_0_0_0_1_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5206, 2179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5198, 5207 },
      -1,
   } },
   /* search1858_1_0_0_0_0_1 -> 5161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5208, 5161 },
      -1,
   } },
   /* search1858_1_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5209, 403 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5211, 5139 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5212, 810 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5214, 5143 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5215, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5213, 5216 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5217, 5147 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5218, 2179 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_0_0_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5220, 5139 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5221, 810 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 5136, 5137 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_1_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5223, 5143 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_0_1_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5224, 810 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5222, 5225 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_0_1 -> 5157 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5226, 5157 },
      -1,
   } },
   /* search1858_1_0_0_1_0_0_1_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5227, 2179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5219, 5228 },
      -1,
   } },
   /* search1858_1_0_0_1_0_1 -> 5183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5229, 5183 },
      -1,
   } },
   /* search1858_1_0_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5230, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5210, 5231 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5232, 5233 },
      -1,
   } },
   /* search1858_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 5234, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5189, 5235 },
      -1,
   } },

   /* replace1858_0 -> 5093 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 5093 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_0 -> 5138 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5138, 398 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_0_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5238, 5233 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_0 -> 5142 in the cache */
   /* search1859_0_0_0_0_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5142, 398 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_0_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5240, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5239, 5241 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5242, 403 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_0_1 -> 5183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5243, 5183 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_0 -> 5150 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5150, 398 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5245, 5233 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_0 -> 5153 in the cache */
   /* search1859_0_0_0_0_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5153, 398 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5247, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5246, 5248 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5249, 403 },
      -1,
   } },
   /* search1859_0_0_0_0_0_0_1_1 -> 5161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5250, 5161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5244, 5251 },
      -1,
   } },
   /* search1859_0_0_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5252, 2179 },
      -1,
   } },
   /* search1859_0_0_0_0_1 -> 5157 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5253, 5157 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_0 -> 5164 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5164, 398 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5255, 5233 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_0 -> 5167 in the cache */
   /* search1859_0_0_0_1_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5167, 398 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5257, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5256, 5258 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5259, 403 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_0_1 -> 5183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5260, 5183 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_0 -> 5173 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5173, 398 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5262, 5233 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_0 -> 5176 in the cache */
   /* search1859_0_0_0_1_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5176, 398 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5264, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5263, 5265 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5266, 403 },
      -1,
   } },
   /* search1859_0_0_0_1_0_0_1_1 -> 5161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5267, 5161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5261, 5268 },
      -1,
   } },
   /* search1859_0_0_0_1_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5269, 2179 },
      -1,
   } },
   /* search1859_0_0_0_1_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5270, 5147 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5254, 5271 },
      -1,
   } },
   /* search1859_0_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 5272, 810 },
      -1,
   } },
   /* search1859_0_1 -> 5143 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5273, 5143 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_0 -> 5190 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5190, 398 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5275, 5233 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_0 -> 5193 in the cache */
   /* search1859_1_0_0_0_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5193, 398 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5277, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5276, 5278 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5279, 403 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_0_1 -> 5183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5280, 5183 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_0 -> 5199 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5199, 398 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5282, 5233 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_0 -> 5202 in the cache */
   /* search1859_1_0_0_0_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5202, 398 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5284, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5283, 5285 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5286, 403 },
      -1,
   } },
   /* search1859_1_0_0_0_0_0_1_1 -> 5161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5287, 5161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5281, 5288 },
      -1,
   } },
   /* search1859_1_0_0_0_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5289, 2179 },
      -1,
   } },
   /* search1859_1_0_0_0_1 -> 5157 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5290, 5157 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_0 -> 5211 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5211, 398 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5292, 5233 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_0 -> 5214 in the cache */
   /* search1859_1_0_0_1_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5214, 398 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5294, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5293, 5295 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5296, 403 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_0_1 -> 5183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5297, 5183 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_0 -> 5220 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5220, 398 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_0_0_0_1 -> 5233 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5299, 5233 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5136 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5093 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 832 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5137 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_0 -> 5223 in the cache */
   /* search1859_1_0_0_1_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5223, 398 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_0_0_1_1 -> 5187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5301, 5187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5300, 5302 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5303, 403 },
      -1,
   } },
   /* search1859_1_0_0_1_0_0_1_1 -> 5161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5304, 5161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5298, 5305 },
      -1,
   } },
   /* search1859_1_0_0_1_0_1 -> 2179 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5306, 2179 },
      -1,
   } },
   /* search1859_1_0_0_1_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5307, 5147 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5291, 5308 },
      -1,
   } },
   /* search1859_1_0_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5309, 810 },
      -1,
   } },
   /* search1859_1_1 -> 5139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5310, 5139 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5274, 5311 },
      -1,
   } },

   /* replace1859_0 -> 5093 in the cache */
   /* replace1859 -> 5237 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1860_0_0 -> 0 in the cache */
   /* search1860_0_1 -> 3 in the cache */
   /* search1860_0 -> 1059 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1059, 5313 },
      -1,
   } },

   /* replace1860_0 -> 0 in the cache */
   /* replace1860_1 -> 3 in the cache */
   /* replace1860 -> 2419 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1861_0_0 -> 0 in the cache */
   /* search1861_0_1 -> 3 in the cache */
   /* search1861_0 -> 1053 in the cache */
   /* search1861_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1053, 5313 },
      -1,
   } },

   /* replace1861_0 -> 0 in the cache */
   /* replace1861_1 -> 3 in the cache */
   /* replace1861 -> 2489 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1862_0_0 -> 0 in the cache */
   /* search1862_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5316, 5317 },
      -1,
   } },

   /* replace1862_0 -> 0 in the cache */
   /* replace1862_1 -> 3 in the cache */
   /* replace1862 -> 2530 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1863_0_0 -> 0 in the cache */
   /* search1863_0_1 -> 3 in the cache */
   /* search1863_0 -> 4031 in the cache */
   /* search1863_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 4031, 5317 },
      -1,
   } },

   /* replace1863_0 -> 0 in the cache */
   /* replace1863_1 -> 3 in the cache */
   /* replace1863 -> 2571 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1864_0_0 -> 0 in the cache */
   /* search1864_0_1 -> 3 in the cache */
   /* search1864_0 -> 1059 in the cache */
   /* search1864_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1059, 5313 },
      -1,
   } },

   /* replace1864_0 -> 0 in the cache */
   /* replace1864_1 -> 3 in the cache */
   /* replace1864 -> 2425 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1865_0_0 -> 0 in the cache */
   /* search1865_0_1 -> 3 in the cache */
   /* search1865_0 -> 1053 in the cache */
   /* search1865_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1053, 5313 },
      -1,
   } },

   /* replace1865_0 -> 0 in the cache */
   /* replace1865_1 -> 3 in the cache */
   /* replace1865 -> 2493 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1866_0_0 -> 0 in the cache */
   /* search1866_0_1 -> 3 in the cache */
   /* search1866_0 -> 5316 in the cache */
   /* search1866_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5316, 5317 },
      -1,
   } },

   /* replace1866_0 -> 0 in the cache */
   /* replace1866_1 -> 3 in the cache */
   /* replace1866 -> 2534 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1867_0_0 -> 0 in the cache */
   /* search1867_0_1 -> 3 in the cache */
   /* search1867_0 -> 4031 in the cache */
   /* search1867_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 4031, 5317 },
      -1,
   } },

   /* replace1867_0 -> 0 in the cache */
   /* replace1867_1 -> 3 in the cache */
   /* replace1867 -> 2575 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1868_0_0 -> 0 in the cache */
   /* search1868_0_1 -> 3 in the cache */
   /* search1868_0 -> 1059 in the cache */
   /* search1868_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1059, 5313 },
      -1,
   } },

   /* replace1868_0 -> 0 in the cache */
   /* replace1868_1 -> 3 in the cache */
   /* replace1868 -> 2432 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1869_0_0 -> 0 in the cache */
   /* search1869_0_1 -> 3 in the cache */
   /* search1869_0 -> 1053 in the cache */
   /* search1869_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1053, 5313 },
      -1,
   } },

   /* replace1869_0 -> 0 in the cache */
   /* replace1869_1 -> 3 in the cache */
   /* replace1869 -> 2499 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1870_0_0 -> 0 in the cache */
   /* search1870_0_1 -> 3 in the cache */
   /* search1870_0 -> 5316 in the cache */
   /* search1870_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5316, 5317 },
      -1,
   } },

   /* replace1870_0 -> 0 in the cache */
   /* replace1870_1 -> 3 in the cache */
   /* replace1870 -> 2540 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1871_0_0 -> 0 in the cache */
   /* search1871_0_1 -> 3 in the cache */
   /* search1871_0 -> 4031 in the cache */
   /* search1871_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 4031, 5317 },
      -1,
   } },

   /* replace1871_0 -> 0 in the cache */
   /* replace1871_1 -> 3 in the cache */
   /* replace1871 -> 2581 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1872_0_0 -> 0 in the cache */
   /* search1872_0_1 -> 3 in the cache */
   /* search1872_0 -> 1059 in the cache */
   /* search1872_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1059, 5313 },
      -1,
   } },

   /* replace1872_0 -> 0 in the cache */
   /* replace1872_1 -> 3 in the cache */
   /* replace1872 -> 2439 in the cache */

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1873_0_0 -> 0 in the cache */
   /* search1873_0_1 -> 3 in the cache */
   /* search1873_0 -> 1053 in the cache */
   /* search1873_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1053, 5313 },
      -1,
   } },

   /* replace1873_0 -> 0 in the cache */
   /* replace1873_1 -> 3 in the cache */
   /* replace1873 -> 2504 in the cache */

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1874_0_0 -> 0 in the cache */
   /* search1874_0_1 -> 3 in the cache */
   /* search1874_0 -> 5316 in the cache */
   /* search1874_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5316, 5317 },
      -1,
   } },

   /* replace1874_0 -> 0 in the cache */
   /* replace1874_1 -> 3 in the cache */
   /* replace1874 -> 2545 in the cache */

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1875_0_0 -> 0 in the cache */
   /* search1875_0_1 -> 3 in the cache */
   /* search1875_0 -> 4031 in the cache */
   /* search1875_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 4031, 5317 },
      -1,
   } },

   /* replace1875_0 -> 0 in the cache */
   /* replace1875_1 -> 3 in the cache */
   /* replace1875 -> 2586 in the cache */

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1876_0_0 -> 0 in the cache */
   /* search1876_0_1 -> 3 in the cache */
   /* search1876_0 -> 1059 in the cache */
   /* search1876_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1059, 5313 },
      -1,
   } },

   /* replace1876_0 -> 0 in the cache */
   /* replace1876_1 -> 3 in the cache */
   /* replace1876 -> 2456 in the cache */

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1877_0_0 -> 0 in the cache */
   /* search1877_0_1 -> 3 in the cache */
   /* search1877_0 -> 1053 in the cache */
   /* search1877_1 -> 5313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1053, 5313 },
      -1,
   } },

   /* replace1877_0 -> 0 in the cache */
   /* replace1877_1 -> 3 in the cache */
   /* replace1877 -> 2513 in the cache */

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1878_0_0 -> 0 in the cache */
   /* search1878_0_1 -> 3 in the cache */
   /* search1878_0 -> 5316 in the cache */
   /* search1878_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5316, 5317 },
      -1,
   } },

   /* replace1878_0 -> 0 in the cache */
   /* replace1878_1 -> 3 in the cache */
   /* replace1878 -> 2554 in the cache */

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1879_0_0 -> 0 in the cache */
   /* search1879_0_1 -> 3 in the cache */
   /* search1879_0 -> 4031 in the cache */
   /* search1879_1 -> 5317 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 4031, 5317 },
      -1,
   } },

   /* replace1879_0 -> 0 in the cache */
   /* replace1879_1 -> 3 in the cache */
   /* replace1879 -> 2595 in the cache */

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1880_0_0 -> 0 in the cache */
   /* search1880_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1880_1_0 -> 0 in the cache */
   /* search1880_1_1 -> 3 in the cache */
   /* search1880_1 -> 1028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5336, 1028 },
      -1,
   } },

   /* replace1880_0 -> 0 in the cache */
   /* replace1880_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1881_0_0 -> 32 in the cache */
   /* search1881_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1881_1_0 -> 2252 in the cache */
   /* search1881_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5339, 5340 },
      -1,
   } },

   /* replace1881_0 -> 2252 in the cache */
   /* replace1881_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2252, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1882_0_0 -> 0 in the cache */
   /* search1882_0_1 -> 0 in the cache */
   /* search1882_0 -> 5336 in the cache */
   /* search1882_1_0 -> 0 in the cache */
   /* search1882_1_1 -> 3 in the cache */
   /* search1882_1 -> 1025 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5336, 1025 },
      -1,
   } },

   /* replace1882_0 -> 0 in the cache */
   /* replace1882_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1883_0_0 -> 32 in the cache */
   /* search1883_0_1 -> 32 in the cache */
   /* search1883_0 -> 5339 in the cache */
   /* search1883_1_0 -> 2252 in the cache */
   /* search1883_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5339, 5345 },
      -1,
   } },

   /* replace1883_0 -> 2252 in the cache */
   /* replace1883_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2252, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1884_0_0 -> 0 in the cache */
   /* search1884_0_1 -> 0 in the cache */
   /* search1884_0 -> 5336 in the cache */
   /* search1884_1_0 -> 0 in the cache */
   /* search1884_1_1 -> 3 in the cache */
   /* search1884_1 -> 1053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5336, 1053 },
      -1,
   } },

   /* replace1884_0 -> 0 in the cache */
   /* replace1884_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1885_0_0 -> 32 in the cache */
   /* search1885_0_1 -> 32 in the cache */
   /* search1885_0 -> 5339 in the cache */
   /* search1885_1_0 -> 2252 in the cache */
   /* search1885_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2252, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5339, 5350 },
      -1,
   } },

   /* replace1885_0 -> 2252 in the cache */
   /* replace1885_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2252, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1886_0_0 -> 739 in the cache */
   /* search1886_0_1 -> 1007 in the cache */
   /* search1886_0_2 -> 3418 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1007, 3418 },
      -1,
   } },
   /* search1886_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5353, 1010 },
      -1,
   } },

   /* replace1886_0 -> 739 in the cache */
   /* replace1886_1_0 -> 152 in the cache */
   /* replace1886_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1886_2_0 -> 154 in the cache */
   /* replace1886_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5355, 5356 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1887_0_0 -> 739 in the cache */
   /* search1887_0_1 -> 1007 in the cache */
   /* search1887_0_2 -> 3418 in the cache */
   /* search1887_0 -> 5353 in the cache */
   /* search1887_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5353, 1010 },
      -1,
   } },

   /* replace1887_0 -> 739 in the cache */
   /* replace1887_1_0 -> 152 in the cache */
   /* replace1887_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1887_2_0 -> 154 in the cache */
   /* replace1887_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5359, 5360 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1888_0_0 -> 739 in the cache */
   /* search1888_0_1 -> 1007 in the cache */
   /* search1888_0_2 -> 3418 in the cache */
   /* search1888_0 -> 5353 in the cache */
   /* search1888_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5353, 1010 },
      -1,
   } },

   /* replace1888_0 -> 739 in the cache */
   /* replace1888_1_0 -> 152 in the cache */
   /* replace1888_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1888_2_0 -> 154 in the cache */
   /* replace1888_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5363, 5364 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1889_0_0 -> 739 in the cache */
   /* search1889_0_1 -> 1007 in the cache */
   /* search1889_0_2 -> 3418 in the cache */
   /* search1889_0 -> 5353 in the cache */
   /* search1889_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5353, 1010 },
      -1,
   } },

   /* replace1889_0 -> 739 in the cache */
   /* replace1889_1_0 -> 152 in the cache */
   /* replace1889_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1889_2_0 -> 154 in the cache */
   /* replace1889_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5367, 5368 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1890_0_0 -> 739 in the cache */
   /* search1890_0_1 -> 1007 in the cache */
   /* search1890_0_2 -> 3418 in the cache */
   /* search1890_0 -> 5353 in the cache */
   /* search1890_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1890_0 -> 739 in the cache */
   /* replace1890_1_0 -> 152 in the cache */
   /* replace1890_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1890_2_0 -> 154 in the cache */
   /* replace1890_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5371, 5372 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1891_1_0 -> 1148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5375, 5376 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1891_0 -> 1148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1891_2_0 -> 5379 in the cache */
   /* replace1891_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5381, 5382 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1892_0_0 -> 739 in the cache */
   /* search1892_0_1 -> 1007 in the cache */
   /* search1892_0_2 -> 3418 in the cache */
   /* search1892_0 -> 5353 in the cache */
   /* search1892_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1892_0 -> 739 in the cache */
   /* replace1892_1_0 -> 152 in the cache */
   /* replace1892_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1892_2_0 -> 154 in the cache */
   /* replace1892_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5385, 5386 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1893_0 -> 5374 in the cache */
   /* search1893_1_0 -> 1148 in the cache */
   /* search1893_1_1 -> 5375 in the cache */
   /* search1893_1_2 -> 5376 in the cache */
   /* search1893_1 -> 5377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1893_0 -> 1148 in the cache */
   /* replace1893_1_0 -> 5379 in the cache */
   /* replace1893_1_1 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1893_2_0 -> 5379 in the cache */
   /* replace1893_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5389, 5390 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1894_0_0 -> 739 in the cache */
   /* search1894_0_1 -> 1007 in the cache */
   /* search1894_0_2 -> 3418 in the cache */
   /* search1894_0 -> 5353 in the cache */
   /* search1894_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1894_0 -> 739 in the cache */
   /* replace1894_1_0 -> 152 in the cache */
   /* replace1894_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1894_2_0 -> 154 in the cache */
   /* replace1894_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5393, 5394 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1895_0 -> 5374 in the cache */
   /* search1895_1_0 -> 1148 in the cache */
   /* search1895_1_1 -> 5375 in the cache */
   /* search1895_1_2 -> 5376 in the cache */
   /* search1895_1 -> 5377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1895_0 -> 1148 in the cache */
   /* replace1895_1_0 -> 5379 in the cache */
   /* replace1895_1_1 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1895_2_0 -> 5379 in the cache */
   /* replace1895_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5397, 5398 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1896_0_0 -> 739 in the cache */
   /* search1896_0_1 -> 1007 in the cache */
   /* search1896_0_2 -> 3418 in the cache */
   /* search1896_0 -> 5353 in the cache */
   /* search1896_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1896_0 -> 739 in the cache */
   /* replace1896_1_0 -> 152 in the cache */
   /* replace1896_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1896_2_0 -> 154 in the cache */
   /* replace1896_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5401, 5402 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1897_0 -> 5374 in the cache */
   /* search1897_1_0 -> 1148 in the cache */
   /* search1897_1_1 -> 5375 in the cache */
   /* search1897_1_2 -> 5376 in the cache */
   /* search1897_1 -> 5377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1897_0 -> 1148 in the cache */
   /* replace1897_1_0 -> 5379 in the cache */
   /* replace1897_1_1 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1897_2_0 -> 5379 in the cache */
   /* replace1897_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5405, 5406 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1898_0_0 -> 739 in the cache */
   /* search1898_0_1 -> 1007 in the cache */
   /* search1898_0_2 -> 3418 in the cache */
   /* search1898_0 -> 5353 in the cache */
   /* search1898_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1898_0 -> 739 in the cache */
   /* replace1898_1_0 -> 152 in the cache */
   /* replace1898_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1898_2_0 -> 154 in the cache */
   /* replace1898_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5409, 5410 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1899_0 -> 5374 in the cache */
   /* search1899_1_0 -> 1148 in the cache */
   /* search1899_1_1 -> 5375 in the cache */
   /* search1899_1_2 -> 5376 in the cache */
   /* search1899_1 -> 5377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1899_0 -> 1148 in the cache */
   /* replace1899_1_0 -> 5379 in the cache */
   /* replace1899_1_1 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1899_2_0 -> 5379 in the cache */
   /* replace1899_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5413, 5414 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1900_0_0 -> 739 in the cache */
   /* search1900_0_1 -> 1007 in the cache */
   /* search1900_0_2 -> 3418 in the cache */
   /* search1900_0 -> 5353 in the cache */
   /* search1900_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5353, 1010 },
      -1,
   } },

   /* replace1900_0 -> 739 in the cache */
   /* replace1900_1_0 -> 152 in the cache */
   /* replace1900_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1900_2_0 -> 154 in the cache */
   /* replace1900_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5417, 5418 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1901_0 -> 5374 in the cache */
   /* search1901_1_0 -> 1148 in the cache */
   /* search1901_1_1 -> 5375 in the cache */
   /* search1901_1_2 -> 5376 in the cache */
   /* search1901_1 -> 5377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5374, 5377 },
      -1,
   } },

   /* replace1901_0 -> 1148 in the cache */
   /* replace1901_1_0 -> 5379 in the cache */
   /* replace1901_1_1 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5379, 5380 },
      -1,
   } },
   /* replace1901_2_0 -> 5379 in the cache */
   /* replace1901_2_1 -> 1703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5379, 1703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1148, 5421, 5422 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1902_0_0 -> 739 in the cache */
   /* search1902_0_1 -> 1007 in the cache */
   /* search1902_0_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 1007, 154 },
      0,
   } },
   /* search1902_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5424, 1010 },
      -1,
   } },

   /* replace1902_0 -> 739 in the cache */
   /* replace1902_1_0 -> 152 in the cache */
   /* replace1902_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1902_2_0 -> 154 in the cache */
   /* replace1902_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5426, 5427 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1903_0_0 -> 739 in the cache */
   /* search1903_0_1 -> 1007 in the cache */
   /* search1903_0_2 -> 154 in the cache */
   /* search1903_0 -> 5424 in the cache */
   /* search1903_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5424, 1010 },
      -1,
   } },

   /* replace1903_0 -> 739 in the cache */
   /* replace1903_1_0 -> 152 in the cache */
   /* replace1903_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1903_2_0 -> 154 in the cache */
   /* replace1903_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5430, 5431 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1904_0_0 -> 739 in the cache */
   /* search1904_0_1 -> 33 in the cache */
   /* search1904_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 33, 137 },
      0,
   } },
   /* search1904_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5433, 313 },
      -1,
   } },

   /* replace1904_0 -> 739 in the cache */
   /* replace1904_1_0 -> 36 in the cache */
   /* replace1904_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 165 },
      -1,
   } },
   /* replace1904_2_0 -> 137 in the cache */
   /* replace1904_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5435, 5436 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1905_0_0 -> 739 in the cache */
   /* search1905_0_1 -> 1007 in the cache */
   /* search1905_0_2 -> 154 in the cache */
   /* search1905_0 -> 5424 in the cache */
   /* search1905_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5424, 1010 },
      -1,
   } },

   /* replace1905_0 -> 739 in the cache */
   /* replace1905_1_0 -> 152 in the cache */
   /* replace1905_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1905_2_0 -> 154 in the cache */
   /* replace1905_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5439, 5440 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1906_0_0 -> 739 in the cache */
   /* search1906_0_1 -> 1007 in the cache */
   /* search1906_0_2 -> 154 in the cache */
   /* search1906_0 -> 5424 in the cache */
   /* search1906_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5424, 1010 },
      -1,
   } },

   /* replace1906_0 -> 739 in the cache */
   /* replace1906_1_0 -> 152 in the cache */
   /* replace1906_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1906_2_0 -> 154 in the cache */
   /* replace1906_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5443, 5444 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1907_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1907 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1908_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1908 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1909_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1909 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1910_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1910 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1911_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1911 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1912_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1912 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1913_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5452, 36 },
      -1,
   } },

   /* replace1913 -> 124 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1914_0 -> 5452 in the cache */
   /* search1914_1 -> 36 in the cache */
   /* search1914_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5452, 36, 137 },
      -1,
   } },

   /* replace1914 -> 137 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1915_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      32,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1915_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5455, 137 },
      -1,
   } },

   /* replace1915 -> 137 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1916_0 -> 739 in the cache */
   /* search1916_1_0 -> 731 in the cache */
   /* search1916_1_1 -> 732 in the cache */
   /* search1916_1_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 732, 741 },
      0,
   } },
   /* search1916_2_0 -> 731 in the cache */
   /* search1916_2_1 -> 732 in the cache */
   /* search1916_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 732, 743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5457, 5458 },
      -1,
   } },

   /* replace1916_0 -> 731 in the cache */
   /* replace1916_1 -> 732 in the cache */
   /* replace1916_2_0 -> 739 in the cache */
   /* replace1916_2_1 -> 741 in the cache */
   /* replace1916_2_2 -> 743 in the cache */
   /* replace1916_2 -> 1294 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 732, 1294 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1917_0 -> 739 in the cache */
   /* search1917_1_0 -> 731 in the cache */
   /* search1917_1_1 -> 732 in the cache */
   /* search1917_1_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 732, 741 },
      -1,
   } },
   /* search1917_2_0 -> 731 in the cache */
   /* search1917_2_1 -> 732 in the cache */
   /* search1917_2_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 732, 743 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5461, 5462 },
      -1,
   } },

   /* replace1917_0 -> 731 in the cache */
   /* replace1917_1 -> 732 in the cache */
   /* replace1917_2_0 -> 739 in the cache */
   /* replace1917_2_1 -> 741 in the cache */
   /* replace1917_2_2 -> 743 in the cache */
   /* replace1917_2 -> 1294 in the cache */
   /* replace1917 -> 5460 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1918_0 -> 739 in the cache */
   /* search1918_1_0 -> 731 in the cache */
   /* search1918_1_1 -> 732 in the cache */
   /* search1918_1_2 -> 741 in the cache */
   /* search1918_1 -> 5457 in the cache */
   /* search1918_2_0 -> 731 in the cache */
   /* search1918_2_1 -> 743 in the cache */
   /* search1918_2_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 743, 741 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5457, 5464 },
      -1,
   } },

   /* replace1918_0 -> 731 in the cache */
   /* replace1918_1_0 -> 739 in the cache */
   /* replace1918_1_1 -> 732 in the cache */
   /* replace1918_1_2 -> 743 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 732, 743 },
      -1,
   } },
   /* replace1918_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 5466, 741 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1919_0 -> 739 in the cache */
   /* search1919_1_0 -> 731 in the cache */
   /* search1919_1_1 -> 732 in the cache */
   /* search1919_1_2 -> 741 in the cache */
   /* search1919_1 -> 5461 in the cache */
   /* search1919_2_0 -> 731 in the cache */
   /* search1919_2_1 -> 743 in the cache */
   /* search1919_2_2 -> 741 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 731, 743, 741 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5461, 5468 },
      -1,
   } },

   /* replace1919_0 -> 731 in the cache */
   /* replace1919_1_0 -> 739 in the cache */
   /* replace1919_1_1 -> 732 in the cache */
   /* replace1919_1_2 -> 743 in the cache */
   /* replace1919_1 -> 5466 in the cache */
   /* replace1919_2 -> 741 in the cache */
   /* replace1919 -> 5467 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1920_0 -> 739 in the cache */
   /* search1920_1_0 -> 152 in the cache */
   /* search1920_1_1 -> 154 in the cache */
   /* search1920_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 152, 154, 155 },
      0,
   } },
   /* search1920_2_0 -> 1300 in the cache */
   /* search1920_2_1 -> 154 in the cache */
   /* search1920_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1300, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5470, 5471 },
      -1,
   } },

   /* replace1920_0_0 -> 739 in the cache */
   /* replace1920_0_1 -> 152 in the cache */
   /* replace1920_0_2 -> 1300 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 152, 1300 },
      -1,
   } },
   /* replace1920_1 -> 154 in the cache */
   /* replace1920_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5473, 154, 155 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1921_0 -> 739 in the cache */
   /* search1921_1_0 -> 152 in the cache */
   /* search1921_1_1 -> 154 in the cache */
   /* search1921_1_2 -> 155 in the cache */
   /* search1921_1 -> 684 in the cache */
   /* search1921_2_0 -> 1300 in the cache */
   /* search1921_2_1 -> 154 in the cache */
   /* search1921_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1300, 154, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 684, 5475 },
      -1,
   } },

   /* replace1921_0_0 -> 739 in the cache */
   /* replace1921_0_1 -> 152 in the cache */
   /* replace1921_0_2 -> 1300 in the cache */
   /* replace1921_0 -> 5473 in the cache */
   /* replace1921_1 -> 154 in the cache */
   /* replace1921_2 -> 155 in the cache */
   /* replace1921 -> 5474 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1922_0 -> 739 in the cache */
   /* search1922_1_0 -> 36 in the cache */
   /* search1922_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 137 },
      0,
   } },
   /* search1922_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5478 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5477, 5479 },
      -1,
   } },

   /* replace1922_0 -> 36 in the cache */
   /* replace1922_1_0 -> 739 in the cache */
   /* replace1922_1_1 -> 137 in the cache */
   /* replace1922_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5481 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1923_0 -> 739 in the cache */
   /* search1923_1_0 -> 36 in the cache */
   /* search1923_1_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 349 },
      0,
   } },
   /* search1923_2_0 -> 36 in the cache */
   /* search1923_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5483, 5484 },
      -1,
   } },

   /* replace1923_0 -> 36 in the cache */
   /* replace1923_1_0 -> 739 in the cache */
   /* replace1923_1_1 -> 137 in the cache */
   /* replace1923_1_2 -> 165 in the cache */
   /* replace1923_1 -> 5481 in the cache */
   /* replace1923 -> 5482 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1924_0 -> 739 in the cache */
   /* search1924_1_0 -> 36 in the cache */
   /* search1924_1_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 349 },
      -1,
   } },
   /* search1924_2_0 -> 36 in the cache */
   /* search1924_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5486, 5487 },
      -1,
   } },

   /* replace1924_0 -> 36 in the cache */
   /* replace1924_1_0 -> 739 in the cache */
   /* replace1924_1_1 -> 137 in the cache */
   /* replace1924_1_2 -> 165 in the cache */
   /* replace1924_1 -> 5481 in the cache */
   /* replace1924 -> 5482 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1925_0 -> 739 in the cache */
   /* search1925_1_0 -> 36 in the cache */
   /* search1925_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 137 },
      -1,
   } },
   /* search1925_2_0 -> 36 in the cache */
   /* search1925_2_1 -> 5478 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5478 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5489, 5490 },
      -1,
   } },

   /* replace1925_0 -> 36 in the cache */
   /* replace1925_1_0 -> 739 in the cache */
   /* replace1925_1_1 -> 137 in the cache */
   /* replace1925_1_2 -> 165 in the cache */
   /* replace1925_1 -> 5481 in the cache */
   /* replace1925 -> 5482 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1926_0 -> 739 in the cache */
   /* search1926_1_0 -> 152 in the cache */
   /* search1926_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1926_2_0 -> 152 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5492, 5494 },
      -1,
   } },

   /* replace1926_0 -> 152 in the cache */
   /* replace1926_1_0 -> 739 in the cache */
   /* replace1926_1_1 -> 154 in the cache */
   /* replace1926_1_2 -> 155 in the cache */
   /* replace1926_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1927_0 -> 739 in the cache */
   /* search1927_1_0 -> 152 in the cache */
   /* search1927_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1927_2_0 -> 152 in the cache */
   /* search1927_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5497, 5498 },
      -1,
   } },

   /* replace1927_0 -> 152 in the cache */
   /* replace1927_1_0 -> 739 in the cache */
   /* replace1927_1_1 -> 154 in the cache */
   /* replace1927_1_2 -> 155 in the cache */
   /* replace1927_1 -> 1289 in the cache */
   /* replace1927 -> 5496 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1928_0 -> 739 in the cache */
   /* search1928_1_0 -> 152 in the cache */
   /* search1928_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1928_2_0 -> 152 in the cache */
   /* search1928_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5500, 5501 },
      -1,
   } },

   /* replace1928_0 -> 152 in the cache */
   /* replace1928_1_0 -> 739 in the cache */
   /* replace1928_1_1 -> 154 in the cache */
   /* replace1928_1_2 -> 155 in the cache */
   /* replace1928_1 -> 1289 in the cache */
   /* replace1928 -> 5496 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1929_0 -> 739 in the cache */
   /* search1929_1_0 -> 152 in the cache */
   /* search1929_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1929_2_0 -> 152 in the cache */
   /* search1929_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5503, 5504 },
      -1,
   } },

   /* replace1929_0 -> 152 in the cache */
   /* replace1929_1_0 -> 739 in the cache */
   /* replace1929_1_1 -> 154 in the cache */
   /* replace1929_1_2 -> 155 in the cache */
   /* replace1929_1 -> 1289 in the cache */
   /* replace1929 -> 5496 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1930_0 -> 739 in the cache */
   /* search1930_1_0 -> 152 in the cache */
   /* search1930_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1930_2_0 -> 152 in the cache */
   /* search1930_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5506, 5507 },
      -1,
   } },

   /* replace1930_0 -> 152 in the cache */
   /* replace1930_1_0 -> 739 in the cache */
   /* replace1930_1_1 -> 154 in the cache */
   /* replace1930_1_2 -> 155 in the cache */
   /* replace1930_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1931_0 -> 739 in the cache */
   /* search1931_1_0 -> 152 in the cache */
   /* search1931_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1931_2_0 -> 152 in the cache */
   /* search1931_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5510, 5511 },
      -1,
   } },

   /* replace1931_0 -> 152 in the cache */
   /* replace1931_1_0 -> 739 in the cache */
   /* replace1931_1_1 -> 154 in the cache */
   /* replace1931_1_2 -> 155 in the cache */
   /* replace1931_1 -> 1289 in the cache */
   /* replace1931 -> 5509 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1932_0 -> 739 in the cache */
   /* search1932_1_0 -> 152 in the cache */
   /* search1932_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1932_2_0 -> 152 in the cache */
   /* search1932_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5513, 5514 },
      -1,
   } },

   /* replace1932_0 -> 152 in the cache */
   /* replace1932_1_0 -> 739 in the cache */
   /* replace1932_1_1 -> 154 in the cache */
   /* replace1932_1_2 -> 155 in the cache */
   /* replace1932_1 -> 1289 in the cache */
   /* replace1932 -> 5509 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1933_0 -> 739 in the cache */
   /* search1933_1_0 -> 152 in the cache */
   /* search1933_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1933_2_0 -> 152 in the cache */
   /* search1933_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5516, 5517 },
      -1,
   } },

   /* replace1933_0 -> 152 in the cache */
   /* replace1933_1_0 -> 739 in the cache */
   /* replace1933_1_1 -> 154 in the cache */
   /* replace1933_1_2 -> 155 in the cache */
   /* replace1933_1 -> 1289 in the cache */
   /* replace1933 -> 5509 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1934_0 -> 739 in the cache */
   /* search1934_1_0 -> 152 in the cache */
   /* search1934_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1934_2_0 -> 152 in the cache */
   /* search1934_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5519, 5520 },
      -1,
   } },

   /* replace1934_0 -> 152 in the cache */
   /* replace1934_1_0 -> 739 in the cache */
   /* replace1934_1_1 -> 154 in the cache */
   /* replace1934_1_2 -> 155 in the cache */
   /* replace1934_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1935_0 -> 739 in the cache */
   /* search1935_1_0 -> 152 in the cache */
   /* search1935_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1935_2_0 -> 152 in the cache */
   /* search1935_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5523, 5524 },
      -1,
   } },

   /* replace1935_0 -> 152 in the cache */
   /* replace1935_1_0 -> 739 in the cache */
   /* replace1935_1_1 -> 154 in the cache */
   /* replace1935_1_2 -> 155 in the cache */
   /* replace1935_1 -> 1289 in the cache */
   /* replace1935 -> 5522 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1936_0 -> 739 in the cache */
   /* search1936_1_0 -> 152 in the cache */
   /* search1936_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1936_2_0 -> 152 in the cache */
   /* search1936_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5526, 5527 },
      -1,
   } },

   /* replace1936_0 -> 152 in the cache */
   /* replace1936_1_0 -> 739 in the cache */
   /* replace1936_1_1 -> 154 in the cache */
   /* replace1936_1_2 -> 155 in the cache */
   /* replace1936_1 -> 1289 in the cache */
   /* replace1936 -> 5522 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1937_0 -> 739 in the cache */
   /* search1937_1_0 -> 152 in the cache */
   /* search1937_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1937_2_0 -> 152 in the cache */
   /* search1937_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5529, 5530 },
      -1,
   } },

   /* replace1937_0 -> 152 in the cache */
   /* replace1937_1_0 -> 739 in the cache */
   /* replace1937_1_1 -> 154 in the cache */
   /* replace1937_1_2 -> 155 in the cache */
   /* replace1937_1 -> 1289 in the cache */
   /* replace1937 -> 5522 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1938_0 -> 739 in the cache */
   /* search1938_1_0 -> 152 in the cache */
   /* search1938_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1938_2_0 -> 152 in the cache */
   /* search1938_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5532, 5533 },
      -1,
   } },

   /* replace1938_0 -> 152 in the cache */
   /* replace1938_1_0 -> 739 in the cache */
   /* replace1938_1_1 -> 154 in the cache */
   /* replace1938_1_2 -> 155 in the cache */
   /* replace1938_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1939_0 -> 739 in the cache */
   /* search1939_1_0 -> 152 in the cache */
   /* search1939_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1939_2_0 -> 152 in the cache */
   /* search1939_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5536, 5537 },
      -1,
   } },

   /* replace1939_0 -> 152 in the cache */
   /* replace1939_1_0 -> 739 in the cache */
   /* replace1939_1_1 -> 154 in the cache */
   /* replace1939_1_2 -> 155 in the cache */
   /* replace1939_1 -> 1289 in the cache */
   /* replace1939 -> 5535 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1940_0 -> 739 in the cache */
   /* search1940_1_0 -> 152 in the cache */
   /* search1940_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1940_2_0 -> 152 in the cache */
   /* search1940_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5539, 5540 },
      -1,
   } },

   /* replace1940_0 -> 152 in the cache */
   /* replace1940_1_0 -> 739 in the cache */
   /* replace1940_1_1 -> 154 in the cache */
   /* replace1940_1_2 -> 155 in the cache */
   /* replace1940_1 -> 1289 in the cache */
   /* replace1940 -> 5535 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1941_0 -> 739 in the cache */
   /* search1941_1_0 -> 152 in the cache */
   /* search1941_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1941_2_0 -> 152 in the cache */
   /* search1941_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5542, 5543 },
      -1,
   } },

   /* replace1941_0 -> 152 in the cache */
   /* replace1941_1_0 -> 739 in the cache */
   /* replace1941_1_1 -> 154 in the cache */
   /* replace1941_1_2 -> 155 in the cache */
   /* replace1941_1 -> 1289 in the cache */
   /* replace1941 -> 5535 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1942_0 -> 739 in the cache */
   /* search1942_1_0 -> 152 in the cache */
   /* search1942_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1942_2_0 -> 152 in the cache */
   /* search1942_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5545, 5546 },
      -1,
   } },

   /* replace1942_0 -> 152 in the cache */
   /* replace1942_1_0 -> 739 in the cache */
   /* replace1942_1_1 -> 154 in the cache */
   /* replace1942_1_2 -> 155 in the cache */
   /* replace1942_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1943_0 -> 739 in the cache */
   /* search1943_1_0 -> 152 in the cache */
   /* search1943_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1943_2_0 -> 152 in the cache */
   /* search1943_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5549, 5550 },
      -1,
   } },

   /* replace1943_0 -> 152 in the cache */
   /* replace1943_1_0 -> 739 in the cache */
   /* replace1943_1_1 -> 154 in the cache */
   /* replace1943_1_2 -> 155 in the cache */
   /* replace1943_1 -> 1289 in the cache */
   /* replace1943 -> 5548 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1944_0 -> 739 in the cache */
   /* search1944_1_0 -> 152 in the cache */
   /* search1944_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1944_2_0 -> 152 in the cache */
   /* search1944_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5552, 5553 },
      -1,
   } },

   /* replace1944_0 -> 152 in the cache */
   /* replace1944_1_0 -> 739 in the cache */
   /* replace1944_1_1 -> 154 in the cache */
   /* replace1944_1_2 -> 155 in the cache */
   /* replace1944_1 -> 1289 in the cache */
   /* replace1944 -> 5548 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1945_0 -> 739 in the cache */
   /* search1945_1_0 -> 152 in the cache */
   /* search1945_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1945_2_0 -> 152 in the cache */
   /* search1945_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5555, 5556 },
      -1,
   } },

   /* replace1945_0 -> 152 in the cache */
   /* replace1945_1_0 -> 739 in the cache */
   /* replace1945_1_1 -> 154 in the cache */
   /* replace1945_1_2 -> 155 in the cache */
   /* replace1945_1 -> 1289 in the cache */
   /* replace1945 -> 5548 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1946_0 -> 739 in the cache */
   /* search1946_1_0 -> 152 in the cache */
   /* search1946_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1946_2_0 -> 152 in the cache */
   /* search1946_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5558, 5559 },
      -1,
   } },

   /* replace1946_0 -> 152 in the cache */
   /* replace1946_1_0 -> 739 in the cache */
   /* replace1946_1_1 -> 154 in the cache */
   /* replace1946_1_2 -> 155 in the cache */
   /* replace1946_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1947_0 -> 739 in the cache */
   /* search1947_1_0 -> 152 in the cache */
   /* search1947_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1947_2_0 -> 152 in the cache */
   /* search1947_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5562, 5563 },
      -1,
   } },

   /* replace1947_0 -> 152 in the cache */
   /* replace1947_1_0 -> 739 in the cache */
   /* replace1947_1_1 -> 154 in the cache */
   /* replace1947_1_2 -> 155 in the cache */
   /* replace1947_1 -> 1289 in the cache */
   /* replace1947 -> 5561 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1948_0 -> 739 in the cache */
   /* search1948_1_0 -> 152 in the cache */
   /* search1948_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1948_2_0 -> 152 in the cache */
   /* search1948_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5565, 5566 },
      -1,
   } },

   /* replace1948_0 -> 152 in the cache */
   /* replace1948_1_0 -> 739 in the cache */
   /* replace1948_1_1 -> 154 in the cache */
   /* replace1948_1_2 -> 155 in the cache */
   /* replace1948_1 -> 1289 in the cache */
   /* replace1948 -> 5561 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1949_0 -> 739 in the cache */
   /* search1949_1_0 -> 152 in the cache */
   /* search1949_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1949_2_0 -> 152 in the cache */
   /* search1949_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5568, 5569 },
      -1,
   } },

   /* replace1949_0 -> 152 in the cache */
   /* replace1949_1_0 -> 739 in the cache */
   /* replace1949_1_1 -> 154 in the cache */
   /* replace1949_1_2 -> 155 in the cache */
   /* replace1949_1 -> 1289 in the cache */
   /* replace1949 -> 5561 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1950_0 -> 739 in the cache */
   /* search1950_1_0 -> 152 in the cache */
   /* search1950_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1950_2_0 -> 152 in the cache */
   /* search1950_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5571, 5572 },
      -1,
   } },

   /* replace1950_0 -> 152 in the cache */
   /* replace1950_1_0 -> 739 in the cache */
   /* replace1950_1_1 -> 154 in the cache */
   /* replace1950_1_2 -> 155 in the cache */
   /* replace1950_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1951_0 -> 739 in the cache */
   /* search1951_1_0 -> 152 in the cache */
   /* search1951_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1951_2_0 -> 152 in the cache */
   /* search1951_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5575, 5576 },
      -1,
   } },

   /* replace1951_0 -> 152 in the cache */
   /* replace1951_1_0 -> 739 in the cache */
   /* replace1951_1_1 -> 154 in the cache */
   /* replace1951_1_2 -> 155 in the cache */
   /* replace1951_1 -> 1289 in the cache */
   /* replace1951 -> 5574 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1952_0 -> 739 in the cache */
   /* search1952_1_0 -> 152 in the cache */
   /* search1952_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1952_2_0 -> 152 in the cache */
   /* search1952_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5578, 5579 },
      -1,
   } },

   /* replace1952_0 -> 152 in the cache */
   /* replace1952_1_0 -> 739 in the cache */
   /* replace1952_1_1 -> 154 in the cache */
   /* replace1952_1_2 -> 155 in the cache */
   /* replace1952_1 -> 1289 in the cache */
   /* replace1952 -> 5574 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1953_0 -> 739 in the cache */
   /* search1953_1_0 -> 152 in the cache */
   /* search1953_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1953_2_0 -> 152 in the cache */
   /* search1953_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5581, 5582 },
      -1,
   } },

   /* replace1953_0 -> 152 in the cache */
   /* replace1953_1_0 -> 739 in the cache */
   /* replace1953_1_1 -> 154 in the cache */
   /* replace1953_1_2 -> 155 in the cache */
   /* replace1953_1 -> 1289 in the cache */
   /* replace1953 -> 5574 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1954_0 -> 739 in the cache */
   /* search1954_1_0 -> 152 in the cache */
   /* search1954_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1954_2_0 -> 152 in the cache */
   /* search1954_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5584, 5585 },
      -1,
   } },

   /* replace1954_0 -> 152 in the cache */
   /* replace1954_1_0 -> 739 in the cache */
   /* replace1954_1_1 -> 154 in the cache */
   /* replace1954_1_2 -> 155 in the cache */
   /* replace1954_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1955_0 -> 739 in the cache */
   /* search1955_1_0 -> 152 in the cache */
   /* search1955_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1955_2_0 -> 152 in the cache */
   /* search1955_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5588, 5589 },
      -1,
   } },

   /* replace1955_0 -> 152 in the cache */
   /* replace1955_1_0 -> 739 in the cache */
   /* replace1955_1_1 -> 154 in the cache */
   /* replace1955_1_2 -> 155 in the cache */
   /* replace1955_1 -> 1289 in the cache */
   /* replace1955 -> 5587 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1956_0 -> 739 in the cache */
   /* search1956_1_0 -> 152 in the cache */
   /* search1956_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1956_2_0 -> 152 in the cache */
   /* search1956_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5591, 5592 },
      -1,
   } },

   /* replace1956_0 -> 152 in the cache */
   /* replace1956_1_0 -> 739 in the cache */
   /* replace1956_1_1 -> 154 in the cache */
   /* replace1956_1_2 -> 155 in the cache */
   /* replace1956_1 -> 1289 in the cache */
   /* replace1956 -> 5587 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1957_0 -> 739 in the cache */
   /* search1957_1_0 -> 152 in the cache */
   /* search1957_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1957_2_0 -> 152 in the cache */
   /* search1957_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5594, 5595 },
      -1,
   } },

   /* replace1957_0 -> 152 in the cache */
   /* replace1957_1_0 -> 739 in the cache */
   /* replace1957_1_1 -> 154 in the cache */
   /* replace1957_1_2 -> 155 in the cache */
   /* replace1957_1 -> 1289 in the cache */
   /* replace1957 -> 5587 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1958_0 -> 739 in the cache */
   /* search1958_1_0 -> 152 in the cache */
   /* search1958_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1958_2_0 -> 152 in the cache */
   /* search1958_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5597, 5598 },
      -1,
   } },

   /* replace1958_0 -> 152 in the cache */
   /* replace1958_1_0 -> 739 in the cache */
   /* replace1958_1_1 -> 154 in the cache */
   /* replace1958_1_2 -> 155 in the cache */
   /* replace1958_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1959_0 -> 739 in the cache */
   /* search1959_1_0 -> 152 in the cache */
   /* search1959_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1959_2_0 -> 152 in the cache */
   /* search1959_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5601, 5602 },
      -1,
   } },

   /* replace1959_0 -> 152 in the cache */
   /* replace1959_1_0 -> 739 in the cache */
   /* replace1959_1_1 -> 154 in the cache */
   /* replace1959_1_2 -> 155 in the cache */
   /* replace1959_1 -> 1289 in the cache */
   /* replace1959 -> 5600 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1960_0 -> 739 in the cache */
   /* search1960_1_0 -> 152 in the cache */
   /* search1960_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1960_2_0 -> 152 in the cache */
   /* search1960_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5604, 5605 },
      -1,
   } },

   /* replace1960_0 -> 152 in the cache */
   /* replace1960_1_0 -> 739 in the cache */
   /* replace1960_1_1 -> 154 in the cache */
   /* replace1960_1_2 -> 155 in the cache */
   /* replace1960_1 -> 1289 in the cache */
   /* replace1960 -> 5600 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1961_0 -> 739 in the cache */
   /* search1961_1_0 -> 152 in the cache */
   /* search1961_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1961_2_0 -> 152 in the cache */
   /* search1961_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5607, 5608 },
      -1,
   } },

   /* replace1961_0 -> 152 in the cache */
   /* replace1961_1_0 -> 739 in the cache */
   /* replace1961_1_1 -> 154 in the cache */
   /* replace1961_1_2 -> 155 in the cache */
   /* replace1961_1 -> 1289 in the cache */
   /* replace1961 -> 5600 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1962_0 -> 739 in the cache */
   /* search1962_1_0 -> 152 in the cache */
   /* search1962_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1962_2_0 -> 152 in the cache */
   /* search1962_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5610, 5611 },
      -1,
   } },

   /* replace1962_0 -> 152 in the cache */
   /* replace1962_1_0 -> 739 in the cache */
   /* replace1962_1_1 -> 154 in the cache */
   /* replace1962_1_2 -> 155 in the cache */
   /* replace1962_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1963_0 -> 739 in the cache */
   /* search1963_1_0 -> 152 in the cache */
   /* search1963_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1963_2_0 -> 152 in the cache */
   /* search1963_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5614, 5615 },
      -1,
   } },

   /* replace1963_0 -> 152 in the cache */
   /* replace1963_1_0 -> 739 in the cache */
   /* replace1963_1_1 -> 154 in the cache */
   /* replace1963_1_2 -> 155 in the cache */
   /* replace1963_1 -> 1289 in the cache */
   /* replace1963 -> 5613 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1964_0 -> 739 in the cache */
   /* search1964_1_0 -> 152 in the cache */
   /* search1964_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1964_2_0 -> 152 in the cache */
   /* search1964_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5617, 5618 },
      -1,
   } },

   /* replace1964_0 -> 152 in the cache */
   /* replace1964_1_0 -> 739 in the cache */
   /* replace1964_1_1 -> 154 in the cache */
   /* replace1964_1_2 -> 155 in the cache */
   /* replace1964_1 -> 1289 in the cache */
   /* replace1964 -> 5613 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1965_0 -> 739 in the cache */
   /* search1965_1_0 -> 152 in the cache */
   /* search1965_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1965_2_0 -> 152 in the cache */
   /* search1965_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5620, 5621 },
      -1,
   } },

   /* replace1965_0 -> 152 in the cache */
   /* replace1965_1_0 -> 739 in the cache */
   /* replace1965_1_1 -> 154 in the cache */
   /* replace1965_1_2 -> 155 in the cache */
   /* replace1965_1 -> 1289 in the cache */
   /* replace1965 -> 5613 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1966_0 -> 739 in the cache */
   /* search1966_1_0 -> 152 in the cache */
   /* search1966_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1966_2_0 -> 152 in the cache */
   /* search1966_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5623, 5624 },
      -1,
   } },

   /* replace1966_0 -> 152 in the cache */
   /* replace1966_1_0 -> 739 in the cache */
   /* replace1966_1_1 -> 154 in the cache */
   /* replace1966_1_2 -> 155 in the cache */
   /* replace1966_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1967_0 -> 739 in the cache */
   /* search1967_1_0 -> 152 in the cache */
   /* search1967_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1967_2_0 -> 152 in the cache */
   /* search1967_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5627, 5628 },
      -1,
   } },

   /* replace1967_0 -> 152 in the cache */
   /* replace1967_1_0 -> 739 in the cache */
   /* replace1967_1_1 -> 154 in the cache */
   /* replace1967_1_2 -> 155 in the cache */
   /* replace1967_1 -> 1289 in the cache */
   /* replace1967 -> 5626 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1968_0 -> 739 in the cache */
   /* search1968_1_0 -> 152 in the cache */
   /* search1968_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1968_2_0 -> 152 in the cache */
   /* search1968_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5630, 5631 },
      -1,
   } },

   /* replace1968_0 -> 152 in the cache */
   /* replace1968_1_0 -> 739 in the cache */
   /* replace1968_1_1 -> 154 in the cache */
   /* replace1968_1_2 -> 155 in the cache */
   /* replace1968_1 -> 1289 in the cache */
   /* replace1968 -> 5626 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1969_0 -> 739 in the cache */
   /* search1969_1_0 -> 152 in the cache */
   /* search1969_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1969_2_0 -> 152 in the cache */
   /* search1969_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5633, 5634 },
      -1,
   } },

   /* replace1969_0 -> 152 in the cache */
   /* replace1969_1_0 -> 739 in the cache */
   /* replace1969_1_1 -> 154 in the cache */
   /* replace1969_1_2 -> 155 in the cache */
   /* replace1969_1 -> 1289 in the cache */
   /* replace1969 -> 5626 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1970_0 -> 739 in the cache */
   /* search1970_1_0 -> 152 in the cache */
   /* search1970_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1970_2_0 -> 152 in the cache */
   /* search1970_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 5493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5636, 5637 },
      -1,
   } },

   /* replace1970_0 -> 152 in the cache */
   /* replace1970_1_0 -> 739 in the cache */
   /* replace1970_1_1 -> 154 in the cache */
   /* replace1970_1_2 -> 155 in the cache */
   /* replace1970_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1971_0 -> 739 in the cache */
   /* search1971_1_0 -> 152 in the cache */
   /* search1971_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 3433 },
      0,
   } },
   /* search1971_2_0 -> 152 in the cache */
   /* search1971_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5640, 5641 },
      -1,
   } },

   /* replace1971_0 -> 152 in the cache */
   /* replace1971_1_0 -> 739 in the cache */
   /* replace1971_1_1 -> 154 in the cache */
   /* replace1971_1_2 -> 155 in the cache */
   /* replace1971_1 -> 1289 in the cache */
   /* replace1971 -> 5639 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1972_0 -> 739 in the cache */
   /* search1972_1_0 -> 152 in the cache */
   /* search1972_1_1 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 3433 },
      -1,
   } },
   /* search1972_2_0 -> 152 in the cache */
   /* search1972_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5643, 5644 },
      -1,
   } },

   /* replace1972_0 -> 152 in the cache */
   /* replace1972_1_0 -> 739 in the cache */
   /* replace1972_1_1 -> 154 in the cache */
   /* replace1972_1_2 -> 155 in the cache */
   /* replace1972_1 -> 1289 in the cache */
   /* replace1972 -> 5639 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1973_0 -> 739 in the cache */
   /* search1973_1_0 -> 152 in the cache */
   /* search1973_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1973_2_0 -> 152 in the cache */
   /* search1973_2_1 -> 5493 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 5493 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 739, 5646, 5647 },
      -1,
   } },

   /* replace1973_0 -> 152 in the cache */
   /* replace1973_1_0 -> 739 in the cache */
   /* replace1973_1_1 -> 154 in the cache */
   /* replace1973_1_2 -> 155 in the cache */
   /* replace1973_1 -> 1289 in the cache */
   /* replace1973 -> 5639 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1974_0 -> 739 in the cache */
   /* search1974_1_0 -> 152 in the cache */
   /* search1974_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 154 },
      0,
   } },
   /* search1974_2_0 -> 152 in the cache */
   /* search1974_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5649, 5650 },
      -1,
   } },

   /* replace1974_0 -> 152 in the cache */
   /* replace1974_1_0 -> 739 in the cache */
   /* replace1974_1_1 -> 154 in the cache */
   /* replace1974_1_2 -> 155 in the cache */
   /* replace1974_1 -> 1289 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 1289 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1975_0 -> 739 in the cache */
   /* search1975_1_0 -> 152 in the cache */
   /* search1975_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 154 },
      -1,
   } },
   /* search1975_2_0 -> 152 in the cache */
   /* search1975_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5653, 5654 },
      -1,
   } },

   /* replace1975_0 -> 152 in the cache */
   /* replace1975_1_0 -> 739 in the cache */
   /* replace1975_1_1 -> 154 in the cache */
   /* replace1975_1_2 -> 155 in the cache */
   /* replace1975_1 -> 1289 in the cache */
   /* replace1975 -> 5652 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1976_0 -> 739 in the cache */
   /* search1976_1_0 -> 129 in the cache */
   /* search1976_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 129, 131 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1976_2_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5657, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5656, 5658 },
      -1,
   } },

   /* replace1976_0_0 -> 739 in the cache */
   /* replace1976_0_1 -> 129 in the cache */
   /* replace1976_0_2 -> 5657 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 129, 5657 },
      -1,
   } },
   /* replace1976_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5660, 131 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1977_0 -> 739 in the cache */
   /* search1977_1_0 -> 129 in the cache */
   /* search1977_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   /* search1977_2_0 -> 5657 in the cache */
   /* search1977_2_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5657, 131 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 739, 5662, 5663 },
      -1,
   } },

   /* replace1977_0_0 -> 739 in the cache */
   /* replace1977_0_1 -> 129 in the cache */
   /* replace1977_0_2 -> 5657 in the cache */
   /* replace1977_0 -> 5660 in the cache */
   /* replace1977_1 -> 131 in the cache */
   /* replace1977 -> 5661 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1978_0 -> 523 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5665 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5666, 5668 },
      -1,
   } },

   /* replace1978_0_0 -> 523 in the cache */
   /* replace1978_0_1 -> 5665 in the cache */
   /* replace1978_0_2 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5665, 5667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1979_0 -> 523 in the cache */
   /* search1979_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1979_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5672, 5673 },
      -1,
   } },

   /* replace1979_0_0 -> 523 in the cache */
   /* replace1979_0_1 -> 5665 in the cache */
   /* replace1979_0_2 -> 5667 in the cache */
   /* replace1979_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1980_0 -> 523 in the cache */
   /* search1980_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1980_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5676, 5677 },
      -1,
   } },

   /* replace1980_0_0 -> 523 in the cache */
   /* replace1980_0_1 -> 5665 in the cache */
   /* replace1980_0_2 -> 5667 in the cache */
   /* replace1980_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1981_0 -> 523 in the cache */
   /* search1981_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1981_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5680, 5681 },
      -1,
   } },

   /* replace1981_0_0 -> 523 in the cache */
   /* replace1981_0_1 -> 5665 in the cache */
   /* replace1981_0_2 -> 5667 in the cache */
   /* replace1981_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1982_0 -> 523 in the cache */
   /* search1982_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1982_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5684, 5685 },
      -1,
   } },

   /* replace1982_0_0 -> 523 in the cache */
   /* replace1982_0_1 -> 5665 in the cache */
   /* replace1982_0_2 -> 5667 in the cache */
   /* replace1982_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1983_0 -> 523 in the cache */
   /* search1983_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1983_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5688, 5689 },
      -1,
   } },

   /* replace1983_0_0 -> 523 in the cache */
   /* replace1983_0_1 -> 5665 in the cache */
   /* replace1983_0_2 -> 5667 in the cache */
   /* replace1983_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1984_0 -> 523 in the cache */
   /* search1984_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1984_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5692, 5693 },
      -1,
   } },

   /* replace1984_0_0 -> 523 in the cache */
   /* replace1984_0_1 -> 5665 in the cache */
   /* replace1984_0_2 -> 5667 in the cache */
   /* replace1984_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1985_0 -> 523 in the cache */
   /* search1985_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1985_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5696, 5697 },
      -1,
   } },

   /* replace1985_0_0 -> 523 in the cache */
   /* replace1985_0_1 -> 5665 in the cache */
   /* replace1985_0_2 -> 5667 in the cache */
   /* replace1985_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search1986_0 -> 523 in the cache */
   /* search1986_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1986_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5700, 5701 },
      -1,
   } },

   /* replace1986_0_0 -> 523 in the cache */
   /* replace1986_0_1 -> 5665 in the cache */
   /* replace1986_0_2 -> 5667 in the cache */
   /* replace1986_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search1987_0 -> 523 in the cache */
   /* search1987_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1987_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5704, 5705 },
      -1,
   } },

   /* replace1987_0_0 -> 523 in the cache */
   /* replace1987_0_1 -> 5665 in the cache */
   /* replace1987_0_2 -> 5667 in the cache */
   /* replace1987_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1988_0 -> 523 in the cache */
   /* search1988_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1988_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5708, 5709 },
      -1,
   } },

   /* replace1988_0_0 -> 523 in the cache */
   /* replace1988_0_1 -> 5665 in the cache */
   /* replace1988_0_2 -> 5667 in the cache */
   /* replace1988_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1989_0 -> 523 in the cache */
   /* search1989_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5665 },
      0,
   } },
   /* search1989_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5667 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5712, 5713 },
      -1,
   } },

   /* replace1989_0_0 -> 523 in the cache */
   /* replace1989_0_1 -> 5665 in the cache */
   /* replace1989_0_2 -> 5667 in the cache */
   /* replace1989_0 -> 5670 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5670 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1990_0 -> 523 in the cache */
   /* search1990_1_0 -> 5665 in the cache */
   /* search1990_1 -> 5688 in the cache */
   /* search1990_2_0 -> 5667 in the cache */
   /* search1990_2 -> 5689 in the cache */
   /* search1990 -> 5690 in the cache */

   /* replace1990_0_0 -> 523 in the cache */
   /* replace1990_0_1 -> 5665 in the cache */
   /* replace1990_0_2 -> 5667 in the cache */
   /* replace1990_0 -> 5670 in the cache */
   /* replace1990 -> 5691 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1991_0_0 -> 523 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5716, 5717 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5718 },
      -1,
   } },

   /* replace1991_0 -> 523 in the cache */
   /* replace1991_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5665 },
      -1,
   } },
   /* replace1991_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5720, 5721 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1992_0_0 -> 523 in the cache */
   /* search1992_0_1 -> 5716 in the cache */
   /* search1992_0_2 -> 5717 in the cache */
   /* search1992_0 -> 5718 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5718 },
      -1,
   } },

   /* replace1992_0 -> 523 in the cache */
   /* replace1992_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5665 },
      -1,
   } },
   /* replace1992_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5724, 5725 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1993_0_0 -> 523 in the cache */
   /* search1993_0_1 -> 5716 in the cache */
   /* search1993_0_2 -> 5717 in the cache */
   /* search1993_0 -> 5718 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5718 },
      -1,
   } },

   /* replace1993_0 -> 523 in the cache */
   /* replace1993_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5665 },
      -1,
   } },
   /* replace1993_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5728, 5729 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1994_0_0 -> 523 in the cache */
   /* search1994_0_1 -> 5716 in the cache */
   /* search1994_0_2 -> 5717 in the cache */
   /* search1994_0 -> 5718 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5718 },
      -1,
   } },

   /* replace1994_0 -> 523 in the cache */
   /* replace1994_1_0 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5665 },
      -1,
   } },
   /* replace1994_2_0 -> 5667 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5667 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5732, 5733 },
      -1,
   } },

   /* ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048)) */
   /* search1995_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 11 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xfff /* 4095 */ },
   } },
   /* replace1995_1_0_0 -> 11 in the cache */
   /* replace1995_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x800 /* 2048 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5737, 5738 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5736, 5739 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1996_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1996_1_0_0 -> 16 in the cache */
   /* replace1996_1_0_1 -> 398 in the cache */
   /* replace1996_1_0 -> 970 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 970, 5743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5742, 5744 },
      -1,
   } },

   /* ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992)) */
   /* search1997_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 21 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3fffffffffffff /* 18014398509481983 */ },
   } },
   /* replace1997_1_0_0 -> 21 in the cache */
   /* replace1997_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x20000000000000 /* 9007199254740992 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5748, 5749 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5747, 5750 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search1998_0_0 -> 16 in the cache */
   /* search1998_0_1 -> 36 in the cache */
   /* search1998_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* replace1998_0_0 -> 16 in the cache */
   /* replace1998_0 -> 3908 in the cache */
   /* replace1998_1_0 -> 36 in the cache */
   /* replace1998_1 -> 3905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3908, 3905 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search1999_0_0 -> 16 in the cache */
   /* search1999_0_1 -> 36 in the cache */
   /* search1999_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* replace1999_0_0 -> 16 in the cache */
   /* replace1999_0 -> 1974 in the cache */
   /* replace1999_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1974, 5755 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search2000_0_0 -> 16 in the cache */
   /* search2000_0_1 -> 36 in the cache */
   /* search2000_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* replace2000_0_0 -> 16 in the cache */
   /* replace2000_0 -> 3230 in the cache */
   /* replace2000_1_0 -> 36 in the cache */
   /* replace2000_1 -> 4702 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3230, 4702 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search2001_0_0 -> 16 in the cache */
   /* search2001_0_1 -> 36 in the cache */
   /* search2001_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* replace2001_0_0 -> 16 in the cache */
   /* replace2001_0 -> 4188 in the cache */
   /* replace2001_1_0 -> 36 in the cache */
   /* replace2001_1 -> 4373 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4188, 4373 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search2002_0_0 -> 16 in the cache */
   /* search2002_0_1 -> 36 in the cache */
   /* search2002_0 -> 3133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 3133 },
      -1,
   } },

   /* replace2002_0_0 -> 16 in the cache */
   /* replace2002_0 -> 1985 in the cache */
   /* replace2002_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1985, 5762 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search2003_0_0 -> 16 in the cache */
   /* search2003_0_1 -> 36 in the cache */
   /* search2003_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5764 },
      -1,
   } },

   /* replace2003_0_0 -> 16 in the cache */
   /* replace2003_0 -> 3908 in the cache */
   /* replace2003_1_0 -> 36 in the cache */
   /* replace2003_1 -> 3905 in the cache */
   /* replace2003_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3908, 3905, 5766 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search2004_0_0 -> 16 in the cache */
   /* search2004_0_1 -> 36 in the cache */
   /* search2004_0_2 -> 137 in the cache */
   /* search2004_0 -> 5764 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5764 },
      -1,
   } },

   /* replace2004_0_0 -> 16 in the cache */
   /* replace2004_0 -> 1974 in the cache */
   /* replace2004_1_0 -> 36 in the cache */
   /* replace2004_1 -> 5755 in the cache */
   /* replace2004_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1974, 5755, 5769 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search2005_0_0 -> 16 in the cache */
   /* search2005_0_1 -> 36 in the cache */
   /* search2005_0_2 -> 137 in the cache */
   /* search2005_0 -> 5764 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5764 },
      -1,
   } },

   /* replace2005_0_0 -> 16 in the cache */
   /* replace2005_0 -> 3230 in the cache */
   /* replace2005_1_0 -> 36 in the cache */
   /* replace2005_1 -> 4702 in the cache */
   /* replace2005_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3230, 4702, 5772 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search2006_0_0 -> 16 in the cache */
   /* search2006_0_1 -> 36 in the cache */
   /* search2006_0_2 -> 137 in the cache */
   /* search2006_0 -> 5764 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5764 },
      -1,
   } },

   /* replace2006_0_0 -> 16 in the cache */
   /* replace2006_0 -> 4188 in the cache */
   /* replace2006_1_0 -> 36 in the cache */
   /* replace2006_1 -> 4373 in the cache */
   /* replace2006_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4188, 4373, 5775 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search2007_0_0 -> 16 in the cache */
   /* search2007_0_1 -> 36 in the cache */
   /* search2007_0_2 -> 137 in the cache */
   /* search2007_0 -> 5764 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5764 },
      -1,
   } },

   /* replace2007_0_0 -> 16 in the cache */
   /* replace2007_0 -> 1985 in the cache */
   /* replace2007_1_0 -> 36 in the cache */
   /* replace2007_1 -> 5762 in the cache */
   /* replace2007_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1985, 5762, 5778 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search2008_0_0 -> 16 in the cache */
   /* search2008_0_1 -> 36 in the cache */
   /* search2008_0_2 -> 137 in the cache */
   /* search2008_0_3 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5780 },
      -1,
   } },

   /* replace2008_0_0 -> 16 in the cache */
   /* replace2008_0 -> 3908 in the cache */
   /* replace2008_1_0 -> 36 in the cache */
   /* replace2008_1 -> 3905 in the cache */
   /* replace2008_2_0 -> 137 in the cache */
   /* replace2008_2 -> 5766 in the cache */
   /* replace2008_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3908, 3905, 5766, 5782 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search2009_0_0 -> 16 in the cache */
   /* search2009_0_1 -> 36 in the cache */
   /* search2009_0_2 -> 137 in the cache */
   /* search2009_0_3 -> 165 in the cache */
   /* search2009_0 -> 5780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5780 },
      -1,
   } },

   /* replace2009_0_0 -> 16 in the cache */
   /* replace2009_0 -> 1974 in the cache */
   /* replace2009_1_0 -> 36 in the cache */
   /* replace2009_1 -> 5755 in the cache */
   /* replace2009_2_0 -> 137 in the cache */
   /* replace2009_2 -> 5769 in the cache */
   /* replace2009_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1974, 5755, 5769, 5785 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search2010_0_0 -> 16 in the cache */
   /* search2010_0_1 -> 36 in the cache */
   /* search2010_0_2 -> 137 in the cache */
   /* search2010_0_3 -> 165 in the cache */
   /* search2010_0 -> 5780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5780 },
      -1,
   } },

   /* replace2010_0_0 -> 16 in the cache */
   /* replace2010_0 -> 3230 in the cache */
   /* replace2010_1_0 -> 36 in the cache */
   /* replace2010_1 -> 4702 in the cache */
   /* replace2010_2_0 -> 137 in the cache */
   /* replace2010_2 -> 5772 in the cache */
   /* replace2010_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3230, 4702, 5772, 5788 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search2011_0_0 -> 16 in the cache */
   /* search2011_0_1 -> 36 in the cache */
   /* search2011_0_2 -> 137 in the cache */
   /* search2011_0_3 -> 165 in the cache */
   /* search2011_0 -> 5780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5780 },
      -1,
   } },

   /* replace2011_0_0 -> 16 in the cache */
   /* replace2011_0 -> 4188 in the cache */
   /* replace2011_1_0 -> 36 in the cache */
   /* replace2011_1 -> 4373 in the cache */
   /* replace2011_2_0 -> 137 in the cache */
   /* replace2011_2 -> 5775 in the cache */
   /* replace2011_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4188, 4373, 5775, 5791 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search2012_0_0 -> 16 in the cache */
   /* search2012_0_1 -> 36 in the cache */
   /* search2012_0_2 -> 137 in the cache */
   /* search2012_0_3 -> 165 in the cache */
   /* search2012_0 -> 5780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5780 },
      -1,
   } },

   /* replace2012_0_0 -> 16 in the cache */
   /* replace2012_0 -> 1985 in the cache */
   /* replace2012_1_0 -> 36 in the cache */
   /* replace2012_1 -> 5762 in the cache */
   /* replace2012_2_0 -> 137 in the cache */
   /* replace2012_2 -> 5778 in the cache */
   /* replace2012_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1985, 5762, 5778, 5794 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_ult_32),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2681, 1201, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3072, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3672, 3685, 78 },
   { 3957, 3968, 109 },
   { 3977, 3988, 109 },
   { 3997, 4007, 109 },
   { 3672, 4022, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 120, 32, 0 },
   { 3672, 3685, 78 },
   { 3957, 3968, 109 },
   { 3977, 3988, 109 },
   { 3997, 4007, 109 },
   { 3672, 4022, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3686, 3694, 78 },
   { 3969, 3976, 109 },
   { 3989, 3996, 109 },
   { 4008, 4015, 109 },
   { 3686, 4027, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 32, 0 },
   { 3686, 3694, 78 },
   { 3969, 3976, 109 },
   { 3989, 3996, 109 },
   { 4008, 4015, 109 },
   { 3686, 4027, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3658, 3662, 74 },
   { 3663, 3665, 75 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 122, 32, 0 },
   { 3658, 3662, 74 },
   { 3663, 3665, 75 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 3667, 76 },
   { 3668, 3671, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 123, 32, 0 },
   { 3666, 3667, 76 },
   { 3668, 3671, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 125, 16, 0 },
   { 127, 126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 270, 271, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 241, 124, 0 },
   { 242, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 3921, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 350, 352, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 350, 352, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 353, 355, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 353, 355, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 365, 366, 7 },
   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 367, 368, 8 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 367, 368, 8 },
   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 359, 361, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 359, 361, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 362, 364, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 362, 364, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 371, 372, 7 },
   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 373, 374, 8 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 308, 36, 0 },
   { 356, 358, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 308, 36, 0 },
   { 356, 358, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 309, 36, 0 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 36, 0 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 309, 36, 0 },
   { 310, 36, 0 },
   { 369, 370, 7 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 690, 694, 20 },
   { 3067, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 695, 697, 21 },
   { 698, 700, 21 },
   { 701, 703, 22 },
   { 3065, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 696, 710, 25 },
   { 699, 711, 25 },
   { 702, 712, 26 },
   { 3069, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 713, 715, 27 },
   { 3066, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 747, 752, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 783, 784, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 781, 782, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 779, 780, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 775, 778, 0 },
   { 779, 780, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 785, 778, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1201, 0 },
   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 32, 0 },
   { 3160, 3161, 57 },
   { 3162, 408, 57 },
   { 3163, 3164, 57 },
   { 3194, 441, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2683, 1201, 0 },
   { 2685, 2684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2683, 1201, 0 },
   { 2685, 2684, 0 },
   { 2686, 32, 0 },
   { 3160, 3161, 57 },
   { 3162, 408, 57 },
   { 3163, 3164, 57 },
   { 3194, 441, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3119, 1056, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1320, 32, 0 },
   { 1321, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3832, 3835, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3827, 3831, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3827, 3831, 89 },
   { 4941, 11, 0 },
   { 4994, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3836, 3840, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3836, 3840, 90 },
   { 5046, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3841, 3844, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3841, 3844, 90 },
   { 5019, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2351, 2359, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 2360, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2362, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2381, 2388, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2389, 2391, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2392, 2394, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2395, 2397, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2398, 2400, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2401, 2404, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2405, 2409, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2410, 2412, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2413, 2415, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2418, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 2424, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 2431, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 2438, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2439, 2455, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 2488, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2489, 2492, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2493, 2498, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2499, 2503, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2504, 2512, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2513, 2529, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2530, 2533, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2534, 2539, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2540, 2544, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2545, 2553, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2554, 2570, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2571, 2574, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2575, 2580, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2581, 2585, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2586, 2594, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2595, 2611, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3381, 3382, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3381, 3382, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2714, 2717, 49 },
   { 2693, 2696, 49 },
   { 2700, 2703, 49 },
   { 2718, 2721, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2722, 2724, 49 },
   { 2706, 2708, 49 },
   { 2711, 2713, 49 },
   { 2725, 2727, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { 2757, 32, 0 },
   { 2758, 253, 0 },
   { 2759, 2756, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { 2760, 2730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { 2757, 32, 0 },
   { 2758, 253, 0 },
   { 2759, 2756, 0 },
   { 2760, 2730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2749, 2803, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2798, 2800, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2797, 2778, 0 },
   { 2798, 2800, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2805, 2887, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2888, 2957, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3001, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3068, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3120, 3222, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3229, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3230, 63 },
   { 3146, 3230, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3148, 3231, 63 },
   { 3148, 3231, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3771, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3182, 414, 57 },
   { 3183, 417, 57 },
   { 3184, 421, 57 },
   { 3185, 424, 57 },
   { 3198, 446, 58 },
   { 3199, 449, 58 },
   { 3771, 124, 0 },
   { 3773, 3775, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3772, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3186, 395, 57 },
   { 3187, 399, 57 },
   { 3188, 404, 57 },
   { 3189, 408, 57 },
   { 3200, 438, 58 },
   { 3201, 441, 58 },
   { 3772, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3223, 3226, 61 },
   { 3223, 3913, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3233, 3911, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3240, 3912, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3268, 3910, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3268, 3910, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3268, 3910, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3268, 3910, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3377, 16, 0 },
   { 3378, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3379, 3380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3383, 3385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3386, 3387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3823, 3826, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3806, 3810, 85 },
   { 3806, 3814, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3816, 3820, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3602, 3605, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3606, 3609, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3610, 3613, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3614, 3615, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3620, 3624, 70 },
   { 3620, 3724, 81 },
   { 3620, 3726, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3625, 3628, 71 },
   { 3638, 3642, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3629, 3631, 71 },
   { 3643, 3645, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3632, 3634, 71 },
   { 3646, 3650, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3635, 3637, 71 },
   { 3651, 3653, 72 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3654, 3655, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3656, 3657, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3730, 3733, 83 },
   { 3730, 3799, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3734, 3736, 83 },
   { 3734, 3805, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3737, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3821, 3822, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3846, 3852, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3853, 3858, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3859, 3866, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3867, 3872, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3873, 3878, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3879, 3886, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3887, 3894, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3895, 3904, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3914, 3916, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3922, 930, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3923, 3927, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3928, 3932, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3933, 3934, 106 },
   { 3933, 49, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3935, 3928, 107 },
   { 3935, 3937, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3938, 3923, 108 },
   { 3938, 49, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3939, 3934, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3940, 557, 0 },
   { 3941, 3942, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3939, 3934, 0 },
   { 3940, 557, 0 },
   { 3941, 3942, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3940, 557, 0 },
   { 3941, 3942, 0 },
   { 3943, 3945, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3939, 3934, 0 },
   { 3940, 557, 0 },
   { 3941, 3942, 0 },
   { 3943, 3945, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3947, 3949, 1 },
   { 3951, 3955, 1 },
   { 3956, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 739, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4080, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4081, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4082, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5072, 5092, 112 },
   { 5094, 5112, 112 },
   { 5114, 5135, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5446, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5447, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5448, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5449, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5450, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5451, 113, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5453, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5456, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5454, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5454, 137, 0 },
   { 5456, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 5740, 115 },
   { 5741, 5745, 115 },
   { 5746, 5751, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4983, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4955, 4928, 0 },
   { 5008, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3413, 3414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3413, 3414, 0 },
   { 3457, 3414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1003, 1006, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5442, 5445, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4930, 4928, 0 },
   { 4983, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4955, 4928, 0 },
   { 5008, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4930, 4928, 0 },
   { 4983, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4955, 4928, 0 },
   { 5008, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2630, 2631, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4955, 4928, 0 },
   { 4983, 49, 0 },
   { 5008, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4983, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4983, 49, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4955, 4928, 0 },
   { 5008, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4955, 4928, 0 },
   { 5008, 49, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5035, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3503, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3503, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3443, 3444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3443, 3444, 0 },
   { 3485, 3444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 314, 316, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 318, 319, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 325, 326, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 328, 329, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 321, 323, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5438, 5441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 188, 190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4952, 3979, 0 },
   { 4980, 3999, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5032, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3267, 3268, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3519, 3504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3521, 3507, 0 },
   { 3526, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3522, 3510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3523, 3513, 0 },
   { 3528, 3513, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3524, 3516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2790, 2792, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3595, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3595, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3595, 103, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3595, 103, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2967, 739, 0 },
   { 2968, 1104, 0 },
   { 2971, 2972, 0 },
   { 2973, 2974, 0 },
   { 2977, 2978, 0 },
   { 2979, 2980, 0 },
   { 2981, 2982, 0 },
   { 2983, 2984, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 56 },
   { 2992, 2993, 56 },
   { 2996, 2997, 56 },
   { 2998, 2999, 56 },
   { 3000, 3, 0 },
   { 3002, 2229, 0 },
   { 3003, 3005, 0 },
   { 3007, 1200, 0 },
   { 3008, 3004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5521, 5522, 0 },
   { 5525, 5522, 0 },
   { 5528, 5522, 0 },
   { 5531, 5522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5508, 5509, 0 },
   { 5512, 5509, 0 },
   { 5515, 5509, 0 },
   { 5518, 5509, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5495, 5496, 0 },
   { 5499, 5496, 0 },
   { 5502, 5496, 0 },
   { 5505, 5496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5480, 5482, 0 },
   { 5485, 5482, 0 },
   { 5488, 5482, 0 },
   { 5491, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5534, 5535, 0 },
   { 5538, 5535, 0 },
   { 5541, 5535, 0 },
   { 5544, 5535, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5547, 5548, 0 },
   { 5551, 5548, 0 },
   { 5554, 5548, 0 },
   { 5557, 5548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5690, 5691, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5459, 5460, 0 },
   { 5463, 5460, 0 },
   { 5465, 5467, 0 },
   { 5469, 5467, 0 },
   { 5472, 5474, 0 },
   { 5476, 5474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1287, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1287, 1288, 0 },
   { 1290, 1288, 0 },
   { 1293, 1295, 0 },
   { 1298, 1295, 0 },
   { 1302, 1304, 0 },
   { 1307, 1304, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3596, 3597, 0 },
   { 3599, 3601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1754, 1756, 0 },
   { 1861, 1863, 0 },
   { 1944, 1946, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5573, 5574, 0 },
   { 5577, 5574, 0 },
   { 5580, 5574, 0 },
   { 5583, 5574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5586, 5587, 0 },
   { 5590, 5587, 0 },
   { 5593, 5587, 0 },
   { 5596, 5587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5599, 5600, 0 },
   { 5603, 5600, 0 },
   { 5606, 5600, 0 },
   { 5609, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5612, 5613, 0 },
   { 5616, 5613, 0 },
   { 5619, 5613, 0 },
   { 5622, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5625, 5626, 0 },
   { 5629, 5626, 0 },
   { 5632, 5626, 0 },
   { 5635, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5638, 5639, 0 },
   { 5642, 5639, 0 },
   { 5645, 5639, 0 },
   { 5648, 5639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4922, 4917, 0 },
   { 4975, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4947, 4917, 0 },
   { 5000, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5052, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 5027, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5560, 5561, 0 },
   { 5564, 5561, 0 },
   { 5567, 5561, 0 },
   { 5570, 5561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5651, 5652, 0 },
   { 5655, 5652, 0 },
   { 5659, 5661, 0 },
   { 5664, 5661, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5678, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5669, 5671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5674, 5675, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2113, 2114, 0 },
   { 2144, 2145, 0 },
   { 2174, 925, 0 },
   { 2204, 2205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2113, 2114, 0 },
   { 2144, 2145, 0 },
   { 2174, 925, 0 },
   { 2204, 2205, 0 },
   { 2681, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 802, 804, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 806, 815, 0 },
   { 828, 836, 0 },
   { 849, 856, 0 },
   { 869, 877, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 999, 1001, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 969, 970, 0 },
   { 976, 977, 0 },
   { 983, 984, 0 },
   { 992, 993, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 889, 892, 0 },
   { 897, 900, 0 },
   { 905, 908, 0 },
   { 913, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 889, 892, 0 },
   { 897, 900, 0 },
   { 905, 908, 0 },
   { 913, 916, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 889, 892, 0 },
   { 897, 900, 0 },
   { 905, 908, 0 },
   { 913, 916, 0 },
   { 2113, 2114, 0 },
   { 2144, 2145, 0 },
   { 2174, 925, 0 },
   { 2204, 2205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 889, 892, 0 },
   { 897, 900, 0 },
   { 905, 908, 0 },
   { 913, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 893, 892, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 917, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 893, 892, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 917, 916, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 893, 892, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 917, 916, 0 },
   { 2113, 2114, 0 },
   { 2144, 2145, 0 },
   { 2174, 925, 0 },
   { 2204, 2205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 893, 892, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 917, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { 3262, 3263, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 929, 930, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 924, 925, 0 },
   { 971, 970, 0 },
   { 978, 977, 0 },
   { 986, 984, 0 },
   { 995, 993, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 934, 936, 0 },
   { 940, 942, 0 },
   { 946, 948, 0 },
   { 952, 954, 0 },
   { 958, 960, 0 },
   { 964, 966, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2673, 2674, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2673, 2674, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 3487, 3489, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 972, 0 },
   { 980, 979, 0 },
   { 988, 987, 0 },
   { 997, 996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2659, 61, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2042, 2043, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 195, 0 },
   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1061, 1056, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2095, 2097, 42 },
   { 2095, 2103, 44 },
   { 2126, 2128, 42 },
   { 2126, 2134, 44 },
   { 2156, 2158, 42 },
   { 2156, 2164, 44 },
   { 2186, 2188, 42 },
   { 2186, 2194, 44 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2107, 2108, 45 },
   { 2138, 2139, 45 },
   { 2168, 2169, 45 },
   { 2198, 2199, 45 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5348, 5349, 0 },
   { 5351, 5352, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5337, 5338, 0 },
   { 5341, 5342, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5343, 5344, 0 },
   { 5346, 5347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1055, 1056, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2632, 2631, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2033, 2035, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2038, 2039, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2677, 2678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1621, 1607, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1731, 1732, 0 },
   { 1733, 1732, 0 },
   { 1838, 1839, 0 },
   { 1840, 1839, 0 },
   { 1921, 1922, 0 },
   { 1923, 1922, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1621, 1607, 0 },
   { 1731, 1732, 0 },
   { 1733, 1732, 0 },
   { 1838, 1839, 0 },
   { 1840, 1839, 0 },
   { 1921, 1922, 0 },
   { 1923, 1922, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1626, 1610, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1626, 1610, 0 },
   { 1731, 1732, 0 },
   { 1733, 1732, 0 },
   { 1838, 1839, 0 },
   { 1840, 1839, 0 },
   { 1921, 1922, 0 },
   { 1923, 1922, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1056, 0 },
   { 1605, 1607, 0 },
   { 1608, 1610, 0 },
   { 1621, 1607, 0 },
   { 1626, 1610, 0 },
   { 1731, 1732, 0 },
   { 1733, 1732, 0 },
   { 1838, 1839, 0 },
   { 1840, 1839, 0 },
   { 1921, 1922, 0 },
   { 1923, 1922, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1629, 1613, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 37 },
   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1734, 1735, 0 },
   { 1736, 1735, 0 },
   { 1841, 1842, 0 },
   { 1843, 1842, 0 },
   { 1924, 1925, 0 },
   { 1926, 1925, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 37 },
   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1629, 1613, 0 },
   { 1734, 1735, 0 },
   { 1736, 1735, 0 },
   { 1841, 1842, 0 },
   { 1843, 1842, 0 },
   { 1924, 1925, 0 },
   { 1926, 1925, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1632, 1616, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 37 },
   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1632, 1616, 0 },
   { 1734, 1735, 0 },
   { 1736, 1735, 0 },
   { 1841, 1842, 0 },
   { 1843, 1842, 0 },
   { 1924, 1925, 0 },
   { 1926, 1925, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 37 },
   { 1611, 1613, 0 },
   { 1614, 1616, 0 },
   { 1629, 1613, 0 },
   { 1632, 1616, 0 },
   { 1734, 1735, 0 },
   { 1736, 1735, 0 },
   { 1841, 1842, 0 },
   { 1843, 1842, 0 },
   { 1924, 1925, 0 },
   { 1926, 1925, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1063, 1056, 0 },
   { 1673, 1674, 0 },
   { 1675, 1676, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1065, 1056, 0 },
   { 1681, 1682, 0 },
   { 1683, 1684, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1677, 1678, 0 },
   { 1679, 1680, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1685, 1686, 0 },
   { 1687, 1688, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2021, 2022, 0 },
   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4958, 2004, 0 },
   { 4986, 2012, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2016, 2018, 0 },
   { 2655, 32, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2025, 2026, 0 },
   { 2655, 32, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5038, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2029, 2030, 0 },
   { 2655, 32, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 2671, 2293, 0 },
   { 3491, 3493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 2663, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2066, 2067, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2104, 2106, 45 },
   { 2135, 2137, 45 },
   { 2165, 2167, 45 },
   { 2195, 2197, 45 },
   { 2217, 2218, 0 },
   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 2222, 0 },
   { 2225, 2226, 0 },
   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2100, 2101, 43 },
   { 2100, 2109, 44 },
   { 2131, 2132, 43 },
   { 2131, 2140, 44 },
   { 2161, 2162, 43 },
   { 2161, 2170, 44 },
   { 2191, 2192, 43 },
   { 2191, 2200, 44 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2633, 2634, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2061, 2063, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2064, 2065, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 2679, 2680, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1714, 1031, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1593, 1574, 0 },
   { 1714, 1031, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1714, 1031, 0 },
   { 1717, 1719, 0 },
   { 1722, 1719, 0 },
   { 1824, 1826, 0 },
   { 1829, 1826, 0 },
   { 1907, 1909, 0 },
   { 1912, 1909, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1593, 1574, 0 },
   { 1714, 1031, 0 },
   { 1717, 1719, 0 },
   { 1722, 1719, 0 },
   { 1824, 1826, 0 },
   { 1829, 1826, 0 },
   { 1907, 1909, 0 },
   { 1912, 1909, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1598, 1580, 0 },
   { 1714, 1031, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1598, 1580, 0 },
   { 1714, 1031, 0 },
   { 1717, 1719, 0 },
   { 1722, 1719, 0 },
   { 1824, 1826, 0 },
   { 1829, 1826, 0 },
   { 1907, 1909, 0 },
   { 1912, 1909, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1572, 1574, 0 },
   { 1578, 1580, 0 },
   { 1593, 1574, 0 },
   { 1598, 1580, 0 },
   { 1714, 1031, 0 },
   { 1717, 1719, 0 },
   { 1722, 1719, 0 },
   { 1824, 1826, 0 },
   { 1829, 1826, 0 },
   { 1907, 1909, 0 },
   { 1912, 1909, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1601, 1585, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1725, 1727, 0 },
   { 1730, 1727, 0 },
   { 1832, 1834, 0 },
   { 1837, 1834, 0 },
   { 1915, 1917, 0 },
   { 1920, 1917, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1601, 1585, 0 },
   { 1725, 1727, 0 },
   { 1730, 1727, 0 },
   { 1832, 1834, 0 },
   { 1837, 1834, 0 },
   { 1915, 1917, 0 },
   { 1920, 1917, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1604, 1590, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1604, 1590, 0 },
   { 1725, 1727, 0 },
   { 1730, 1727, 0 },
   { 1832, 1834, 0 },
   { 1837, 1834, 0 },
   { 1915, 1917, 0 },
   { 1920, 1917, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1583, 1585, 0 },
   { 1588, 1590, 0 },
   { 1601, 1585, 0 },
   { 1604, 1590, 0 },
   { 1725, 1727, 0 },
   { 1730, 1727, 0 },
   { 1832, 1834, 0 },
   { 1837, 1834, 0 },
   { 1915, 1917, 0 },
   { 1920, 1917, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1635, 1637, 0 },
   { 1640, 1642, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1655, 1657, 0 },
   { 1660, 1662, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1645, 1647, 0 },
   { 1650, 1652, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1665, 1667, 0 },
   { 1670, 1672, 0 },
   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2055, 2056, 0 },
   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4961, 2046, 0 },
   { 4989, 2050, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4989, 2050, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2052, 2054, 0 },
   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4961, 2046, 0 },
   { 5014, 2050, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2057, 2058, 0 },
   { 2660, 32, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5041, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2059, 2060, 0 },
   { 2660, 32, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 3269, 3268, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2667, 3, 0 },
   { 2668, 2658, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2667, 3, 0 },
   { 2668, 2658, 0 },
   { 3495, 3497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2090, 2091, 0 },
   { 2664, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2085, 2087, 0 },
   { 2664, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2088, 2089, 0 },
   { 2664, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2079, 2080, 0 },
   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4964, 2070, 0 },
   { 4992, 2074, 0 },
   { 5017, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4939, 2070, 0 },
   { 4992, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2076, 2078, 0 },
   { 2664, 61, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4964, 2070, 0 },
   { 5017, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2081, 2082, 0 },
   { 2664, 61, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 5044, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2083, 2084, 0 },
   { 2664, 61, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2117, 2118, 0 },
   { 2148, 2149, 0 },
   { 2177, 2178, 0 },
   { 2208, 2209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2117, 2118, 0 },
   { 2148, 2149, 0 },
   { 2177, 2178, 0 },
   { 2208, 2209, 0 },
   { 2687, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 3192, 446, 58 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { 2117, 2118, 0 },
   { 2148, 2149, 0 },
   { 2177, 2178, 0 },
   { 2208, 2209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 817, 819, 0 },
   { 838, 840, 0 },
   { 858, 860, 0 },
   { 879, 881, 0 },
   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { 3264, 3261, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2115, 2116, 0 },
   { 2146, 2147, 0 },
   { 2175, 2176, 0 },
   { 2206, 2207, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2115, 2116, 0 },
   { 2146, 2147, 0 },
   { 2175, 2176, 0 },
   { 2206, 2207, 0 },
   { 2683, 1201, 0 },
   { 2685, 2684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 32, 0 },
   { 3160, 3161, 57 },
   { 3162, 408, 57 },
   { 3163, 3164, 57 },
   { 3193, 438, 58 },
   { 3194, 441, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2686, 32, 0 },
   { 3160, 3161, 57 },
   { 3162, 408, 57 },
   { 3163, 3164, 57 },
   { 3194, 441, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2115, 2116, 0 },
   { 2146, 2147, 0 },
   { 2175, 2176, 0 },
   { 2206, 2207, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 821, 826, 0 },
   { 842, 847, 0 },
   { 862, 867, 0 },
   { 883, 888, 0 },
   { 2686, 32, 0 },
   { 3160, 3161, 57 },
   { 3162, 408, 57 },
   { 3163, 3164, 57 },
   { 3194, 441, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3337, 3338, 0 },
   { 3340, 421, 0 },
   { 3341, 417, 0 },
   { 3342, 414, 0 },
   { 3344, 3315, 0 },
   { 3346, 3310, 0 },
   { 3348, 3305, 0 },
   { 3350, 3302, 0 },
   { 3352, 3298, 0 },
   { 3354, 3294, 0 },
   { 3356, 3357, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3287, 3155, 0 },
   { 3289, 417, 0 },
   { 3290, 421, 0 },
   { 3291, 424, 0 },
   { 3293, 3294, 0 },
   { 3296, 3298, 0 },
   { 3300, 3302, 0 },
   { 3303, 3305, 0 },
   { 3308, 3310, 0 },
   { 3313, 3315, 0 },
   { 3316, 3159, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3317, 3155, 0 },
   { 3319, 417, 0 },
   { 3320, 421, 0 },
   { 3321, 424, 0 },
   { 3323, 3294, 0 },
   { 3325, 3298, 0 },
   { 3327, 3302, 0 },
   { 3329, 3305, 0 },
   { 3331, 3310, 0 },
   { 3333, 3315, 0 },
   { 3334, 3159, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3191, 3175, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3190, 3175, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3335, 3169, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3279, 3280, 0 },
   { 3281, 3282, 0 },
   { 3283, 3284, 0 },
   { 3285, 3286, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3358, 3359, 0 },
   { 3360, 404, 0 },
   { 3361, 399, 0 },
   { 3362, 395, 0 },
   { 3363, 3364, 0 },
   { 3365, 3366, 0 },
   { 3367, 3368, 0 },
   { 3369, 3370, 0 },
   { 3371, 3372, 0 },
   { 3373, 3374, 0 },
   { 3375, 3376, 0 },
   { 3827, 3831, 89 },
   { 4941, 11, 0 },
   { 4994, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3271, 3272, 0 },
   { 3273, 3274, 0 },
   { 3275, 3276, 0 },
   { 3277, 3278, 0 },
   { 3827, 3831, 89 },
   { 4941, 11, 0 },
   { 4994, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3139, 21, 0 },
   { 3120, 3222, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3137, 3227, 62 },
   { 3237, 3137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3129, 16, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3126, 16, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3121, 16, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3124, 2382, 0 },
   { 3137, 3227, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2352, 2351, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2354, 2353, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 2355, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2357, 0 },
   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4049, 739, 0 },
   { 4052, 6, 0 },
   { 4056, 11, 0 },
   { 4058, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3428, 3430, 0 },
   { 3432, 3430, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3428, 3430, 0 },
   { 3432, 3430, 0 },
   { 3459, 3430, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3435, 3437, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3435, 3437, 0 },
   { 3466, 3468, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3439, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3439, 3441, 0 },
   { 3476, 3478, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5425, 5428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 168, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3401, 3403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3401, 3403, 0 },
   { 3446, 3403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3409, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3409, 3411, 0 },
   { 3450, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 5429, 5432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { 5429, 5432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2788, 2789, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2635, 1240, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2793, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3390, 3391, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3584, 3585, 0 },
   { 3587, 3588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3390, 3391, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3405, 3407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3405, 3407, 0 },
   { 3448, 3407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 5434, 5437, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3584, 3585, 0 },
   { 3587, 3588, 0 },
   { 5434, 5437, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3390, 3391, 6 },
   { 3584, 3585, 0 },
   { 3587, 3588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 2795, 2796, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { 3453, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { 3453, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { 3453, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3419, 3421, 0 },
   { 3453, 3421, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3424, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3424, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3424, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3424, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3393, 3394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3393, 3394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3393, 3394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { 3393, 3394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { 3454, 3423, 0 },
   { 3455, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { 3454, 3423, 0 },
   { 3455, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { 3454, 3423, 0 },
   { 3455, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3422, 3423, 0 },
   { 3454, 3423, 0 },
   { 3455, 3425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3395, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 270, 271, 6 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3395, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3395, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 29 },
   { 727, 290, 32 },
   { 3395, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 1507, 219, 0 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1502, 1504, 0 },
   { 219, 1494, 39 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1506, 1505, 0 },
   { 219, 1494, 39 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1163, 1164, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1085, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 1207, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1163, 1164, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1163, 1164, 0 },
   { 1182, 1184, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1034, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { 5354, 5357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1198, 1104, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1217, 1207, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2614, 1028, 0 },
   { 2622, 1025, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2615, 1025, 0 },
   { 2623, 1028, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2612, 1034, 0 },
   { 2620, 1031, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2613, 1031, 0 },
   { 2621, 1034, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1070, 1071, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1163, 1164, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1136, 1135, 0 },
   { 1383, 1135, 0 },
   { 1387, 1135, 0 },
   { 1391, 1135, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1209, 0 },
   { 4849, 4851, 111 },
   { 4866, 4851, 111 },
   { 4874, 4875, 0 },
   { 4888, 4890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1144, 691, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2260, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2254, 2255, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1076, 1077, 0 },
   { 1144, 691, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1226, 1227, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1214, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1089, 1091, 0 },
   { 1099, 1100, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { 5378, 5383, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2260, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2254, 2255, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1074, 1075, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1067, 1057, 0 },
   { 1144, 691, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1212, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1144, 691, 0 },
   { 1159, 1160, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 2260, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 2254, 2255, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 1168, 1171, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { 5370, 5373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2256, 1057, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2256, 1057, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1144, 691, 0 },
   { 2256, 1057, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2256, 1057, 0 },
   { 2260, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2254, 2255, 0 },
   { 2256, 1057, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1222, 1223, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2261, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2261, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1144, 691, 0 },
   { 2261, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2260, 1056, 0 },
   { 2261, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2254, 2255, 0 },
   { 2261, 1056, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { 4856, 4857, 111 },
   { 4863, 4864, 111 },
   { 4869, 4857, 111 },
   { 4873, 4864, 111 },
   { 4880, 4881, 0 },
   { 4885, 4886, 0 },
   { 4895, 4896, 0 },
   { 4901, 4902, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2258, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1080, 1081, 0 },
   { 1145, 1146, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1231, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1210, 1211, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { 5388, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1103, 1104, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2258, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1220, 1221, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1068, 1069, 0 },
   { 1145, 1146, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1208, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 1161, 1162, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 2258, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 2262, 2263, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 1177, 1178, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1094, 1025, 0 },
   { 1098, 1081, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { 5384, 5387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2264, 1069, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2264, 1069, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 2264, 1069, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2258, 1209, 0 },
   { 2264, 1069, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2264, 1069, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1218, 1219, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2259, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2259, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 2259, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2258, 1209, 0 },
   { 2259, 1209, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2259, 1209, 0 },
   { 2262, 2263, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { 4854, 4855, 111 },
   { 4860, 4862, 111 },
   { 4868, 4855, 111 },
   { 4872, 4862, 111 },
   { 4878, 4879, 0 },
   { 4883, 4884, 0 },
   { 4893, 4894, 0 },
   { 4898, 4900, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1165, 1166, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1083, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1204, 1205, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1165, 1166, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1165, 1166, 0 },
   { 1190, 1191, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1096, 1031, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { 5358, 5361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1199, 739, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1216, 1205, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2618, 1028, 0 },
   { 2626, 1025, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2619, 1025, 0 },
   { 2627, 1028, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2616, 1034, 0 },
   { 2624, 1031, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2617, 1031, 0 },
   { 2625, 1034, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1073, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1165, 1166, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1125, 1124, 0 },
   { 1384, 1368, 0 },
   { 1388, 1368, 0 },
   { 1392, 1368, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1056, 0 },
   { 4852, 4853, 111 },
   { 4867, 4853, 111 },
   { 4876, 4877, 0 },
   { 4891, 4892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1484, 32, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1548, 1549, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1249, 0 },
   { 1312, 32, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1494, 219, 37 },
   { 1498, 1499, 37 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1242, 1240, 0 },
   { 1312, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1488, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1488, 103, 0 },
   { 1492, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1546, 1547, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1496, 219, 37 },
   { 1501, 1499, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1488, 103, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1488, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1236, 1237, 0 },
   { 1313, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5719, 5722, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2111, 6, 0 },
   { 2142, 11, 0 },
   { 2172, 16, 0 },
   { 2202, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 3072, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 3072, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3072, 32, 0 },
   { 5723, 5726, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { 3036, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { 3029, 11, 0 },
   { 3031, 16, 0 },
   { 4050, 739, 0 },
   { 4054, 6, 0 },
   { 3029, 11, 0 },
   { 3031, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2958, 2959, 0 },
   { 2960, 2961, 0 },
   { 2962, 1205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 3916, 3914, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1480, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1489, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1489, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 3918, 3914, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1489, 106, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1489, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1763, 11, 0 },
   { 1870, 16, 0 },
   { 1953, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4061, 3020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3032, 3033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1761, 11, 0 },
   { 1868, 16, 0 },
   { 1951, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1789, 1790, 0 },
   { 1812, 1813, 0 },
   { 1896, 1897, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1977, 1978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1765, 11, 0 },
   { 1872, 16, 0 },
   { 1955, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4060, 3020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3034, 3035, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1764, 11, 0 },
   { 1871, 16, 0 },
   { 1954, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1787, 1788, 0 },
   { 1810, 1811, 0 },
   { 1894, 1895, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1975, 1976, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1792, 1793, 0 },
   { 1815, 1793, 0 },
   { 1898, 1791, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1784, 1381, 0 },
   { 1807, 1381, 0 },
   { 1891, 1385, 0 },
   { 4059, 1505, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5781, 5783, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5765, 5767, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5752, 5753, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1795, 1796, 0 },
   { 1817, 1796, 0 },
   { 1899, 1794, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1779, 11, 0 },
   { 1802, 11, 0 },
   { 1886, 16, 0 },
   { 3063, 16, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 16, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 1971, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3062, 1968, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1969, 1970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5784, 5786, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5768, 5770, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5754, 5756, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1972, 1973, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3039, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3038, 1231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5727, 5730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1030, 1031, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1024, 1025, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1027, 1028, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1033, 1034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1036, 1037, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1039, 1040, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1042, 1043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1046, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1194, 1195, 0 },
   { 2646, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 2646, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1194, 1195, 0 },
   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 1398, 1399, 0 },
   { 1403, 1402, 0 },
   { 1420, 1421, 0 },
   { 1425, 1424, 0 },
   { 1442, 1443, 0 },
   { 1447, 1446, 0 },
   { 1462, 1463, 0 },
   { 1467, 1466, 0 },
   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { 5362, 5365, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1202, 1104, 0 },
   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1406, 1399, 0 },
   { 1408, 1402, 0 },
   { 1428, 1421, 0 },
   { 1430, 1424, 0 },
   { 1450, 1443, 0 },
   { 1451, 1446, 0 },
   { 1470, 1463, 0 },
   { 1472, 1466, 0 },
   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1411, 1399, 0 },
   { 1413, 1402, 0 },
   { 1433, 1421, 0 },
   { 1435, 1424, 0 },
   { 1454, 1443, 0 },
   { 1455, 1446, 0 },
   { 1475, 1463, 0 },
   { 1477, 1466, 0 },
   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { 4212, 4217, 110 },
   { 4259, 4264, 110 },
   { 4305, 4310, 110 },
   { 4372, 4377, 111 },
   { 4423, 4428, 111 },
   { 4501, 4506, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { 4555, 4558, 110 },
   { 4595, 4599, 110 },
   { 4637, 4642, 110 },
   { 4701, 4706, 111 },
   { 4746, 4751, 111 },
   { 4818, 4823, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { 3793, 3790, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { 3789, 3790, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 1194, 1195, 0 },
   { 2646, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1366, 1135, 0 },
   { 1371, 1135, 0 },
   { 1375, 1135, 0 },
   { 1379, 1135, 0 },
   { 2646, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 4194, 4196, 110 },
   { 4251, 4196, 110 },
   { 4296, 4196, 110 },
   { 4343, 4344, 111 },
   { 4357, 4359, 111 },
   { 4408, 4344, 111 },
   { 4416, 4359, 111 },
   { 4460, 4461, 0 },
   { 4473, 4474, 0 },
   { 4486, 4488, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 4539, 4541, 110 },
   { 4587, 4541, 110 },
   { 4629, 4541, 110 },
   { 4673, 4674, 111 },
   { 4686, 4688, 111 },
   { 4731, 4674, 111 },
   { 4739, 4688, 111 },
   { 4778, 4779, 0 },
   { 4791, 4792, 0 },
   { 4803, 4805, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1196, 1197, 0 },
   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1196, 1197, 0 },
   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 1400, 1399, 0 },
   { 1401, 1402, 0 },
   { 1422, 1421, 0 },
   { 1423, 1424, 0 },
   { 1444, 1443, 0 },
   { 1445, 1446, 0 },
   { 1464, 1463, 0 },
   { 1465, 1466, 0 },
   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { 5366, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1203, 739, 0 },
   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1405, 1402, 0 },
   { 1409, 1399, 0 },
   { 1427, 1424, 0 },
   { 1431, 1421, 0 },
   { 1449, 1446, 0 },
   { 1452, 1443, 0 },
   { 1469, 1466, 0 },
   { 1473, 1463, 0 },
   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1402, 0 },
   { 1414, 1399, 0 },
   { 1432, 1424, 0 },
   { 1436, 1421, 0 },
   { 1453, 1446, 0 },
   { 1456, 1443, 0 },
   { 1474, 1466, 0 },
   { 1478, 1463, 0 },
   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { 4218, 4221, 110 },
   { 4265, 4268, 110 },
   { 4311, 4314, 110 },
   { 4378, 4381, 111 },
   { 4429, 4432, 111 },
   { 4507, 4510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { 4559, 4562, 110 },
   { 4600, 4603, 110 },
   { 4643, 4646, 110 },
   { 4707, 4710, 111 },
   { 4752, 4755, 111 },
   { 4824, 4827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { 3792, 3788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { 3783, 3788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 1196, 1197, 0 },
   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1367, 1368, 0 },
   { 1372, 1368, 0 },
   { 1376, 1368, 0 },
   { 1380, 1368, 0 },
   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 4197, 4198, 110 },
   { 4252, 4198, 110 },
   { 4297, 4198, 110 },
   { 4345, 4346, 111 },
   { 4360, 4361, 111 },
   { 4409, 4346, 111 },
   { 4417, 4361, 111 },
   { 4462, 4463, 0 },
   { 4475, 4476, 0 },
   { 4489, 4490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 4542, 4543, 110 },
   { 4588, 4543, 110 },
   { 4630, 4543, 110 },
   { 4675, 4676, 111 },
   { 4689, 4690, 111 },
   { 4732, 4676, 111 },
   { 4740, 4690, 111 },
   { 4780, 4781, 0 },
   { 4793, 4794, 0 },
   { 4806, 4807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2729, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 1056, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { 5412, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2337, 2338, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { 3757, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2314, 2316, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { 4569, 4574, 110 },
   { 4610, 4615, 110 },
   { 4654, 4660, 110 },
   { 4716, 4720, 111 },
   { 4762, 4767, 111 },
   { 4833, 4837, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2292, 1056, 0 },
   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { 5408, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2292, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2275, 1064, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2318, 2320, 0 },
   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1056, 0 },
   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1056, 0 },
   { 2292, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2286, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2273, 2274, 0 },
   { 2286, 1056, 0 },
   { 2648, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1056, 0 },
   { 2339, 2340, 0 },
   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3119, 1056, 0 },
   { 4563, 4568, 110 },
   { 4604, 4609, 110 },
   { 4647, 4653, 110 },
   { 4711, 4715, 111 },
   { 4756, 4761, 111 },
   { 4828, 4832, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 4546, 4547, 110 },
   { 4553, 4554, 110 },
   { 4590, 4547, 110 },
   { 4594, 4554, 110 },
   { 4632, 4547, 110 },
   { 4636, 4554, 110 },
   { 4679, 4680, 111 },
   { 4684, 4685, 111 },
   { 4693, 4694, 111 },
   { 4699, 4700, 111 },
   { 4734, 4680, 111 },
   { 4737, 4685, 111 },
   { 4742, 4694, 111 },
   { 4745, 4700, 111 },
   { 4784, 4785, 0 },
   { 4789, 4790, 0 },
   { 4797, 4798, 0 },
   { 4801, 4802, 0 },
   { 4810, 4811, 0 },
   { 4816, 4817, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2288, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { 5420, 5423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2322, 2324, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2288, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2288, 0 },
   { 2341, 2342, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { 4581, 4586, 110 },
   { 4622, 4627, 110 },
   { 4667, 4672, 110 },
   { 4726, 4730, 111 },
   { 4773, 4777, 111 },
   { 4843, 4847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 1209, 0 },
   { 2296, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2296, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2288, 0 },
   { 2296, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { 5416, 5419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2295, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2289, 2290, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 2288, 0 },
   { 2289, 2290, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2343, 2344, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1209, 0 },
   { 2295, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2277, 1209, 0 },
   { 2278, 1209, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1209, 0 },
   { 2287, 2288, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1209, 0 },
   { 2326, 2328, 0 },
   { 2649, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { 4575, 4580, 110 },
   { 4616, 4621, 110 },
   { 4661, 4666, 110 },
   { 4721, 4725, 111 },
   { 4768, 4772, 111 },
   { 4838, 4842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2649, 1209, 0 },
   { 4544, 4545, 110 },
   { 4550, 4552, 110 },
   { 4589, 4545, 110 },
   { 4593, 4552, 110 },
   { 4631, 4545, 110 },
   { 4635, 4552, 110 },
   { 4677, 4678, 111 },
   { 4682, 4683, 111 },
   { 4691, 4692, 111 },
   { 4696, 4698, 111 },
   { 4733, 4678, 111 },
   { 4736, 4683, 111 },
   { 4741, 4692, 111 },
   { 4744, 4698, 111 },
   { 4782, 4783, 0 },
   { 4787, 4788, 0 },
   { 4795, 4796, 0 },
   { 4799, 4800, 0 },
   { 4808, 4809, 0 },
   { 4813, 4815, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { 1331, 1267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3739, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3737, 2674, 0 },
   { 3739, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 4903, 3227, 0 },
   { 4904, 3230, 0 },
   { 4906, 4764, 0 },
   { 4908, 1990, 0 },
   { 4909, 2006, 0 },
   { 4911, 4657, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1785, 1369, 0 },
   { 1808, 1369, 0 },
   { 1892, 1373, 0 },
   { 4065, 3020, 0 },
   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 5790, 5792, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 5774, 5776, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 5759, 5760, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1781, 11, 0 },
   { 1804, 11, 0 },
   { 1888, 16, 0 },
   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 4084, 4085, 0 },
   { 4092, 4085, 0 },
   { 4098, 4085, 0 },
   { 4104, 4085, 0 },
   { 4108, 4109, 0 },
   { 4112, 4083, 0 },
   { 4116, 4083, 0 },
   { 4120, 4083, 0 },
   { 4124, 4125, 0 },
   { 4128, 4125, 0 },
   { 4130, 4131, 0 },
   { 4134, 4091, 0 },
   { 4138, 4091, 0 },
   { 4142, 4143, 0 },
   { 4146, 4143, 0 },
   { 4148, 4149, 0 },
   { 4151, 4143, 0 },
   { 4153, 4149, 0 },
   { 4155, 1780, 0 },
   { 4157, 4097, 0 },
   { 4161, 4162, 0 },
   { 4165, 4162, 0 },
   { 4167, 4168, 0 },
   { 4171, 4162, 0 },
   { 4173, 4168, 0 },
   { 4175, 1803, 0 },
   { 4177, 4162, 0 },
   { 4179, 4168, 0 },
   { 4181, 1803, 0 },
   { 4183, 1887, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 4087, 4088, 0 },
   { 4094, 4088, 0 },
   { 4100, 4088, 0 },
   { 4105, 4088, 0 },
   { 4113, 4086, 0 },
   { 4117, 4086, 0 },
   { 4121, 4086, 0 },
   { 4135, 4093, 0 },
   { 4139, 4093, 0 },
   { 4158, 4099, 0 },
   { 4940, 11, 0 },
   { 4993, 16, 0 },
   { 5045, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3057, 16, 0 },
   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3059, 1982, 0 },
   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 4185, 4186, 0 },
   { 4185, 4186, 0 },
   { 4187, 4188, 0 },
   { 4187, 4188, 0 },
   { 4189, 4069, 0 },
   { 4189, 4069, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1786, 1369, 0 },
   { 1809, 1369, 0 },
   { 1893, 1373, 0 },
   { 4063, 3020, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 5787, 5789, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 5771, 5773, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 5757, 5758, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3172, 3174, 57 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 4089, 4085, 0 },
   { 4095, 4085, 0 },
   { 4101, 4085, 0 },
   { 4106, 4085, 0 },
   { 4114, 4083, 0 },
   { 4118, 4083, 0 },
   { 4122, 4083, 0 },
   { 4136, 4091, 0 },
   { 4140, 4091, 0 },
   { 4159, 4097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1783, 11, 0 },
   { 1806, 11, 0 },
   { 1890, 16, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 4090, 4088, 0 },
   { 4096, 4088, 0 },
   { 4102, 4088, 0 },
   { 4107, 4088, 0 },
   { 4110, 4111, 0 },
   { 4115, 4086, 0 },
   { 4119, 4086, 0 },
   { 4123, 4086, 0 },
   { 4126, 4127, 0 },
   { 4129, 4127, 0 },
   { 4132, 4133, 0 },
   { 4137, 4093, 0 },
   { 4141, 4093, 0 },
   { 4144, 4145, 0 },
   { 4147, 4145, 0 },
   { 4150, 3202, 0 },
   { 4152, 4145, 0 },
   { 4154, 3202, 0 },
   { 4156, 1782, 0 },
   { 4160, 4099, 0 },
   { 4163, 4164, 0 },
   { 4166, 4164, 0 },
   { 4169, 4170, 0 },
   { 4172, 4164, 0 },
   { 4174, 4170, 0 },
   { 4176, 1805, 0 },
   { 4178, 4164, 0 },
   { 4180, 4170, 0 },
   { 4182, 1805, 0 },
   { 4184, 1889, 0 },
   { 4912, 11, 0 },
   { 4965, 16, 0 },
   { 5018, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3058, 16, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3168, 3170, 57 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3060, 1979, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 4190, 2006, 0 },
   { 4190, 2006, 0 },
   { 4191, 3230, 0 },
   { 4191, 3230, 0 },
   { 4192, 4074, 0 },
   { 4192, 4074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 3229, 62 },
   { 3244, 3138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3131, 1437, 0 },
   { 3138, 3229, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3128, 124, 0 },
   { 3138, 3229, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3122, 36, 0 },
   { 3138, 3229, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3125, 2385, 0 },
   { 3138, 3229, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3230, 63 },
   { 3234, 3146, 0 },
   { 3146, 3230, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3230, 63 },
   { 3248, 3146, 0 },
   { 3249, 3148, 0 },
   { 3146, 3230, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3148, 3231, 63 },
   { 3241, 3148, 0 },
   { 3148, 3231, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3742, 3735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3744, 3735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3744, 3735, 0 },
   { 3771, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3742, 3735, 0 },
   { 3744, 3735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 3732, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3746, 3732, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3746, 3732, 0 },
   { 3772, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 3732, 0 },
   { 3746, 3732, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3232, 3233, 0 },
   { 3233, 3911, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3247, 3240, 0 },
   { 3233, 3911, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3245, 3233, 0 },
   { 3246, 3240, 0 },
   { 3233, 3911, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3239, 3240, 0 },
   { 3240, 3912, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3748, 3749, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3751, 3749, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3748, 3749, 0 },
   { 3751, 3749, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 2424, 47 },
   { 5314, 2419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 2424, 47 },
   { 5315, 2489, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 2431, 47 },
   { 5320, 2425, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2425, 2431, 47 },
   { 5321, 2493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 2438, 47 },
   { 5324, 2432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 2438, 47 },
   { 5325, 2499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2439, 2455, 47 },
   { 5328, 2439, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2439, 2455, 47 },
   { 5329, 2504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 2488, 47 },
   { 5332, 2456, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 2488, 47 },
   { 5333, 2513, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2233, 2234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2530, 2533, 47 },
   { 5318, 2530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2530, 2533, 47 },
   { 5319, 2571, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2534, 2539, 47 },
   { 5322, 2534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2534, 2539, 47 },
   { 5323, 2575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2540, 2544, 47 },
   { 5326, 2540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2540, 2544, 47 },
   { 5327, 2581, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2545, 2553, 47 },
   { 5330, 2545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2545, 2553, 47 },
   { 5331, 2586, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2554, 2570, 47 },
   { 5334, 2554, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2554, 2570, 47 },
   { 5335, 2595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 2267, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 5396, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1056, 0 },
   { 2329, 2330, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 2267, 0 },
   { 2298, 2300, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 4231, 4237, 110 },
   { 4277, 4282, 110 },
   { 4324, 4330, 110 },
   { 4390, 4395, 111 },
   { 4441, 4447, 111 },
   { 4519, 4525, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 1466, 3708, 80 },
   { 5392, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1062, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1062, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 3701, 3703, 79 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1062, 0 },
   { 2279, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 2267, 0 },
   { 2268, 1062, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1062, 0 },
   { 2302, 2304, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 3701, 3703, 79 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2280, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2280, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 3696, 3699, 79 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1056, 0 },
   { 2280, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 2267, 0 },
   { 2280, 1056, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2280, 1056, 0 },
   { 2331, 2332, 0 },
   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 3696, 3699, 79 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 1466, 3708, 80 },
   { 4222, 4229, 110 },
   { 4269, 4276, 110 },
   { 4315, 4322, 110 },
   { 4382, 4389, 111 },
   { 4433, 4440, 111 },
   { 4511, 4518, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 4201, 4202, 110 },
   { 4210, 4211, 110 },
   { 4254, 4202, 110 },
   { 4258, 4211, 110 },
   { 4299, 4202, 110 },
   { 4303, 4211, 110 },
   { 4349, 4350, 111 },
   { 4354, 4355, 111 },
   { 4364, 4365, 111 },
   { 4370, 4371, 111 },
   { 4411, 4350, 111 },
   { 4414, 4355, 111 },
   { 4419, 4365, 111 },
   { 4422, 4371, 111 },
   { 4466, 4467, 0 },
   { 4471, 4472, 0 },
   { 4479, 4480, 0 },
   { 4483, 4484, 0 },
   { 4493, 4494, 0 },
   { 4499, 4500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 1209, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 5404, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 1209, 0 },
   { 2306, 2308, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2333, 2334, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 4244, 4249, 110 },
   { 4289, 4294, 110 },
   { 4337, 4342, 110 },
   { 4402, 4407, 111 },
   { 4454, 4459, 111 },
   { 4532, 4537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { 5400, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2284, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2284, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 3706, 3707, 79 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 1209, 0 },
   { 2283, 2284, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2283, 2284, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 2284, 0 },
   { 2335, 2336, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 3706, 3707, 79 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2271, 1209, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2271, 1209, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 3704, 3705, 79 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 1209, 0 },
   { 2271, 1209, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2271, 1209, 0 },
   { 2281, 2282, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2271, 1209, 0 },
   { 2310, 2312, 0 },
   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 3704, 3705, 79 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { 4238, 4243, 110 },
   { 4283, 4288, 110 },
   { 4331, 4336, 110 },
   { 4396, 4401, 111 },
   { 4448, 4453, 111 },
   { 4526, 4531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 4199, 4200, 110 },
   { 4207, 4209, 110 },
   { 4253, 4200, 110 },
   { 4257, 4209, 110 },
   { 4298, 4200, 110 },
   { 4302, 4209, 110 },
   { 4347, 4348, 111 },
   { 4352, 4353, 111 },
   { 4362, 4363, 111 },
   { 4367, 4369, 111 },
   { 4410, 4348, 111 },
   { 4413, 4353, 111 },
   { 4418, 4363, 111 },
   { 4421, 4369, 111 },
   { 4464, 4465, 0 },
   { 4469, 4470, 0 },
   { 4477, 4478, 0 },
   { 4481, 4482, 0 },
   { 4491, 4492, 0 },
   { 4496, 4498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3914, 3916, 100 },
   { 5731, 5734, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2731, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2784, 2785, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2776, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2779, 2780, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 2783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2767, 2769, 0 },
   { 2749, 2803, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2770, 2771, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2802, 2781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2801, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2804, 2749, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2772, 2775, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3052, 1369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3042, 3043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3053, 1369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3044, 3045, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4062, 1505, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1797, 1798, 0 },
   { 1818, 1819, 0 },
   { 1900, 1901, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1986, 1987, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4064, 1505, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1758, 1759, 0 },
   { 1865, 1866, 0 },
   { 1948, 1949, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1799, 1800, 0 },
   { 1820, 1821, 0 },
   { 1902, 1903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1988, 1989, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3051, 1369, 0 },
   { 3051, 1369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5793, 5795, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5777, 5779, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5761, 5763, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1983, 1984, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1980, 1981, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3040, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3041, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3054, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 3047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3055, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 3049, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 755, 757, 35 },
   { 767, 768, 0 },
   { 783, 784, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 755, 757, 35 },
   { 762, 764, 0 },
   { 767, 768, 0 },
   { 783, 784, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 755, 757, 35 },
   { 759, 266, 0 },
   { 762, 764, 0 },
   { 767, 768, 0 },
   { 783, 784, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 772, 764, 0 },
   { 781, 782, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 770, 266, 0 },
   { 772, 764, 0 },
   { 781, 782, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 774, 266, 0 },
   { 779, 780, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 774, 266, 0 },
   { 775, 778, 0 },
   { 779, 780, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1325, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1320, 32, 0 },
   { 1321, 63, 0 },
   { 1325, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3217, 3218, 0 },
   { 3841, 3844, 90 },
   { 5019, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3219, 3218, 0 },
   { 3841, 3844, 90 },
   { 5019, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3265, 3261, 0 },
   { 3841, 3844, 90 },
   { 5019, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 46 },
   { 2367, 2351, 0 },
   { 2375, 2353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 46 },
   { 2368, 2353, 0 },
   { 2376, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 46 },
   { 2364, 2355, 0 },
   { 2373, 2357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 2361, 46 },
   { 2366, 2357, 0 },
   { 2374, 2355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2362, 46 },
   { 2371, 2351, 0 },
   { 2379, 2353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2362, 46 },
   { 2372, 2353, 0 },
   { 2380, 2351, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2362, 46 },
   { 2369, 2355, 0 },
   { 2377, 2357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 2362, 46 },
   { 2370, 2357, 0 },
   { 2378, 2355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { 2757, 32, 0 },
   { 2758, 253, 0 },
   { 2759, 2756, 0 },
   { 2764, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3132, 3133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3134, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3143, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3145, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3136, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3574, 3539, 64 },
   { 3823, 3826, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3575, 3576, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 213, 3, 0 },
   { 3443, 3444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 213, 3, 0 },
   { 3443, 3444, 0 },
   { 3485, 3444, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4926, 3979, 0 },
   { 4980, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4951, 3979, 0 },
   { 4980, 3999, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4926, 3979, 0 },
   { 4949, 3979, 0 },
   { 4980, 3999, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4926, 3979, 0 },
   { 4979, 3999, 0 },
   { 4980, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4926, 3979, 0 },
   { 4977, 3999, 0 },
   { 4980, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4952, 3979, 0 },
   { 5005, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4951, 3979, 0 },
   { 4952, 3979, 0 },
   { 5004, 3999, 0 },
   { 5005, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 4952, 3979, 0 },
   { 5002, 3999, 0 },
   { 5005, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4952, 3979, 0 },
   { 4979, 3999, 0 },
   { 5005, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4952, 3979, 0 },
   { 4977, 3999, 0 },
   { 5005, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { 5057, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5032, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5032, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { 5032, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4951, 3979, 0 },
   { 5004, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4949, 3979, 0 },
   { 5002, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4925, 3979, 0 },
   { 4979, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4923, 3979, 0 },
   { 4977, 3999, 0 },
   { 5029, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4949, 3979, 0 },
   { 4951, 3979, 0 },
   { 5002, 3999, 0 },
   { 5004, 3999, 0 },
   { 5054, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4951, 3979, 0 },
   { 4979, 3999, 0 },
   { 5004, 3999, 0 },
   { 5031, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4951, 3979, 0 },
   { 4977, 3999, 0 },
   { 5004, 3999, 0 },
   { 5029, 3999, 0 },
   { 5056, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4925, 3979, 0 },
   { 4949, 3979, 0 },
   { 4979, 3999, 0 },
   { 5002, 3999, 0 },
   { 5031, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4949, 3979, 0 },
   { 4977, 3999, 0 },
   { 5002, 3999, 0 },
   { 5029, 3999, 0 },
   { 5054, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4923, 3979, 0 },
   { 4925, 3979, 0 },
   { 4977, 3999, 0 },
   { 4979, 3999, 0 },
   { 5029, 3999, 0 },
   { 5031, 3999, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3258, 3259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4954, 4928, 0 },
   { 5007, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4953, 4928, 0 },
   { 5006, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4982, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4981, 49, 0 },
   { 5033, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1011, 1015, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1003, 1006, 0 },
   { 1011, 1015, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4954, 4928, 0 },
   { 5007, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4953, 4928, 0 },
   { 5006, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4929, 4928, 0 },
   { 4982, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4927, 4928, 0 },
   { 4981, 49, 0 },
   { 5033, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4954, 4928, 0 },
   { 5007, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4953, 4928, 0 },
   { 5006, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4929, 4928, 0 },
   { 4982, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 4927, 4928, 0 },
   { 4981, 49, 0 },
   { 5033, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4954, 4928, 0 },
   { 4983, 49, 0 },
   { 5007, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4930, 4928, 0 },
   { 4953, 4928, 0 },
   { 4983, 49, 0 },
   { 5006, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4930, 4928, 0 },
   { 4982, 49, 0 },
   { 4983, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4930, 4928, 0 },
   { 4981, 49, 0 },
   { 4983, 49, 0 },
   { 5033, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4954, 4928, 0 },
   { 4955, 4928, 0 },
   { 5007, 49, 0 },
   { 5008, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4953, 4928, 0 },
   { 4955, 4928, 0 },
   { 5006, 49, 0 },
   { 5008, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4955, 4928, 0 },
   { 4982, 49, 0 },
   { 5008, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4955, 4928, 0 },
   { 4981, 49, 0 },
   { 5008, 49, 0 },
   { 5033, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4954, 4928, 0 },
   { 5007, 49, 0 },
   { 5059, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4953, 4928, 0 },
   { 5006, 49, 0 },
   { 5058, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4982, 49, 0 },
   { 5034, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4981, 49, 0 },
   { 5033, 49, 0 },
   { 5060, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4954, 4928, 0 },
   { 5007, 49, 0 },
   { 5035, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4953, 4928, 0 },
   { 5006, 49, 0 },
   { 5035, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4982, 49, 0 },
   { 5034, 49, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4981, 49, 0 },
   { 5033, 49, 0 },
   { 5035, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4953, 4928, 0 },
   { 4954, 4928, 0 },
   { 5006, 49, 0 },
   { 5007, 49, 0 },
   { 5058, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4954, 4928, 0 },
   { 4982, 49, 0 },
   { 5007, 49, 0 },
   { 5034, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4954, 4928, 0 },
   { 4981, 49, 0 },
   { 5007, 49, 0 },
   { 5033, 49, 0 },
   { 5059, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4929, 4928, 0 },
   { 4953, 4928, 0 },
   { 4982, 49, 0 },
   { 5006, 49, 0 },
   { 5034, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4953, 4928, 0 },
   { 4981, 49, 0 },
   { 5006, 49, 0 },
   { 5033, 49, 0 },
   { 5058, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4927, 4928, 0 },
   { 4929, 4928, 0 },
   { 4981, 49, 0 },
   { 4982, 49, 0 },
   { 5033, 49, 0 },
   { 5034, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2681, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 889, 892, 0 },
   { 897, 900, 0 },
   { 905, 908, 0 },
   { 913, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 893, 892, 0 },
   { 901, 900, 0 },
   { 909, 908, 0 },
   { 917, 916, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1017, 1020, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 795, 799, 0 },
   { 999, 1001, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 999, 1001, 0 },
   { 1017, 1020, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { 3252, 3254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2121, 2123, 0 },
   { 2151, 2153, 0 },
   { 2181, 2183, 0 },
   { 2212, 2214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2687, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2121, 2123, 0 },
   { 2151, 2153, 0 },
   { 2181, 2183, 0 },
   { 2212, 2214, 0 },
   { 2687, 1201, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 894, 896, 0 },
   { 902, 904, 0 },
   { 910, 912, 0 },
   { 918, 920, 0 },
   { 2121, 2123, 0 },
   { 2151, 2153, 0 },
   { 2181, 2183, 0 },
   { 2212, 2214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { 3255, 3251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { 3594, 3592, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { 3591, 3592, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3071, 32, 0 },
   { 3591, 3592, 0 },
   { 3594, 3592, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1129, 1128, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1133, 1132, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1085, 0 },
   { 1186, 1189, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1127, 1128, 0 },
   { 1163, 1164, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1132, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1130, 1128, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1070, 1071, 0 },
   { 1137, 1135, 0 },
   { 2629, 1231, 0 },
   { 2653, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1114, 1111, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1119, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1083, 0 },
   { 1192, 1193, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1110, 1111, 0 },
   { 1165, 1166, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1118, 1119, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1116, 1111, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1073, 0 },
   { 1126, 1124, 0 },
   { 2628, 1227, 0 },
   { 2654, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { 5429, 5432, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 257, 255, 0 },
   { 3401, 3403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 257, 255, 0 },
   { 3401, 3403, 0 },
   { 3446, 3403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3388, 3389, 0 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 255, 0 },
   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 380, 381, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 380, 381, 9 },
   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 526, 527, 0 },
   { 589, 590, 0 },
   { 593, 594, 0 },
   { 661, 662, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 532, 534, 0 },
   { 598, 600, 0 },
   { 671, 673, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 386, 387, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 386, 387, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 386, 387, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2661, 32, 0 },
   { 2662, 63, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2696, 2693, 48 },
   { 2703, 2700, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1209, 0 },
   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2708, 2706, 48 },
   { 2713, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2663, 63, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1693, 1696, 0 },
   { 1700, 1696, 0 },
   { 1705, 1708, 0 },
   { 1712, 1708, 0 },
   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4960, 2046, 0 },
   { 4989, 2050, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4936, 2046, 0 },
   { 4959, 2046, 0 },
   { 4989, 2050, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4936, 2046, 0 },
   { 4988, 2050, 0 },
   { 4989, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4936, 2046, 0 },
   { 4987, 2050, 0 },
   { 4989, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 4961, 2046, 0 },
   { 5013, 2050, 0 },
   { 5014, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 4961, 2046, 0 },
   { 5012, 2050, 0 },
   { 5014, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4961, 2046, 0 },
   { 4988, 2050, 0 },
   { 5014, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4961, 2046, 0 },
   { 4987, 2050, 0 },
   { 5014, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5065, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5064, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { 5066, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4960, 2046, 0 },
   { 5013, 2050, 0 },
   { 5041, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 5012, 2050, 0 },
   { 5041, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { 5041, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2696, 2693, 48 },
   { 2703, 2700, 48 },
   { 2708, 2706, 48 },
   { 2713, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4988, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 3011, 3012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4959, 2046, 0 },
   { 4960, 2046, 0 },
   { 5012, 2050, 0 },
   { 5013, 2050, 0 },
   { 5064, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4960, 2046, 0 },
   { 4988, 2050, 0 },
   { 5013, 2050, 0 },
   { 5040, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4960, 2046, 0 },
   { 4987, 2050, 0 },
   { 5013, 2050, 0 },
   { 5039, 2050, 0 },
   { 5065, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4935, 2046, 0 },
   { 4959, 2046, 0 },
   { 4988, 2050, 0 },
   { 5012, 2050, 0 },
   { 5040, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4959, 2046, 0 },
   { 4987, 2050, 0 },
   { 5012, 2050, 0 },
   { 5039, 2050, 0 },
   { 5064, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4935, 2046, 0 },
   { 4987, 2050, 0 },
   { 4988, 2050, 0 },
   { 5039, 2050, 0 },
   { 5040, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 4934, 2046, 0 },
   { 4987, 2050, 0 },
   { 5039, 2050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 3260, 3259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4035, 4036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4041, 4042, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4047, 4048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4030, 4033, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4038, 4039, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4044, 4045, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3022, 1505, 0 },
   { 3023, 3020, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2659, 61, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1993, 1996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2673, 2674, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 195, 0 },
   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2095, 2097, 42 },
   { 2095, 2103, 44 },
   { 2126, 2128, 42 },
   { 2126, 2134, 44 },
   { 2156, 2158, 42 },
   { 2156, 2164, 44 },
   { 2186, 2188, 42 },
   { 2186, 2194, 44 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1061, 1056, 0 },
   { 2655, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2677, 2678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4986, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4957, 2004, 0 },
   { 4986, 2012, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4933, 2004, 0 },
   { 4956, 2004, 0 },
   { 4986, 2012, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4933, 2004, 0 },
   { 4985, 2012, 0 },
   { 4986, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4933, 2004, 0 },
   { 4984, 2012, 0 },
   { 4986, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4958, 2004, 0 },
   { 5011, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4957, 2004, 0 },
   { 4958, 2004, 0 },
   { 5010, 2012, 0 },
   { 5011, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 4958, 2004, 0 },
   { 5009, 2012, 0 },
   { 5011, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4958, 2004, 0 },
   { 4985, 2012, 0 },
   { 5011, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4958, 2004, 0 },
   { 4984, 2012, 0 },
   { 5011, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { 5063, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5038, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5038, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { 5038, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 2672, 3, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 3009, 3010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1395, 1396, 0 },
   { 1417, 1418, 0 },
   { 1439, 1440, 0 },
   { 1459, 1460, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4957, 2004, 0 },
   { 5010, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 5009, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4985, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2095, 2097, 42 },
   { 2095, 2103, 44 },
   { 2126, 2128, 42 },
   { 2126, 2134, 44 },
   { 2156, 2158, 42 },
   { 2156, 2164, 44 },
   { 2186, 2188, 42 },
   { 2186, 2194, 44 },
   { 2655, 32, 0 },
   { 3151, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4956, 2004, 0 },
   { 4957, 2004, 0 },
   { 5009, 2012, 0 },
   { 5010, 2012, 0 },
   { 5061, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4957, 2004, 0 },
   { 4985, 2012, 0 },
   { 5010, 2012, 0 },
   { 5037, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4957, 2004, 0 },
   { 4984, 2012, 0 },
   { 5010, 2012, 0 },
   { 5036, 2012, 0 },
   { 5062, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4932, 2004, 0 },
   { 4956, 2004, 0 },
   { 4985, 2012, 0 },
   { 5009, 2012, 0 },
   { 5037, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4956, 2004, 0 },
   { 4984, 2012, 0 },
   { 5009, 2012, 0 },
   { 5036, 2012, 0 },
   { 5061, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4932, 2004, 0 },
   { 4984, 2012, 0 },
   { 4985, 2012, 0 },
   { 5036, 2012, 0 },
   { 5037, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 32, 0 },
   { 4931, 2004, 0 },
   { 4984, 2012, 0 },
   { 5036, 2012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2349, 0 },
   { 3072, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3141, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1111, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1074, 1075, 0 },
   { 1229, 1227, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1074, 1075, 0 },
   { 1173, 1176, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1074, 1075, 0 },
   { 2643, 739, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 1251, 1028, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 1168, 1171, 0 },
   { 1251, 1028, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1143, 1128, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 1232, 1231, 0 },
   { 1232, 1231, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 1179, 1180, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 1106, 1104, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1484, 32, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1564, 1565, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1496, 219, 37 },
   { 1501, 1499, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1486, 32, 0 },
   { 1488, 103, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1488, 103, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1488, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { 1488, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { 1486, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1241, 0 },
   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { 1490, 103, 0 },
   { 1552, 1555, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1323, 1255, 0 },
   { 1336, 1338, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 1510, 1512, 37 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 1515, 1517, 37 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 1520, 1522, 40 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 1524, 1528, 37 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1494, 39 },
   { 2636, 1237, 0 },
   { 3074, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3461, 3464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3470, 3474, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3480, 3483, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 789, 791, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 218, 3, 0 },
   { 3428, 3430, 0 },
   { 3432, 3430, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 218, 3, 0 },
   { 3428, 3430, 0 },
   { 3432, 3430, 0 },
   { 3459, 3430, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 218, 3, 0 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 218, 3, 0 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2732, 2735, 50 },
   { 2757, 32, 0 },
   { 2758, 253, 0 },
   { 2759, 2756, 0 },
   { 2766, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2736, 2732, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2736, 2732, 51 },
   { 2748, 2749, 0 },
   { 2752, 253, 0 },
   { 2755, 2756, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { 1480, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { 1485, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 3025, 3012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1487, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1487, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 3918, 3914, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1487, 32, 0 },
   { 1489, 106, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1489, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { 1489, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1487, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1487, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { 1487, 32, 0 },
   { 1491, 106, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1491, 106, 38 },
   { 3024, 3010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1315, 32, 0 },
   { 1327, 1275, 0 },
   { 1346, 1348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 1209, 0 },
   { 2963, 739, 0 },
   { 2966, 1104, 0 },
   { 3013, 1104, 0 },
   { 3014, 739, 0 },
   { 3110, 1056, 0 },
   { 3713, 3714, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 1056, 0 },
   { 2964, 1104, 0 },
   { 2965, 739, 0 },
   { 3015, 739, 0 },
   { 3016, 1104, 0 },
   { 3109, 1209, 0 },
   { 3710, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2232, 1368, 0 },
   { 2647, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2644, 1056, 0 },
   { 3018, 739, 0 },
   { 3114, 1056, 0 },
   { 3115, 1209, 0 },
   { 3116, 1209, 0 },
   { 1466, 3708, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { 3753, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2648, 1056, 0 },
   { 3019, 739, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { 3753, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2337, 2338, 0 },
   { 2648, 1056, 0 },
   { 3118, 1209, 0 },
   { 3715, 3712, 80 },
   { 3753, 1056, 0 },
   { 3757, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2294, 1056, 0 },
   { 2648, 1056, 0 },
   { 3753, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2275, 1064, 0 },
   { 2285, 1056, 0 },
   { 2648, 1056, 0 },
   { 3753, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1056, 0 },
   { 2286, 1056, 0 },
   { 2648, 1056, 0 },
   { 3753, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2645, 1209, 0 },
   { 3017, 1104, 0 },
   { 3111, 1209, 0 },
   { 3112, 1056, 0 },
   { 3113, 1056, 0 },
   { 1463, 3709, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 3027, 3010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1325, 1265, 0 },
   { 1341, 1343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1320, 32, 0 },
   { 1321, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1320, 32, 0 },
   { 1321, 63, 0 },
   { 1325, 1265, 0 },
   { 1341, 1343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1325, 1265, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 3026, 3012, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1319, 32, 0 },
   { 1325, 1265, 0 },
   { 1341, 1343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2969, 1090, 0 },
   { 2970, 686, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 393, 394, 9 },
   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1284, 1285, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 1254, 1255, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 1259, 1260, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1273, 0 },
   { 1274, 1275, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 2347, 2348, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1264, 1265, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4945, 4917, 0 },
   { 4998, 4970, 0 },
   { 5050, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4943, 4917, 0 },
   { 4996, 4970, 0 },
   { 5048, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4920, 4917, 0 },
   { 4973, 4970, 0 },
   { 5025, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1266, 1267, 0 },
   { 1269, 1270, 0 },
   { 1290, 1288, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3599, 3601, 0 },
   { 4916, 4917, 0 },
   { 4969, 4970, 0 },
   { 5022, 4970, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3506, 3504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3509, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3512, 3510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3515, 3513, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1276, 1277, 0 },
   { 1279, 1280, 0 },
   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3518, 3516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3778, 3776, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3781, 3776, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1569, 1568, 0 },
   { 3832, 3835, 89 },
   { 4913, 11, 0 },
   { 4966, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4963, 2070, 0 },
   { 5016, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4962, 2070, 0 },
   { 5015, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4991, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4963, 2070, 0 },
   { 5016, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4962, 2070, 0 },
   { 5015, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4938, 2070, 0 },
   { 4991, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2668, 2658, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4963, 2070, 0 },
   { 4992, 2074, 0 },
   { 5016, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4939, 2070, 0 },
   { 4962, 2070, 0 },
   { 4992, 2074, 0 },
   { 5015, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4939, 2070, 0 },
   { 4991, 2074, 0 },
   { 4992, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4939, 2070, 0 },
   { 4990, 2074, 0 },
   { 4992, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4963, 2070, 0 },
   { 4964, 2070, 0 },
   { 5016, 2074, 0 },
   { 5017, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4962, 2070, 0 },
   { 4964, 2070, 0 },
   { 5015, 2074, 0 },
   { 5017, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4964, 2070, 0 },
   { 4991, 2074, 0 },
   { 5017, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4964, 2070, 0 },
   { 4990, 2074, 0 },
   { 5017, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4963, 2070, 0 },
   { 5016, 2074, 0 },
   { 5068, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4962, 2070, 0 },
   { 5015, 2074, 0 },
   { 5067, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4991, 2074, 0 },
   { 5043, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { 5069, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4963, 2070, 0 },
   { 5016, 2074, 0 },
   { 5044, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4962, 2070, 0 },
   { 5015, 2074, 0 },
   { 5044, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4991, 2074, 0 },
   { 5043, 2074, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { 5044, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4963, 2070, 0 },
   { 5016, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4962, 2070, 0 },
   { 5015, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4938, 2070, 0 },
   { 4991, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 2667, 3, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4962, 2070, 0 },
   { 4963, 2070, 0 },
   { 5015, 2074, 0 },
   { 5016, 2074, 0 },
   { 5067, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4963, 2070, 0 },
   { 4991, 2074, 0 },
   { 5016, 2074, 0 },
   { 5043, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4963, 2070, 0 },
   { 4990, 2074, 0 },
   { 5016, 2074, 0 },
   { 5042, 2074, 0 },
   { 5068, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4938, 2070, 0 },
   { 4962, 2070, 0 },
   { 4991, 2074, 0 },
   { 5015, 2074, 0 },
   { 5043, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4962, 2070, 0 },
   { 4990, 2074, 0 },
   { 5015, 2074, 0 },
   { 5042, 2074, 0 },
   { 5067, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4938, 2070, 0 },
   { 4990, 2074, 0 },
   { 4991, 2074, 0 },
   { 5042, 2074, 0 },
   { 5043, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2664, 61, 0 },
   { 4937, 2070, 0 },
   { 4990, 2074, 0 },
   { 5042, 2074, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1783, 11, 0 },
   { 1806, 11, 0 },
   { 1890, 16, 0 },
   { 1999, 1996, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 4090, 4088, 0 },
   { 4096, 4088, 0 },
   { 4102, 4088, 0 },
   { 4107, 4088, 0 },
   { 4110, 4111, 0 },
   { 4115, 4086, 0 },
   { 4119, 4086, 0 },
   { 4123, 4086, 0 },
   { 4126, 4127, 0 },
   { 4129, 4127, 0 },
   { 4132, 4133, 0 },
   { 4137, 4093, 0 },
   { 4141, 4093, 0 },
   { 4144, 4145, 0 },
   { 4147, 4145, 0 },
   { 4150, 3202, 0 },
   { 4152, 4145, 0 },
   { 4154, 3202, 0 },
   { 4156, 1782, 0 },
   { 4160, 4099, 0 },
   { 4163, 4164, 0 },
   { 4166, 4164, 0 },
   { 4169, 4170, 0 },
   { 4172, 4164, 0 },
   { 4174, 4170, 0 },
   { 4176, 1805, 0 },
   { 4178, 4164, 0 },
   { 4180, 4170, 0 },
   { 4182, 1805, 0 },
   { 4184, 1889, 0 },
   { 4912, 11, 0 },
   { 4965, 16, 0 },
   { 5018, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1783, 11, 0 },
   { 1806, 11, 0 },
   { 1890, 16, 0 },
   { 3180, 3181, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { 4090, 4088, 0 },
   { 4096, 4088, 0 },
   { 4102, 4088, 0 },
   { 4107, 4088, 0 },
   { 4110, 4111, 0 },
   { 4115, 4086, 0 },
   { 4119, 4086, 0 },
   { 4123, 4086, 0 },
   { 4126, 4127, 0 },
   { 4129, 4127, 0 },
   { 4132, 4133, 0 },
   { 4137, 4093, 0 },
   { 4141, 4093, 0 },
   { 4144, 4145, 0 },
   { 4147, 4145, 0 },
   { 4150, 3202, 0 },
   { 4152, 4145, 0 },
   { 4154, 3202, 0 },
   { 4156, 1782, 0 },
   { 4160, 4099, 0 },
   { 4163, 4164, 0 },
   { 4166, 4164, 0 },
   { 4169, 4170, 0 },
   { 4172, 4164, 0 },
   { 4174, 4170, 0 },
   { 4176, 1805, 0 },
   { 4178, 4164, 0 },
   { 4180, 4170, 0 },
   { 4182, 1805, 0 },
   { 4184, 1889, 0 },
   { 4912, 11, 0 },
   { 4965, 16, 0 },
   { 5018, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3177, 3179, 0 },
   { 4066, 739, 0 },
   { 4067, 6, 0 },
   { 4068, 11, 0 },
   { 4069, 16, 0 },
   { 4070, 21, 0 },
   { 4087, 4088, 0 },
   { 4094, 4088, 0 },
   { 4100, 4088, 0 },
   { 4105, 4088, 0 },
   { 4113, 4086, 0 },
   { 4117, 4086, 0 },
   { 4121, 4086, 0 },
   { 4135, 4093, 0 },
   { 4139, 4093, 0 },
   { 4158, 4099, 0 },
   { 4940, 11, 0 },
   { 4993, 16, 0 },
   { 5045, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2111, 6, 0 },
   { 2142, 11, 0 },
   { 2172, 16, 0 },
   { 2202, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1317, 61, 0 },
   { 1318, 32, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1331, 1267, 0 },
   { 1356, 1358, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1316, 32, 0 },
   { 1542, 1543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3550, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3570, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3552, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3572, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3548, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3551, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3569, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3571, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3541, 3533, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3546, 3533, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3543, 3539, 64 },
   { 3550, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3547, 3539, 64 },
   { 3552, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3562, 3507, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3567, 3507, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3564, 3534, 65 },
   { 3570, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3568, 3534, 65 },
   { 3572, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3532, 3533, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3544, 3533, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3538, 3539, 64 },
   { 3548, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3545, 3539, 64 },
   { 3551, 3539, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3556, 3507, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3565, 3507, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1310, 1119, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3560, 3534, 65 },
   { 3569, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 3000, 3, 0 },
   { 3566, 3534, 65 },
   { 3571, 3534, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2692, 2693, 48 },
   { 2699, 2700, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2705, 2706, 48 },
   { 2710, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2692, 2693, 48 },
   { 2699, 2700, 48 },
   { 2708, 2706, 48 },
   { 2713, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2696, 2693, 48 },
   { 2703, 2700, 48 },
   { 2705, 2706, 48 },
   { 2710, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2692, 2693, 48 },
   { 2699, 2700, 48 },
   { 2705, 2706, 48 },
   { 2710, 2711, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 924, 925, 0 },
   { 971, 970, 0 },
   { 978, 977, 0 },
   { 986, 984, 0 },
   { 995, 993, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 972, 0 },
   { 980, 979, 0 },
   { 988, 987, 0 },
   { 997, 996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 705, 695, 23 },
   { 707, 698, 23 },
   { 709, 701, 24 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 3501, 3430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 1769, 1770, 41 },
   { 1876, 1877, 41 },
   { 1959, 1960, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2045, 2047, 0 },
   { 2049, 2051, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2003, 2005, 0 },
   { 2011, 2013, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2069, 2071, 0 },
   { 2073, 2075, 0 },
   { 4071, 739, 0 },
   { 4072, 6, 0 },
   { 4073, 11, 0 },
   { 4074, 16, 0 },
   { 4075, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 969, 970, 0 },
   { 976, 977, 0 },
   { 983, 984, 0 },
   { 992, 993, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1532, 1533, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1494, 219, 37 },
   { 1498, 1499, 37 },
   { 1532, 1533, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 3075, 219, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1484, 32, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1484, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1482, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1532, 1533, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1558, 1560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1329, 1257, 0 },
   { 1351, 1353, 0 },
   { 1479, 1228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1312, 32, 0 },
   { 1479, 1228, 0 },
   { 1532, 1533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3578, 3579, 0 },
   { 3581, 3582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3388, 3389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 526, 527, 0 },
   { 585, 580, 0 },
   { 593, 594, 0 },
   { 656, 651, 0 },
   { 665, 666, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 716, 718, 28 },
   { 236, 720, 29 },
   { 721, 723, 30 },
   { 724, 718, 31 },
   { 725, 720, 32 },
   { 726, 723, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1134, 1135, 0 },
   { 1163, 1164, 0 },
   { 2653, 1209, 0 },
   { 3091, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1123, 1124, 0 },
   { 1165, 1166, 0 },
   { 2654, 1056, 0 },
   { 3090, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2742, 2745, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1074, 1075, 0 },
   { 1140, 1111, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1078, 1079, 0 },
   { 1142, 1128, 0 },
   { 2652, 1209, 0 },
   { 3094, 1209, 0 },
   { 3097, 1056, 0 },
   { 3100, 1056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1537, 1538, 0 },
   { 3916, 3914, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1485, 32, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1480, 1481, 0 },
   { 1483, 1481, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1314, 32, 0 },
   { 1333, 1277, 0 },
   { 1361, 1363, 0 },
   { 1537, 1538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 1776, 1777, 41 },
   { 1883, 1884, 41 },
   { 1966, 1967, 41 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3763, 3764, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3744, 3735, 0 },
   { 3763, 3764, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3765, 3766, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3746, 3732, 0 },
   { 3765, 3766, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3769, 3770, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3748, 3749, 0 },
   { 3769, 3770, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 2671, 2293, 0 },
   { 3213, 3215, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 1168, 1171, 0 },
   { 2650, 1056, 0 },
   { 3079, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1159, 1160, 0 },
   { 1168, 1171, 0 },
   { 1251, 1028, 0 },
   { 2650, 1056, 0 },
   { 3083, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1155, 1158, 0 },
   { 2256, 1057, 0 },
   { 2650, 1056, 0 },
   { 3102, 1056, 0 },
   { 3105, 1209, 0 },
   { 3108, 1209, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 3086, 3078, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 32, 0 },
   { 1564, 1565, 37 },
   { 3088, 3082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 738, 746, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 540, 541, 15 },
   { 606, 607, 17 },
   { 679, 680, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 569, 570, 17 },
   { 639, 640, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 513, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 582, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 569, 570, 17 },
   { 639, 640, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 2242, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2247, 2251, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 2242, 0 },
   { 2247, 2251, 0 },
   { 2655, 32, 0 },
   { 2659, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1308, 1111, 0 },
   { 1309, 1111, 0 },
   { 1311, 1119, 0 },
   { 1744, 1751, 0 },
   { 1851, 1858, 0 },
   { 1934, 1941, 0 },
   { 3000, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 924, 925, 0 },
   { 971, 970, 0 },
   { 978, 977, 0 },
   { 986, 984, 0 },
   { 995, 993, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 972, 0 },
   { 980, 979, 0 },
   { 988, 987, 0 },
   { 997, 996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 969, 970, 0 },
   { 976, 977, 0 },
   { 983, 984, 0 },
   { 992, 993, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 924, 925, 0 },
   { 971, 970, 0 },
   { 978, 977, 0 },
   { 986, 984, 0 },
   { 995, 993, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 972, 0 },
   { 980, 979, 0 },
   { 988, 987, 0 },
   { 997, 996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 969, 970, 0 },
   { 976, 977, 0 },
   { 983, 984, 0 },
   { 992, 993, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 2672, 3, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 924, 925, 0 },
   { 971, 970, 0 },
   { 978, 977, 0 },
   { 986, 984, 0 },
   { 995, 993, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 973, 972, 0 },
   { 980, 979, 0 },
   { 988, 987, 0 },
   { 997, 996, 0 },
   { 2638, 2639, 0 },
   { 2641, 2642, 0 },
   { 2655, 32, 0 },
   { 2656, 61, 0 },
   { 2657, 32, 0 },
   { 3165, 3166, 57 },
   { 3196, 3197, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 969, 970, 0 },
   { 976, 977, 0 },
   { 983, 984, 0 },
   { 992, 993, 0 },
   { 2682, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2688, 32, 0 },
   { 3154, 3155, 57 },
   { 996, 424, 57 },
   { 3157, 3159, 57 },
   { 987, 449, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2660, 32, 0 },
   { 2670, 3, 0 },
   { 5312, 5237, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 32, 0 },
   { 5236, 5237, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         3,
         3,
         360,
         361,
         362,
         363,
         364,
         3,
         365,
         366,
         367,
         368,
         2111,
         2112,
         2113,
         2114,
         2115,
         2116,
         2,
         360,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         361,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         355,
         362,
         355,
         355,
         355,
         355,
         355,
         355,
         369,
         370,
         371,
         372,
         355,
         355,
         2117,
         2118,
         2119,
         2120,
         2,
         363,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         364,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         373,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         356,
         365,
         356,
         356,
         369,
         356,
         356,
         356,
         356,
         374,
         375,
         376,
         356,
         356,
         2121,
         2122,
         2123,
         2124,
         357,
         366,
         357,
         357,
         370,
         357,
         357,
         357,
         374,
         357,
         377,
         378,
         357,
         357,
         2125,
         2126,
         2127,
         2128,
         358,
         367,
         358,
         358,
         371,
         358,
         358,
         358,
         375,
         377,
         358,
         379,
         358,
         358,
         2129,
         2130,
         2131,
         2132,
         359,
         368,
         359,
         359,
         372,
         359,
         359,
         359,
         376,
         378,
         379,
         359,
         359,
         359,
         2133,
         2134,
         2135,
         2136,
         2,
         2111,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         2112,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2107,
         2113,
         2107,
         2107,
         2117,
         2107,
         2107,
         2107,
         2121,
         2125,
         2129,
         2133,
         2107,
         2107,
         2107,
         2137,
         2138,
         2139,
         2108,
         2114,
         2108,
         2108,
         2118,
         2108,
         2108,
         2108,
         2122,
         2126,
         2130,
         2134,
         2108,
         2108,
         2137,
         2108,
         2140,
         2141,
         2109,
         2115,
         2109,
         2109,
         2119,
         2109,
         2109,
         2109,
         2123,
         2127,
         2131,
         2135,
         2109,
         2109,
         2138,
         2140,
         2109,
         2142,
         2110,
         2116,
         2110,
         2110,
         2120,
         2110,
         2110,
         2110,
         2124,
         2128,
         2132,
         2136,
         2110,
         2110,
         2139,
         2141,
         2142,
         2110,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         13,
         13,
         13,
         13,
         13,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         6,
         7,
         6,
         6,
         6,
         1085,
         6,
         6,
         6,
         1086,
         6,
         6,
         6,
         2144,
         6,
         6,
         6,
         1085,
         6,
         1085,
         6,
         1085,
         6,
         1085,
         4,
         1087,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1088,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1089,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1090,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         1091,
         1092,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1094,
         1091,
         1091,
         1091,
         2145,
         1091,
         1091,
         1091,
         1093,
         1091,
         1093,
         1091,
         1093,
         1091,
         1093,
         1095,
         1096,
         1095,
         1095,
         1095,
         1097,
         1095,
         1095,
         1095,
         1098,
         1095,
         1095,
         1095,
         2146,
         1095,
         1095,
         1095,
         1097,
         1095,
         1097,
         1095,
         1097,
         1095,
         1097,
         4,
         1099,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         5,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1100,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2147,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2148,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1089,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2149,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2150,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2151,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2830,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2923,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2929,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2933,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2938,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2942,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2947,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         1324,
         1325,
         1326,
         1327,
         1328,
         1329,
         1330,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         380,
         381,
         380,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1331,
         1332,
         1333,
         1334,
         1335,
         1336,
         1337,
         1338,
         1339,
         1340,
         1341,
         1342,
         1343,
         2487,
         2488,
         2489,
         2823,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         11,
         5,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         17,
         1608,
         1609,
         1610,
         1611,
         1612,
         1613,
         1614,
         1615,
         1616,
         1617,
         2754,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         18,
         1344,
         1345,
         1346,
         1347,
         1348,
         1349,
         1350,
         1351,
         2160,
         2161,
         2162,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         1958,
         1959,
         1960,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1618,
         1619,
         1620,
         2407,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1352,
         1353,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1621,
         1622,
         1623,
         1624,
         1625,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         5,
         23,
         27,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         20,
         3,
         21,
         21,
         21,
         21,
         21,
         21,
         4,
         4,
         20,
         20,
         3,
         20,
         20,
         3,
         0,
         2,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         20,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         43,
         44,
         43,
         44,
         43,
         45,
         43,
         44,
         43,
         44,
         46,
         47,
         48,
         49,
         43,
         44,
         50,
         51,
         52,
         44,
         43,
         44,
         53,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 54,
      .table = (const uint16_t []) {
      
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         24,
         24,
         1356,
         1357,
         1358,
         24,
         24,
         1359,
         1360,
         1361,
         1362,
         24,
         1363,
         24,
         2472,
         2473,
         2474,
         2475,
         2476,
         2477,
         2478,
         2479,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2801,
         2801,
         2802,
         2801,
         2801,
         2803,
         2803,
         2801,
         2801,
         2804,
         2805,
         2476,
         2910,
         24,
         2801,
         2801,
         24,
         2803,
         24,
         2801,
         2802,
         2801,
         2801,
         2801,
         1354,
         1356,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1355,
         1357,
         1364,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1364,
         1364,
         1364,
         1364,
         1364,
         2481,
         2471,
         2471,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         2808,
         2808,
         1355,
         2808,
         2808,
         2809,
         2809,
         2808,
         2808,
         1355,
         1364,
         1364,
         1364,
         1355,
         2808,
         2808,
         1355,
         2809,
         1355,
         2808,
         1355,
         2808,
         2808,
         2808,
         1355,
         1358,
         1364,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1364,
         1364,
         1364,
         1364,
         1364,
         2481,
         2471,
         2471,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         2808,
         2808,
         1355,
         2808,
         2808,
         2809,
         2809,
         2808,
         2808,
         1355,
         1364,
         1364,
         1364,
         1355,
         2808,
         2808,
         1355,
         2809,
         1355,
         2808,
         1355,
         2808,
         2808,
         2808,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         1365,
         2811,
         2811,
         1365,
         2813,
         1365,
         2811,
         1365,
         2810,
         2811,
         2811,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         1367,
         23,
         23,
         1368,
         1368,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1359,
         1354,
         1355,
         1355,
         1366,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1366,
         1366,
         1366,
         1366,
         1366,
         1366,
         23,
         23,
         2814,
         2814,
         1366,
         2814,
         2814,
         2815,
         2815,
         2814,
         2814,
         23,
         1354,
         1354,
         1354,
         1366,
         2814,
         2814,
         1366,
         2815,
         1366,
         2814,
         1366,
         2814,
         2814,
         2814,
         23,
         1360,
         1354,
         1355,
         1355,
         1366,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1366,
         1366,
         1366,
         1366,
         1366,
         1366,
         23,
         23,
         2814,
         2814,
         1366,
         2814,
         2814,
         2815,
         2815,
         2814,
         2814,
         23,
         1354,
         1354,
         1354,
         1366,
         2814,
         2814,
         1366,
         2815,
         1366,
         2814,
         1366,
         2814,
         2814,
         2814,
         23,
         1361,
         1354,
         1355,
         1355,
         23,
         1368,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1362,
         1354,
         1355,
         1355,
         23,
         1368,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1363,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         1354,
         1354,
         1354,
         1354,
         2483,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         2483,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         1354,
         2472,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2473,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2474,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2475,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2476,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         2470,
         2477,
         2470,
         2481,
         2481,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2484,
         2484,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2816,
         2816,
         2470,
         2816,
         2816,
         2817,
         2817,
         2816,
         2816,
         2470,
         2470,
         2470,
         2470,
         2470,
         2816,
         2816,
         2470,
         2817,
         2470,
         2816,
         2470,
         2816,
         2816,
         2816,
         2471,
         2478,
         2480,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2480,
         2480,
         2480,
         2480,
         2480,
         2484,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2818,
         2818,
         2471,
         2818,
         2818,
         2819,
         2819,
         2818,
         2818,
         2471,
         2480,
         2480,
         2480,
         2471,
         2818,
         2818,
         2471,
         2819,
         2471,
         2818,
         2471,
         2818,
         2818,
         2818,
         2471,
         2479,
         2480,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2480,
         2480,
         2480,
         2480,
         2480,
         2484,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2818,
         2818,
         2471,
         2818,
         2818,
         2819,
         2819,
         2818,
         2818,
         2471,
         2480,
         2480,
         2480,
         2471,
         2818,
         2818,
         2471,
         2819,
         2471,
         2818,
         2471,
         2818,
         2818,
         2818,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         1365,
         2914,
         2914,
         1365,
         2915,
         1365,
         2914,
         1365,
         2810,
         2811,
         2914,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         1365,
         2811,
         2811,
         1365,
         2813,
         2485,
         2821,
         1365,
         2810,
         2811,
         2811,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2914,
         2914,
         2911,
         2915,
         2911,
         2914,
         2911,
         2912,
         2913,
         2916,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2917,
         2821,
         2911,
         2912,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         1365,
         2914,
         2914,
         1365,
         2915,
         2485,
         2918,
         1365,
         2810,
         2811,
         2914,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         1354,
         1354,
         1354,
         1354,
         2483,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         2822,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2810,
         2811,
         2811,
         2810,
         2813,
         2810,
         2811,
         2810,
         2810,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2811,
         2813,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         23,
         2802,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2912,
         2811,
         2811,
         2912,
         2813,
         2912,
         2811,
         2912,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2811,
         2913,
         2813,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         2800,
         2803,
         2807,
         2809,
         2809,
         2812,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2800,
         2800,
         2812,
         2813,
         2812,
         2812,
         2813,
         2812,
         2813,
         2812,
         2813,
         2800,
         2807,
         2807,
         2807,
         2812,
         2915,
         2915,
         2812,
         2915,
         2812,
         2915,
         2812,
         2812,
         2813,
         2915,
         2800,
         2803,
         2807,
         2809,
         2809,
         2813,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2800,
         2800,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2800,
         2807,
         2807,
         2807,
         2813,
         2915,
         2915,
         2813,
         2915,
         2813,
         2915,
         2813,
         2813,
         2813,
         2915,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2820,
         2810,
         2820,
         2820,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         2799,
         2806,
         2806,
         2806,
         2810,
         2811,
         2811,
         2810,
         2813,
         2820,
         2821,
         2810,
         2810,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2821,
         2811,
         2821,
         2821,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2821,
         2821,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2811,
         2813,
         2821,
         2821,
         2811,
         2811,
         2811,
         2811,
         23,
         2804,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         1354,
         2805,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2476,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2822,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2910,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2811,
         2914,
         2811,
         2914,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2914,
         2915,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2811,
         2914,
         2811,
         2914,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2811,
         2916,
         2915,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2914,
         2916,
         2911,
         2915,
         2911,
         2914,
         2911,
         2912,
         2913,
         2916,
         2800,
         2803,
         2807,
         2809,
         2809,
         2813,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2813,
         2915,
         2813,
         2915,
         2813,
         2915,
         2800,
         2800,
         2813,
         2813,
         2813,
         2813,
         2813,
         2915,
         2915,
         2813,
         2813,
         2800,
         2807,
         2807,
         2807,
         2813,
         2915,
         2915,
         2915,
         2915,
         2813,
         2915,
         2813,
         2813,
         2813,
         2915,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         2485,
         2911,
         2917,
         2485,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2917,
         2821,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2821,
         2914,
         2821,
         2918,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2821,
         2821,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2914,
         2915,
         2821,
         2821,
         2811,
         2811,
         2811,
         2811,
         23,
         2802,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2912,
         2810,
         2810,
         2912,
         2912,
         2810,
         2799,
         2799,
         2810,
         2811,
         2912,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2912,
         2811,
         2913,
         2912,
         2813,
         2912,
         2811,
         2912,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2913,
         2811,
         2811,
         2913,
         2913,
         2811,
         2799,
         2799,
         2811,
         2811,
         2913,
         2913,
         2913,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2913,
         2913,
         2813,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2913,
         2914,
         2811,
         2916,
         2913,
         2914,
         2799,
         2799,
         2811,
         2811,
         2913,
         2913,
         2913,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2913,
         2916,
         2915,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         16,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         22,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         6,
         6,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         23,
         5,
         5,
         5,
         24,
         25,
         26,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         34,
         35,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         7,
         7,
         7,
         7,
         21,
         21,
         21,
         21,
         21,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         31,
         29,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         13,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 37,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         26,
         26,
         26,
         393,
         26,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         401,
         402,
         403,
         404,
         405,
         406,
         26,
         26,
         26,
         2017,
         2018,
         2019,
         2020,
         2021,
         2022,
         2023,
         2024,
         2025,
         2026,
         2027,
         26,
         26,
         26,
         26,
         394,
         25,
         26,
         407,
         407,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         393,
         407,
         407,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         408,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         382,
         394,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         25,
         395,
         25,
         25,
         25,
         409,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         409,
         409,
         409,
         409,
         409,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         409,
         383,
         396,
         383,
         383,
         383,
         410,
         383,
         383,
         420,
         421,
         422,
         423,
         424,
         383,
         425,
         426,
         427,
         428,
         383,
         383,
         383,
         2012,
         2012,
         410,
         410,
         410,
         410,
         410,
         2034,
         2035,
         2036,
         2037,
         383,
         383,
         383,
         383,
         410,
         384,
         397,
         384,
         384,
         384,
         411,
         384,
         420,
         384,
         429,
         430,
         431,
         432,
         384,
         433,
         434,
         435,
         436,
         384,
         384,
         384,
         2038,
         2039,
         411,
         411,
         411,
         411,
         411,
         2040,
         2041,
         2042,
         2043,
         384,
         384,
         384,
         384,
         411,
         385,
         398,
         385,
         385,
         385,
         412,
         385,
         421,
         429,
         385,
         437,
         438,
         439,
         385,
         440,
         441,
         442,
         443,
         385,
         385,
         385,
         2044,
         2045,
         412,
         412,
         412,
         412,
         412,
         2046,
         2047,
         2048,
         2049,
         385,
         385,
         385,
         385,
         412,
         386,
         399,
         386,
         386,
         386,
         413,
         386,
         422,
         430,
         437,
         386,
         444,
         445,
         386,
         446,
         447,
         448,
         449,
         386,
         386,
         386,
         2050,
         2051,
         413,
         413,
         413,
         413,
         413,
         2052,
         2053,
         2054,
         2055,
         386,
         386,
         386,
         386,
         413,
         387,
         400,
         387,
         387,
         387,
         414,
         387,
         423,
         431,
         438,
         444,
         387,
         450,
         387,
         451,
         452,
         453,
         454,
         387,
         387,
         387,
         2056,
         2057,
         414,
         414,
         414,
         414,
         414,
         2058,
         2059,
         2060,
         2061,
         387,
         387,
         387,
         387,
         414,
         388,
         401,
         388,
         388,
         388,
         415,
         388,
         424,
         432,
         439,
         445,
         450,
         388,
         388,
         455,
         456,
         457,
         458,
         388,
         388,
         388,
         2062,
         2063,
         415,
         415,
         415,
         415,
         415,
         2064,
         2065,
         2066,
         2067,
         388,
         388,
         388,
         388,
         415,
         25,
         402,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         389,
         403,
         389,
         389,
         389,
         416,
         389,
         425,
         433,
         440,
         446,
         451,
         455,
         389,
         389,
         459,
         460,
         461,
         389,
         389,
         389,
         2068,
         2069,
         416,
         416,
         416,
         416,
         416,
         2070,
         2071,
         2072,
         2073,
         389,
         389,
         389,
         389,
         416,
         390,
         404,
         390,
         390,
         390,
         417,
         390,
         426,
         434,
         441,
         447,
         452,
         456,
         390,
         459,
         390,
         462,
         463,
         390,
         390,
         390,
         2074,
         2075,
         417,
         417,
         417,
         417,
         417,
         2076,
         2077,
         2078,
         2079,
         390,
         390,
         390,
         390,
         417,
         391,
         405,
         391,
         391,
         391,
         418,
         391,
         427,
         435,
         442,
         448,
         453,
         457,
         391,
         460,
         462,
         391,
         464,
         391,
         391,
         391,
         2080,
         2081,
         418,
         418,
         418,
         418,
         418,
         2082,
         2083,
         2084,
         2085,
         391,
         391,
         391,
         391,
         418,
         392,
         406,
         392,
         392,
         392,
         419,
         392,
         428,
         436,
         443,
         449,
         454,
         458,
         392,
         461,
         463,
         464,
         392,
         392,
         392,
         392,
         2086,
         2087,
         419,
         419,
         419,
         419,
         419,
         2088,
         2089,
         2090,
         2091,
         392,
         392,
         392,
         392,
         419,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         465,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         465,
         25,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         465,
         465,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         2011,
         2017,
         2011,
         2011,
         2011,
         2028,
         2011,
         2012,
         2038,
         2044,
         2050,
         2056,
         2062,
         2011,
         2068,
         2074,
         2080,
         2086,
         2011,
         2011,
         2011,
         2011,
         2012,
         2028,
         2028,
         2028,
         2028,
         2028,
         2092,
         2093,
         2094,
         2095,
         2011,
         2011,
         2011,
         2011,
         2028,
         2012,
         2018,
         2012,
         2012,
         2012,
         2029,
         2012,
         2012,
         2039,
         2045,
         2051,
         2057,
         2063,
         2012,
         2069,
         2075,
         2081,
         2087,
         2012,
         2012,
         2012,
         2012,
         2012,
         2029,
         2029,
         2029,
         2029,
         2029,
         2096,
         2097,
         2098,
         2099,
         2012,
         2012,
         2012,
         2012,
         2029,
         382,
         2019,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2020,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2021,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2022,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2023,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         2013,
         2024,
         2013,
         2013,
         2013,
         2030,
         2013,
         2034,
         2040,
         2046,
         2052,
         2058,
         2064,
         2013,
         2070,
         2076,
         2082,
         2088,
         2013,
         2013,
         2013,
         2092,
         2096,
         2030,
         2030,
         2030,
         2030,
         2030,
         2013,
         2100,
         2101,
         2102,
         2013,
         2013,
         2013,
         2013,
         2030,
         2014,
         2025,
         2014,
         2014,
         2014,
         2031,
         2014,
         2035,
         2041,
         2047,
         2053,
         2059,
         2065,
         2014,
         2071,
         2077,
         2083,
         2089,
         2014,
         2014,
         2014,
         2093,
         2097,
         2031,
         2031,
         2031,
         2031,
         2031,
         2100,
         2014,
         2103,
         2104,
         2014,
         2014,
         2014,
         2014,
         2031,
         2015,
         2026,
         2015,
         2015,
         2015,
         2032,
         2015,
         2036,
         2042,
         2048,
         2054,
         2060,
         2066,
         2015,
         2072,
         2078,
         2084,
         2090,
         2015,
         2015,
         2015,
         2094,
         2098,
         2032,
         2032,
         2032,
         2032,
         2032,
         2101,
         2103,
         2015,
         2105,
         2015,
         2015,
         2015,
         2015,
         2032,
         2016,
         2027,
         2016,
         2016,
         2016,
         2033,
         2016,
         2037,
         2043,
         2049,
         2055,
         2061,
         2067,
         2016,
         2073,
         2079,
         2085,
         2091,
         2016,
         2016,
         2016,
         2095,
         2099,
         2033,
         2033,
         2033,
         2033,
         2033,
         2102,
         2104,
         2105,
         2016,
         2016,
         2016,
         2016,
         2016,
         2033,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         2894,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         2106,
         2106,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         2106,
         25,
         2106,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         2106,
         2106,
         2106,
         382,
         382,
         394,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         2894,
         382,
         382,
         382,
         382,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         27,
         28,
         28,
         28,
      },
   },
   [nir_op_isub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         29,
         30,
         29,
         30,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         31,
         32,
         32,
         32,
      },
   },
   [nir_op_usub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         34,
         33,
         34,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         35,
         35,
         35,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         19,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         37,
         37,
         1376,
         1377,
         1378,
         1379,
         1380,
         1381,
         1382,
         1383,
         1384,
         37,
         1385,
         1386,
         37,
         1383,
         2181,
         1376,
         2182,
         2183,
         2184,
         2185,
         2852,
         2853,
         2909,
         1370,
         1376,
         1370,
         1370,
         1370,
         1370,
         1370,
         1387,
         1388,
         1370,
         1389,
         1370,
         1390,
         1391,
         1370,
         1370,
         2186,
         1370,
         2187,
         2188,
         2189,
         2189,
         2854,
         2855,
         1370,
         36,
         1377,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1392,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1378,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1392,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1379,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1380,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1371,
         1381,
         1387,
         1371,
         1371,
         1371,
         1371,
         1393,
         1394,
         1371,
         1395,
         1371,
         1396,
         1397,
         1371,
         1371,
         2190,
         2191,
         2192,
         2193,
         2194,
         2194,
         2856,
         2857,
         1371,
         1372,
         1382,
         1388,
         1392,
         1392,
         1372,
         1372,
         1394,
         1372,
         1372,
         1398,
         1372,
         1399,
         1400,
         1372,
         1372,
         2195,
         1388,
         2196,
         2197,
         2198,
         2198,
         2858,
         2859,
         1372,
         36,
         1383,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1373,
         1384,
         1389,
         1373,
         1373,
         1373,
         1373,
         1395,
         1398,
         1373,
         1373,
         1373,
         1401,
         1402,
         1373,
         1373,
         2177,
         1389,
         2199,
         2200,
         2201,
         2201,
         2860,
         2861,
         1373,
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         1403,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1374,
         1385,
         1390,
         1374,
         1374,
         1374,
         1374,
         1396,
         1399,
         1374,
         1401,
         1374,
         1404,
         1405,
         1374,
         1374,
         2202,
         1390,
         2203,
         2204,
         2205,
         2205,
         2862,
         2863,
         1374,
         1375,
         1386,
         1391,
         1375,
         1375,
         1375,
         1375,
         1397,
         1400,
         1375,
         1402,
         1375,
         1405,
         1375,
         1375,
         1375,
         2206,
         1391,
         2207,
         2208,
         2209,
         2209,
         2864,
         2865,
         1375,
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         1406,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1383,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         2210,
         2211,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         2177,
         2181,
         2186,
         2177,
         2177,
         2177,
         2177,
         2190,
         2195,
         2177,
         2177,
         2177,
         2202,
         2206,
         2177,
         2211,
         2211,
         2186,
         2212,
         2213,
         2214,
         2214,
         2866,
         2867,
         2177,
         1370,
         1376,
         1370,
         1370,
         1370,
         1370,
         1370,
         2191,
         1388,
         1370,
         1389,
         1370,
         1390,
         1391,
         1370,
         1370,
         2186,
         1370,
         2187,
         2188,
         2189,
         2189,
         2868,
         2855,
         1370,
         2178,
         2182,
         2187,
         2178,
         2178,
         2178,
         2178,
         2192,
         2196,
         2178,
         2199,
         2178,
         2203,
         2207,
         2178,
         2178,
         2212,
         2187,
         2178,
         2179,
         2215,
         2215,
         2869,
         2851,
         2178,
         2179,
         2183,
         2188,
         2179,
         2179,
         2179,
         2179,
         2193,
         2197,
         2179,
         2200,
         2179,
         2204,
         2208,
         2179,
         2179,
         2213,
         2188,
         2179,
         2216,
         2217,
         2217,
         2870,
         2871,
         2179,
         2180,
         2184,
         2189,
         2180,
         2180,
         2180,
         2180,
         2194,
         2198,
         2180,
         2201,
         2180,
         2205,
         2209,
         2180,
         2180,
         2214,
         2189,
         2215,
         2217,
         2180,
         2180,
         2872,
         2873,
         2180,
         2180,
         2185,
         2189,
         2180,
         2180,
         2180,
         2180,
         2194,
         2198,
         2180,
         2201,
         2180,
         2205,
         2209,
         2180,
         2180,
         2214,
         2189,
         2215,
         2217,
         2180,
         2180,
         2872,
         2873,
         2180,
         2850,
         2852,
         2854,
         2850,
         2850,
         2850,
         2850,
         2856,
         2858,
         2850,
         2860,
         2850,
         2862,
         2864,
         2850,
         2850,
         2866,
         2868,
         2869,
         2870,
         2872,
         2872,
         2856,
         2874,
         2850,
         2851,
         2853,
         2855,
         2851,
         2851,
         2851,
         2851,
         2857,
         2859,
         2851,
         2861,
         2851,
         2863,
         2865,
         2851,
         2851,
         2867,
         2855,
         2851,
         2871,
         2873,
         2873,
         2874,
         2871,
         2851,
         36,
         2909,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         38,
         39,
         1407,
         38,
         38,
         38,
         1408,
         38,
         39,
         39,
         1409,
         1410,
         1411,
         1412,
         1413,
         39,
         1407,
         1409,
         1407,
         1407,
         1407,
         1407,
         1414,
         1407,
         38,
         1410,
         1407,
         38,
         38,
         38,
         1408,
         38,
         38,
         1411,
         1407,
         38,
         38,
         38,
         1408,
         38,
         38,
         1412,
         1407,
         38,
         38,
         38,
         1408,
         38,
         1408,
         1413,
         1414,
         1408,
         1408,
         1408,
         1408,
         1408,
         38,
         39,
         1407,
         38,
         38,
         38,
         1408,
         1415,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         3,
         11,
         11,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         44,
         45,
         44,
         1425,
         1425,
         44,
         1426,
         44,
         44,
         44,
         44,
         1425,
         1425,
         1426,
         1426,
         44,
         1427,
         1428,
         1427,
         1429,
         1429,
         1427,
         1430,
         1427,
         1427,
         1427,
         1427,
         1429,
         1429,
         1430,
         1430,
         1427,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1439,
         1440,
         1439,
         1441,
         1441,
         1439,
         1442,
         1439,
         1439,
         1439,
         1439,
         1441,
         1441,
         1442,
         1442,
         1439,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         2223,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         2224,
         2225,
         2224,
         2226,
         2226,
         2224,
         2227,
         2224,
         2224,
         2224,
         2224,
         2226,
         2226,
         2227,
         2227,
         2224,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         2876,
         2876,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1427,
         1428,
         1427,
         1429,
         1429,
         1427,
         1430,
         1427,
         1427,
         1427,
         1427,
         1429,
         1429,
         1430,
         1430,
         1427,
         1443,
         1444,
         1443,
         1445,
         1445,
         1443,
         1446,
         1443,
         1443,
         1443,
         1443,
         1445,
         1445,
         1446,
         1446,
         1443,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1448,
         1449,
         1448,
         1450,
         1450,
         1448,
         1451,
         1448,
         1448,
         1448,
         1448,
         1450,
         1450,
         1451,
         2228,
         1448,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         2229,
         2230,
         2229,
         2231,
         2231,
         2229,
         2232,
         2229,
         2229,
         2229,
         2229,
         2231,
         2231,
         2232,
         2232,
         2229,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         2877,
         2877,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         1439,
         1440,
         1439,
         1441,
         1441,
         1439,
         1442,
         1439,
         1439,
         1439,
         1439,
         1441,
         1441,
         1442,
         1442,
         1439,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         2223,
         42,
         1448,
         1449,
         1448,
         1450,
         1450,
         1448,
         1451,
         1448,
         1448,
         1448,
         1448,
         1450,
         1450,
         1451,
         2228,
         1448,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2234,
         2219,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2237,
         2237,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2879,
         2879,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         2241,
         2242,
         2241,
         2243,
         2243,
         2241,
         2244,
         2241,
         2241,
         2241,
         2241,
         2243,
         2243,
         2244,
         2244,
         2241,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2224,
         2225,
         2224,
         2226,
         2226,
         2224,
         2227,
         2224,
         2224,
         2224,
         2224,
         2226,
         2226,
         2227,
         2227,
         2224,
         2229,
         2230,
         2229,
         2231,
         2231,
         2229,
         2232,
         2229,
         2229,
         2229,
         2229,
         2231,
         2231,
         2232,
         2232,
         2229,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2234,
         2219,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2880,
         2880,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2237,
         2237,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         2876,
         2876,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         2877,
         2877,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2879,
         2879,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2880,
         2880,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         50,
         51,
         50,
         1457,
         1457,
         1458,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         1459,
         1460,
         1459,
         1461,
         1461,
         1462,
         1463,
         1464,
         1463,
         1465,
         1465,
         1466,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         1467,
         1468,
         1467,
         1469,
         1469,
         1470,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         1459,
         1460,
         1459,
         1461,
         1461,
         1462,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         1463,
         1464,
         1463,
         1465,
         1465,
         1466,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         10,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         16,
         17,
         18,
         19,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         29,
         30,
         31,
         32,
         32,
         32,
         32,
         33,
         33,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         16,
         16,
         17,
         17,
         18,
         18,
         19,
         18,
         19,
         18,
         19,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         26,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         25,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         46,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         47,
         11,
         11,
         48,
         49,
         11,
         11,
         11,
         11,
         11,
         11,
         10,
         10,
         10,
         10,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         12,
         12,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         31,
         30,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         16,
         16,
         16,
         16,
         16,
         16,
         55,
         17,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         20,
         20,
         20,
         20,
         20,
         20,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         23,
         22,
         22,
         22,
         22,
         22,
         27,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         13,
         12,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         29,
         0,
         22,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         22,
         22,
         22,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         17,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         53,
         53,
         1108,
         53,
         1109,
         1110,
         53,
         1111,
         1112,
         1113,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1114,
         53,
         53,
         1115,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1116,
         53,
         1117,
         53,
         1118,
         53,
         1119,
         2322,
         2323,
         2324,
         2325,
         2326,
         53,
         53,
         2327,
         2328,
         2329,
         2330,
         2797,
         2798,
         1115,
         1115,
         1115,
         2925,
         2927,
         2928,
         2935,
         2936,
         2937,
         2944,
         2945,
         2946,
         52,
         1108,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         1109,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         1110,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         2331,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1101,
         1111,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1122,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1123,
         1101,
         1124,
         1101,
         1125,
         1101,
         1126,
         2332,
         1121,
         1101,
         2333,
         2334,
         1101,
         1101,
         2335,
         2336,
         2337,
         2338,
         1101,
         1101,
         1122,
         1122,
         1122,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1112,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1122,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1123,
         1101,
         1124,
         1101,
         1125,
         1101,
         1126,
         2332,
         1121,
         1101,
         2333,
         2334,
         1101,
         1101,
         2335,
         2336,
         2337,
         2338,
         1101,
         1101,
         1122,
         1122,
         1122,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1102,
         1113,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         1134,
         1134,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2347,
         1133,
         1133,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         1133,
         1133,
         52,
         1135,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2347,
         1133,
         1133,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1136,
         52,
         52,
         52,
         52,
         52,
         1103,
         1137,
         1137,
         1137,
         1137,
         1138,
         1138,
         1138,
         1138,
         1139,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         1140,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         52,
         1114,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1142,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1142,
         1142,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1148,
         1148,
         1148,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1149,
         1150,
         1151,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1150,
         1152,
         1153,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1151,
         1153,
         1154,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1155,
         1155,
         1155,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1156,
         1157,
         1158,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1157,
         1159,
         1160,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1158,
         1160,
         1161,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1139,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1162,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1163,
         1163,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1163,
         1163,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         2919,
         2920,
         2921,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1164,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1165,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1166,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1167,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1104,
         1116,
         1104,
         1104,
         1104,
         1104,
         1104,
         1123,
         1123,
         1129,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1144,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1167,
         1167,
         1104,
         1168,
         1104,
         1169,
         1104,
         1170,
         2355,
         1129,
         1104,
         2356,
         2357,
         1104,
         1104,
         2358,
         2359,
         2360,
         2361,
         1104,
         1104,
         1144,
         1144,
         1144,
         1129,
         1104,
         1104,
         1129,
         1104,
         1104,
         1129,
         1104,
         1104,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1171,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1105,
         1117,
         1105,
         1105,
         1105,
         1105,
         1105,
         1124,
         1124,
         1130,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1145,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1168,
         1171,
         1171,
         1105,
         1172,
         1105,
         1173,
         2362,
         1130,
         1105,
         2363,
         2364,
         1105,
         1105,
         2365,
         2366,
         2367,
         2368,
         1105,
         1105,
         1145,
         1145,
         1145,
         1130,
         1105,
         1105,
         1130,
         1105,
         1105,
         1130,
         1105,
         1105,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1174,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1106,
         1118,
         1106,
         1106,
         1106,
         1106,
         1106,
         1125,
         1125,
         1131,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1146,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1169,
         1106,
         1172,
         1174,
         1174,
         1106,
         1175,
         2369,
         1131,
         1106,
         2370,
         2371,
         1106,
         1106,
         2372,
         2373,
         2374,
         2375,
         1106,
         1106,
         1146,
         1146,
         1146,
         1131,
         1106,
         1106,
         1131,
         1106,
         1106,
         1131,
         1106,
         1106,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1176,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1107,
         1119,
         1107,
         1107,
         1107,
         1107,
         1107,
         1126,
         1126,
         1132,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1147,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1170,
         1107,
         1173,
         1107,
         1175,
         1176,
         1176,
         2376,
         1132,
         1107,
         2377,
         2378,
         1107,
         1107,
         2379,
         2380,
         2381,
         2382,
         1107,
         1107,
         1147,
         1147,
         1147,
         1132,
         1107,
         1107,
         1132,
         1107,
         1107,
         1132,
         1107,
         1107,
         2315,
         2322,
         2315,
         2315,
         2315,
         2315,
         2315,
         2332,
         2332,
         2339,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2348,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2355,
         2315,
         2362,
         2315,
         2369,
         2315,
         2376,
         2339,
         2339,
         2315,
         2383,
         2384,
         2315,
         2315,
         2385,
         2386,
         2387,
         2388,
         2315,
         2315,
         2348,
         2348,
         2348,
         2339,
         2315,
         2315,
         2339,
         2315,
         2315,
         2339,
         2315,
         2315,
         1102,
         2323,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2324,
         52,
         52,
         52,
         52,
         2331,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         2389,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         2316,
         2325,
         2316,
         2316,
         2316,
         2316,
         2316,
         2333,
         2333,
         2340,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2349,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2356,
         2316,
         2363,
         2316,
         2370,
         2316,
         2377,
         2383,
         2340,
         2316,
         2349,
         2390,
         2316,
         2316,
         2391,
         2392,
         2393,
         2394,
         2316,
         2316,
         2349,
         2349,
         2349,
         2340,
         2316,
         2316,
         2340,
         2316,
         2316,
         2340,
         2316,
         2316,
         2317,
         2326,
         2317,
         2317,
         2317,
         2317,
         2317,
         2334,
         2334,
         2341,
         2317,
         2346,
         2347,
         2347,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2350,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2357,
         2317,
         2364,
         2317,
         2371,
         2317,
         2378,
         2384,
         2341,
         2317,
         2390,
         2346,
         2346,
         2346,
         2395,
         2396,
         2397,
         2398,
         2317,
         2317,
         2350,
         2350,
         2350,
         2341,
         2317,
         2317,
         2341,
         2317,
         2317,
         2341,
         2317,
         2317,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         1134,
         2399,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         2399,
         1134,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         2318,
         2327,
         2318,
         2318,
         2318,
         2318,
         2318,
         2335,
         2335,
         2342,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2351,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2358,
         2318,
         2365,
         2318,
         2372,
         2318,
         2379,
         2385,
         2342,
         2318,
         2391,
         2395,
         2318,
         2318,
         2318,
         2400,
         2401,
         2402,
         2318,
         2318,
         2351,
         2351,
         2351,
         2342,
         2318,
         2318,
         2342,
         2318,
         2318,
         2342,
         2318,
         2318,
         2319,
         2328,
         2319,
         2319,
         2319,
         2319,
         2319,
         2336,
         2336,
         2343,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2352,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2359,
         2319,
         2366,
         2319,
         2373,
         2319,
         2380,
         2386,
         2343,
         2319,
         2392,
         2396,
         2319,
         2319,
         2400,
         2319,
         2403,
         2404,
         2319,
         2319,
         2352,
         2352,
         2352,
         2343,
         2319,
         2319,
         2343,
         2319,
         2319,
         2343,
         2319,
         2319,
         2320,
         2329,
         2320,
         2320,
         2320,
         2320,
         2320,
         2337,
         2337,
         2344,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2353,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2360,
         2320,
         2367,
         2320,
         2374,
         2320,
         2381,
         2387,
         2344,
         2320,
         2393,
         2397,
         2320,
         2320,
         2401,
         2403,
         2320,
         2405,
         2320,
         2320,
         2353,
         2353,
         2353,
         2344,
         2320,
         2320,
         2344,
         2320,
         2320,
         2344,
         2320,
         2320,
         2321,
         2330,
         2321,
         2321,
         2321,
         2321,
         2321,
         2338,
         2338,
         2345,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2354,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2361,
         2321,
         2368,
         2321,
         2375,
         2321,
         2382,
         2388,
         2345,
         2321,
         2394,
         2398,
         2321,
         2321,
         2402,
         2404,
         2405,
         2406,
         2321,
         2321,
         2354,
         2354,
         2354,
         2345,
         2321,
         2321,
         2345,
         2321,
         2321,
         2345,
         2321,
         2321,
         52,
         2797,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2798,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2919,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2920,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2921,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1102,
         2925,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2927,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2928,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         2935,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2936,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2937,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         2944,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2945,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2946,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         11,
         12,
         13,
         14,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         24,
         25,
         25,
         26,
         26,
         26,
         26,
         27,
         27,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         46,
         11,
         46,
         11,
         12,
         11,
         46,
         12,
         12,
         13,
         13,
         14,
         13,
         14,
         13,
         14,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         16,
         16,
         16,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         17,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         16,
         20,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         21,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         21,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         20,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         11,
         56,
         11,
         56,
         11,
         12,
         12,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         15,
         15,
         15,
         15,
         15,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         18,
         17,
         17,
         17,
         17,
         17,
         22,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         25,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         15,
         15,
         15,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         24,
         0,
         17,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         12,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         12,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         12,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         55,
         55,
         55,
         55,
         1186,
         1187,
         1188,
         1189,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1190,
         1191,
         1191,
         1191,
         1191,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1192,
         55,
         55,
         1193,
         55,
         1194,
         55,
         1195,
         55,
         55,
         55,
         55,
         55,
         1187,
         1188,
         55,
         55,
         2253,
         2254,
         2255,
         2256,
         55,
         55,
         55,
         55,
         55,
         1187,
         1187,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1188,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1179,
         1189,
         1179,
         1179,
         1200,
         1207,
         1207,
         1214,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1215,
         1216,
         1216,
         1216,
         1216,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1217,
         1179,
         1218,
         1179,
         1179,
         1219,
         1179,
         1220,
         1179,
         1221,
         1179,
         1179,
         1179,
         1179,
         1179,
         1207,
         1207,
         1179,
         1179,
         2266,
         2267,
         2268,
         2269,
         1179,
         1179,
         1179,
         1179,
         1179,
         1207,
         1207,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         1222,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         1223,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         1224,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         1225,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         1227,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         1227,
         1227,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1180,
         1190,
         1180,
         1180,
         1201,
         1208,
         1208,
         1215,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1228,
         1229,
         1229,
         1229,
         1229,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1230,
         1180,
         1180,
         1231,
         1180,
         1232,
         1180,
         1233,
         1180,
         1180,
         1180,
         1180,
         1180,
         1208,
         1208,
         1180,
         1180,
         2271,
         2272,
         2273,
         2274,
         1180,
         1180,
         1180,
         1180,
         1180,
         1208,
         1208,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1234,
         1234,
         1234,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1239,
         1240,
         1241,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1240,
         1242,
         1243,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1241,
         1243,
         1244,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1245,
         1245,
         1245,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1246,
         1247,
         1248,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1247,
         1249,
         1250,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1248,
         1250,
         1251,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         1224,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         1252,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         1253,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         1254,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1255,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1256,
         1256,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1217,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1256,
         1256,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1257,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1182,
         1192,
         1182,
         1182,
         1203,
         1210,
         1210,
         1218,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1230,
         1235,
         1235,
         1235,
         1235,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1257,
         1257,
         1182,
         1182,
         1258,
         1182,
         1259,
         1182,
         1260,
         1182,
         1182,
         1182,
         1182,
         1182,
         1210,
         1210,
         1182,
         1182,
         2280,
         2281,
         2282,
         2283,
         1182,
         1182,
         1182,
         1182,
         1182,
         1210,
         1210,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         2284,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1261,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1183,
         1193,
         1183,
         1183,
         1204,
         1211,
         1211,
         1219,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1231,
         1236,
         1236,
         1236,
         1236,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1258,
         1183,
         1261,
         1261,
         1183,
         1262,
         1183,
         1263,
         1183,
         1183,
         1183,
         1183,
         1183,
         1211,
         1211,
         1183,
         1183,
         2285,
         2286,
         2287,
         2288,
         1183,
         1183,
         1183,
         1183,
         1183,
         1211,
         1211,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1264,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1184,
         1194,
         1184,
         1184,
         1205,
         1212,
         1212,
         1220,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1232,
         1237,
         1237,
         1237,
         1237,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1259,
         1184,
         1184,
         1262,
         1264,
         1264,
         1184,
         1265,
         1184,
         1184,
         1184,
         1184,
         1184,
         1212,
         1212,
         1184,
         1184,
         2289,
         2290,
         2291,
         2292,
         1184,
         1184,
         1184,
         1184,
         1184,
         1212,
         1212,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1266,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1185,
         1195,
         1185,
         1185,
         1206,
         1213,
         1213,
         1221,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1233,
         1238,
         1238,
         1238,
         1238,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1260,
         1185,
         1185,
         1263,
         1185,
         1265,
         1266,
         1266,
         1185,
         1185,
         1185,
         1185,
         1185,
         1213,
         1213,
         1185,
         1185,
         2293,
         2294,
         2295,
         2296,
         1185,
         1185,
         1185,
         1185,
         1185,
         1213,
         1213,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         1267,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         1267,
         54,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         1267,
         1267,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         2270,
         2270,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2297,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2793,
         1178,
         1178,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         2284,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2298,
         2299,
         54,
         54,
         54,
         1196,
         2791,
         2794,
         2901,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         2275,
         2275,
         2275,
         2275,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1188,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         2275,
         2275,
         2275,
         2275,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         54,
         55,
         2257,
         2257,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2297,
         2257,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2795,
         54,
         1178,
         1178,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         2300,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         2249,
         2253,
         2249,
         2249,
         2258,
         2262,
         2262,
         2266,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2271,
         2276,
         2276,
         2276,
         2276,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2280,
         2249,
         2249,
         2285,
         2249,
         2289,
         2249,
         2293,
         2249,
         2249,
         2249,
         2249,
         2249,
         2262,
         2262,
         2249,
         2249,
         2249,
         2301,
         2302,
         2303,
         2249,
         2249,
         2249,
         2249,
         2249,
         2262,
         2262,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2250,
         2254,
         2250,
         2250,
         2259,
         2263,
         2263,
         2267,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2272,
         2277,
         2277,
         2277,
         2277,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2281,
         2250,
         2250,
         2286,
         2250,
         2290,
         2250,
         2294,
         2250,
         2250,
         2250,
         2250,
         2250,
         2263,
         2263,
         2250,
         2250,
         2301,
         2250,
         2304,
         2305,
         2250,
         2250,
         2250,
         2250,
         2250,
         2263,
         2263,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2251,
         2255,
         2251,
         2251,
         2260,
         2264,
         2264,
         2268,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2273,
         2278,
         2278,
         2278,
         2278,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2282,
         2251,
         2251,
         2287,
         2251,
         2291,
         2251,
         2295,
         2251,
         2251,
         2251,
         2251,
         2298,
         2264,
         2264,
         2251,
         2251,
         2302,
         2304,
         2251,
         2306,
         2251,
         2251,
         2251,
         2251,
         2251,
         2264,
         2264,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2252,
         2256,
         2252,
         2252,
         2261,
         2265,
         2265,
         2269,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2274,
         2279,
         2279,
         2279,
         2279,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2283,
         2252,
         2252,
         2288,
         2252,
         2292,
         2252,
         2296,
         2252,
         2252,
         2252,
         2252,
         2299,
         2265,
         2265,
         2252,
         2252,
         2303,
         2305,
         2306,
         2307,
         2252,
         2252,
         2252,
         2252,
         2252,
         2265,
         2265,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         2308,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         2308,
         54,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         2308,
         2308,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         2792,
         2792,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2795,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2796,
         1178,
         1178,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         54,
         55,
         2791,
         2791,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2793,
         2791,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2796,
         54,
         1178,
         1178,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         2794,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         2901,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         2902,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         2902,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         2931,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         2931,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2932,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         2940,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         2940,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2941,
         1177,
         1177,
         1196,
         2941,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         2949,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         2949,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2941,
         1177,
         1177,
         1196,
         2950,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1177,
         2950,
         1226,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         19,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         56,
         57,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         57,
         57,
         1718,
         1719,
         1720,
         1721,
         1722,
         1723,
         1724,
         1725,
         1726,
         1727,
         1728,
         1729,
         1730,
         1731,
         1732,
         1733,
         1734,
         2522,
         1716,
         1718,
         1716,
         1735,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1717,
         1719,
         1735,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         56,
         1720,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1721,
         1716,
         1717,
         56,
         1736,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1722,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1723,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1724,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1725,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         1737,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1726,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         1738,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1727,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1728,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1729,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1730,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1731,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1732,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1733,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1734,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         2522,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         58,
         59,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         59,
         59,
         1741,
         1742,
         1743,
         1744,
         1745,
         1746,
         1747,
         1748,
         1749,
         1750,
         1751,
         1752,
         1753,
         1754,
         2523,
         1739,
         1741,
         1739,
         1755,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1740,
         1742,
         1755,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         58,
         1743,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1744,
         1739,
         1740,
         58,
         1756,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1745,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1746,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1747,
         1739,
         1740,
         58,
         58,
         58,
         58,
         1757,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1748,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         1758,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1749,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1750,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1751,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1752,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1753,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1754,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         2523,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         2524,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         60,
         1471,
         1472,
         1473,
         1474,
         2464,
         2465,
         2466,
         2467,
         2468,
         2469,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         61,
         61,
         61,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         62,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
         67,
         68,
         67,
         67,
         1702,
         69,
         70,
         69,
         69,
         1703,
         1704,
         1705,
         1704,
         1704,
         1706,
         1707,
         1708,
         1707,
         1707,
         1709,
         67,
         68,
         67,
         67,
         1702,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1710,
         1711,
         1710,
         1710,
         1712,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1713,
         1714,
         1713,
         1713,
         1715,
         63,
         64,
         63,
         63,
         1694,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         71,
         72,
         73,
         74,
         73,
         74,
         75,
         76,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         77,
         78,
         79,
         80,
         79,
         80,
         81,
         82,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         83,
         83,
         84,
         84,
         84,
         84,
         85,
         85,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         86,
         87,
         88,
         89,
         88,
         89,
         90,
         91,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         92,
         93,
         94,
         95,
         94,
         95,
         96,
         97,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         99,
         100,
         101,
         100,
         101,
         102,
         103,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         104,
         104,
         105,
         105,
         105,
         105,
         106,
         106,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         107,
         107,
         108,
         108,
         108,
         108,
         109,
         109,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         110,
         111,
         112,
         113,
         114,
         115,
         116,
         117,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         118,
         118,
         119,
         119,
         120,
         120,
         121,
         121,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         11,
         0,
         12,
         0,
         0,
         13,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         16,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         20,
         21,
         22,
         21,
         22,
         23,
         23,
         23,
         23,
         0,
         0,
         24,
         25,
         26,
         26,
         26,
         26,
         27,
         27,
         28,
         28,
         29,
         29,
         0,
         30,
         30,
         31,
         31,
         32,
         32,
         33,
         33,
         34,
         34,
         0,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         36,
         0,
         37,
         0,
         38,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         41,
         41,
         41,
         41,
         42,
         43,
         44,
         0,
         0,
         45,
         46,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         48,
         49,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         55,
         56,
         57,
         58,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         59,
         60,
         61,
         62,
         0,
         0,
         0,
         0,
         63,
         17,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         64,
         65,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         66,
         67,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         25,
         24,
         25,
         24,
         24,
         25,
         24,
         25,
         24,
         24,
         25,
         25,
         24,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         68,
         69,
         70,
         71,
         72,
         0,
         40,
         40,
         40,
         40,
         40,
         42,
         43,
         43,
         43,
         43,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         34,
         34,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         41,
         0,
         0,
         0,
         0,
         0,
         47,
         51,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         73,
         74,
         75,
         76,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         20,
         20,
         20,
         20,
         20,
         20,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         21,
         22,
         22,
         22,
         22,
         22,
         23,
         23,
         23,
         23,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         41,
         3,
         3,
         3,
         63,
         63,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         11,
         12,
         0,
         25,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         35,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         67,
         67,
         65,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         20,
         20,
         20,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         17,
         22,
         23,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         22,
         22,
         22,
         30,
         30,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         77,
         0,
         0,
         9,
         15,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 78,
      .table = (const uint16_t []) {
      
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         128,
         129,
         128,
         525,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         526,
         128,
         128,
         527,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         126,
         127,
         528,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         529,
         530,
         529,
         531,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         532,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         126,
         127,
         126,
         523,
         533,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         535,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         536,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         537,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         538,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         539,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         540,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         541,
         542,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         544,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         546,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         547,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         548,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         549,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         550,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         551,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         552,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         553,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         554,
         555,
         554,
         556,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         557,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         558,
         559,
         558,
         560,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         561,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         562,
         563,
         562,
         564,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         565,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         566,
         567,
         566,
         568,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         569,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         570,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         571,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         572,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         573,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         574,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         575,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         576,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         577,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         578,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         579,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         2562,
         2563,
         2562,
         2564,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2565,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2566,
         2567,
         2566,
         2568,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2569,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2570,
         2571,
         2570,
         2572,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2573,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2574,
         2575,
         2574,
         2576,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2577,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         584,
         585,
         584,
         586,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         587,
         584,
         584,
         588,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         580,
         581,
         589,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         590,
         591,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         593,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         580,
         581,
         580,
         582,
         594,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         596,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         597,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         598,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         599,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         600,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         601,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         602,
         603,
         602,
         604,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         605,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         607,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         608,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         609,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         610,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         611,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         612,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         613,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         614,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         615,
         616,
         615,
         617,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         618,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         619,
         620,
         619,
         621,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         622,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         623,
         624,
         623,
         625,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         626,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         627,
         628,
         627,
         629,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         630,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         631,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         632,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         633,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         634,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         635,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         636,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         637,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         638,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         639,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         640,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         2578,
         2579,
         2578,
         2580,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2581,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2582,
         2583,
         2582,
         2584,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2585,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2586,
         2587,
         2586,
         2588,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2589,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2590,
         2591,
         2590,
         2592,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2593,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         646,
         647,
         646,
         648,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         649,
         646,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         2594,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         2926,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         655,
         656,
         655,
         657,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         658,
         655,
         655,
         659,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         651,
         652,
         660,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         661,
         662,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         651,
         652,
         651,
         653,
         665,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         667,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         668,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         669,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         670,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         671,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         672,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         673,
         674,
         673,
         675,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         676,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         678,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         679,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         680,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         681,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         682,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         683,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         684,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         685,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         686,
         687,
         686,
         688,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         689,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         690,
         691,
         690,
         692,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         693,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         694,
         695,
         694,
         696,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         697,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         698,
         699,
         698,
         700,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         701,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         702,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         703,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         704,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         705,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         706,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         707,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         708,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         709,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         710,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         711,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         2595,
         2596,
         2595,
         2597,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2598,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2599,
         2600,
         2599,
         2601,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2602,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2603,
         2604,
         2603,
         2605,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2606,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2607,
         2608,
         2607,
         2609,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2610,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         716,
         717,
         716,
         718,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         719,
         716,
         716,
         720,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         712,
         713,
         721,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         722,
         723,
         722,
         724,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         725,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         712,
         713,
         712,
         714,
         726,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         728,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         729,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         730,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         731,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         732,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         733,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         734,
         735,
         734,
         736,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         737,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         739,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         740,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         741,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         742,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         743,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         744,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         745,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         746,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         747,
         748,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         751,
         752,
         751,
         753,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         754,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         755,
         756,
         755,
         757,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         758,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         759,
         760,
         759,
         761,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         762,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         763,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         764,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         765,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         766,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         767,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         768,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         769,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         770,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         771,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         772,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         2611,
         2612,
         2611,
         2613,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2614,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2615,
         2616,
         2615,
         2617,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2618,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2619,
         2620,
         2619,
         2621,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2622,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2623,
         2624,
         2623,
         2625,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2626,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         716,
         717,
         716,
         718,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         719,
         716,
         716,
         720,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         773,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         712,
         713,
         721,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         774,
         775,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         777,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         712,
         713,
         712,
         714,
         726,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         728,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         729,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         730,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         731,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         732,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         733,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         734,
         735,
         734,
         736,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         737,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         739,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         740,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         741,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         742,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         743,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         744,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         745,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         746,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         747,
         748,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         751,
         752,
         751,
         753,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         754,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         755,
         756,
         755,
         757,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         758,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         759,
         760,
         759,
         761,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         762,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         763,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         764,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         765,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         766,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         767,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         768,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         769,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         770,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         771,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         772,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         2611,
         2612,
         2611,
         2613,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2614,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2615,
         2616,
         2615,
         2617,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2618,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2619,
         2620,
         2619,
         2621,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2622,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2623,
         2624,
         2623,
         2625,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2626,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         782,
         783,
         782,
         784,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         785,
         782,
         782,
         786,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         778,
         779,
         787,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         788,
         789,
         788,
         790,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         791,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         778,
         779,
         778,
         780,
         792,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         794,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         795,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         796,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         797,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         798,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         799,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         800,
         801,
         800,
         802,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         803,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         805,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         806,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         807,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         808,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         809,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         810,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         811,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         812,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         813,
         814,
         813,
         815,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         816,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         817,
         818,
         817,
         819,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         820,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         821,
         822,
         821,
         823,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         824,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         825,
         826,
         825,
         827,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         828,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         829,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         830,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         831,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         832,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         833,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         834,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         835,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         836,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         837,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         838,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         2627,
         2628,
         2627,
         2629,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2630,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2631,
         2632,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2635,
         2636,
         2635,
         2637,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2638,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2639,
         2640,
         2639,
         2641,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2642,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         843,
         844,
         843,
         845,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         846,
         843,
         843,
         847,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         839,
         840,
         848,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         849,
         850,
         849,
         851,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         852,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         839,
         840,
         839,
         841,
         853,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         855,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         856,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         857,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         858,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         859,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         860,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         861,
         862,
         861,
         863,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         864,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         866,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         867,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         868,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         869,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         870,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         871,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         872,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         873,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         874,
         875,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         878,
         879,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         882,
         883,
         882,
         884,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         885,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         886,
         887,
         886,
         888,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         889,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         890,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         891,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         892,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         893,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         894,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         895,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         896,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         897,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         898,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         899,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         2643,
         2644,
         2643,
         2645,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2646,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2647,
         2648,
         2647,
         2649,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2650,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2651,
         2652,
         2651,
         2653,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2654,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2655,
         2656,
         2655,
         2657,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2658,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         843,
         844,
         843,
         845,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         846,
         843,
         843,
         847,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         839,
         840,
         848,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         849,
         850,
         849,
         851,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         852,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         839,
         840,
         839,
         841,
         853,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         855,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         856,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         857,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         858,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         859,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         860,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         861,
         862,
         861,
         863,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         864,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         866,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         867,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         868,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         869,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         870,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         871,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         872,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         873,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         874,
         875,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         878,
         879,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         882,
         883,
         882,
         884,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         885,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         886,
         887,
         886,
         888,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         889,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         890,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         891,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         892,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         893,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         894,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         895,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         896,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         897,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         898,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         899,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         2659,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         2643,
         2644,
         2643,
         2645,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2646,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2647,
         2648,
         2647,
         2649,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2650,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2651,
         2652,
         2651,
         2653,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2654,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2655,
         2656,
         2655,
         2657,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2658,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         904,
         905,
         904,
         906,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         907,
         904,
         904,
         908,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         900,
         901,
         909,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         910,
         911,
         910,
         912,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         913,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         900,
         901,
         900,
         902,
         914,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         916,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         917,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         918,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         919,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         920,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         921,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         922,
         923,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         927,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         928,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         929,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         930,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         931,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         932,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         933,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         934,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         935,
         936,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         939,
         940,
         939,
         941,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         942,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         943,
         944,
         943,
         945,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         946,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         947,
         948,
         947,
         949,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         950,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         951,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         952,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         953,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         954,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         955,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         956,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         957,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         958,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         959,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         960,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         2660,
         2661,
         2660,
         2662,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2663,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2664,
         2665,
         2664,
         2666,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2667,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2668,
         2669,
         2668,
         2670,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2671,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2672,
         2673,
         2672,
         2674,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2675,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1026,
         1027,
         1026,
         1028,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1029,
         1026,
         1026,
         1030,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1022,
         1023,
         1031,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1032,
         1033,
         1032,
         1034,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1035,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1022,
         1023,
         1022,
         1024,
         1036,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1038,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1039,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1040,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1041,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1042,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1043,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1044,
         1045,
         1044,
         1046,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1047,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1049,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1050,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1051,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1052,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1053,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1054,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1055,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1056,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1057,
         1058,
         1057,
         1059,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1060,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1061,
         1062,
         1061,
         1063,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1064,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1065,
         1066,
         1065,
         1067,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1068,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1069,
         1070,
         1069,
         1071,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1072,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1073,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1074,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1075,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1076,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1077,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1078,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1079,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1080,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1081,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1082,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         2692,
         2693,
         2692,
         2694,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2695,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2696,
         2697,
         2696,
         2698,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2699,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2700,
         2701,
         2700,
         2702,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2703,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2704,
         2705,
         2704,
         2706,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2707,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2775,
         2767,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2776,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2777,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2778,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         2779,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2780,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         124,
         2781,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2782,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2783,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2784,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2785,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2786,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2787,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2788,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2789,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2790,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2708,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2709,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2710,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2711,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2712,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         130,
         131,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         131,
         131,
         1477,
         1478,
         1479,
         1480,
         1481,
         1482,
         1483,
         1484,
         131,
         1485,
         1486,
         1487,
         1488,
         2163,
         2164,
         2165,
         1477,
         2166,
         2167,
         2881,
         1475,
         1477,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         1489,
         1490,
         1475,
         1490,
         130,
         1478,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1476,
         1479,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         1476,
         1480,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         130,
         1481,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1482,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1483,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         1491,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         2168,
         1476,
         130,
         1476,
         130,
         1484,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         131,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         1492,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1485,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1486,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1487,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1488,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         2163,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         2164,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1475,
         2165,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         1489,
         1490,
         1475,
         1490,
         1475,
         1477,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         2168,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         2169,
         1490,
         1475,
         1490,
         1476,
         2166,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         130,
         2167,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1476,
         2881,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         4,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         3,
         1,
         3,
         1,
         1,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         132,
         1759,
         1760,
         2490,
         2491,
         2883,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         133,
         1987,
         1988,
         1989,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         134,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         135,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         136,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         137,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         138,
         1885,
         1886,
         1887,
         1888,
         2713,
         2714,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         139,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         140,
         1977,
         1978,
         1979,
         1977,
         1977,
         1978,
         1979,
         1978,
         1978,
         1978,
         1979,
         1979,
         1979,
         1979,
         1979,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         141,
         142,
         141,
         143,
         141,
         142,
         141,
         144,
         141,
         142,
         141,
         143,
         141,
         142,
         141,
         144,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         145,
         1980,
         1981,
         1980,
         1980,
         1981,
         1981,
         1981,
         1981,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         146,
         147,
         146,
         148,
         146,
         147,
         146,
         148,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         149,
         150,
         1982,
         150,
         150,
         1983,
         1982,
         1983,
         1982,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         151,
         152,
         151,
         151,
         153,
         154,
         153,
         153,
         151,
         152,
         151,
         1322,
         151,
         152,
         151,
         151,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         155,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         8,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         13,
         0,
         3,
         3,
         8,
         4,
         14,
         9,
         2,
         4,
         15,
         3,
         3,
         8,
         4,
         16,
         9,
         2,
         4,
         17,
         3,
         3,
         8,
         4,
         0,
         9,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         158,
         159,
         158,
         1298,
         158,
         1299,
         158,
         2154,
         2155,
         158,
         158,
         1298,
         158,
         1298,
         158,
         1298,
         158,
         1298,
         1300,
         1301,
         1300,
         1302,
         1300,
         1303,
         1300,
         2156,
         2157,
         1300,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1304,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1305,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         1300,
         1301,
         1300,
         1302,
         1300,
         1303,
         1300,
         2156,
         2157,
         1300,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         156,
         2158,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2159,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2831,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2924,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2930,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2934,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2939,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2943,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2948,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         160,
         161,
         160,
         160,
         1306,
         160,
         162,
         163,
         162,
         162,
         1307,
         162,
         160,
         1308,
         160,
         160,
         1306,
         160,
         1309,
         1310,
         1309,
         1309,
         1311,
         1309,
         160,
         161,
         160,
         160,
         1306,
         160,
         160,
         1312,
         160,
         160,
         1306,
         160,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         7,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         11,
         11,
         12,
         12,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         164,
         1680,
         1681,
         1682,
         1683,
         1684,
         1685,
         1686,
         1687,
         1688,
         1689,
         1690,
         1691,
         1692,
         1693,
         2309,
         2310,
         2311,
         2312,
         2313,
         2314,
         2827,
         2828,
         2829,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         20,
         6,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         167,
         168,
         1496,
         1497,
         1498,
         167,
         167,
         1499,
         1500,
         1501,
         1502,
         1503,
         167,
         1496,
         1496,
         1496,
         167,
         167,
         2409,
         1496,
         167,
         167,
         1501,
         165,
         1504,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         1506,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1507,
         1508,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         1512,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         1513,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1514,
         1515,
         1516,
         1514,
         1514,
         1514,
         1514,
         1514,
         1514,
         1517,
         1514,
         1518,
         1514,
         1516,
         1516,
         1516,
         1514,
         1514,
         1514,
         1516,
         1514,
         1514,
         1517,
         165,
         1519,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1520,
         1521,
         1522,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1523,
         1520,
         1524,
         1520,
         1522,
         1522,
         1522,
         1520,
         1520,
         1520,
         1522,
         1520,
         1520,
         1523,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         1525,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         2410,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         2411,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         2412,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         1507,
         2413,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         2414,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         1508,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         165,
         2884,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         1507,
         2904,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         2905,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1514,
         2906,
         1516,
         1514,
         1514,
         1514,
         1514,
         1514,
         1514,
         1517,
         1514,
         1518,
         1514,
         1516,
         1516,
         1516,
         1514,
         1514,
         1514,
         1516,
         1514,
         1514,
         1517,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         171,
         172,
         1529,
         1530,
         1531,
         171,
         171,
         171,
         1532,
         1533,
         1534,
         1535,
         1536,
         171,
         1529,
         1529,
         1529,
         2415,
         1529,
         169,
         1537,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         1539,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1540,
         1541,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         1540,
         1545,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         169,
         1546,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         1547,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1548,
         1549,
         1550,
         1548,
         1548,
         1548,
         1548,
         1548,
         1548,
         1548,
         1551,
         1548,
         1552,
         1548,
         1550,
         1550,
         1550,
         1548,
         1550,
         169,
         1553,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1554,
         1555,
         1556,
         1554,
         1554,
         1554,
         1554,
         1554,
         1554,
         1554,
         1557,
         1554,
         1558,
         1554,
         1556,
         1556,
         1556,
         1554,
         1556,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         1559,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         2416,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         2417,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         2418,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         1540,
         1541,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         169,
         2885,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         173,
         174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         174,
         174,
         1562,
         1563,
         1564,
         1565,
         1566,
         1567,
         1568,
         1569,
         174,
         1570,
         1571,
         1572,
         1573,
         2170,
         2171,
         2172,
         1562,
         2173,
         2174,
         2882,
         1560,
         1562,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         1574,
         1575,
         1560,
         1575,
         173,
         1563,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1561,
         1564,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         1561,
         1565,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         173,
         1566,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1567,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1568,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         1576,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         2175,
         1561,
         173,
         1561,
         173,
         1569,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         1577,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1570,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1571,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1572,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1573,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         2170,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         2171,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1560,
         2172,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         1574,
         1575,
         1560,
         1575,
         1560,
         1562,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         2175,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         2176,
         1575,
         1560,
         1575,
         1561,
         2173,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         173,
         2174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1561,
         2882,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         175,
         176,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
         175,
         176,
         1901,
         1899,
         1902,
         1900,
         1903,
         1904,
         175,
         175,
         1905,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
         1906,
         1907,
         1906,
         1908,
         1908,
         1909,
         1909,
         1906,
         1906,
         1906,
         1910,
         1906,
         1908,
         1908,
         1909,
         1909,
         1906,
         1906,
         1911,
         1912,
         1911,
         1913,
         1913,
         1914,
         1914,
         1911,
         1911,
         1911,
         1915,
         1911,
         1913,
         1913,
         1914,
         1914,
         1911,
         1911,
         175,
         1916,
         175,
         1899,
         1899,
         1900,
         1900,
         1917,
         175,
         175,
         2525,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         5,
         5,
         12,
         6,
         6,
         11,
         11,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         11,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         5,
         5,
         6,
         6,
         11,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         179,
         180,
         1764,
         179,
         1765,
         1766,
         1767,
         1768,
         1769,
         1770,
         2527,
         2528,
         2529,
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1771,
         1772,
         1773,
         1771,
         1771,
         1774,
         1774,
         1775,
         1775,
         1771,
         1771,
         2530,
         2530,
         177,
         1776,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1777,
         1778,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1777,
         1782,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1783,
         1784,
         1785,
         1783,
         1783,
         1786,
         1786,
         1787,
         1787,
         1783,
         1783,
         2532,
         2532,
         1783,
         1788,
         1785,
         1783,
         1783,
         1786,
         1786,
         1787,
         1787,
         1783,
         1783,
         2532,
         2532,
         177,
         1789,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         1790,
         177,
         2526,
         2526,
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1777,
         1778,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1777,
         1782,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         181,
         182,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         182,
         1920,
         1918,
         1921,
         1919,
         1922,
         1923,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1924,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1925,
         1926,
         1925,
         1927,
         1927,
         1928,
         1928,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1929,
         1925,
         1927,
         1927,
         1928,
         1928,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1930,
         1931,
         1930,
         1932,
         1932,
         1933,
         1933,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1934,
         1930,
         1932,
         1932,
         1933,
         1933,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         181,
         1935,
         181,
         1918,
         1918,
         1919,
         1919,
         1936,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1937,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1938,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1939,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1940,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1941,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         2533,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         183,
         183,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         184,
         184,
         1794,
         184,
         1795,
         1796,
         1797,
         1798,
         1799,
         1800,
         183,
         183,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         1801,
         1801,
         1802,
         1801,
         1801,
         1803,
         1803,
         1804,
         1804,
         1801,
         183,
         1805,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         1806,
         1806,
         1807,
         1806,
         1806,
         1808,
         1808,
         1809,
         1809,
         1806,
         1806,
         1810,
         1807,
         1806,
         1806,
         1808,
         1808,
         1809,
         1809,
         1806,
         1811,
         1811,
         1812,
         1811,
         1811,
         1813,
         1813,
         1814,
         1814,
         1811,
         1811,
         1815,
         1812,
         1811,
         1811,
         1813,
         1813,
         1814,
         1814,
         1811,
         183,
         1816,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         1817,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         185,
         186,
         1578,
         1579,
         185,
         185,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         186,
         186,
         1582,
         1583,
         1584,
         1585,
         1586,
         1587,
         1588,
         2422,
         1582,
         2423,
         2424,
         2834,
         2835,
         2836,
         1578,
         1582,
         1578,
         1589,
         1578,
         1578,
         1590,
         1591,
         1591,
         2419,
         1578,
         2420,
         2425,
         2837,
         2837,
         2833,
         1579,
         1583,
         1589,
         1579,
         1579,
         1579,
         1592,
         1593,
         1593,
         2426,
         1589,
         2427,
         2428,
         2838,
         2838,
         2839,
         185,
         1584,
         1578,
         1579,
         185,
         185,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         185,
         1585,
         1578,
         1579,
         185,
         1594,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         1580,
         1586,
         1590,
         1592,
         1580,
         1580,
         1580,
         1595,
         1595,
         2429,
         1590,
         2430,
         2421,
         2840,
         2840,
         2841,
         1581,
         1587,
         1591,
         1593,
         1581,
         1581,
         1595,
         1581,
         1581,
         2431,
         1591,
         2432,
         2433,
         2832,
         2832,
         2842,
         1581,
         1588,
         1591,
         1593,
         1581,
         1581,
         1595,
         1581,
         1581,
         2431,
         1591,
         2432,
         2433,
         2832,
         2832,
         2842,
         2419,
         2422,
         2419,
         2426,
         2419,
         2419,
         2429,
         2431,
         2431,
         2419,
         2419,
         2434,
         2435,
         2843,
         2843,
         2844,
         1578,
         1582,
         1578,
         1589,
         1578,
         1578,
         1590,
         1591,
         1591,
         2419,
         2436,
         2420,
         2425,
         2837,
         2837,
         2833,
         2420,
         2423,
         2420,
         2427,
         2420,
         2420,
         2430,
         2432,
         2432,
         2434,
         2420,
         2420,
         2437,
         2845,
         2845,
         2846,
         2421,
         2424,
         2425,
         2428,
         2421,
         2421,
         2421,
         2433,
         2433,
         2435,
         2425,
         2437,
         2421,
         2847,
         2847,
         2848,
         2832,
         2834,
         2837,
         2838,
         2832,
         2832,
         2840,
         2832,
         2832,
         2843,
         2837,
         2845,
         2847,
         2832,
         2832,
         2849,
         2832,
         2835,
         2837,
         2838,
         2832,
         2832,
         2840,
         2832,
         2832,
         2843,
         2837,
         2845,
         2847,
         2832,
         2832,
         2849,
         2833,
         2836,
         2833,
         2839,
         2833,
         2833,
         2841,
         2842,
         2842,
         2844,
         2833,
         2846,
         2848,
         2849,
         2849,
         2833,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         187,
         1961,
         1962,
         1963,
         1964,
         2922,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         188,
         189,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         189,
         189,
         1599,
         1600,
         1601,
         189,
         1602,
         1603,
         2442,
         1599,
         2443,
         2444,
         2445,
         2446,
         2447,
         2907,
         2908,
         1596,
         1599,
         1596,
         1604,
         1596,
         1596,
         1596,
         1605,
         2438,
         1596,
         2439,
         1596,
         2448,
         2448,
         2449,
         1596,
         1596,
         1597,
         1600,
         1604,
         1597,
         1597,
         1597,
         1597,
         1606,
         2450,
         1604,
         2451,
         1597,
         2452,
         2452,
         2453,
         1597,
         1597,
         188,
         1601,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         189,
         1596,
         1597,
         188,
         1607,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         1602,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         1598,
         1603,
         1605,
         1606,
         1598,
         1598,
         1598,
         1598,
         2454,
         1605,
         2455,
         1598,
         2456,
         2456,
         2441,
         1598,
         1598,
         2438,
         2442,
         2438,
         2450,
         2438,
         2438,
         2438,
         2454,
         2438,
         2438,
         2457,
         2438,
         2458,
         2458,
         2459,
         2438,
         2438,
         1596,
         1599,
         1596,
         1604,
         1596,
         1596,
         1596,
         1605,
         2438,
         2460,
         2439,
         1596,
         2448,
         2448,
         2449,
         1596,
         1596,
         2439,
         2443,
         2439,
         2451,
         2439,
         2439,
         2439,
         2455,
         2457,
         2439,
         2439,
         2439,
         2461,
         2461,
         2462,
         2439,
         2439,
         188,
         2444,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         2440,
         2445,
         2448,
         2452,
         2440,
         2440,
         2440,
         2456,
         2458,
         2448,
         2461,
         2440,
         2440,
         2440,
         2463,
         2440,
         2440,
         2440,
         2446,
         2448,
         2452,
         2440,
         2440,
         2440,
         2456,
         2458,
         2448,
         2461,
         2440,
         2440,
         2440,
         2463,
         2440,
         2440,
         2441,
         2447,
         2449,
         2453,
         2441,
         2441,
         2441,
         2441,
         2459,
         2449,
         2462,
         2441,
         2463,
         2463,
         2441,
         2441,
         2441,
         188,
         2907,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         2908,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         190,
         191,
         1626,
         1627,
         1628,
         1629,
         1629,
         2492,
         1626,
         2493,
         2886,
         2886,
         191,
         191,
         1630,
         1631,
         1632,
         1633,
         1634,
         2494,
         1630,
         2495,
         2887,
         2888,
         1626,
         1630,
         1626,
         1635,
         1636,
         1637,
         1637,
         2492,
         1626,
         2496,
         2889,
         2889,
         1627,
         1631,
         1635,
         1627,
         1638,
         1639,
         1639,
         2497,
         1635,
         2498,
         2890,
         2890,
         1628,
         1632,
         1636,
         1638,
         1628,
         1640,
         1640,
         2499,
         1636,
         2493,
         2891,
         2891,
         1629,
         1633,
         1637,
         1639,
         1640,
         1629,
         1629,
         2500,
         1637,
         2501,
         2886,
         2886,
         1629,
         1634,
         1637,
         1639,
         1640,
         1629,
         1629,
         2500,
         1637,
         2501,
         2886,
         2886,
         2492,
         2494,
         2492,
         2497,
         2499,
         2500,
         2500,
         2492,
         2492,
         2502,
         2892,
         2892,
         1626,
         1630,
         1626,
         1635,
         1636,
         1637,
         1637,
         2492,
         2503,
         2496,
         2889,
         2889,
         2493,
         2495,
         2496,
         2498,
         2493,
         2501,
         2501,
         2502,
         2496,
         2493,
         2893,
         2893,
         2886,
         2887,
         2889,
         2890,
         2891,
         2886,
         2886,
         2892,
         2889,
         2893,
         2886,
         2886,
         2886,
         2888,
         2889,
         2890,
         2891,
         2886,
         2886,
         2892,
         2889,
         2893,
         2886,
         2886,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         2,
         7,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         192,
         193,
         1641,
         1642,
         192,
         1643,
         2504,
         1641,
         2505,
         2505,
         2506,
         193,
         193,
         1644,
         1645,
         1646,
         1647,
         2507,
         1644,
         2508,
         2509,
         2510,
         1641,
         1644,
         1641,
         1648,
         1641,
         1649,
         2504,
         1641,
         2511,
         2511,
         2512,
         1642,
         1645,
         1648,
         1642,
         1642,
         1650,
         2513,
         1648,
         2514,
         2514,
         2515,
         192,
         1646,
         1641,
         1642,
         192,
         1643,
         2504,
         1641,
         2505,
         2505,
         2506,
         1643,
         1647,
         1649,
         1650,
         1643,
         1643,
         2516,
         1649,
         2517,
         2517,
         2506,
         2504,
         2507,
         2504,
         2513,
         2504,
         2516,
         2504,
         2504,
         2518,
         2518,
         2519,
         1641,
         1644,
         1641,
         1648,
         1641,
         1649,
         2504,
         2520,
         2511,
         2511,
         2512,
         2505,
         2508,
         2511,
         2514,
         2505,
         2517,
         2518,
         2511,
         2505,
         2505,
         2521,
         2505,
         2509,
         2511,
         2514,
         2505,
         2517,
         2518,
         2511,
         2505,
         2505,
         2521,
         2506,
         2510,
         2512,
         2515,
         2506,
         2506,
         2519,
         2512,
         2521,
         2521,
         2506,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         3,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         3,
         8,
         4,
         8,
         4,
         8,
         4,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         3,
         6,
         6,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         194,
         195,
         1818,
         1819,
         1820,
         194,
         2534,
         2755,
         2756,
         195,
         195,
         1821,
         1822,
         1823,
         195,
         2535,
         2757,
         2758,
         1818,
         1821,
         1818,
         1824,
         1825,
         1818,
         2536,
         2759,
         2760,
         1819,
         1822,
         1824,
         1819,
         1826,
         1819,
         2534,
         2761,
         2762,
         1820,
         1823,
         1825,
         1826,
         1820,
         1820,
         2537,
         2763,
         2756,
         194,
         195,
         1818,
         1819,
         1820,
         2538,
         2534,
         2755,
         2756,
         2534,
         2535,
         2536,
         2534,
         2537,
         2534,
         2534,
         2764,
         2765,
         2755,
         2757,
         2759,
         2761,
         2763,
         2755,
         2764,
         2755,
         2766,
         2756,
         2758,
         2760,
         2762,
         2756,
         2756,
         2765,
         2766,
         2756,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         4,
         4,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         196,
         197,
         1990,
         196,
         2539,
         2540,
         197,
         197,
         1991,
         197,
         2541,
         2542,
         1990,
         1991,
         1990,
         1990,
         2543,
         2540,
         196,
         197,
         1990,
         2544,
         2539,
         2540,
         2539,
         2541,
         2543,
         2539,
         2539,
         2545,
         2540,
         2542,
         2540,
         2540,
         2545,
         2540,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         198,
         199,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         199,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1313,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1314,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1315,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1316,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1317,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1318,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1319,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         2715,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         200,
         1651,
         1652,
         1653,
         1654,
         1655,
         1656,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         201,
         1657,
         1658,
         1659,
         1660,
         1661,
         1662,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         202,
         1663,
         1664,
         1665,
         1666,
         1667,
         1668,
         1669,
         1670,
         1671,
         1672,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         203,
         1829,
         1830,
         1831,
         1832,
         1833,
         1834,
         1835,
         1836,
         1837,
         1838,
         2753,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         204,
         1839,
         1840,
         1841,
         1842,
         1843,
         1844,
         1845,
         1846,
         1847,
         1848,
         1849,
         1850,
         1851,
         2751,
         2752,
         2824,
         2825,
         2826,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         205,
         1673,
         1674,
         1675,
         1676,
         1677,
         1678,
         1679,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         206,
         1965,
         1966,
         1967,
         1968,
         1969,
         1970,
         1971,
         1972,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         207,
         208,
         207,
         207,
         207,
         208,
         207,
         207,
         207,
         1320,
         207,
         207,
         207,
         1321,
         207,
         207,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         209,
         210,
         209,
         210,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         211,
         212,
         211,
         211,
         211,
         211,
         212,
         211,
         211,
         211,
         211,
         1992,
         211,
         211,
         211,
         211,
         1993,
         211,
         211,
         211,
         211,
         1994,
         211,
         211,
         211,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         21,
         21,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         1273,
         214,
         1274,
         214,
         1275,
         214,
         1276,
         1277,
         1278,
         2720,
         2721,
         2722,
         2723,
         213,
         214,
         213,
         1279,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         1279,
         1279,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         1280,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         1280,
         1280,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         1281,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         1281,
         1281,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1282,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1268,
         1273,
         1268,
         1268,
         1268,
         1268,
         1268,
         1268,
         1282,
         1282,
         1268,
         1283,
         1268,
         1284,
         1268,
         1285,
         1286,
         1286,
         2724,
         2725,
         2726,
         2727,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1287,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1269,
         1274,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1283,
         1287,
         1287,
         1269,
         1288,
         1269,
         1289,
         1290,
         1290,
         2728,
         2729,
         2730,
         2731,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1291,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1270,
         1275,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1284,
         1270,
         1288,
         1291,
         1291,
         1270,
         1292,
         1293,
         1293,
         2732,
         2733,
         2734,
         2735,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1294,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1271,
         1276,
         1271,
         1271,
         1271,
         1271,
         1271,
         1271,
         1271,
         1285,
         1271,
         1289,
         1271,
         1292,
         1294,
         1294,
         1295,
         1295,
         2736,
         2737,
         2738,
         2739,
         1272,
         1277,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1286,
         1272,
         1290,
         1272,
         1293,
         1272,
         1295,
         1272,
         1272,
         2740,
         2741,
         2742,
         2743,
         1272,
         1278,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1286,
         1272,
         1290,
         1272,
         1293,
         1272,
         1295,
         1272,
         1272,
         2740,
         2741,
         2742,
         2743,
         2716,
         2720,
         2716,
         2716,
         2716,
         2716,
         2716,
         2716,
         2716,
         2724,
         2716,
         2728,
         2716,
         2732,
         2716,
         2736,
         2740,
         2740,
         2716,
         2744,
         2745,
         2746,
         2717,
         2721,
         2717,
         2717,
         2717,
         2717,
         2717,
         2717,
         2717,
         2725,
         2717,
         2729,
         2717,
         2733,
         2717,
         2737,
         2741,
         2741,
         2744,
         2717,
         2747,
         2748,
         2718,
         2722,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2726,
         2718,
         2730,
         2718,
         2734,
         2718,
         2738,
         2742,
         2742,
         2745,
         2747,
         2718,
         2749,
         2719,
         2723,
         2719,
         2719,
         2719,
         2719,
         2719,
         2719,
         2719,
         2727,
         2719,
         2731,
         2719,
         2735,
         2719,
         2739,
         2743,
         2743,
         2746,
         2748,
         2749,
         2750,
      },
   },
   [nir_op_slt] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         215,
      },
   },
   [nir_op_sge] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         216,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1995,
         1996,
         1997,
         1998,
         217,
         1995,
         217,
         217,
         217,
         217,
         217,
         1996,
         217,
         217,
         217,
         217,
         217,
         1997,
         217,
         217,
         217,
         217,
         217,
         1998,
         217,
         217,
         217,
         217,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         1999,
         2000,
         2001,
         2002,
         218,
         1999,
         218,
         218,
         218,
         218,
         218,
         2000,
         218,
         218,
         218,
         218,
         218,
         2001,
         218,
         218,
         218,
         218,
         218,
         2002,
         218,
         218,
         218,
         218,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         219,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         220,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fall_equal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_fany_nequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         227,
      },
   },
   [nir_op_fany_nequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         228,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         1875,
         1876,
         229,
         1875,
         229,
         229,
         229,
         1876,
         229,
         229,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         1877,
         1878,
         230,
         1877,
         230,
         230,
         230,
         1878,
         230,
         230,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         1879,
         1880,
         231,
         1879,
         231,
         231,
         231,
         1880,
         231,
         231,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         232,
         232,
         232,
         232,
         232,
         232,
         1881,
         1882,
         232,
         1881,
         232,
         232,
         232,
         1882,
         232,
         232,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         233,
         233,
         233,
         233,
         233,
         233,
         1883,
         1884,
         233,
         1883,
         233,
         233,
         233,
         1884,
         233,
         233,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_ball_fequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_ball_fequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         238,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         239,
         239,
         239,
         239,
         239,
         239,
         1889,
         1890,
         239,
         1889,
         239,
         239,
         239,
         1890,
         239,
         239,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         240,
         240,
         240,
         240,
         240,
         240,
         1891,
         1892,
         240,
         1891,
         240,
         240,
         240,
         1892,
         240,
         240,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         241,
         241,
         241,
         241,
         241,
         241,
         1893,
         1894,
         241,
         1893,
         241,
         241,
         241,
         1894,
         241,
         241,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         242,
         242,
         242,
         242,
         242,
         242,
         1895,
         1896,
         242,
         1895,
         242,
         242,
         242,
         1896,
         242,
         242,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         243,
         243,
         243,
         243,
         243,
         243,
         1897,
         1898,
         243,
         1897,
         243,
         243,
         243,
         1898,
         243,
         243,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         244,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         245,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         246,
      },
   },
   [nir_op_bany_fnequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         247,
      },
   },
   [nir_op_bany_fnequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         248,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         249,
         249,
         250,
         250,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         251,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         252,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         253,
         1943,
         1944,
         1945,
         1946,
         1947,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         254,
         255,
         254,
         254,
         256,
         257,
         256,
         256,
         254,
         2003,
         254,
         254,
         254,
         2486,
         254,
         254,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         258,
         1948,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         259,
         1949,
         1950,
         1951,
         1952,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         260,
         1953,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         261,
         261,
         262,
         262,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         263,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         264,
      },
   },
   [nir_op_fcsel] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         265,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         266,
         1954,
         1955,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         267,
         1956,
         1957,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         268,
         1973,
         1974,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         269,
         1975,
         1976,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         270,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         271,
         271,
         271,
         271,
         271,
         1323,
         271,
         271,
         271,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         272,
         1852,
         1853,
         1854,
         1855,
         1856,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         273,
         2006,
         2408,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         274,
         2004,
         2005,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         2008,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         276,
         2007,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         277,
         1857,
         1858,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         278,
         1859,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         284,
         1868,
         1869,
         1870,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         285,
         1871,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         1984,
         1985,
         1986,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         286,
         287,
         288,
         289,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         291,
         0,
         291,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         294,
      },
   },
   [nir_op_find_lsb] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         295,
         2009,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_ifind_msb_rev] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_ufind_msb_rev] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         299,
         2010,
      },
   },
   [nir_op_bitfield_reverse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         303,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_imul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_umul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         311,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         312,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         313,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         1872,
         0,
         1873,
         1874,
         1873,
         2899,
         2900,
         2899,
      },
   },
   [nir_op_uclz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         319,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         320,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         321,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         322,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         323,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         324,
         1942,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         331,
         332,
         333,
         332,
         333,
         334,
         335,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         336,
         336,
         336,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         337,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         338,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         339,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         340,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         341,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         342,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         343,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         344,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         345,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         346,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         347,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         348,
         348,
         348,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         349,
         349,
         350,
         350,
         351,
         351,
      },
   },
   [nir_op_fsin_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         352,
      },
   },
   [nir_op_fcos_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         353,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         354,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   67,
   74,
   80,
   87,
   90,
   94,
   97,
   101,
   0,
   104,
   111,
   115,
   121,
   128,
   138,
   150,
   165,
   178,
   194,
   200,
   207,
   216,
   226,
   236,
   247,
   249,
   257,
   259,
   263,
   265,
   271,
   273,
   279,
   282,
   285,
   287,
   289,
   293,
   296,
   301,
   304,
   309,
   313,
   319,
   321,
   323,
   326,
   329,
   333,
   337,
   339,
   341,
   344,
   347,
   351,
   355,
   357,
   360,
   364,
   366,
   369,
   372,
   376,
   380,
   385,
   387,
   389,
   392,
   395,
   399,
   403,
   405,
   407,
   410,
   413,
   417,
   421,
   423,
   426,
   430,
   432,
   435,
   439,
   441,
   443,
   446,
   449,
   452,
   455,
   460,
   465,
   467,
   470,
   473,
   478,
   482,
   487,
   492,
   516,
   522,
   529,
   536,
   562,
   564,
   0,
   0,
   567,
   570,
   575,
   580,
   0,
   583,
   585,
   0,
   0,
   0,
   0,
   587,
   0,
   0,
   0,
   589,
   591,
   0,
   0,
   0,
   0,
   594,
   0,
   596,
   602,
   604,
   0,
   611,
   617,
   620,
   0,
   628,
   633,
   638,
   643,
   648,
   653,
   658,
   663,
   668,
   670,
   673,
   678,
   684,
   686,
   689,
   693,
   698,
   703,
   709,
   711,
   713,
   715,
   0,
   718,
   720,
   722,
   724,
   726,
   728,
   730,
   732,
   736,
   738,
   742,
   744,
   0,
   0,
   748,
   752,
   758,
   0,
   0,
   764,
   766,
   770,
   772,
   775,
   777,
   780,
   782,
   786,
   788,
   790,
   792,
   794,
   796,
   798,
   800,
   802,
   804,
   806,
   808,
   810,
   812,
   814,
   816,
   818,
   820,
   822,
   824,
   826,
   828,
   830,
   832,
   834,
   836,
   838,
   840,
   842,
   844,
   846,
   848,
   850,
   852,
   854,
   856,
   858,
   863,
   0,
   868,
   870,
   875,
   878,
   884,
   0,
   0,
   886,
   888,
   891,
   893,
   895,
   0,
   0,
   0,
   0,
   897,
   899,
   901,
   0,
   0,
   0,
   0,
   903,
   906,
   909,
   911,
   920,
   922,
   930,
   933,
   935,
   937,
   939,
   941,
   943,
   0,
   945,
   948,
   950,
   952,
   954,
   956,
   959,
   0,
   0,
   0,
   961,
   963,
   965,
   967,
   969,
   973,
   976,
   979,
   982,
   985,
   987,
   989,
   992,
   995,
   997,
   999,
   1001,
   1003,
   1005,
   1007,
   1009,
   1011,
   1013,
   1015,
   1017,
   1019,
   1021,
   1023,
   1026,
   1029,
   1032,
   1034,
   1037,
   1041,
   1045,
   1050,
   1054,
   1056,
   1058,
   1060,
   1062,
   1066,
   1068,
   1070,
   1072,
   1074,
   1076,
   1078,
   1080,
   1082,
   1084,
   0,
   0,
   1087,
   1091,
   1093,
   1096,
   1099,
   1101,
   1103,
   1115,
   1128,
   1140,
   1152,
   1164,
   1177,
   1190,
   1202,
   1214,
   1218,
   1222,
   1225,
   1228,
   1230,
   1235,
   1239,
   1243,
   1247,
   1251,
   1254,
   1256,
   1261,
   0,
   1263,
   1265,
   1267,
   1269,
   1271,
   1274,
   1277,
   1280,
   1282,
   1284,
   1286,
   1289,
   1292,
   1296,
   1300,
   1304,
   1308,
   1312,
   1317,
   1320,
   1324,
   1328,
   1331,
   1334,
   1336,
   1338,
   1341,
   1344,
   1347,
   1350,
   1353,
   1356,
   1360,
   1364,
   1368,
   1371,
   1374,
   1376,
   1378,
   1380,
   1382,
   1385,
   1388,
   1391,
   1393,
   1395,
   1398,
   1401,
   1404,
   1408,
   1412,
   1416,
   1419,
   1422,
   1425,
   1428,
   1432,
   1436,
   1440,
   1443,
   1446,
   1449,
   1453,
   1457,
   1461,
   1464,
   1467,
   1471,
   1475,
   1479,
   1482,
   1485,
   1490,
   1495,
   1499,
   1503,
   1508,
   1512,
   1516,
   1520,
   1524,
   1527,
   1529,
   1533,
   1539,
   1544,
   1551,
   1556,
   1564,
   1568,
   1573,
   1578,
   1584,
   1589,
   1597,
   1605,
   1613,
   1621,
   1629,
   1635,
   1645,
   1651,
   1658,
   1664,
   1676,
   1681,
   1686,
   1693,
   1701,
   1709,
   1717,
   1725,
   1733,
   1741,
   1747,
   1754,
   1760,
   1768,
   1774,
   1781,
   1787,
   1795,
   1800,
   1806,
   1811,
   1818,
   1823,
   1829,
   1834,
   1841,
   1849,
   1854,
   1862,
   1867,
   1872,
   1877,
   1882,
   1887,
   1892,
   1897,
   1903,
   1911,
   1918,
   1927,
   1934,
   1944,
   1950,
   1957,
   1964,
   1972,
   1979,
   1989,
   1999,
   2009,
   2019,
   2029,
   2037,
   2049,
   2057,
   2066,
   2074,
   2088,
   2095,
   2102,
   2111,
   2121,
   2131,
   2141,
   2151,
   2161,
   2171,
   2179,
   2188,
   2196,
   2206,
   2214,
   2223,
   2231,
   2241,
   2248,
   2256,
   2263,
   2272,
   2279,
   2287,
   2294,
   2303,
   2313,
   2320,
   2330,
   2337,
   2344,
   2351,
   2358,
   2365,
   2372,
   2379,
   2384,
   2390,
   2395,
   2402,
   2408,
   2433,
   2439,
   2447,
   2453,
   2462,
   2467,
   2473,
   2479,
   2486,
   2492,
   2501,
   2510,
   2519,
   2528,
   2537,
   2544,
   2555,
   2562,
   2570,
   2577,
   2590,
   2596,
   2602,
   2610,
   2619,
   2628,
   2637,
   2646,
   2655,
   2664,
   2671,
   2679,
   2686,
   2695,
   2702,
   2710,
   2717,
   2726,
   2732,
   2739,
   2745,
   2753,
   2759,
   2766,
   2772,
   2780,
   2789,
   2795,
   2804,
   2810,
   2816,
   2822,
   2828,
   2834,
   2840,
   2846,
   2852,
   2859,
   2865,
   2872,
   2878,
   2883,
   2907,
   2912,
   2919,
   2924,
   2929,
   2935,
   2940,
   2947,
   2953,
   2978,
   2984,
   2992,
   2998,
   3007,
   3012,
   3018,
   3024,
   3031,
   3037,
   3046,
   3055,
   3064,
   3073,
   3082,
   3089,
   3100,
   3107,
   3115,
   3122,
   3135,
   3141,
   3147,
   3155,
   3164,
   3173,
   3182,
   3191,
   3200,
   3209,
   3216,
   3224,
   3231,
   3240,
   3247,
   3255,
   3262,
   3271,
   3277,
   3284,
   3290,
   3298,
   3304,
   3311,
   3317,
   3325,
   3334,
   3340,
   3349,
   3355,
   3361,
   3367,
   3373,
   3379,
   3385,
   3391,
   3397,
   3404,
   3410,
   3418,
   3425,
   3451,
   3458,
   3467,
   3474,
   3484,
   3490,
   3497,
   3504,
   3512,
   3519,
   3529,
   3539,
   3549,
   3559,
   3569,
   3577,
   3589,
   3597,
   3606,
   3614,
   3628,
   3635,
   3642,
   3651,
   3661,
   3671,
   3681,
   3691,
   3701,
   3711,
   3719,
   3728,
   3736,
   3746,
   3754,
   3763,
   3771,
   3781,
   3788,
   3796,
   3803,
   3812,
   3819,
   3827,
   3834,
   3843,
   3853,
   3860,
   3870,
   3877,
   3884,
   3891,
   3898,
   3905,
   3912,
   3919,
   3927,
   3934,
   3942,
   3950,
   3959,
   3965,
   3972,
   3978,
   3986,
   3993,
   4019,
   4026,
   4035,
   4042,
   4052,
   4058,
   4065,
   4072,
   4080,
   4087,
   4097,
   4107,
   4117,
   4127,
   4137,
   4145,
   4157,
   4165,
   4174,
   4182,
   4196,
   4203,
   4210,
   4219,
   4229,
   4239,
   4249,
   4259,
   4269,
   4279,
   4287,
   4296,
   4304,
   4314,
   4322,
   4331,
   4339,
   4349,
   4356,
   4364,
   4371,
   4380,
   4387,
   4395,
   4402,
   4411,
   4421,
   4428,
   4438,
   4445,
   4452,
   4459,
   4466,
   4473,
   4480,
   4487,
   4493,
   4500,
   4506,
   4514,
   4521,
   4547,
   4554,
   4563,
   4570,
   4580,
   4586,
   4593,
   4600,
   4608,
   4615,
   4625,
   4635,
   4645,
   4655,
   4665,
   4673,
   4685,
   4693,
   4702,
   4710,
   4724,
   4731,
   4738,
   4747,
   4757,
   4767,
   4777,
   4787,
   4797,
   4807,
   4815,
   4824,
   4832,
   4842,
   4850,
   4859,
   4867,
   4877,
   4884,
   4892,
   4899,
   4908,
   4915,
   4923,
   4930,
   4939,
   4949,
   4956,
   4966,
   4973,
   4980,
   4987,
   4994,
   5001,
   5008,
   5015,
   5021,
   5028,
   5034,
   5042,
   5049,
   5075,
   5082,
   5091,
   5098,
   5108,
   5114,
   5121,
   5128,
   5136,
   5143,
   5153,
   5163,
   5173,
   5183,
   5193,
   5201,
   5213,
   5221,
   5230,
   5238,
   5252,
   5259,
   5266,
   5275,
   5285,
   5295,
   5305,
   5315,
   5325,
   5335,
   5343,
   5352,
   5360,
   5370,
   5378,
   5387,
   5395,
   5405,
   5412,
   5420,
   5427,
   5436,
   5443,
   5451,
   5458,
   5467,
   5477,
   5484,
   5494,
   5501,
   5508,
   5515,
   5522,
   5529,
   5536,
   5543,
   5549,
   5556,
   5562,
   5570,
   5577,
   5603,
   5610,
   5619,
   5626,
   5636,
   5642,
   5649,
   5656,
   5664,
   5671,
   5681,
   5691,
   5701,
   5711,
   5721,
   5729,
   5741,
   5749,
   5758,
   5766,
   5780,
   5787,
   5794,
   5803,
   5813,
   5823,
   5833,
   5843,
   5853,
   5863,
   5871,
   5880,
   5888,
   5898,
   5906,
   5915,
   5923,
   5933,
   5940,
   5948,
   5955,
   5964,
   5971,
   5979,
   5986,
   5995,
   6005,
   6012,
   6022,
   6029,
   6036,
   6043,
   6050,
   6057,
   6064,
   6071,
   6077,
   6084,
   6090,
   6098,
   6105,
   6131,
   6138,
   6147,
   6154,
   6164,
   6170,
   6177,
   6184,
   6192,
   6199,
   6209,
   6219,
   6229,
   6239,
   6249,
   6257,
   6269,
   6277,
   6286,
   6294,
   6308,
   6315,
   6322,
   6331,
   6341,
   6351,
   6361,
   6371,
   6381,
   6391,
   6399,
   6408,
   6416,
   6426,
   6434,
   6443,
   6451,
   6461,
   6468,
   6476,
   6483,
   6492,
   6499,
   6507,
   6514,
   6523,
   6533,
   6540,
   6550,
   6557,
   6564,
   6571,
   6578,
   6585,
   6592,
   6599,
   0,
   6604,
   6610,
   6612,
   6616,
   6623,
   6627,
   6634,
   6639,
   6646,
   6655,
   6660,
   6665,
   6672,
   6681,
   6686,
   6689,
   6693,
   6696,
   6699,
   6702,
   6706,
   6710,
   6713,
   6716,
   6725,
   6738,
   6752,
   6761,
   6771,
   6780,
   6792,
   6801,
   6811,
   6821,
   6830,
   6839,
   6842,
   6846,
   6850,
   6855,
   6860,
   6864,
   6868,
   6872,
   6876,
   6881,
   6886,
   6890,
   6894,
   6897,
   6907,
   6913,
   6917,
   6921,
   6925,
   6928,
   6931,
   6934,
   6937,
   6941,
   6946,
   6951,
   6955,
   6959,
   6964,
   6970,
   6981,
   6993,
   6999,
   7011,
   7024,
   7028,
   7033,
   7044,
   7056,
   7061,
   7073,
   7086,
   7088,
   7093,
   7098,
   7102,
   7106,
   7111,
   7117,
   7122,
   7127,
   7132,
   7137,
   7142,
   7146,
   7150,
   7154,
   7157,
   7160,
   7163,
   7166,
   7168,
   7172,
   7176,
   7179,
   7182,
   7187,
   7192,
   7198,
   7203,
   7208,
   7212,
   7218,
   7224,
   7229,
   7234,
   7237,
   7239,
   7243,
   7247,
   7251,
   7255,
   7258,
   7263,
   7268,
   7272,
   7276,
   7280,
   7284,
   7287,
   7292,
   7297,
   7301,
   7305,
   7313,
   7317,
   7320,
   7325,
   7330,
   7335,
   7339,
   7343,
   7353,
   7355,
   7357,
   7360,
   7363,
   7366,
   7370,
   7373,
   7378,
   7383,
   7387,
   7391,
   7396,
   7400,
   7404,
   7407,
   7410,
   7416,
   7427,
   7439,
   7445,
   7457,
   7470,
   7474,
   7479,
   7489,
   7500,
   7505,
   7516,
   7528,
   7530,
   7534,
   7538,
   7542,
   7546,
   7551,
   7557,
   7562,
   7567,
   7572,
   7577,
   7582,
   7586,
   7590,
   7594,
   7597,
   7601,
   7605,
   7608,
   7611,
   7614,
   7620,
   7626,
   7631,
   7636,
   7641,
   7647,
   7650,
   7653,
   7656,
   7661,
   7667,
   7672,
   7677,
   7682,
   7687,
   7692,
   7697,
   7702,
   7706,
   7710,
   7714,
   7718,
   7722,
   0,
   7727,
   7733,
   7735,
   7740,
   7751,
   7760,
   7765,
   7775,
   7782,
   7787,
   7794,
   0,
   7801,
   7807,
   7812,
   7822,
   7837,
   7852,
   7867,
   7872,
   7877,
   7882,
   7890,
   7905,
   0,
   7913,
   7916,
   7919,
   7922,
   7925,
   7928,
   7931,
   7934,
   7937,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   7939,
   7942,
   7945,
   7947,
   7950,
   7953,
   7956,
   7959,
   7961,
   7963,
   7968,
   7970,
   7972,
   7977,
   7984,
   7992,
   7997,
   8003,
   8008,
   8014,
   8019,
   8023,
   8025,
   8027,
   8029,
   0,
   8031,
   0,
   0,
   8033,
   0,
   0,
   8036,
   8044,
   8052,
   8061,
   8069,
   8078,
   8085,
   8092,
   8100,
   8110,
   8117,
   8124,
   8126,
   8128,
   8132,
   8134,
   8136,
   0,
   0,
   8138,
   0,
   0,
   8141,
   0,
   0,
   8144,
   8147,
   8150,
   8152,
   0,
   8154,
   8156,
   8161,
   8167,
   8174,
   8181,
   8189,
   8196,
   8205,
   8212,
   8217,
   8225,
   8233,
   8246,
   8259,
   8266,
   8276,
   8284,
   8292,
   8301,
   8315,
   8329,
   8341,
   8356,
   8369,
   8382,
   8395,
   8411,
   8426,
   8440,
   8454,
   8471,
   8487,
   8502,
   8515,
   8531,
   8545,
   8559,
   8567,
   8578,
   8587,
   8596,
   8605,
   8612,
   8622,
   8630,
   8638,
   8645,
   8652,
   8662,
   8672,
   8680,
   8691,
   8702,
   8712,
   8723,
   8735,
   8746,
   8758,
   8771,
   8785,
   8798,
   8805,
   8813,
   8821,
   8829,
   8832,
   8836,
   8840,
   8844,
   8847,
   8850,
   8855,
   8859,
   8863,
   8868,
   8872,
   8876,
   8880,
   8884,
   8889,
   8894,
   8899,
   8904,
   8908,
   8912,
   8918,
   8924,
   8930,
   8936,
   8942,
   8949,
   8955,
   8961,
   8968,
   8974,
   8980,
   8986,
   8992,
   8998,
   9005,
   9011,
   9017,
   9023,
   9030,
   9037,
   9044,
   9051,
   9057,
   9063,
   9069,
   9076,
   9083,
   9090,
   9096,
   9102,
   9108,
   9115,
   9122,
   9129,
   9142,
   9148,
   9154,
   9160,
   9167,
   9173,
   9179,
   9185,
   9191,
   9197,
   9203,
   9209,
   9215,
   9222,
   9228,
   9234,
   9240,
   9247,
   9254,
   9261,
   9268,
   9275,
   9281,
   9287,
   9293,
   9300,
   9307,
   9314,
   9320,
   9326,
   9332,
   9339,
   9346,
   9353,
   9366,
   9369,
   9372,
   9377,
   9381,
   9385,
   9390,
   9394,
   9398,
   9402,
   9406,
   9411,
   9416,
   9421,
   9426,
   9430,
   9434,
   9440,
   9446,
   9449,
   9452,
   9455,
   9457,
   9461,
   9465,
   9469,
   9473,
   9477,
   9480,
   9485,
   9489,
   9493,
   9496,
   9500,
   9503,
   9506,
   9509,
   9512,
   9515,
   9518,
   9521,
   9525,
   9528,
   9532,
   9535,
   9539,
   9543,
   9547,
   9550,
   0,
   0,
   9552,
   9554,
   0,
   0,
   0,
   0,
   0,
   9559,
   9562,
   9565,
   9568,
   9574,
   9579,
   9589,
   9593,
   9597,
   9600,
   9603,
   9606,
   9608,
   9611,
   9614,
   9617,
   9619,
   9622,
   9626,
   9630,
   9633,
   9637,
   9640,
   9643,
   9646,
   9649,
   9652,
   9655,
   9658,
   9661,
   9664,
   9668,
   9672,
   9676,
   9680,
   9682,
   9684,
   9688,
   9692,
   9694,
   9698,
   9700,
   9702,
   9706,
   9710,
   9712,
   9719,
   9727,
   9732,
   9737,
   9742,
   9749,
   9757,
   9762,
   9767,
   9772,
   9774,
   9776,
   9778,
   9780,
   9782,
   9784,
   9786,
   9788,
   9790,
   9792,
   9794,
   0,
   9796,
   9798,
   9800,
   9802,
   9804,
   9806,
   9808,
   9810,
   9812,
   9817,
   9823,
   9829,
   9837,
   9846,
   9851,
   9858,
   9866,
   9872,
   9879,
   9886,
   9895,
   9905,
   9911,
   9919,
   9928,
   9937,
   9948,
   9960,
   9966,
   9974,
   9983,
   9986,
   9989,
   9996,
   10011,
   10018,
   10025,
   10039,
   10053,
   10059,
   10071,
   10083,
   10089,
   10095,
   10102,
   10109,
   10115,
   10121,
   10127,
   10133,
   10137,
   10143,
   10155,
   10167,
   10170,
   10173,
   10180,
   10195,
   10202,
   10209,
   10223,
   10237,
   10249,
   10261,
   10268,
   10275,
   10281,
   10287,
   10293,
   10299,
   10303,
   10309,
   10321,
   0,
   10333,
   10335,
   10338,
   10341,
   10344,
   10349,
   10354,
   10359,
   10366,
   10371,
   10377,
   10387,
   10390,
   10394,
   10398,
   10402,
   10406,
   10410,
   10413,
   10417,
   10421,
   10425,
   10429,
   10434,
   10437,
   10441,
   10445,
   10449,
   10453,
   10458,
   10467,
   10489,
   10492,
   10495,
   10498,
   10501,
   10504,
   10507,
   10511,
   10514,
   10518,
   10526,
   10529,
   10533,
   10537,
   10541,
   10544,
   10547,
   10551,
   10555,
   10559,
   10563,
   10566,
   10570,
   10574,
   10578,
   10582,
   10590,
   10612,
   10614,
   10617,
   10619,
   10623,
   10628,
   10632,
   10635,
   10637,
   10640,
   10642,
   10645,
   10657,
   10667,
   10674,
   10681,
   10688,
   10727,
   10746,
   10753,
   10760,
   10772,
   10778,
   10788,
   10795,
   10802,
   10809,
   10816,
   10822,
   10838,
   10880,
   10887,
   10894,
   10901,
   10913,
   10916,
   10919,
   10922,
   10925,
   10928,
   10932,
   10937,
   10941,
   10943,
   10945,
   10948,
   10951,
   10953,
   10955,
   10958,
   10961,
   10964,
   10967,
   10971,
   10974,
   10976,
   10978,
   10981,
   10984,
   10987,
   10990,
   10993,
   10996,
   10999,
   11002,
   11005,
   11008,
   11011,
   0,
   0,
   0,
   11013,
   11016,
   11019,
   11022,
   11025,
   11028,
   11031,
   11034,
   11037,
   11040,
   11043,
   11049,
   11055,
   11061,
   11068,
   11075,
   11086,
   11093,
   11099,
   11107,
   11114,
   11121,
   11130,
   11136,
   11144,
   11151,
   11158,
   11167,
   11179,
   11204,
   11210,
   11216,
   11222,
   11229,
   11236,
   11247,
   11254,
   11260,
   11268,
   11275,
   11282,
   11291,
   11297,
   11305,
   11312,
   11319,
   11328,
   11340,
   11365,
   11371,
   11377,
   11383,
   11389,
   11395,
   11398,
   11400,
   11402,
   11404,
   11406,
   11408,
   11411,
   11413,
   11415,
   11417,
   11419,
   11421,
   11423,
   11425,
   11427,
   11429,
   11431,
   11435,
   11437,
   11439,
   11443,
   11447,
   11449,
   11452,
   11454,
   11456,
   11458,
   11460,
   11462,
   11464,
   11466,
   11468,
   11470,
   11472,
   11474,
   11478,
   11483,
   11489,
   11492,
   11496,
   11499,
   0,
   0,
   0,
   0,
   0,
   0,
   11503,
   11506,
   11511,
   11515,
   11519,
   11523,
   11527,
   11531,
   11535,
   11539,
   11543,
   11547,
   11551,
   11555,
   11561,
   11563,
   11565,
   11567,
   11569,
   11571,
   11574,
   11576,
   11578,
   11580,
   11584,
   11588,
   11592,
   11596,
   11600,
   11605,
   11608,
   11611,
   11614,
   11617,
   11620,
   11625,
   11630,
   11635,
   11640,
   11644,
   11648,
   11653,
   11658,
   11663,
   11668,
   11672,
   11676,
   11680,
   11684,
   11687,
   11690,
   11695,
   11700,
   11705,
   11710,
   11713,
   11716,
   11721,
   11726,
   11731,
   11736,
   11739,
   11742,
   11747,
   11752,
   11757,
   11762,
   11765,
   11768,
   11773,
   11778,
   11783,
   11788,
   11792,
   11796,
   11802,
   11808,
   11814,
   11820,
   11824,
   11828,
   11834,
   11840,
   11846,
   11852,
   11856,
   11860,
   11866,
   11872,
   11878,
   11884,
   11887,
   11890,
   11895,
   11900,
   11905,
   11910,
   11913,
   11916,
   11921,
   11926,
   11931,
   11936,
   11941,
   11946,
   11951,
   11956,
   11961,
   11966,
   11971,
   11976,
   11983,
   11990,
   11997,
   12004,
   12011,
   12018,
   12020,
   12024,
   12028,
   12032,
   12036,
   12048,
   12061,
   12075,
   12089,
   12103,
   12117,
   12122,
   12127,
   12132,
   12137,
   12143,
   12149,
   12155,
   12161,
   12167,
   12173,
   12179,
   12185,
   12190,
   12195,
   12200,
   12205,
   12210,
   12215,
   12220,
   12225,
   12232,
   12239,
   12246,
   12253,
   12260,
   0,
   12267,
   12269,
   12274,
   12279,
   12283,
   12288,
   12293,
   12296,
   0,
   12300,
   12305,
   12307,
   12313,
   12318,
   12327,
   12333,
   12340,
   12343,
   12346,
   12350,
   12354,
   12358,
   12364,
   12369,
   12373,
   12377,
   12382,
   12386,
   12390,
   12396,
   12401,
   12405,
   12409,
   12414,
   0,
   0,
   12418,
   12420,
   12431,
   12438,
   12445,
   12454,
   12464,
   12469,
   12471,
   12473,
   12476,
   12480,
   0,
   0,
   12482,
   12484,
   0,
   0,
   12488,
   12491,
   12494,
   12497,
   12501,
   0,
   0,
   12505,
   12507,
   0,
   0,
   12511,
   12513,
   12515,
   12520,
   12524,
   12528,
   12533,
   0,
   12535,
   12537,
   12548,
   12556,
   12567,
   12576,
   12585,
   12601,
   12614,
   12630,
   12644,
   12658,
   12669,
   12677,
   12688,
   12697,
   12706,
   12716,
   12728,
   12738,
   12751,
   12762,
   12773,
   12787,
   12798,
   12806,
   12817,
   12826,
   12835,
   12844,
   12856,
   12866,
   12876,
   12881,
   12886,
   12891,
   12896,
   12903,
   12910,
   12917,
   12924,
   12928,
   12934,
   12940,
   12946,
   12952,
   12958,
   12964,
   12970,
   12976,
   12982,
   12988,
   12994,
   13000,
   13004,
   13010,
   13016,
   13022,
   13028,
   13035,
   13040,
   13045,
   13050,
   13055,
   13062,
   13069,
   13076,
   13083,
   13085,
   13092,
   13099,
   13106,
   13113,
   13119,
   13125,
   13131,
   13137,
   13143,
   13149,
   13155,
   13161,
   13167,
   13172,
   13177,
   13180,
   13188,
   13196,
   13204,
   13212,
   13220,
   13228,
   13233,
   13236,
   13238,
   13240,
   13242,
   13244,
   13246,
   13248,
   13251,
   13258,
   13260,
   13265,
   13270,
   13275,
   13280,
   13289,
   13298,
   13308,
   13321,
   13329,
   13340,
   13351,
   13362,
   13374,
   13376,
   13380,
   13388,
   13391,
   13397,
   13403,
   13409,
   13415,
   13419,
   13427,
   13430,
   13436,
   13442,
   13448,
   13454,
   13464,
   13467,
   13471,
   13479,
   13482,
   13488,
   13494,
   13500,
   13506,
   13511,
   13520,
   13524,
   13531,
   13538,
   13545,
   13552,
   13557,
   13566,
   13570,
   13577,
   13584,
   13591,
   13598,
   13602,
   13610,
   13613,
   13619,
   13625,
   13631,
   13637,
   13641,
   13649,
   13652,
   13658,
   13664,
   13670,
   13676,
   13684,
   13687,
   13693,
   13699,
   13705,
   13711,
   13714,
   13721,
   13731,
   13741,
   13751,
   13761,
   13766,
   13771,
   13776,
   13781,
   13792,
   13800,
   13808,
   13816,
   13824,
   13832,
   13840,
   13845,
   13848,
   13850,
   13856,
   13863,
   13870,
   13877,
   13884,
   13892,
   13898,
   13906,
   13913,
   13920,
   13924,
   13928,
   13932,
   13937,
   13942,
   13947,
   13952,
   13957,
   13962,
   13967,
   13972,
   13977,
   13981,
   13985,
   13989,
   13994,
   14000,
   14004,
   14010,
   14014,
   14018,
   14020,
   14024,
   14028,
   14032,
   14035,
   14037,
   14041,
   14045,
   14048,
   14053,
   14058,
   14063,
   14066,
   14071,
   14076,
   14081,
   14084,
   14089,
   14093,
   14099,
   14103,
   14107,
   14113,
   14117,
   14121,
   14125,
   14129,
   14133,
   14136,
   14140,
   14145,
   14148,
   14154,
   14160,
   14166,
   14172,
   14177,
   14185,
   14193,
   14202,
   14207,
   14214,
   14216,
   14218,
   14226,
   14228,
   0,
   0,
   0,
   14234,
   14236,
   14241,
   14245,
   14249,
   14253,
   14257,
   14262,
   14267,
   14272,
   14277,
   14281,
   14285,
   14291,
   14295,
   14299,
   14301,
   14305,
   14309,
   14311,
   14314,
   14318,
   14321,
   14326,
   14331,
   14334,
   14339,
   14344,
   14347,
   14351,
   14357,
   14361,
   14365,
   14373,
   14381,
   14384,
   14391,
   14395,
   14400,
   14406,
   14414,
   14419,
   14424,
   14429,
   14436,
   14440,
   14446,
   14450,
   14454,
   14457,
   14459,
   14463,
   14467,
   14473,
   14476,
   14479,
   14483,
   14490,
   14498,
   14505,
   14514,
   14521,
   14529,
   14536,
   14545,
   14552,
   14560,
   14567,
   14576,
   14583,
   14591,
   14598,
   14607,
   14616,
   14626,
   14635,
   14646,
   14655,
   14665,
   14674,
   14685,
   14694,
   14704,
   14713,
   14724,
   14733,
   14743,
   14752,
   14763,
   14771,
   14780,
   14788,
   14798,
   14806,
   14815,
   14823,
   14833,
   14841,
   14850,
   14858,
   14868,
   14876,
   14885,
   14893,
   14903,
   14909,
   14917,
   14926,
   14934,
   14944,
   14952,
   14961,
   14969,
   14979,
   14987,
   14996,
   15004,
   15014,
   15022,
   15031,
   15039,
   15049,
   15058,
   15068,
   15077,
   15088,
   15097,
   15107,
   15116,
   15127,
   15136,
   15146,
   15155,
   15166,
   15175,
   15185,
   15194,
   15205,
   15214,
   15224,
   15233,
   15244,
   15253,
   15263,
   15272,
   15283,
   15292,
   15302,
   15311,
   15322,
   15331,
   15341,
   15350,
   15361,
   15370,
   15380,
   15389,
   15400,
   15409,
   15419,
   15428,
   15439,
   15448,
   15458,
   15467,
   15478,
   15487,
   15497,
   15506,
   15517,
   15524,
   15533,
   15543,
   15552,
   15563,
   15572,
   15582,
   15591,
   15602,
   15611,
   15621,
   15630,
   15641,
   15650,
   15660,
   15669,
   15680,
   15689,
   15699,
   15708,
   15719,
   15728,
   15738,
   15747,
   15758,
   15767,
   15777,
   15786,
   15797,
   15806,
   15816,
   15825,
   15836,
   15845,
   15855,
   15864,
   15875,
   15884,
   15894,
   15903,
   15914,
   15923,
   15933,
   15942,
   15953,
   15962,
   15972,
   15981,
   15992,
   16000,
   16008,
   16016,
   16024,
   16032,
   16034,
   16036,
   16041,
   16046,
   16051,
   16056,
   16061,
   16068,
   16075,
   16082,
   16089,
   16096,
   16103,
   16110,
   16117,
   16124,
   16131,
   16138,
   16145,
   16151,
   16157,
   16163,
   16169,
   16175,
   16181,
   16187,
   16193,
   16199,
   16205,
   16211,
   16217,
   16225,
   16233,
   16241,
   16249,
   16257,
   16265,
   16270,
   16313,
   16356,
   16376,
   16381,
   16383,
   16386,
   16390,
   16395,
   16397,
   16400,
   16403,
   16407,
   16409,
   16413,
   16418,
   16421,
   16427,
   16433,
   16438,
   16443,
   16449,
   16454,
   16460,
   16465,
   16471,
   16476,
   16483,
   16489,
   16495,
   16500,
   16507,
   16513,
   16519,
   16524,
   16531,
   16537,
   16543,
   16548,
   16555,
   16561,
   16565,
   16569,
   16575,
   16578,
   16584,
   16590,
   16603,
   16615,
   16619,
   16626,
   16633,
   16637,
   16647,
   16651,
   16656,
   16661,
   16669,
   16674,
   16682,
   16687,
   16695,
   16703,
   16714,
   16719,
   16727,
   16735,
   16746,
   16752,
   16761,
   16766,
   16774,
   0,
   16779,
   16787,
   16795,
   0,
   0,
   0,
   16803,
   16810,
   16816,
   16819,
   16822,
   16826,
   16832,
   16836,
   16840,
   16844,
   16848,
   16852,
   16856,
   16859,
   16864,
   16868,
   16873,
   16877,
   16882,
   16887,
   0,
   0,
   16891,
   16898,
   16905,
   16907,
   0,
   0,
   0,
   0,
   16909,
   16912,
   0,
   0,
   0,
   0,
   16915,
   16919,
   16923,
   0,
   0,
   0,
   16925,
   16927,
   0,
   16929,
   16940,
   16956,
   16967,
   16979,
   16993,
   17005,
   17010,
   17015,
   17017,
   17024,
   17031,
   17034,
   17037,
   17041,
   17045,
   17049,
   17053,
   17058,
   17063,
   17068,
   17070,
   17073,
   17075,
   17078,
   17080,
   17083,
   17087,
   17091,
   17093,
   17101,
   17110,
   17117,
   17120,
   17124,
   17132,
   17140,
   17145,
   17153,
   17164,
   17175,
   17189,
   17203,
   17208,
   17219,
   17223,
   17227,
   0,
   17232,
   17235,
   17241,
   17250,
   17258,
   17271,
   17283,
   17290,
   17296,
   17300,
   17302,
   17305,
   17311,
   17320,
   17333,
   17345,
   17352,
   17358,
   17362,
   17364,
   17367,
   17373,
   17382,
   17395,
   17407,
   17414,
   17420,
   17425,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[117];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5796 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = options->lower_ffloor || ((options->lower_doubles_options & nir_lower_dfloor) && !(options->lower_doubles_options & nir_lower_dfloor));
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[25] = options->lower_ffract;
   condition_flags[26] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[27] = options->lower_fceil;
   condition_flags[28] = options->lower_ffma16;
   condition_flags[29] = options->lower_ffma32;
   condition_flags[30] = options->lower_ffma64;
   condition_flags[31] = options->fuse_ffma16;
   condition_flags[32] = options->fuse_ffma32;
   condition_flags[33] = options->fuse_ffma64;
   condition_flags[34] = options->lower_fdph;
   condition_flags[35] = !options->lower_fdph;
   condition_flags[36] = options->lower_fdot;
   condition_flags[37] = !options->lower_fsat;
   condition_flags[38] = !options->lower_iabs;
   condition_flags[39] = options->lower_fsat;
   condition_flags[40] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[41] = !options->lower_fsign;
   condition_flags[42] = options->lower_umax;
   condition_flags[43] = options->lower_umin;
   condition_flags[44] = !options->lower_umax;
   condition_flags[45] = !options->lower_umin;
   condition_flags[46] = options->lower_scmp;
   condition_flags[47] = options->lower_vector_cmp;
   condition_flags[48] = !options->lower_rotate;
   condition_flags[49] = options->lower_rotate;
   condition_flags[50] = options->lower_fpow;
   condition_flags[51] = !options->lower_fpow;
   condition_flags[52] = options->lower_fdiv;
   condition_flags[53] = options->lower_fsqrt;
   condition_flags[54] = !options->lower_fsqrt;
   condition_flags[55] = options->lower_sincos;
   condition_flags[56] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[57] = !options->lower_extract_byte;
   condition_flags[58] = !options->lower_extract_word;
   condition_flags[59] = options->has_pack_32_4x8;
   condition_flags[60] = options->lower_pack_64_2x32_split;
   condition_flags[61] = options->lower_pack_32_2x16_split;
   condition_flags[62] = options->lower_unpack_64_2x32_split;
   condition_flags[63] = options->lower_unpack_32_2x16_split;
   condition_flags[64] = options->has_find_msb_rev;
   condition_flags[65] = !options->lower_find_msb_to_reverse;
   condition_flags[66] = !options->lower_find_lsb;
   condition_flags[67] = options->lower_fmod;
   condition_flags[68] = options->lower_uadd_carry;
   condition_flags[69] = options->lower_usub_borrow;
   condition_flags[70] = options->lower_bitfield_insert;
   condition_flags[71] = options->lower_hadd;
   condition_flags[72] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[73] = options->lower_mul_32x16;
   condition_flags[74] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[75] = options->lower_uadd_sat;
   condition_flags[76] = options->lower_usub_sat;
   condition_flags[77] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[78] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[81] = options->lower_bitfield_insert_to_shifts;
   condition_flags[82] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[83] = options->lower_bitfield_extract;
   condition_flags[84] = options->lower_bitfield_extract_to_shifts;
   condition_flags[85] = options->lower_ifind_msb;
   condition_flags[86] = options->lower_find_msb_to_reverse;
   condition_flags[87] = options->lower_uclz;
   condition_flags[88] = options->lower_find_lsb;
   condition_flags[89] = options->lower_extract_byte;
   condition_flags[90] = options->lower_extract_word;
   condition_flags[91] = options->lower_pack_unorm_2x16;
   condition_flags[92] = options->lower_pack_unorm_4x8;
   condition_flags[93] = options->lower_pack_snorm_2x16;
   condition_flags[94] = options->lower_pack_snorm_4x8;
   condition_flags[95] = options->lower_unpack_unorm_2x16;
   condition_flags[96] = options->lower_unpack_unorm_4x8;
   condition_flags[97] = options->lower_unpack_snorm_2x16;
   condition_flags[98] = options->lower_unpack_snorm_4x8;
   condition_flags[99] = options->lower_pack_split;
   condition_flags[100] = options->lower_isign;
   condition_flags[101] = !options->lower_isign;
   condition_flags[102] = options->lower_fsign;
   condition_flags[103] = !options->has_imul24;
   condition_flags[104] = !options->has_umul24;
   condition_flags[105] = !options->has_umad24;
   condition_flags[106] = options->has_imul24;
   condition_flags[107] = options->has_umad24;
   condition_flags[108] = options->has_umul24;
   condition_flags[109] = options->lower_iadd_sat;
   condition_flags[110] = options->support_8bit_alu;
   condition_flags[111] = options->support_16bit_alu;
   condition_flags[112] = options->lower_ldexp;
   condition_flags[113] = !options->lower_bitfield_reverse;
   condition_flags[114] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[115] = options->lower_fisnormal;
   condition_flags[116] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search2014_0_0 -> 0 in the cache */
   /* search2014_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2014_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace2014_0_0 -> 5 in the cache */
   /* replace2014_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2014_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search2015_0_0 -> 0 in the cache */
   /* search2015_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2015_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace2015_0_0 -> 5 in the cache */
   /* replace2015_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2015_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search2016_0_0 -> 0 in the cache */
   /* search2016_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2016_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace2016_0_0 -> 5 in the cache */
   /* replace2016_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2016_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search2017_0_0 -> 5 in the cache */
   /* search2017_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2017_1_0 -> 5 in the cache */
   /* search2017_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace2017_0 -> 5 in the cache */
   /* replace2017_1_0 -> 8 in the cache */
   /* replace2017_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search2018_0_0 -> 5 in the cache */
   /* search2018_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2018_1_0 -> 5 in the cache */
   /* search2018_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace2018_0 -> 5 in the cache */
   /* replace2018_1_0 -> 8 in the cache */
   /* replace2018_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2019_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search2020_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2020_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2021_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace2021 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search2022_0 -> 39 in the cache */
   /* search2022_1_0_0 -> 39 in the cache */
   /* search2022_1_0 -> 40 in the cache */
   /* search2022_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace2022 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search2023_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2023_1_0 -> 39 in the cache */
   /* search2023_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace2023 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search2024_0 -> 39 in the cache */
   /* search2024_1_0_0 -> 39 in the cache */
   /* search2024_1_0 -> 46 in the cache */
   /* search2024_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace2024 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search2025_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search2025_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace2025_0_0 -> 51 in the cache */
   /* replace2025_0_1 -> 53 in the cache */
   /* replace2025_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace2025_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search2026_0_0 -> 39 in the cache */
   /* search2026_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search2026_1_0 -> 39 in the cache */
   /* search2026_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search2026_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace2026_0_0 -> 53 in the cache */
   /* replace2026_0_1 -> 51 in the cache */
   /* replace2026_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace2026_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search2027_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace2027_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace2027_1_0 -> 64 in the cache */
   /* replace2027_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[117];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = options->lower_ffloor || ((options->lower_doubles_options & nir_lower_dfloor) && !(options->lower_doubles_options & nir_lower_dfloor));
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[25] = options->lower_ffract;
   condition_flags[26] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[27] = options->lower_fceil;
   condition_flags[28] = options->lower_ffma16;
   condition_flags[29] = options->lower_ffma32;
   condition_flags[30] = options->lower_ffma64;
   condition_flags[31] = options->fuse_ffma16;
   condition_flags[32] = options->fuse_ffma32;
   condition_flags[33] = options->fuse_ffma64;
   condition_flags[34] = options->lower_fdph;
   condition_flags[35] = !options->lower_fdph;
   condition_flags[36] = options->lower_fdot;
   condition_flags[37] = !options->lower_fsat;
   condition_flags[38] = !options->lower_iabs;
   condition_flags[39] = options->lower_fsat;
   condition_flags[40] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[41] = !options->lower_fsign;
   condition_flags[42] = options->lower_umax;
   condition_flags[43] = options->lower_umin;
   condition_flags[44] = !options->lower_umax;
   condition_flags[45] = !options->lower_umin;
   condition_flags[46] = options->lower_scmp;
   condition_flags[47] = options->lower_vector_cmp;
   condition_flags[48] = !options->lower_rotate;
   condition_flags[49] = options->lower_rotate;
   condition_flags[50] = options->lower_fpow;
   condition_flags[51] = !options->lower_fpow;
   condition_flags[52] = options->lower_fdiv;
   condition_flags[53] = options->lower_fsqrt;
   condition_flags[54] = !options->lower_fsqrt;
   condition_flags[55] = options->lower_sincos;
   condition_flags[56] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[57] = !options->lower_extract_byte;
   condition_flags[58] = !options->lower_extract_word;
   condition_flags[59] = options->has_pack_32_4x8;
   condition_flags[60] = options->lower_pack_64_2x32_split;
   condition_flags[61] = options->lower_pack_32_2x16_split;
   condition_flags[62] = options->lower_unpack_64_2x32_split;
   condition_flags[63] = options->lower_unpack_32_2x16_split;
   condition_flags[64] = options->has_find_msb_rev;
   condition_flags[65] = !options->lower_find_msb_to_reverse;
   condition_flags[66] = !options->lower_find_lsb;
   condition_flags[67] = options->lower_fmod;
   condition_flags[68] = options->lower_uadd_carry;
   condition_flags[69] = options->lower_usub_borrow;
   condition_flags[70] = options->lower_bitfield_insert;
   condition_flags[71] = options->lower_hadd;
   condition_flags[72] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[73] = options->lower_mul_32x16;
   condition_flags[74] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[75] = options->lower_uadd_sat;
   condition_flags[76] = options->lower_usub_sat;
   condition_flags[77] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[78] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[81] = options->lower_bitfield_insert_to_shifts;
   condition_flags[82] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[83] = options->lower_bitfield_extract;
   condition_flags[84] = options->lower_bitfield_extract_to_shifts;
   condition_flags[85] = options->lower_ifind_msb;
   condition_flags[86] = options->lower_find_msb_to_reverse;
   condition_flags[87] = options->lower_uclz;
   condition_flags[88] = options->lower_find_lsb;
   condition_flags[89] = options->lower_extract_byte;
   condition_flags[90] = options->lower_extract_word;
   condition_flags[91] = options->lower_pack_unorm_2x16;
   condition_flags[92] = options->lower_pack_unorm_4x8;
   condition_flags[93] = options->lower_pack_snorm_2x16;
   condition_flags[94] = options->lower_pack_snorm_4x8;
   condition_flags[95] = options->lower_unpack_unorm_2x16;
   condition_flags[96] = options->lower_unpack_unorm_4x8;
   condition_flags[97] = options->lower_unpack_snorm_2x16;
   condition_flags[98] = options->lower_unpack_snorm_4x8;
   condition_flags[99] = options->lower_pack_split;
   condition_flags[100] = options->lower_isign;
   condition_flags[101] = !options->lower_isign;
   condition_flags[102] = options->lower_fsign;
   condition_flags[103] = !options->has_imul24;
   condition_flags[104] = !options->has_umul24;
   condition_flags[105] = !options->has_umad24;
   condition_flags[106] = options->has_imul24;
   condition_flags[107] = options->has_umad24;
   condition_flags[108] = options->has_umul24;
   condition_flags[109] = options->lower_iadd_sat;
   condition_flags[110] = options->support_8bit_alu;
   condition_flags[111] = options->support_16bit_alu;
   condition_flags[112] = options->lower_ldexp;
   condition_flags[113] = !options->lower_bitfield_reverse;
   condition_flags[114] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[115] = options->lower_fisnormal;
   condition_flags[116] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 211
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2028_0 -> 0 in the cache */
   /* replace2028_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search2029_0_0_0 -> 0 in the cache */
   /* search2029_0_0_1 -> 1 in the cache */
   /* search2029_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search2029_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2029_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2029_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search2030_0 -> 3 in the cache */
   /* search2030_1_0 -> 0 in the cache */
   /* search2030_1_1 -> 1 in the cache */
   /* search2030_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2030_0_0 -> 0 in the cache */
   /* replace2030_0 -> 9 in the cache */
   /* replace2030_1 -> 1 in the cache */
   /* replace2030 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search2031_0 -> 3 in the cache */
   /* search2031_1_0_0 -> 0 in the cache */
   /* search2031_1_0_1 -> 1 in the cache */
   /* search2031_1_0 -> 2 in the cache */
   /* search2031_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2031_0 -> 0 in the cache */
   /* replace2031_1_0 -> 1 in the cache */
   /* replace2031_1 -> 5 in the cache */
   /* replace2031 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search2032_0_0 -> 0 in the cache */
   /* search2032_0_1 -> 1 in the cache */
   /* search2032_0 -> 2 in the cache */
   /* search2032_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2032_0 -> 0 in the cache */
   /* replace2032_1_0 -> 1 in the cache */
   /* replace2032_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2033_0_0_0 -> 0 in the cache */
   /* search2033_0_0_1 -> 1 in the cache */
   /* search2033_0_0 -> 2 in the cache */
   /* search2033_0 -> 7 in the cache */
   /* search2033_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2033_0_0 -> 0 in the cache */
   /* replace2033_0 -> 9 in the cache */
   /* replace2033_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2034_0 -> 3 in the cache */
   /* search2034_1_0 -> 0 in the cache */
   /* search2034_1_1 -> 1 in the cache */
   /* search2034_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2034_0_0 -> 0 in the cache */
   /* replace2034_0 -> 9 in the cache */
   /* replace2034_1 -> 1 in the cache */
   /* replace2034 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2035_0 -> 3 in the cache */
   /* search2035_1_0_0 -> 0 in the cache */
   /* search2035_1_0_1 -> 1 in the cache */
   /* search2035_1_0 -> 2 in the cache */
   /* search2035_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2035_0 -> 0 in the cache */
   /* replace2035_1_0 -> 1 in the cache */
   /* replace2035_1 -> 5 in the cache */
   /* replace2035 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2036_0_0 -> 0 in the cache */
   /* search2036_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2036_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2036_0 -> 0 in the cache */
   /* replace2036_1_0 -> 1 in the cache */
   /* replace2036_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2037_0_0 -> 0 in the cache */
   /* search2037_0_1 -> 1 in the cache */
   /* search2037_0 -> 19 in the cache */
   /* search2037_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2037_0 -> 0 in the cache */
   /* replace2037_1_0 -> 1 in the cache */
   /* replace2037_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2038_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search2038_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace2038_0 -> 0 in the cache */
   /* replace2038_1_0 -> 1 in the cache */
   /* replace2038_1 -> 5 in the cache */
   /* replace2038 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2039_0_0_0 -> 24 in the cache */
   /* search2039_0_0_1 -> 1 in the cache */
   /* search2039_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search2039_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace2039_0_0 -> 0 in the cache */
   /* replace2039_0 -> 9 in the cache */
   /* replace2039_1 -> 1 in the cache */
   /* replace2039 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2040_0 -> 3 in the cache */
   /* search2040_1_0 -> 24 in the cache */
   /* search2040_1_1 -> 1 in the cache */
   /* search2040_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace2040_0_0 -> 0 in the cache */
   /* replace2040_0 -> 9 in the cache */
   /* replace2040_1 -> 1 in the cache */
   /* replace2040 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2041_0 -> 3 in the cache */
   /* search2041_1_0_0 -> 24 in the cache */
   /* search2041_1_0_1 -> 1 in the cache */
   /* search2041_1_0 -> 25 in the cache */
   /* search2041_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace2041_0 -> 0 in the cache */
   /* replace2041_1_0 -> 1 in the cache */
   /* replace2041_1 -> 5 in the cache */
   /* replace2041 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2042_0_0 -> 24 in the cache */
   /* search2042_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search2042_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2042_0 -> 0 in the cache */
   /* replace2042_1_0 -> 1 in the cache */
   /* replace2042_1 -> 5 in the cache */
   /* replace2042 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2043_0_0 -> 24 in the cache */
   /* search2043_0_1 -> 1 in the cache */
   /* search2043_0 -> 31 in the cache */
   /* search2043_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2043_0 -> 0 in the cache */
   /* replace2043_1_0 -> 1 in the cache */
   /* replace2043_1 -> 5 in the cache */
   /* replace2043 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search2044_0_0 -> 0 in the cache */
   /* search2044_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2044_1_0_0 -> 0 in the cache */
   /* search2044_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2044_1_1_0 -> 1 in the cache */
   /* search2044_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace2044_0_0 -> 0 in the cache */
   /* replace2044_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace2044_1_0 -> 1 in the cache */
   /* replace2044_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2045_1_0 -> 42 in the cache */
   /* search2045_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace2045_0 -> 43 in the cache */
   /* replace2045_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search2046_0_0 -> 0 in the cache */
   /* search2046_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2046_1_0_0 -> 0 in the cache */
   /* search2046_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2046_1_1_0 -> 1 in the cache */
   /* search2046_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace2046_0_0_0 -> 0 in the cache */
   /* replace2046_0_0_1 -> 1 in the cache */
   /* replace2046_0_0 -> 39 in the cache */
   /* replace2046_0_1_0 -> 1 in the cache */
   /* replace2046_0_1_1 -> 0 in the cache */
   /* replace2046_0_1 -> 40 in the cache */
   /* replace2046_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search2047_0_0 -> 42 in the cache */
   /* search2047_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2047_1_0 -> 42 in the cache */
   /* search2047_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace2047_0_0 -> 43 in the cache */
   /* replace2047_0_1_0 -> 42 in the cache */
   /* replace2047_0_1 -> 47 in the cache */
   /* replace2047_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search2048_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace2048 -> 42 in the cache */

   /* ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace2049_0 -> 61 in the cache */
   /* replace2049_1 -> 62 in the cache */
   /* replace2049_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2050_0_0_0 -> 61 in the cache */
   /* search2050_0_0_1 -> 62 in the cache */
   /* search2050_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2050_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 67, 64 },
      -1,
   } },

   /* replace2050_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2050_1 -> 62 in the cache */
   /* replace2050_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 69, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2051_0_0_0 -> 61 in the cache */
   /* search2051_0_0_1 -> 62 in the cache */
   /* search2051_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2051_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 71, 64 },
      -1,
   } },

   /* replace2051_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2051_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 62 },
      -1,
   } },
   /* replace2051_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2052_0_0_0_0 -> 61 in the cache */
   /* search2052_0_0_0_1 -> 62 in the cache */
   /* search2052_0_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 76 },
      1,
   } },
   /* search2052_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 77, 64 },
      -1,
   } },

   /* replace2052_0_0_0 -> 61 in the cache */
   /* replace2052_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 73 },
      -1,
   } },
   /* replace2052_1_0 -> 62 in the cache */
   /* replace2052_1 -> 74 in the cache */
   /* replace2052_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 79, 74, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 81, 82 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 83, 84 },
      -1,
   } },

   /* replace2053_0 -> 81 in the cache */
   /* replace2053_1 -> 82 in the cache */
   /* replace2053_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2054_0_0_0 -> 81 in the cache */
   /* search2054_0_0_1 -> 82 in the cache */
   /* search2054_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2054_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 87, 84 },
      -1,
   } },

   /* replace2054_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2054_1 -> 82 in the cache */
   /* replace2054_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2055_0_0_0 -> 81 in the cache */
   /* search2055_0_0_1 -> 82 in the cache */
   /* search2055_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2055_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 91, 84 },
      -1,
   } },

   /* replace2055_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2055_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 82 },
      -1,
   } },
   /* replace2055_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2056_0_0_0_0 -> 81 in the cache */
   /* search2056_0_0_0_1 -> 82 in the cache */
   /* search2056_0_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 96 },
      1,
   } },
   /* search2056_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 97, 84 },
      -1,
   } },

   /* replace2056_0_0_0 -> 81 in the cache */
   /* replace2056_0_0 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 93 },
      -1,
   } },
   /* replace2056_1_0 -> 82 in the cache */
   /* replace2056_1 -> 94 in the cache */
   /* replace2056_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search2057_0_0 -> 81 in the cache */
   /* search2057_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 81, 82 },
      1,
   } },
   /* search2057_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 101, 84 },
      -1,
   } },

   /* replace2057_0 -> 81 in the cache */
   /* replace2057_1 -> 82 in the cache */
   /* replace2057_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search2058_0_0_0 -> 81 in the cache */
   /* search2058_0_0_1 -> 82 in the cache */
   /* search2058_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2058_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 104, 84 },
      -1,
   } },

   /* replace2058_0_0 -> 81 in the cache */
   /* replace2058_0 -> 89 in the cache */
   /* replace2058_1 -> 82 in the cache */
   /* replace2058_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2059_0_0_0 -> 81 in the cache */
   /* search2059_0_0_1 -> 82 in the cache */
   /* search2059_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2059_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 107, 84 },
      -1,
   } },

   /* replace2059_0_0 -> 81 in the cache */
   /* replace2059_0 -> 93 in the cache */
   /* replace2059_1_0 -> 82 in the cache */
   /* replace2059_1 -> 94 in the cache */
   /* replace2059_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2060_0_0_0_0 -> 81 in the cache */
   /* search2060_0_0_0_1 -> 82 in the cache */
   /* search2060_0_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 110 },
      1,
   } },
   /* search2060_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 111, 84 },
      -1,
   } },

   /* replace2060_0_0_0 -> 81 in the cache */
   /* replace2060_0_0 -> 93 in the cache */
   /* replace2060_0 -> 99 in the cache */
   /* replace2060_1_0 -> 82 in the cache */
   /* replace2060_1 -> 94 in the cache */
   /* replace2060_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 114, 115 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 116, 117 },
      -1,
   } },

   /* replace2061_0 -> 114 in the cache */
   /* replace2061_1 -> 115 in the cache */
   /* replace2061_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 114, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2062_0_0_0 -> 114 in the cache */
   /* search2062_0_0_1 -> 115 in the cache */
   /* search2062_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2062_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 120, 117 },
      -1,
   } },

   /* replace2062_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2062_1 -> 115 in the cache */
   /* replace2062_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 122, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2063_0_0_0 -> 114 in the cache */
   /* search2063_0_0_1 -> 115 in the cache */
   /* search2063_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2063_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 124, 117 },
      -1,
   } },

   /* replace2063_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2063_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 115 },
      -1,
   } },
   /* replace2063_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 126, 127, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2064_0_0_0_0 -> 114 in the cache */
   /* search2064_0_0_0_1 -> 115 in the cache */
   /* search2064_0_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 129 },
      1,
   } },
   /* search2064_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 130, 117 },
      -1,
   } },

   /* replace2064_0_0_0 -> 114 in the cache */
   /* replace2064_0_0 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 126 },
      -1,
   } },
   /* replace2064_1_0 -> 115 in the cache */
   /* replace2064_1 -> 127 in the cache */
   /* replace2064_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 132, 127, 117 },
      -1,
   } },

   /* ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 134, 136 },
      -1,
   } },

   /* replace2065_0 -> 134 in the cache */
   /* replace2065_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 134, 135 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2066_0 -> 61 in the cache */
   /* search2066_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 61, 139 },
      -1,
   } },

   /* replace2066_0 -> 61 in the cache */
   /* replace2066_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 61, 62 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2067_0 -> 81 in the cache */
   /* search2067_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 142 },
      -1,
   } },

   /* replace2067_0 -> 81 in the cache */
   /* replace2067_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2068_0 -> 114 in the cache */
   /* search2068_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 114, 145 },
      -1,
   } },

   /* replace2068_0 -> 114 in the cache */
   /* replace2068_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 114, 115 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search2069_0 -> 42 in the cache */
   /* search2069 -> 59 in the cache */

   /* replace2069_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 148 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search2070_0 -> 0 in the cache */
   /* search2070_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 150 },
      -1,
   } },

   /* replace2070_0 -> 0 in the cache */
   /* replace2070_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search2071_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace2071_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 154, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search2072_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2072_0 -> 42 in the cache */
   /* replace2072_1_0 -> 42 in the cache */
   /* replace2072_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 153 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 158, 159 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 160, 161 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 164, 165 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search2074_0_0 -> 158 in the cache */
   /* search2074_0_1 -> 159 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 158, 159 },
      0,
   } },
   /* search2074_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 167, 161 },
      -1,
   } },

   /* replace2074_0 -> 163 in the cache */
   /* replace2074_1_0 -> 164 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 164 },
      -1,
   } },
   /* replace2074_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 165 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search2075_0_0 -> 158 in the cache */
   /* search2075_0_1 -> 159 in the cache */
   /* search2075_0 -> 167 in the cache */
   /* search2075_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 167, 161 },
      -1,
   } },

   /* replace2075_0 -> 163 in the cache */
   /* replace2075_1_0 -> 164 in the cache */
   /* replace2075_1 -> 169 in the cache */
   /* replace2075_2_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 172 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search2076_0_0 -> 61 in the cache */
   /* search2076_0 -> 69 in the cache */
   /* search2076_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 69, 62 },
      2,
   } },

   /* replace2076_0_0 -> 61 in the cache */
   /* replace2076_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 176, 177 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 178 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search2077_0 -> 61 in the cache */
   /* search2077_1_0 -> 62 in the cache */
   /* search2077_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 139 },
      2,
   } },

   /* replace2077_0_0 -> 61 in the cache */
   /* replace2077_0_1 -> 62 in the cache */
   /* replace2077_0 -> 175 in the cache */
   /* replace2077_1_0 -> 177 in the cache */
   /* replace2077_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 177, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 181 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 184 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 183, 185 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2078_1 -> 184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 187, 184 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search2079_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 189, 190 },
      -1,
   } },

   /* replace2079_0 -> 0 in the cache */
   /* replace2079_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search2080_0_0 -> 0 in the cache */
   /* search2080_0 -> 189 in the cache */
   /* search2080_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2080_0 -> 0 in the cache */
   /* replace2080_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search2081_0_0 -> 0 in the cache */
   /* search2081_0 -> 189 in the cache */
   /* search2081_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2081_0 -> 0 in the cache */
   /* replace2081_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search2082_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 198 },
      -1,
   } },

   /* replace2082_0 -> 42 in the cache */
   /* replace2082_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 202 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 203, 206 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 207, 208 },
      -1,
   } },

   /* replace2083_0_0 -> 201 in the cache */
   /* replace2083_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 201, 210 },
      -1,
   } },
   /* replace2083_1_0 -> 204 in the cache */
   /* replace2083_1_1_0 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 204, 212 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 211, 213 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search2084_0_0 -> 0 in the cache */
   /* search2084_0 -> 9 in the cache */
   /* search2084_1_0 -> 1 in the cache */
   /* search2084_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2084_0 -> 1 in the cache */
   /* replace2084_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search2085_0_0 -> 0 in the cache */
   /* search2085_0 -> 9 in the cache */
   /* search2085_1_0 -> 1 in the cache */
   /* search2085_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2085_0 -> 1 in the cache */
   /* replace2085_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search2086_0_0 -> 0 in the cache */
   /* search2086_0 -> 9 in the cache */
   /* search2086_1_0 -> 1 in the cache */
   /* search2086_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2086_0 -> 1 in the cache */
   /* replace2086_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search2087_0_0 -> 0 in the cache */
   /* search2087_0 -> 9 in the cache */
   /* search2087_1_0 -> 1 in the cache */
   /* search2087_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2087_0 -> 1 in the cache */
   /* replace2087_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search2088_0_0 -> 42 in the cache */
   /* search2088_0 -> 59 in the cache */
   /* search2088_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2088_0 -> 198 in the cache */
   /* replace2088_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search2089_0 -> 148 in the cache */
   /* search2089_1_0 -> 42 in the cache */
   /* search2089_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2089_0 -> 42 in the cache */
   /* replace2089_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search2090_0_0 -> 42 in the cache */
   /* search2090_0 -> 59 in the cache */
   /* search2090_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2090_0 -> 198 in the cache */
   /* replace2090_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search2091_0 -> 148 in the cache */
   /* search2091_1_0 -> 42 in the cache */
   /* search2091_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2091_0 -> 42 in the cache */
   /* replace2091_1 -> 198 in the cache */
   /* replace2091 -> 200 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search2092_0_0 -> 42 in the cache */
   /* search2092_0 -> 59 in the cache */
   /* search2092_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 148 },
      -1,
   } },

   /* replace2092_0 -> 198 in the cache */
   /* replace2092_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 198, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search2093_0 -> 148 in the cache */
   /* search2093_1_0 -> 42 in the cache */
   /* search2093_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 59 },
      -1,
   } },

   /* replace2093_0 -> 42 in the cache */
   /* replace2093_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 198 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search2094_0 -> 42 in the cache */
   /* search2094_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2094 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search2095_0 -> 42 in the cache */
   /* search2095_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2095 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 236 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 237 },
      0,
   } },
   /* search2096_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 238, 198 },
      -1,
   } },

   /* replace2096_0_0 -> 198 in the cache */
   /* replace2096_0_1_0 -> 42 in the cache */
   /* replace2096_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 198, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 240 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search2097_0 -> 0 in the cache */
   /* search2097_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2097_0 -> 0 in the cache */
   /* replace2097_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search2098_0 -> 0 in the cache */
   /* search2098_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2098_0 -> 0 in the cache */
   /* replace2098_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search2099_0 -> 0 in the cache */
   /* search2099_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2099_0 -> 0 in the cache */
   /* replace2099_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search2100_0 -> 0 in the cache */
   /* search2100_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace2100_0 -> 0 in the cache */
   /* replace2100_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search2101_0_0 -> 201 in the cache */
   /* search2101_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 201, 202 },
      0,
   } },
   /* search2101_1_0 -> 201 in the cache */
   /* search2101_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 204 },
      0,
   } },
   /* search2101_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 250, 251, 205 },
      -1,
   } },

   /* replace2101_0_0 -> 202 in the cache */
   /* replace2101_0_1 -> 204 in the cache */
   /* replace2101_0_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 202, 204, 205 },
      -1,
   } },
   /* replace2101_1 -> 201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 253, 201 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search2102_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2102_0_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 42 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 256, 257 },
      -1,
   } },
   /* replace2102_1_0_0_0 -> 42 in the cache */
   /* replace2102_1_0_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 259 },
      -1,
   } },
   /* replace2102_1_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 260, 198 },
      -1,
   } },
   /* replace2102_2_0_0 -> 42 in the cache */
   /* replace2102_2_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 262 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 258, 261, 263 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2103_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 266 },
      -1,
   } },

   /* replace2103_0 -> 266 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace2103_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2104_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search2104_2 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 266 },
      -1,
   } },

   /* replace2104_0 -> 266 in the cache */
   /* replace2104_1 -> 268 in the cache */
   /* replace2104_2_0 -> 81 in the cache */
   /* replace2104_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 89 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2105_0 -> 81 in the cache */
   /* search2105_1 -> 270 in the cache */
   /* search2105_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 268 },
      -1,
   } },

   /* replace2105_0 -> 268 in the cache */
   /* replace2105_1 -> 266 in the cache */
   /* replace2105_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2106_0 -> 81 in the cache */
   /* search2106_1 -> 265 in the cache */
   /* search2106_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 268 },
      -1,
   } },

   /* replace2106_0 -> 268 in the cache */
   /* replace2106_1 -> 266 in the cache */
   /* replace2106_2_0 -> 81 in the cache */
   /* replace2106_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 89 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2107_0_0 -> 265 in the cache */
   /* search2107_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      0,
   } },
   /* search2107_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 266 },
      -1,
   } },

   /* replace2107_0 -> 266 in the cache */
   /* replace2107_1 -> 268 in the cache */
   /* replace2107_2 -> 81 in the cache */
   /* replace2107 -> 269 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2108_0_0 -> 270 in the cache */
   /* search2108_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 270, 81 },
      0,
   } },
   /* search2108_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 266 },
      -1,
   } },

   /* replace2108_0 -> 266 in the cache */
   /* replace2108_1 -> 268 in the cache */
   /* replace2108_2_0 -> 81 in the cache */
   /* replace2108_2 -> 89 in the cache */
   /* replace2108 -> 272 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2109_0_0 -> 270 in the cache */
   /* search2109_0_1 -> 81 in the cache */
   /* search2109_0 -> 279 in the cache */
   /* search2109_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 268 },
      -1,
   } },

   /* replace2109_0 -> 268 in the cache */
   /* replace2109_1 -> 266 in the cache */
   /* replace2109_2 -> 81 in the cache */
   /* replace2109 -> 274 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2110_0_0 -> 265 in the cache */
   /* search2110_0_1 -> 81 in the cache */
   /* search2110_0 -> 277 in the cache */
   /* search2110_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 268 },
      -1,
   } },

   /* replace2110_0 -> 268 in the cache */
   /* replace2110_1 -> 266 in the cache */
   /* replace2110_2_0 -> 81 in the cache */
   /* replace2110_2 -> 89 in the cache */
   /* replace2110 -> 276 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 284 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 283, 285 },
      -1,
   } },
   /* search2111_1 -> 284 in the cache */
   /* search2111_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 286, 284, 284 },
      -1,
   } },

   /* replace2111_0 -> 284 in the cache */
   /* replace2111_1 -> 283 in the cache */
   /* replace2111_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 284, 283, 284 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2112_0 -> 81 in the cache */
   /* search2112_1 -> 265 in the cache */
   /* search2112_2_0_0 -> 81 in the cache */
   /* search2112_2_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 81, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 290 },
      -1,
   } },

   /* replace2112_0 -> 81 in the cache */
   /* replace2112_1 -> 268 in the cache */
   /* replace2112_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2113_0 -> 81 in the cache */
   /* search2113_1 -> 265 in the cache */
   /* search2113_2_0_0 -> 81 in the cache */
   /* search2113_2_0 -> 89 in the cache */
   /* search2113_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 89, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 265, 293 },
      -1,
   } },

   /* replace2113_0 -> 81 in the cache */
   /* replace2113_1 -> 268 in the cache */
   /* replace2113_2 -> 81 in the cache */
   /* replace2113 -> 292 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2114_0 -> 81 in the cache */
   /* search2114_1_0 -> 81 in the cache */
   /* search2114_1 -> 89 in the cache */
   /* search2114_2_0 -> 265 in the cache */
   /* search2114_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 89, 295 },
      -1,
   } },

   /* replace2114_0 -> 81 in the cache */
   /* replace2114_1 -> 268 in the cache */
   /* replace2114_2 -> 81 in the cache */
   /* replace2114 -> 292 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2115_0 -> 81 in the cache */
   /* search2115_1_0 -> 265 in the cache */
   /* search2115_1_1_0 -> 81 in the cache */
   /* search2115_1_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 265, 89 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 81, 297 },
      -1,
   } },

   /* replace2115_0 -> 81 in the cache */
   /* replace2115_1 -> 268 in the cache */
   /* replace2115_2 -> 81 in the cache */
   /* replace2115 -> 292 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 299, 300 },
      0,
   } },
   /* search2116_1_0 -> 299 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 299, 302 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 301, 303 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2116_1_0 -> 300 in the cache */
   /* replace2116_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 306 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2117_0_0 -> 299 in the cache */
   /* search2117_0_1 -> 300 in the cache */
   /* search2117_0 -> 301 in the cache */
   /* search2117_1_0 -> 299 in the cache */
   /* search2117_1_1 -> 302 in the cache */
   /* search2117_1 -> 303 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 301, 303 },
      -1,
   } },

   /* replace2117_0 -> 305 in the cache */
   /* replace2117_1_0 -> 300 in the cache */
   /* replace2117_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 309 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 311 },
      -1,
   } },
   /* search2118_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 312, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2118_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 313, 314, 315 },
      -1,
   } },

   /* replace2118_0_0 -> 42 in the cache */
   /* replace2118_0 -> 315 in the cache */
   /* replace2118_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 315, 314 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 322, 323 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 320, 321, 324 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 318, 319, 325 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 326, 327 },
      -1,
   } },

   /* replace2119_0 -> 318 in the cache */
   /* replace2119_1 -> 319 in the cache */
   /* replace2119_2_0 -> 320 in the cache */
   /* replace2119_2_1 -> 321 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 329, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 320, 321, 332 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 318, 319, 333 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 337, 338 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 335, 336, 339 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 340, 341 },
      -1,
   } },

   /* replace2120_0 -> 335 in the cache */
   /* replace2120_1 -> 336 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 343, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 335, 336, 346 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2121_0_0_0 -> 318 in the cache */
   /* search2121_0_0_1 -> 319 in the cache */
   /* search2121_0_0_2_0 -> 320 in the cache */
   /* search2121_0_0_2_1 -> 321 in the cache */
   /* search2121_0_0_2_2_0 -> 322 in the cache */
   /* search2121_0_0_2_2_1 -> 323 in the cache */
   /* search2121_0_0_2_2 -> 324 in the cache */
   /* search2121_0_0_2 -> 325 in the cache */
   /* search2121_0_0 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 326 },
      -1,
   } },
   /* search2121_1 -> 327 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 348, 327 },
      -1,
   } },

   /* replace2121_0_0 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 318 },
      -1,
   } },
   /* replace2121_1 -> 319 in the cache */
   /* replace2121_2_0_0 -> 320 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 320 },
      -1,
   } },
   /* replace2121_2_1 -> 321 in the cache */
   /* replace2121_2_2_0_0 -> 329 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 329 },
      -1,
   } },
   /* replace2121_2_2_1 -> 330 in the cache */
   /* replace2121_2_2_2 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 352, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 351, 321, 353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 350, 319, 354 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2122_0_0 -> 81 in the cache */
   /* search2122_0_1 -> 82 in the cache */
   /* search2122_0_2_0 -> 84 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 357, 358 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 84, 356, 359 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 81, 82, 360 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 361, 362 },
      -1,
   } },

   /* replace2122_0 -> 81 in the cache */
   /* replace2122_1 -> 82 in the cache */
   /* replace2122_2_0 -> 84 in the cache */
   /* replace2122_2_1 -> 356 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 364, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 84, 356, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 81, 82, 368 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2123_0_0 -> 81 in the cache */
   /* search2123_0_1 -> 82 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 370, 371 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 81, 82, 372 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 373, 374 },
      -1,
   } },

   /* replace2123_0 -> 81 in the cache */
   /* replace2123_1 -> 82 in the cache */
   /* replace2123_2_0 -> 84 in the cache */
   /* replace2123_2_1 -> 356 in the cache */
   /* replace2123_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 84, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 81, 82, 376 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2124_0_0_0 -> 81 in the cache */
   /* search2124_0_0_1 -> 82 in the cache */
   /* search2124_0_0_2_0 -> 84 in the cache */
   /* search2124_0_0_2_1 -> 356 in the cache */
   /* search2124_0_0_2_2_0 -> 357 in the cache */
   /* search2124_0_0_2_2_1 -> 358 in the cache */
   /* search2124_0_0_2_2 -> 359 in the cache */
   /* search2124_0_0_2 -> 360 in the cache */
   /* search2124_0_0 -> 361 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 361 },
      -1,
   } },
   /* search2124_1 -> 362 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 378, 362 },
      -1,
   } },

   /* replace2124_0_0 -> 81 in the cache */
   /* replace2124_0 -> 89 in the cache */
   /* replace2124_1 -> 82 in the cache */
   /* replace2124_2_0_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 84 },
      -1,
   } },
   /* replace2124_2_1 -> 356 in the cache */
   /* replace2124_2_2_0_0 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 364 },
      -1,
   } },
   /* replace2124_2_2_1 -> 365 in the cache */
   /* replace2124_2_2_2 -> 366 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 381, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 380, 356, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 89, 82, 383 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2125_0 -> 81 in the cache */
   /* search2125_1 -> 82 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2125 -> 385 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2126_0 -> 81 in the cache */
   /* search2126_1 -> 82 in the cache */
   /* search2126_2 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2126 -> 385 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2127_0 -> 81 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2127_0_1_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 391, 392 },
      -1,
   } },
   /* replace2127_1_0 -> 81 in the cache */
   /* replace2127_1_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 81, 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 394 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2128_0 -> 81 in the cache */
   /* search2128_1 -> 388 in the cache */
   /* search2128_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   /* replace2128_0_0 -> 81 in the cache */
   /* replace2128_0_1_0_0 -> 82 in the cache */
   /* replace2128_0_1_0_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 82, 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 81, 398 },
      -1,
   } },
   /* replace2128_1_0 -> 84 in the cache */
   /* replace2128_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 399, 392 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2129_0 -> 42 in the cache */
   /* search2129_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2129 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2130_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2130 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2131_0 -> 42 in the cache */
   /* search2131_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2131 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2132_0 -> 42 in the cache */
   /* search2132_1 -> 402 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2132 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2133_0 -> 42 in the cache */
   /* search2133_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2133 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2134_0_0 -> 0 in the cache */
   /* search2134_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2134_0 -> 0 in the cache */
   /* replace2134_1 -> 1 in the cache */
   /* replace2134 -> 407 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2135_0_0 -> 0 in the cache */
   /* search2135_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2135_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2135_0 -> 0 in the cache */
   /* replace2135_1 -> 1 in the cache */
   /* replace2135 -> 407 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2136_0_0 -> 0 in the cache */
   /* search2136_0_1 -> 1 in the cache */
   /* search2136_0 -> 407 in the cache */
   /* search2136_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2136_0 -> 0 in the cache */
   /* replace2136_1 -> 1 in the cache */
   /* replace2136 -> 410 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2137_0_0 -> 0 in the cache */
   /* search2137_0_1 -> 1 in the cache */
   /* search2137_0 -> 410 in the cache */
   /* search2137_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2137_0 -> 0 in the cache */
   /* replace2137_1 -> 1 in the cache */
   /* replace2137 -> 410 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2138_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2138_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2139_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2139_0 -> 61 in the cache */
   /* replace2139_1 -> 416 in the cache */
   /* replace2139 -> 417 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2140_0_0 -> 61 in the cache */
   /* search2140_0 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2140_0 -> 61 in the cache */
   /* replace2140_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2141_0_0 -> 61 in the cache */
   /* search2141_0 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2141_0 -> 61 in the cache */
   /* replace2141_1 -> 416 in the cache */
   /* replace2141 -> 421 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2142_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2142_0 -> 81 in the cache */
   /* replace2142_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2143_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2143_0 -> 81 in the cache */
   /* replace2143_1 -> 385 in the cache */
   /* replace2143 -> 425 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2144_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2144_0 -> 81 in the cache */
   /* replace2144_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2145_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2145_0 -> 81 in the cache */
   /* replace2145_1 -> 385 in the cache */
   /* replace2145 -> 430 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2146_0_0 -> 81 in the cache */
   /* search2146_0 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2146_0 -> 81 in the cache */
   /* replace2146_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2147_0_0 -> 81 in the cache */
   /* search2147_0 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2147_0 -> 81 in the cache */
   /* replace2147_1 -> 385 in the cache */
   /* replace2147 -> 434 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2148_0_0 -> 81 in the cache */
   /* search2148_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2148_0 -> 81 in the cache */
   /* replace2148_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2149_0_0 -> 81 in the cache */
   /* search2149_0 -> 431 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2149_0 -> 81 in the cache */
   /* replace2149_1 -> 385 in the cache */
   /* replace2149 -> 437 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2150_0_0 -> 81 in the cache */
   /* search2150_0_1 -> 385 in the cache */
   /* search2150_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 439 },
      -1,
   } },

   /* replace2150_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2151_0_0 -> 81 in the cache */
   /* search2151_0_1 -> 385 in the cache */
   /* search2151_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 443 },
      -1,
   } },

   /* replace2151_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 445 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2152_0_0 -> 81 in the cache */
   /* search2152_0_1 -> 385 in the cache */
   /* search2152_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 447 },
      -1,
   } },

   /* replace2152_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 449 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2153_0_0 -> 81 in the cache */
   /* search2153_0_1 -> 439 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 439 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 451, 452 },
      -1,
   } },

   /* replace2153_0 -> 81 in the cache */
   /* replace2153_1 -> 441 in the cache */
   /* replace2153 -> 442 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2154_0_0 -> 81 in the cache */
   /* search2154_0_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 443 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 454, 455 },
      -1,
   } },

   /* replace2154_0 -> 81 in the cache */
   /* replace2154_1 -> 445 in the cache */
   /* replace2154 -> 446 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2155_0_0 -> 81 in the cache */
   /* search2155_0_1 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 447 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 457, 458 },
      -1,
   } },

   /* replace2155_0 -> 81 in the cache */
   /* replace2155_1 -> 449 in the cache */
   /* replace2155 -> 450 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2156_0 -> 81 in the cache */
   /* search2156_1 -> 447 in the cache */
   /* search2156 -> 457 in the cache */

   /* replace2156_0 -> 81 in the cache */
   /* replace2156_1 -> 449 in the cache */
   /* replace2156 -> 450 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2157_0 -> 81 in the cache */
   /* search2157_1 -> 443 in the cache */
   /* search2157 -> 454 in the cache */

   /* replace2157_0 -> 81 in the cache */
   /* replace2157_1 -> 441 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2158_0_0 -> 0 in the cache */
   /* search2158_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2158_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 461, 1 },
      -1,
   } },

   /* replace2158_0 -> 0 in the cache */
   /* replace2158_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2159_0_0 -> 0 in the cache */
   /* search2159_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2159_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 464, 1 },
      -1,
   } },

   /* replace2159_0 -> 0 in the cache */
   /* replace2159_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2160_0_0 -> 134 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2160_1_0 -> 135 in the cache */
   /* search2160_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 468, 469 },
      -1,
   } },

   /* replace2160_0_0 -> 134 in the cache */
   /* replace2160_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 134, 135 },
      -1,
   } },
   /* replace2160_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2161_0_0 -> 134 in the cache */
   /* search2161_0_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2161_1_0 -> 135 in the cache */
   /* search2161_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 473, 474 },
      -1,
   } },

   /* replace2161_0_0 -> 134 in the cache */
   /* replace2161_0_1 -> 135 in the cache */
   /* replace2161_0 -> 471 in the cache */
   /* replace2161_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2162_0_0 -> 61 in the cache */
   /* search2162_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2162_1_0 -> 62 in the cache */
   /* search2162_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 477, 478 },
      -1,
   } },

   /* replace2162_0_0 -> 61 in the cache */
   /* replace2162_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2162_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2163_0_0 -> 61 in the cache */
   /* search2163_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2163_1_0 -> 62 in the cache */
   /* search2163_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 482, 483 },
      -1,
   } },

   /* replace2163_0_0 -> 61 in the cache */
   /* replace2163_0_1 -> 62 in the cache */
   /* replace2163_0 -> 480 in the cache */
   /* replace2163_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2164_0_0 -> 81 in the cache */
   /* search2164_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2164_1_0 -> 82 in the cache */
   /* search2164_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 486, 487 },
      -1,
   } },

   /* replace2164_0_0 -> 81 in the cache */
   /* replace2164_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 81, 82 },
      -1,
   } },
   /* replace2164_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2165_0_0 -> 81 in the cache */
   /* search2165_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2165_1_0 -> 82 in the cache */
   /* search2165_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 491, 492 },
      -1,
   } },

   /* replace2165_0_0 -> 81 in the cache */
   /* replace2165_0_1 -> 82 in the cache */
   /* replace2165_0 -> 489 in the cache */
   /* replace2165_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2166_0_0 -> 114 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2166_1_0 -> 115 in the cache */
   /* search2166_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 496, 497 },
      -1,
   } },

   /* replace2166_0_0 -> 114 in the cache */
   /* replace2166_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 114, 115 },
      -1,
   } },
   /* replace2166_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2167_0_0 -> 114 in the cache */
   /* search2167_0_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2167_1_0 -> 115 in the cache */
   /* search2167_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 501, 502 },
      -1,
   } },

   /* replace2167_0_0 -> 114 in the cache */
   /* replace2167_0_1 -> 115 in the cache */
   /* replace2167_0 -> 499 in the cache */
   /* replace2167_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2168_0 -> 177 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2168_1_1_0 -> 62 in the cache */
   /* search2168_1_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 505, 506 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 177, 507 },
      -1,
   } },

   /* replace2168_0_0 -> 177 in the cache */
   /* replace2168_0_1_0 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 177, 509 },
      -1,
   } },
   /* replace2168_1_0 -> 62 in the cache */
   /* replace2168_1_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 510, 511 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2169_1 -> 416 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 416, 516 },
      -1,
   } },

   /* replace2169_0_0_0 -> 513 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 513, 518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2170_0 -> 268 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2170_1_1_0 -> 82 in the cache */
   /* search2170_1_1_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 82, 266 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 522, 523 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 268, 524 },
      -1,
   } },

   /* replace2170_0_0 -> 268 in the cache */
   /* replace2170_0_1_0 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 268, 526 },
      -1,
   } },
   /* replace2170_1_0 -> 82 in the cache */
   /* replace2170_1_1 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 82, 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 527, 528 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2171_0 -> 513 in the cache */
   /* search2171_1 -> 385 in the cache */
   /* search2171_2_0_0 -> 514 in the cache */
   /* search2171_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 385, 530 },
      -1,
   } },

   /* replace2171_0_0_0 -> 513 in the cache */
   /* replace2171_0_0_1 -> 518 in the cache */
   /* replace2171_0_0 -> 519 in the cache */
   /* replace2171_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2172_1_1_0 -> 115 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 115, 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 534, 536 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 533, 537 },
      -1,
   } },

   /* replace2172_0_0 -> 533 in the cache */
   /* replace2172_0_1_0 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 533, 539 },
      -1,
   } },
   /* replace2172_1_0 -> 115 in the cache */
   /* replace2172_1_1 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 115, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 540, 541 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2173_0 -> 513 in the cache */
   /* search2173_1 -> 495 in the cache */
   /* search2173_2_0_0 -> 514 in the cache */
   /* search2173_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 495, 543 },
      -1,
   } },

   /* replace2173_0_0_0 -> 513 in the cache */
   /* replace2173_0_0_1 -> 518 in the cache */
   /* replace2173_0_0 -> 519 in the cache */
   /* replace2173_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2174_0 -> 513 in the cache */
   /* search2174_1_0 -> 202 in the cache */
   /* search2174_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      0,
   } },
   /* search2174_2_0 -> 202 in the cache */
   /* search2174_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 546, 547 },
      -1,
   } },

   /* replace2174_0 -> 202 in the cache */
   /* replace2174_1_0 -> 513 in the cache */
   /* replace2174_1_1 -> 204 in the cache */
   /* replace2174_1_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 549 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2175_0 -> 513 in the cache */
   /* search2175_1_0 -> 202 in the cache */
   /* search2175_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      -1,
   } },
   /* search2175_2_0 -> 202 in the cache */
   /* search2175_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 551, 552 },
      -1,
   } },

   /* replace2175_0 -> 202 in the cache */
   /* replace2175_1_0 -> 513 in the cache */
   /* replace2175_1_1 -> 204 in the cache */
   /* replace2175_1_2 -> 205 in the cache */
   /* replace2175_1 -> 549 in the cache */
   /* replace2175 -> 550 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2176_0 -> 513 in the cache */
   /* search2176_1_0 -> 336 in the cache */
   /* search2176_1_1 -> 343 in the cache */
   /* search2176_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      0,
   } },
   /* search2176_2_0 -> 336 in the cache */
   /* search2176_2_1 -> 343 in the cache */
   /* search2176_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 555 },
      -1,
   } },

   /* replace2176_0 -> 336 in the cache */
   /* replace2176_1 -> 343 in the cache */
   /* replace2176_2_0 -> 513 in the cache */
   /* replace2176_2_1 -> 344 in the cache */
   /* replace2176_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 557 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2177_0 -> 513 in the cache */
   /* search2177_1_0 -> 336 in the cache */
   /* search2177_1_1 -> 343 in the cache */
   /* search2177_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      -1,
   } },
   /* search2177_2_0 -> 336 in the cache */
   /* search2177_2_1 -> 343 in the cache */
   /* search2177_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 560 },
      -1,
   } },

   /* replace2177_0 -> 336 in the cache */
   /* replace2177_1 -> 343 in the cache */
   /* replace2177_2_0 -> 513 in the cache */
   /* replace2177_2_1 -> 344 in the cache */
   /* replace2177_2_2 -> 345 in the cache */
   /* replace2177_2 -> 557 in the cache */
   /* replace2177 -> 558 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2178_0 -> 513 in the cache */
   /* search2178_1_0 -> 336 in the cache */
   /* search2178_1_1 -> 343 in the cache */
   /* search2178_1_2 -> 344 in the cache */
   /* search2178_1 -> 554 in the cache */
   /* search2178_2_0 -> 336 in the cache */
   /* search2178_2_1 -> 345 in the cache */
   /* search2178_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 562 },
      -1,
   } },

   /* replace2178_0 -> 336 in the cache */
   /* replace2178_1_0 -> 513 in the cache */
   /* replace2178_1_1 -> 343 in the cache */
   /* replace2178_1_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 343, 345 },
      -1,
   } },
   /* replace2178_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 564, 344 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2179_0 -> 513 in the cache */
   /* search2179_1_0 -> 336 in the cache */
   /* search2179_1_1 -> 343 in the cache */
   /* search2179_1_2 -> 344 in the cache */
   /* search2179_1 -> 559 in the cache */
   /* search2179_2_0 -> 336 in the cache */
   /* search2179_2_1 -> 345 in the cache */
   /* search2179_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 566 },
      -1,
   } },

   /* replace2179_0 -> 336 in the cache */
   /* replace2179_1_0 -> 513 in the cache */
   /* replace2179_1_1 -> 343 in the cache */
   /* replace2179_1_2 -> 345 in the cache */
   /* replace2179_1 -> 564 in the cache */
   /* replace2179_2 -> 344 in the cache */
   /* replace2179 -> 565 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2180_0 -> 513 in the cache */
   /* search2180_1_0 -> 82 in the cache */
   /* search2180_1_1 -> 84 in the cache */
   /* search2180_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      0,
   } },
   /* search2180_2_0 -> 82 in the cache */
   /* search2180_2_1 -> 84 in the cache */
   /* search2180_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 569 },
      -1,
   } },

   /* replace2180_0 -> 82 in the cache */
   /* replace2180_1 -> 84 in the cache */
   /* replace2180_2_0 -> 513 in the cache */
   /* replace2180_2_1 -> 356 in the cache */
   /* replace2180_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 571 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2181_0 -> 513 in the cache */
   /* search2181_1_0 -> 82 in the cache */
   /* search2181_1_1 -> 84 in the cache */
   /* search2181_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      -1,
   } },
   /* search2181_2_0 -> 82 in the cache */
   /* search2181_2_1 -> 84 in the cache */
   /* search2181_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 574 },
      -1,
   } },

   /* replace2181_0 -> 82 in the cache */
   /* replace2181_1 -> 84 in the cache */
   /* replace2181_2_0 -> 513 in the cache */
   /* replace2181_2_1 -> 356 in the cache */
   /* replace2181_2_2 -> 364 in the cache */
   /* replace2181_2 -> 571 in the cache */
   /* replace2181 -> 572 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2182_0 -> 513 in the cache */
   /* search2182_1_0 -> 82 in the cache */
   /* search2182_1_1 -> 84 in the cache */
   /* search2182_1_2 -> 356 in the cache */
   /* search2182_1 -> 568 in the cache */
   /* search2182_2_0 -> 82 in the cache */
   /* search2182_2_1 -> 364 in the cache */
   /* search2182_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 576 },
      -1,
   } },

   /* replace2182_0 -> 82 in the cache */
   /* replace2182_1_0 -> 513 in the cache */
   /* replace2182_1_1 -> 84 in the cache */
   /* replace2182_1_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 84, 364 },
      -1,
   } },
   /* replace2182_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 578, 356 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2183_0 -> 513 in the cache */
   /* search2183_1_0 -> 82 in the cache */
   /* search2183_1_1 -> 84 in the cache */
   /* search2183_1_2 -> 356 in the cache */
   /* search2183_1 -> 573 in the cache */
   /* search2183_2_0 -> 82 in the cache */
   /* search2183_2_1 -> 364 in the cache */
   /* search2183_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 580 },
      -1,
   } },

   /* replace2183_0 -> 82 in the cache */
   /* replace2183_1_0 -> 513 in the cache */
   /* replace2183_1_1 -> 84 in the cache */
   /* replace2183_1_2 -> 364 in the cache */
   /* replace2183_1 -> 578 in the cache */
   /* replace2183_2 -> 356 in the cache */
   /* replace2183 -> 579 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2184_0_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 583 },
      -1,
   } },

   /* replace2184_0 -> 81 in the cache */
   /* replace2184 -> 93 in the cache */

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2185_0_0_0 -> 81 in the cache */
   /* search2185_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 585 },
      -1,
   } },

   /* replace2185_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2186_0_0_0 -> 81 in the cache */
   /* search2186_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 588 },
      -1,
   } },

   /* replace2186_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2187_0_0_0 -> 81 in the cache */
   /* search2187_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 591 },
      -1,
   } },

   /* replace2187_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2188_0_0_0 -> 81 in the cache */
   /* search2188_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 594 },
      -1,
   } },

   /* replace2188_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2189_0_0_0 -> 81 in the cache */
   /* search2189_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 597 },
      -1,
   } },

   /* replace2189_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2190_0_0_0 -> 81 in the cache */
   /* search2190_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 600 },
      -1,
   } },

   /* replace2190_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2191_0_0_0 -> 81 in the cache */
   /* search2191_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 603 },
      -1,
   } },

   /* replace2191_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2192_0_0_0 -> 81 in the cache */
   /* search2192_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 606 },
      -1,
   } },

   /* replace2192_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2193_0_0_0 -> 81 in the cache */
   /* search2193_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 609 },
      -1,
   } },

   /* replace2193_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2194_0_0_0 -> 81 in the cache */
   /* search2194_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 612 },
      -1,
   } },

   /* replace2194_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2195_0_0_0 -> 81 in the cache */
   /* search2195_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 615 },
      -1,
   } },

   /* replace2195_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2196_0_0_0 -> 81 in the cache */
   /* search2196_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 618 },
      -1,
   } },

   /* replace2196_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2197_0_0_0 -> 81 in the cache */
   /* search2197_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 621 },
      -1,
   } },

   /* replace2197_0 -> 81 in the cache */
   /* replace2197 -> 89 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2198_0_0_0 -> 81 in the cache */
   /* search2198_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 623 },
      -1,
   } },

   /* replace2198_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2199_0_0_0 -> 81 in the cache */
   /* search2199_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 626 },
      -1,
   } },

   /* replace2199_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2200_0_0_0 -> 81 in the cache */
   /* search2200_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 629 },
      -1,
   } },

   /* replace2200_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2201_0_0_0 -> 81 in the cache */
   /* search2201_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 632 },
      -1,
   } },

   /* replace2201_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2202_0_0_0 -> 81 in the cache */
   /* search2202_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 635 },
      -1,
   } },

   /* replace2202_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2203_0_0_0 -> 81 in the cache */
   /* search2203_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 638 },
      -1,
   } },

   /* replace2203_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2204_0_0_0 -> 81 in the cache */
   /* search2204_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 641 },
      -1,
   } },

   /* replace2204_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2205_0_0_0 -> 81 in the cache */
   /* search2205_0_0 -> 582 in the cache */
   /* search2205_0_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 645 },
      -1,
   } },

   /* replace2205_0 -> 81 in the cache */
   /* replace2205_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2206_0_0_0 -> 81 in the cache */
   /* search2206_0_0 -> 582 in the cache */
   /* search2206_0_1_0 -> 82 in the cache */
   /* search2206_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 648 },
      -1,
   } },

   /* replace2206_0 -> 81 in the cache */
   /* replace2206_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2207_0_0_0 -> 81 in the cache */
   /* search2207_0_0 -> 582 in the cache */
   /* search2207_0_1_0 -> 82 in the cache */
   /* search2207_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 651 },
      -1,
   } },

   /* replace2207_0 -> 81 in the cache */
   /* replace2207_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2208_0_0_0 -> 81 in the cache */
   /* search2208_0_0 -> 582 in the cache */
   /* search2208_0_1_0 -> 82 in the cache */
   /* search2208_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 654 },
      -1,
   } },

   /* replace2208_0 -> 81 in the cache */
   /* replace2208_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2209_0_0_0 -> 81 in the cache */
   /* search2209_0_0 -> 582 in the cache */
   /* search2209_0_1_0 -> 82 in the cache */
   /* search2209_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 657 },
      -1,
   } },

   /* replace2209_0 -> 81 in the cache */
   /* replace2209_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2210_0_0_0 -> 81 in the cache */
   /* search2210_0_0 -> 582 in the cache */
   /* search2210_0_1_0 -> 82 in the cache */
   /* search2210_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 660 },
      -1,
   } },

   /* replace2210_0 -> 81 in the cache */
   /* replace2210_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2211_0_0_0 -> 81 in the cache */
   /* search2211_0_0 -> 582 in the cache */
   /* search2211_0_1_0 -> 82 in the cache */
   /* search2211_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 663 },
      -1,
   } },

   /* replace2211_0 -> 81 in the cache */
   /* replace2211_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2212_0_0_0 -> 81 in the cache */
   /* search2212_0_0 -> 582 in the cache */
   /* search2212_0_1_0 -> 82 in the cache */
   /* search2212_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 666 },
      -1,
   } },

   /* replace2212_0 -> 81 in the cache */
   /* replace2212_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2213_0_0_0 -> 81 in the cache */
   /* search2213_0_0 -> 582 in the cache */
   /* search2213_0_1_0 -> 82 in the cache */
   /* search2213_0_1 -> 644 in the cache */
   /* search2213_0_2_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 670 },
      -1,
   } },

   /* replace2213_0 -> 81 in the cache */
   /* replace2213_1 -> 82 in the cache */
   /* replace2213_2 -> 84 in the cache */
   /* replace2213 -> 86 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2214_0_0_0 -> 81 in the cache */
   /* search2214_0_0 -> 582 in the cache */
   /* search2214_0_1_0 -> 82 in the cache */
   /* search2214_0_1 -> 644 in the cache */
   /* search2214_0_2_0 -> 84 in the cache */
   /* search2214_0_2 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 672 },
      -1,
   } },

   /* replace2214_0 -> 81 in the cache */
   /* replace2214_1 -> 82 in the cache */
   /* replace2214_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2215_0_0 -> 81 in the cache */
   /* search2215_0 -> 582 in the cache */
   /* search2215_1_0 -> 82 in the cache */
   /* search2215_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2215_0 -> 81 in the cache */
   /* replace2215_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2216_0_0 -> 81 in the cache */
   /* search2216_0 -> 582 in the cache */
   /* search2216_1_0 -> 82 in the cache */
   /* search2216_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2216_0 -> 81 in the cache */
   /* replace2216_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2217_0_0 -> 81 in the cache */
   /* search2217_0 -> 582 in the cache */
   /* search2217_1_0 -> 82 in the cache */
   /* search2217_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2217_0 -> 81 in the cache */
   /* replace2217_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2218_0_0 -> 81 in the cache */
   /* search2218_0 -> 582 in the cache */
   /* search2218_1_0 -> 82 in the cache */
   /* search2218_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2218_0 -> 81 in the cache */
   /* replace2218_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2219_0 -> 81 in the cache */
   /* search2219 -> 582 in the cache */

   /* replace2219_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2220_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2220_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2221_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2221_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2222_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2222_0 -> 81 in the cache */
   /* replace2222 -> 431 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2223_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2223_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2224_0 -> 81 in the cache */
   /* search2224 -> 688 in the cache */

   /* replace2224_0 -> 81 in the cache */
   /* replace2224 -> 428 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2225_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2225_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2226_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2226_0_0 -> 42 in the cache */
   /* replace2226_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 694 },
      -1,
   } },

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2227_0_0 -> 385 in the cache */
   /* search2227_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2227_1 -> 82 in the cache */
   /* search2227_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 696, 82, 84 },
      -1,
   } },

   /* replace2227_0 -> 81 in the cache */
   /* replace2227_1 -> 82 in the cache */
   /* replace2227_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2228_0_0 -> 81 in the cache */
   /* search2228_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2228_1 -> 82 in the cache */
   /* search2228_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 699, 82, 84 },
      -1,
   } },

   /* replace2228_0_0 -> 81 in the cache */
   /* replace2228_0 -> 89 in the cache */
   /* replace2228_1 -> 82 in the cache */
   /* replace2228_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2229_0_0 -> 81 in the cache */
   /* search2229_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2229_1 -> 82 in the cache */
   /* search2229_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 702, 82, 84 },
      -1,
   } },

   /* replace2229_0 -> 81 in the cache */
   /* replace2229_1 -> 82 in the cache */
   /* replace2229_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2230_0_0 -> 385 in the cache */
   /* search2230_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2230_1 -> 82 in the cache */
   /* search2230_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 705, 82, 84 },
      -1,
   } },

   /* replace2230_0_0 -> 81 in the cache */
   /* replace2230_0 -> 89 in the cache */
   /* replace2230_1 -> 82 in the cache */
   /* replace2230_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search2231_0_0 -> 385 in the cache */
   /* search2231_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2231_1 -> 82 in the cache */
   /* search2231_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 708, 82, 84 },
      -1,
   } },

   /* replace2231_0 -> 81 in the cache */
   /* replace2231_1 -> 82 in the cache */
   /* replace2231_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search2232_0_0 -> 81 in the cache */
   /* search2232_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2232_1 -> 82 in the cache */
   /* search2232_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 711, 82, 84 },
      -1,
   } },

   /* replace2232_0 -> 81 in the cache */
   /* replace2232_1 -> 84 in the cache */
   /* replace2232_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search2233_0_0 -> 81 in the cache */
   /* search2233_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2233_1 -> 82 in the cache */
   /* search2233_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 714, 82, 84 },
      -1,
   } },

   /* replace2233_0 -> 81 in the cache */
   /* replace2233_1 -> 82 in the cache */
   /* replace2233_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search2234_0_0 -> 385 in the cache */
   /* search2234_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2234_1 -> 82 in the cache */
   /* search2234_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 717, 82, 84 },
      -1,
   } },

   /* replace2234_0 -> 81 in the cache */
   /* replace2234_1 -> 84 in the cache */
   /* replace2234_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2235_0_0 -> 385 in the cache */
   /* search2235_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2235_1 -> 82 in the cache */
   /* search2235_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 720, 82, 84 },
      -1,
   } },

   /* replace2235_0 -> 81 in the cache */
   /* replace2235_1 -> 82 in the cache */
   /* replace2235_2 -> 84 in the cache */
   /* replace2235 -> 698 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2236_0_0 -> 81 in the cache */
   /* search2236_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2236_1 -> 82 in the cache */
   /* search2236_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 722, 82, 84 },
      -1,
   } },

   /* replace2236_0_0 -> 81 in the cache */
   /* replace2236_0 -> 89 in the cache */
   /* replace2236_1 -> 82 in the cache */
   /* replace2236_2 -> 84 in the cache */
   /* replace2236 -> 701 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2237_0_0 -> 81 in the cache */
   /* search2237_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2237_1 -> 82 in the cache */
   /* search2237_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 724, 82, 84 },
      -1,
   } },

   /* replace2237_0 -> 81 in the cache */
   /* replace2237_1 -> 82 in the cache */
   /* replace2237_2 -> 84 in the cache */
   /* replace2237 -> 704 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2238_0_0 -> 385 in the cache */
   /* search2238_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2238_1 -> 82 in the cache */
   /* search2238_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 726, 82, 84 },
      -1,
   } },

   /* replace2238_0_0 -> 81 in the cache */
   /* replace2238_0 -> 89 in the cache */
   /* replace2238_1 -> 82 in the cache */
   /* replace2238_2 -> 84 in the cache */
   /* replace2238 -> 707 in the cache */

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_by_fadd),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 157, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 243, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 246, 247, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { 390, 395, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { 396, 400, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 457, 450, 129 },
   { 454, 460, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 404, 42, 0 },
   { 405, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 406, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 582, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 684, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 686, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 688, 431, 0 },
   { 688, 428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 689, 690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 691, 692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 693, 695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 131 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 131 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 131 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 131 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 131 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 131 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 131 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 131 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 131 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 131 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 131 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 131 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 131 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 131 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 131 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 131 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 215, 216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 679, 680, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 192, 0 },
   { 199, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 677, 678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 676, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 681, 682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 102, 103, 32 },
   { 118, 119, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 182, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 124 },
   { 180, 182, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 453, 442, 129 },
   { 456, 446, 129 },
   { 459, 450, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 470, 472, 0 },
   { 479, 481, 0 },
   { 488, 490, 0 },
   { 498, 500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { 475, 476, 0 },
   { 484, 485, 0 },
   { 493, 494, 0 },
   { 503, 504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 120 },
   { 162, 166, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 123 },
   { 168, 170, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 120 },
   { 168, 170, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 173, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 409, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 411, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 412, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 413, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 440, 442, 129 },
   { 444, 446, 129 },
   { 448, 450, 129 },
   { 457, 450, 129 },
   { 454, 460, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 415, 417, 57 },
   { 424, 425, 57 },
   { 429, 430, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 419, 417, 57 },
   { 427, 425, 57 },
   { 432, 430, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 420, 421, 57 },
   { 433, 434, 57 },
   { 436, 437, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 422, 421, 57 },
   { 435, 434, 57 },
   { 438, 437, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 465, 466, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 700, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 131 },
   { 700, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 706, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 131 },
   { 706, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 239, 241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 68, 70, 31 },
   { 85, 86, 32 },
   { 88, 90, 32 },
   { 118, 119, 33 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 105, 106, 32 },
   { 118, 119, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 72, 75, 31 },
   { 85, 86, 32 },
   { 92, 95, 32 },
   { 118, 119, 33 },
   { 125, 128, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 108, 109, 32 },
   { 118, 119, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 102, 103, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 102, 103, 32 },
   { 125, 128, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 108, 109, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 105, 106, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 72, 75, 31 },
   { 88, 90, 32 },
   { 92, 95, 32 },
   { 121, 123, 33 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 108, 109, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 105, 106, 32 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 108, 109, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 127 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 108, 109, 32 },
   { 125, 128, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 622, 89, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 656, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 673, 674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 661, 662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 652, 653, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 646, 647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 671, 86, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 93, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 633, 634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 628, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 642, 643, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 630, 631, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 586, 587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 592, 593, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 595, 596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 598, 599, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 601, 602, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 604, 605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 610, 611, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 619, 620, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 624, 625, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 636, 637, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 649, 650, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 658, 659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 664, 665, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 667, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 131 },
   { 723, 701, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 131 },
   { 727, 707, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 131 },
   { 712, 713, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 131 },
   { 718, 719, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 317, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 78, 80, 31 },
   { 85, 86, 32 },
   { 98, 100, 32 },
   { 118, 119, 33 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 112, 113, 32 },
   { 118, 119, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 102, 103, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 78, 80, 31 },
   { 88, 90, 32 },
   { 98, 100, 32 },
   { 121, 123, 33 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 112, 113, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 105, 106, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 127 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 127 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 78, 80, 31 },
   { 92, 95, 32 },
   { 98, 100, 32 },
   { 125, 128, 33 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 112, 113, 32 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 108, 109, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 127 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 127 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 127 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 112, 113, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 31 },
   { 85, 86, 32 },
   { 118, 119, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 31 },
   { 88, 90, 32 },
   { 121, 123, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 342, 347, 127 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 31 },
   { 92, 95, 32 },
   { 125, 128, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { 375, 377, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 375, 377, 127 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 328, 334, 127 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 31 },
   { 98, 100, 32 },
   { 131, 133, 33 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 32 },
   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { 363, 369, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 363, 369, 127 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 117 },
   { 140, 141, 117 },
   { 143, 144, 117 },
   { 146, 147, 118 },
   { 349, 355, 127 },
   { 379, 384, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         121,
         122,
         123,
         3,
         241,
         0,
         124,
         0,
         0,
         0,
         0,
         0,
         0,
         125,
         0,
         126,
         0,
         0,
         126,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         127,
         0,
         0,
         242,
         0,
         126,
         0,
         0,
         126,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         8,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         3,
         11,
         4,
         10,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         12,
         0,
         12,
         16,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         5,
         6,
         165,
         166,
         166,
         167,
         5,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         6,
         6,
         168,
         169,
         170,
         171,
         6,
         252,
         253,
         254,
         255,
         256,
         257,
         258,
         259,
         260,
         360,
         361,
         362,
         363,
         408,
         409,
         165,
         168,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         169,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         170,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         167,
         171,
         173,
         174,
         174,
         167,
         167,
         271,
         272,
         173,
         174,
         174,
         273,
         274,
         275,
         276,
         370,
         371,
         372,
         373,
         412,
         413,
         5,
         6,
         165,
         166,
         166,
         167,
         175,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         246,
         252,
         246,
         265,
         265,
         271,
         246,
         246,
         277,
         246,
         265,
         265,
         278,
         279,
         280,
         281,
         374,
         375,
         376,
         377,
         414,
         415,
         247,
         253,
         247,
         266,
         266,
         272,
         247,
         277,
         247,
         247,
         266,
         266,
         282,
         283,
         284,
         285,
         378,
         379,
         380,
         381,
         416,
         417,
         165,
         254,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         255,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         256,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         248,
         257,
         261,
         267,
         267,
         273,
         248,
         278,
         282,
         261,
         267,
         267,
         248,
         286,
         287,
         288,
         382,
         383,
         384,
         385,
         418,
         419,
         249,
         258,
         262,
         268,
         268,
         274,
         249,
         279,
         283,
         262,
         268,
         268,
         286,
         249,
         289,
         290,
         386,
         387,
         388,
         389,
         420,
         421,
         250,
         259,
         263,
         269,
         269,
         275,
         250,
         280,
         284,
         263,
         269,
         269,
         287,
         289,
         250,
         291,
         390,
         391,
         392,
         393,
         422,
         423,
         251,
         260,
         264,
         270,
         270,
         276,
         251,
         281,
         285,
         264,
         270,
         270,
         288,
         290,
         291,
         251,
         394,
         395,
         396,
         397,
         424,
         425,
         356,
         360,
         364,
         366,
         366,
         370,
         356,
         374,
         378,
         364,
         366,
         366,
         382,
         386,
         390,
         394,
         356,
         398,
         399,
         400,
         426,
         427,
         357,
         361,
         357,
         367,
         367,
         371,
         357,
         375,
         379,
         357,
         367,
         367,
         383,
         387,
         391,
         395,
         398,
         357,
         401,
         402,
         428,
         429,
         358,
         362,
         358,
         368,
         368,
         372,
         358,
         376,
         380,
         358,
         368,
         368,
         384,
         388,
         392,
         396,
         399,
         401,
         358,
         403,
         430,
         431,
         359,
         363,
         365,
         369,
         369,
         373,
         359,
         377,
         381,
         365,
         369,
         369,
         385,
         389,
         393,
         397,
         400,
         402,
         403,
         359,
         432,
         433,
         406,
         408,
         406,
         410,
         410,
         412,
         406,
         414,
         416,
         406,
         410,
         410,
         418,
         420,
         422,
         424,
         426,
         428,
         430,
         432,
         406,
         434,
         407,
         409,
         407,
         411,
         411,
         413,
         407,
         415,
         417,
         407,
         411,
         411,
         419,
         421,
         423,
         425,
         427,
         429,
         431,
         433,
         434,
         407,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         2,
         2,
         10,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         7,
         128,
         129,
         130,
         131,
         132,
         133,
         353,
         354,
         404,
         405,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         134,
         135,
         9,
         9,
         243,
         9,
         0,
         136,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         137,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         139,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         140,
         0,
         0,
         0,
         244,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         245,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         11,
         12,
         11,
         11,
         11,
         11,
         11,
         12,
         12,
         141,
         142,
         143,
         144,
         12,
         11,
         141,
         11,
         11,
         11,
         11,
         11,
         11,
         142,
         11,
         145,
         11,
         11,
         11,
         11,
         143,
         11,
         11,
         11,
         11,
         11,
         11,
         144,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         11,
         11,
         11,
         11,
         146,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         13,
         14,
         13,
         13,
         13,
         13,
         14,
         14,
         147,
         148,
         149,
         14,
         13,
         147,
         13,
         13,
         13,
         13,
         13,
         148,
         13,
         150,
         13,
         13,
         13,
         149,
         13,
         13,
         13,
         13,
         13,
         14,
         13,
         13,
         13,
         151,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         182,
         15,
         15,
         15,
         15,
         183,
         15,
         184,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         351,
         15,
         15,
         184,
         15,
         15,
         15,
         15,
         351,
         15,
         182,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         185,
         15,
         15,
         15,
         15,
         351,
         351,
         15,
         15,
         15,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         352,
         16,
         16,
         16,
         186,
         16,
         352,
         16,
         16,
         186,
         187,
         16,
         16,
         16,
         16,
         16,
         16,
         188,
         16,
         16,
         352,
         352,
         16,
         16,
         16,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         2,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         17,
         18,
         157,
         158,
         17,
         348,
         18,
         18,
         159,
         160,
         18,
         349,
         157,
         159,
         157,
         161,
         157,
         348,
         158,
         160,
         161,
         158,
         158,
         350,
         17,
         18,
         157,
         158,
         162,
         348,
         348,
         349,
         348,
         350,
         348,
         348,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         189,
         190,
         191,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         20,
         193,
         194,
         195,
         193,
         193,
         196,
         197,
         194,
         196,
         194,
         198,
         195,
         197,
         198,
         195,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         23,
         23,
         199,
         199,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         176,
         177,
         178,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         24,
         212,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         152,
         152,
         0,
         0,
         152,
         153,
         0,
         0,
         0,
         0,
         154,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         25,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         26,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         27,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         28,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         155,
         155,
         155,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         156,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         29,
         213,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         2,
         2,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         181,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         163,
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         5,
         5,
         0,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         7,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         335,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         74,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         75,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         76,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         336,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         78,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         79,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         80,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         337,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         82,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         83,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         84,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         338,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         86,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         87,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         88,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         339,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         90,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         91,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         92,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         340,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         94,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         95,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         96,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         341,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         98,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         99,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         100,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         342,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         102,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         103,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         104,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         343,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         106,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         107,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         108,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         344,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         111,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         112,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         345,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         114,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         115,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         116,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         346,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         118,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         119,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         120,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         347,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         32,
         214,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         215,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         35,
         0,
         36,
         0,
         35,
         0,
         36,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         37,
         0,
         38,
         0,
         37,
         0,
         38,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         39,
         0,
         0,
         39,
         0,
         0,
         204,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         0,
         41,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         200,
         42,
         42,
         42,
         201,
         42,
         42,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         43,
         44,
         43,
         43,
         43,
         44,
         43,
         43,
         43,
         202,
         43,
         43,
         43,
         203,
         43,
         43,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         45,
         206,
         207,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         46,
         208,
         209,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         205,
         205,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         210,
         210,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         47,
         0,
         47,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         48,
         48,
         48,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         211,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         303,
         304,
         305,
         306,
         307,
         308,
         309,
         310,
         311,
         312,
         313,
         314,
         315,
         316,
         317,
         318,
         319,
         320,
         321,
         322,
         323,
         324,
         325,
         326,
         327,
         328,
         329,
         330,
         331,
         332,
         333,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         51,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         216,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         217,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         218,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         219,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         220,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         221,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         222,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         223,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         224,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         225,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         226,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         227,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         228,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         229,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         230,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         231,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         232,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         233,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         234,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         52,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         53,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         54,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         55,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         56,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         57,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         58,
         59,
         60,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         61,
         62,
         63,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         64,
         65,
         66,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         67,
         68,
         69,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   19,
   0,
   21,
   0,
   0,
   0,
   26,
   28,
   31,
   33,
   36,
   41,
   44,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   46,
   48,
   50,
   52,
   55,
   57,
   59,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   61,
   64,
   69,
   74,
   76,
   80,
   86,
   92,
   94,
   98,
   104,
   110,
   113,
   118,
   125,
   132,
   134,
   138,
   144,
   150,
   152,
   156,
   162,
   168,
   171,
   176,
   183,
   190,
   192,
   196,
   202,
   208,
   210,
   214,
   220,
   226,
   229,
   234,
   241,
   248,
   250,
   254,
   260,
   266,
   268,
   272,
   278,
   284,
   287,
   292,
   299,
   306,
   308,
   310,
   312,
   314,
   316,
   318,
   320,
   322,
   325,
   327,
   329,
   331,
   333,
   336,
   338,
   341,
   343,
   345,
   348,
   350,
   353,
   355,
   0,
   357,
   359,
   361,
   364,
   366,
   368,
   370,
   0,
   372,
   0,
   374,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   376,
   0,
   378,
   383,
   387,
   389,
   394,
   398,
   406,
   408,
   416,
   422,
   0,
   427,
   429,
   431,
   0,
   434,
   0,
   436,
   441,
   443,
   446,
   452,
   455,
   457,
   0,
   0,
   0,
   0,
   463,
   465,
   467,
   469,
   472,
   475,
   478,
   480,
   482,
   484,
   486,
   488,
   496,
   498,
   502,
   506,
   510,
   514,
   0,
   0,
   516,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   518,
   520,
   522,
   525,
   527,
   529,
   532,
   535,
   538,
   542,
   546,
   548,
   556,
   562,
   564,
   568,
   570,
   572,
   580,
   586,
   592,
   599,
   610,
   612,
   616,
   618,
   620,
   626,
   634,
   640,
   646,
   657,
   666,
   671,
   678,
   683,
   688,
   697,
   704,
   707,
   712,
   715,
   718,
   727,
   736,
   747,
   756,
   765,
   772,
   781,
   788,
   795,
   800,
   803,
   806,
   811,
   816,
   0,
   819,
   821,
   823,
   825,
   827,
   829,
   832,
   838,
   841,
   844,
   847,
   849,
   851,
   853,
   855,
   857,
   859,
   861,
   863,
   865,
   867,
   869,
   871,
   873,
   875,
   877,
   879,
   881,
   883,
   885,
   887,
   889,
   891,
   893,
   895,
   897,
   899,
   901,
   903,
   905,
   907,
   909,
   913,
   918,
   923,
   929,
   934,
   939,
   945,
   950,
   955,
   961,
   966,
   971,
   977,
   979,
   981,
   983,
   985,
   988,
   991,
   993,
   0,
   995,
   997,
   1005,
   1011,
   1013,
   1015,
   1023,
   1029,
   1031,
   1037,
   1043,
   1048,
   1059,
   1068,
   1073,
   1076,
   1085,
   1092,
   1095,
   1104,
   1115,
   1124,
   1133,
   1140,
   1149,
   1156,
   1163,
   1166,
   1175,
   1182,
   1185,
   1190,
   1201,
   1210,
   1215,
   1218,
   1227,
   1234,
   1237,
   1240,
   1249,
   1256,
   1259,
   1268,
   1275,
   1278,
   1287,
   1296,
   1303,
   1305,
   1307,
   1313,
   1319,
   1325,
   1331,
   1340,
   1349,
   1356,
   1363,
   1372,
   1381,
   1388,
   1395,
   1402,
   1409,
   1418,
   1427,
   1434,
   1441,
   1448,
   1455,
   1462,
   1469,
   1478,
   1487,
   1494,
   1501,
   1508,
   1515,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[132];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(728 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = options->lower_ffloor || ((options->lower_doubles_options & nir_lower_dfloor) && !(options->lower_doubles_options & nir_lower_dfloor));
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[25] = options->lower_ffract;
   condition_flags[26] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[27] = options->lower_fceil;
   condition_flags[28] = options->lower_ffma16;
   condition_flags[29] = options->lower_ffma32;
   condition_flags[30] = options->lower_ffma64;
   condition_flags[31] = options->fuse_ffma16;
   condition_flags[32] = options->fuse_ffma32;
   condition_flags[33] = options->fuse_ffma64;
   condition_flags[34] = options->lower_fdph;
   condition_flags[35] = !options->lower_fdph;
   condition_flags[36] = options->lower_fdot;
   condition_flags[37] = !options->lower_fsat;
   condition_flags[38] = !options->lower_iabs;
   condition_flags[39] = options->lower_fsat;
   condition_flags[40] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[41] = !options->lower_fsign;
   condition_flags[42] = options->lower_umax;
   condition_flags[43] = options->lower_umin;
   condition_flags[44] = !options->lower_umax;
   condition_flags[45] = !options->lower_umin;
   condition_flags[46] = options->lower_scmp;
   condition_flags[47] = options->lower_vector_cmp;
   condition_flags[48] = !options->lower_rotate;
   condition_flags[49] = options->lower_rotate;
   condition_flags[50] = options->lower_fpow;
   condition_flags[51] = !options->lower_fpow;
   condition_flags[52] = options->lower_fdiv;
   condition_flags[53] = options->lower_fsqrt;
   condition_flags[54] = !options->lower_fsqrt;
   condition_flags[55] = options->lower_sincos;
   condition_flags[56] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[57] = !options->lower_extract_byte;
   condition_flags[58] = !options->lower_extract_word;
   condition_flags[59] = options->has_pack_32_4x8;
   condition_flags[60] = options->lower_pack_64_2x32_split;
   condition_flags[61] = options->lower_pack_32_2x16_split;
   condition_flags[62] = options->lower_unpack_64_2x32_split;
   condition_flags[63] = options->lower_unpack_32_2x16_split;
   condition_flags[64] = options->has_find_msb_rev;
   condition_flags[65] = !options->lower_find_msb_to_reverse;
   condition_flags[66] = !options->lower_find_lsb;
   condition_flags[67] = options->lower_fmod;
   condition_flags[68] = options->lower_uadd_carry;
   condition_flags[69] = options->lower_usub_borrow;
   condition_flags[70] = options->lower_bitfield_insert;
   condition_flags[71] = options->lower_hadd;
   condition_flags[72] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[73] = options->lower_mul_32x16;
   condition_flags[74] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[75] = options->lower_uadd_sat;
   condition_flags[76] = options->lower_usub_sat;
   condition_flags[77] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[78] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[81] = options->lower_bitfield_insert_to_shifts;
   condition_flags[82] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[83] = options->lower_bitfield_extract;
   condition_flags[84] = options->lower_bitfield_extract_to_shifts;
   condition_flags[85] = options->lower_ifind_msb;
   condition_flags[86] = options->lower_find_msb_to_reverse;
   condition_flags[87] = options->lower_uclz;
   condition_flags[88] = options->lower_find_lsb;
   condition_flags[89] = options->lower_extract_byte;
   condition_flags[90] = options->lower_extract_word;
   condition_flags[91] = options->lower_pack_unorm_2x16;
   condition_flags[92] = options->lower_pack_unorm_4x8;
   condition_flags[93] = options->lower_pack_snorm_2x16;
   condition_flags[94] = options->lower_pack_snorm_4x8;
   condition_flags[95] = options->lower_unpack_unorm_2x16;
   condition_flags[96] = options->lower_unpack_unorm_4x8;
   condition_flags[97] = options->lower_unpack_snorm_2x16;
   condition_flags[98] = options->lower_unpack_snorm_4x8;
   condition_flags[99] = options->lower_pack_split;
   condition_flags[100] = options->lower_isign;
   condition_flags[101] = !options->lower_isign;
   condition_flags[102] = options->lower_fsign;
   condition_flags[103] = !options->has_imul24;
   condition_flags[104] = !options->has_umul24;
   condition_flags[105] = !options->has_umad24;
   condition_flags[106] = options->has_imul24;
   condition_flags[107] = options->has_umad24;
   condition_flags[108] = options->has_umul24;
   condition_flags[109] = options->lower_iadd_sat;
   condition_flags[110] = options->support_8bit_alu;
   condition_flags[111] = options->support_16bit_alu;
   condition_flags[112] = options->lower_ldexp;
   condition_flags[113] = !options->lower_bitfield_reverse;
   condition_flags[114] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[115] = options->lower_fisnormal;
   condition_flags[116] = !options->vectorize_vec2_16bit;
   condition_flags[117] = options->has_fsub;
   condition_flags[118] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[119] = options->lower_fneg;
   condition_flags[120] = options->has_isub || options->lower_ineg;
   condition_flags[121] = options->lower_ineg;
   condition_flags[122] = options->lower_iabs;
   condition_flags[123] = options->has_iadd3;
   condition_flags[124] = options->vectorize_vec2_16bit;
   condition_flags[125] = options->fdot_replicates;
   condition_flags[126] = options->lower_fround_even;
   condition_flags[127] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[128] = options->avoid_ternary_with_two_constants;
   condition_flags[129] = !options->lower_insert_byte;
   condition_flags[130] = !options->lower_insert_word;
   condition_flags[131] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2239_0 -> 0 in the cache */
   /* replace2239_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2240_0 -> 6 in the cache */
   /* replace2240_1 -> 8 in the cache */
   /* replace2240_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2241_0_0 -> 0 in the cache */
   /* search2241_0 -> 1 in the cache */
   /* search2241_1_0 -> 2 in the cache */
   /* search2241_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2241_0 -> 0 in the cache */
   /* replace2241_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2242_0_0 -> 0 in the cache */
   /* search2242_0 -> 1 in the cache */
   /* search2242_1_0 -> 2 in the cache */
   /* search2242_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2242_0 -> 0 in the cache */
   /* replace2242_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2243_0_0 -> 0 in the cache */
   /* search2243_0 -> 1 in the cache */
   /* search2243_1_0 -> 2 in the cache */
   /* search2243_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2243_0 -> 0 in the cache */
   /* replace2243_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2244 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2245_0_0 -> 0 in the cache */
   /* search2245_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2245_0_0 -> 0 in the cache */
   /* replace2245_0 -> 1 in the cache */
   /* replace2245_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2246_0_0 -> 0 in the cache */
   /* search2246_0_1 -> 2 in the cache */
   /* search2246_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2246_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2246_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2247_0_0 -> 6 in the cache */
   /* search2247_0_1 -> 8 in the cache */
   /* search2247_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2247_0_0 -> 6 in the cache */
   /* replace2247_0 -> 7 in the cache */
   /* replace2247_1 -> 8 in the cache */
   /* replace2247_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2248_0_0 -> 6 in the cache */
   /* search2248_0_1 -> 8 in the cache */
   /* search2248_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2248_0_0 -> 6 in the cache */
   /* replace2248_0 -> 7 in the cache */
   /* replace2248_1_0 -> 8 in the cache */
   /* replace2248_1 -> 9 in the cache */
   /* replace2248_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2249_0_0 -> 0 in the cache */
   /* search2249_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2249_0_0 -> 0 in the cache */
   /* replace2249_0 -> 1 in the cache */
   /* replace2249_1_0 -> 2 in the cache */
   /* replace2249_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2250_0_0 -> 0 in the cache */
   /* search2250_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2250_0_0 -> 0 in the cache */
   /* replace2250_0 -> 1 in the cache */
   /* replace2250_1_0 -> 2 in the cache */
   /* replace2250_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2251_0_0 -> 0 in the cache */
   /* search2251_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2251_0_0 -> 0 in the cache */
   /* replace2251_0 -> 1 in the cache */
   /* replace2251_1_0 -> 2 in the cache */
   /* replace2251_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2252_0_0 -> 0 in the cache */
   /* search2252_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2252_0_0 -> 0 in the cache */
   /* replace2252_0 -> 1 in the cache */
   /* replace2252_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2253_0_0 -> 0 in the cache */
   /* search2253_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2253_0_0 -> 0 in the cache */
   /* replace2253_0 -> 1 in the cache */
   /* replace2253_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2254_0_0 -> 0 in the cache */
   /* search2254_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2254_0_0 -> 0 in the cache */
   /* replace2254_0 -> 1 in the cache */
   /* replace2254_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2255_0_0 -> 0 in the cache */
   /* search2255_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2255_0 -> 0 in the cache */
   /* replace2255_1_0 -> 2 in the cache */
   /* replace2255_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2256_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2256_0_0 -> 19 in the cache */
   /* replace2256_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2257_0_0 -> 19 in the cache */
   /* search2257_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2257_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[132];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ffloor;
   condition_flags[22] = options->lower_ffloor || ((options->lower_doubles_options & nir_lower_dfloor) && !(options->lower_doubles_options & nir_lower_dfloor));
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[25] = options->lower_ffract;
   condition_flags[26] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[27] = options->lower_fceil;
   condition_flags[28] = options->lower_ffma16;
   condition_flags[29] = options->lower_ffma32;
   condition_flags[30] = options->lower_ffma64;
   condition_flags[31] = options->fuse_ffma16;
   condition_flags[32] = options->fuse_ffma32;
   condition_flags[33] = options->fuse_ffma64;
   condition_flags[34] = options->lower_fdph;
   condition_flags[35] = !options->lower_fdph;
   condition_flags[36] = options->lower_fdot;
   condition_flags[37] = !options->lower_fsat;
   condition_flags[38] = !options->lower_iabs;
   condition_flags[39] = options->lower_fsat;
   condition_flags[40] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[41] = !options->lower_fsign;
   condition_flags[42] = options->lower_umax;
   condition_flags[43] = options->lower_umin;
   condition_flags[44] = !options->lower_umax;
   condition_flags[45] = !options->lower_umin;
   condition_flags[46] = options->lower_scmp;
   condition_flags[47] = options->lower_vector_cmp;
   condition_flags[48] = !options->lower_rotate;
   condition_flags[49] = options->lower_rotate;
   condition_flags[50] = options->lower_fpow;
   condition_flags[51] = !options->lower_fpow;
   condition_flags[52] = options->lower_fdiv;
   condition_flags[53] = options->lower_fsqrt;
   condition_flags[54] = !options->lower_fsqrt;
   condition_flags[55] = options->lower_sincos;
   condition_flags[56] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[57] = !options->lower_extract_byte;
   condition_flags[58] = !options->lower_extract_word;
   condition_flags[59] = options->has_pack_32_4x8;
   condition_flags[60] = options->lower_pack_64_2x32_split;
   condition_flags[61] = options->lower_pack_32_2x16_split;
   condition_flags[62] = options->lower_unpack_64_2x32_split;
   condition_flags[63] = options->lower_unpack_32_2x16_split;
   condition_flags[64] = options->has_find_msb_rev;
   condition_flags[65] = !options->lower_find_msb_to_reverse;
   condition_flags[66] = !options->lower_find_lsb;
   condition_flags[67] = options->lower_fmod;
   condition_flags[68] = options->lower_uadd_carry;
   condition_flags[69] = options->lower_usub_borrow;
   condition_flags[70] = options->lower_bitfield_insert;
   condition_flags[71] = options->lower_hadd;
   condition_flags[72] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[73] = options->lower_mul_32x16;
   condition_flags[74] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[75] = options->lower_uadd_sat;
   condition_flags[76] = options->lower_usub_sat;
   condition_flags[77] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[78] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[81] = options->lower_bitfield_insert_to_shifts;
   condition_flags[82] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[83] = options->lower_bitfield_extract;
   condition_flags[84] = options->lower_bitfield_extract_to_shifts;
   condition_flags[85] = options->lower_ifind_msb;
   condition_flags[86] = options->lower_find_msb_to_reverse;
   condition_flags[87] = options->lower_uclz;
   condition_flags[88] = options->lower_find_lsb;
   condition_flags[89] = options->lower_extract_byte;
   condition_flags[90] = options->lower_extract_word;
   condition_flags[91] = options->lower_pack_unorm_2x16;
   condition_flags[92] = options->lower_pack_unorm_4x8;
   condition_flags[93] = options->lower_pack_snorm_2x16;
   condition_flags[94] = options->lower_pack_snorm_4x8;
   condition_flags[95] = options->lower_unpack_unorm_2x16;
   condition_flags[96] = options->lower_unpack_unorm_4x8;
   condition_flags[97] = options->lower_unpack_snorm_2x16;
   condition_flags[98] = options->lower_unpack_snorm_4x8;
   condition_flags[99] = options->lower_pack_split;
   condition_flags[100] = options->lower_isign;
   condition_flags[101] = !options->lower_isign;
   condition_flags[102] = options->lower_fsign;
   condition_flags[103] = !options->has_imul24;
   condition_flags[104] = !options->has_umul24;
   condition_flags[105] = !options->has_umad24;
   condition_flags[106] = options->has_imul24;
   condition_flags[107] = options->has_umad24;
   condition_flags[108] = options->has_umul24;
   condition_flags[109] = options->lower_iadd_sat;
   condition_flags[110] = options->support_8bit_alu;
   condition_flags[111] = options->support_16bit_alu;
   condition_flags[112] = options->lower_ldexp;
   condition_flags[113] = !options->lower_bitfield_reverse;
   condition_flags[114] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[115] = options->lower_fisnormal;
   condition_flags[116] = !options->vectorize_vec2_16bit;
   condition_flags[117] = options->has_fsub;
   condition_flags[118] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[119] = options->lower_fneg;
   condition_flags[120] = options->has_isub || options->lower_ineg;
   condition_flags[121] = options->lower_ineg;
   condition_flags[122] = options->lower_iabs;
   condition_flags[123] = options->has_iadd3;
   condition_flags[124] = options->vectorize_vec2_16bit;
   condition_flags[125] = options->fdot_replicates;
   condition_flags[126] = options->lower_fround_even;
   condition_flags[127] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[128] = options->avoid_ternary_with_two_constants;
   condition_flags[129] = !options->lower_insert_byte;
   condition_flags[130] = !options->lower_insert_word;
   condition_flags[131] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

